//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.dll.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Provides static methods typically used in an application.   Windows message loops can be started and stopped from
 * here, and global, application level events can be hooked up.
 *
 * @security(checkClassLinking=on)
 */
public final class Application {

    
    private static HashTable   eventHandlers;
    private static String startupPath;

        
    private static boolean exiting = false;

    
    private static final Object EVENT_SETTINGCHANGE  = new Object();
    private static final Object EVENT_APPLICATIONEXIT = new Object();
    private static final Object EVENT_SYSTEMSHUTDOWN = new Object();

    
    private Application() {}

    /**
     * Adds an applicationExit event handler to the application.  An application exit
     * event will fire just before the application exits.  This gives an
     * application the chance to cleanup objects that may not otherwise get
     * garbage collected.
     *
     * @param value A com.ms.wfc.core.EventHandler that should
     *              get called at exit time.
     * @see #removeOnApplicationExit
     */
    public static void addOnApplicationExit(EventHandler value) {}

    
    private static synchronized void addEventHandler(Object event, Delegate value) {}

    /**
     * Adds a message filter to the application's message pump.   A message
     * filter allows a program to monitor Windows messages as they are
     * routed to their appropriate destinations.  Message filters are
     * unique to a specific thread.
     *
     * @param value The IMessageFilter you want to install.
     * @see #removeMessageFilter
     */
    public static void addMessageFilter(IMessageFilter value) {}

    /**
     * Adds an idle event handler to the application.  An idle event will
     * fire each time the application returns from processing and
     * is about to enter the idle state.  Idle events are unique
     * to a specific thread.
     *
     * @param value The com.ms.wfc.core.EventHandler for the idle event.
     * @see #removeOnIdle
     */
    public static void addOnIdle(EventHandler value) {}

    /**
     * Adds a settingChange event handler to the application.   A setting change event
     * will fire when the user has changed one or more Windows settings.  WFC
     * internally handles this event and updates brushes, pens and fonts
     * appropriately.
     *
     * @param value A com.ms.wfc.core.EventHandler that should
     *              get called when a user setting changes.
     * @see #removeOnSettingChange
     */
    public static void addOnSettingChange(EventHandler value) {}

    /**
     * Adds a systemShutdown event handler to the application.   A system
     * shut down event will fire just before the user logs off or
     * shuts down the computer.  This event may be canceled, which will
     * abort the shutdown request.  This is typically the last notice
     * an application will get before being terminated, so you should
     * save any open files at this time.
     *
     * @param value A com.ms.wfc.core.CancelEventHandler that will
     *              get called before the system shuts down.
     */
    public static void addOnSystemShutdown(CancelEventHandler value) {}

    /**
     * Adds a threadException event handler to the application.   A thread
     * exception handler will fire when an untrapped Java exception has
     * been thrown.  This allows an application to intelligently handle
     * the problem, rather than just abruptly terminate.  Thread exception
     * handlers are unique to a specific thread.
     *
     * @param value The ThreadExceptionEventHandler to add.
     * @see #removeOnThreadException
     */
    public static void addOnThreadException(ThreadExceptionEventHandler value) {}

    /**
     * Allocates a slot of per-thread storage space and returns an index to it. 
     * The index will always be greater than zero.
     *
     * @return an index of the newly allocated thread storage slot.
     */
    public static int allocThreadStorage() {}

    /**
     * Executes the specified delegate on its own thread asyncronously.   This removes the need for you to design a
     * class that implements java.lang.Runnable or extends java.lang.Thread.
     * The thread is automatically started by this method.
     *
     * @param method A Delegate containing the method to invoke when the thread
     *               is started.  The method cannot have any parameters.
     *
     * @return a Thread object representing the new thread.
     */
    public static Thread createThread(Delegate method) {}
    
    /**
     * Executes the specified delegate on its own thread asyncronously.   This removes the need for you to design a
     * class that implements java.lang.Runnable or extends java.lang.Thread.
     *
     * @param method A Delegate containing the method to invoke when the thread
     *               is started.  The method cannot have any parameters.
     * @param start  If <b>true</b>, this method will automatically start the
     *               thread before returning.  If <b>false</b>, the method will
     *               not start the thread.
     *
     * @return a Thread object representing the new thread.
     */
    public static Thread createThread(Delegate method, boolean start) {}

    /**
     * Executes the specified delegate on its own thread asyncronously.   This removes the need for you to design a
     * class that implements java.lang.Runnable or extends java.lang.Thread.
     * The thread is automatically started by this method.
     *
     * @param method A Delegate containing the method to invoke when the thread
     *               is started.  The method must have parameters that match
     *               the number and type of the objects passed in <i>args</i>.
     * @param args   An array of arguments to pass to the given method.
     *
     * @return a Thread object representing the new thread.
     */
    public static Thread createThread(Delegate method, Object args[]) {}

    /**
     * Executes the specified delegate on its own thread asyncronously.   This removes the need for you to design a
     * class that implements java.lang.Runnable or extends java.lang.Thread.
     *
     * @param method A Delegate containing the method to invoke when the thread
     *               is started.  The method must have parameters that match
     *               the number and type of the objects passed in <i>args</i>.
     * @param args   An array of arguments to pass to the given method.
     * @param start  If <b>true</b>, this method will automatically start the
     *               thread before returning.  If <b>false</b>, the method will
     *               not start the thread.
     *
     * @return a Thread object representing the new thread.
     */
    public static Thread createThread(Delegate method, Object args[], boolean start) {}

    /**
     * Executes the specified delegate on its own thread asyncronously.   This removes the need for you to design a
     * class that implements java.lang.Runnable or extends java.lang.Thread.
     * The thread is automatically started by this method.
     *
     * @param method   A Delegate containing the method to invoke when the thread
     *                 is started.  The method must have parameters that match
     *                 the number and type of the objects passed in <i>args</i>.
     * @param args     An array of arguments to pass to the given method.
     * @param priority The priority of the new thread.
     *
     * @return a Thread object representing the new thread.
     */
    public static Thread createThread(Delegate method, Object args[], int priority) {}

    /**
     * Processes Windows messages currently in the message queue.   Care must
     * be taken when calling this, however, because it can cause code to be
     * re-entered if a message causes an event to fire.
     */
    public static void doEvents() {}

    /**
     * Processes Windows messages currently in the message queue.   The only
     * messages that are processed are those of type <i>message</i>.  This
     * is useful to only allow certain messages (like WM_PAINT) to process
     * while holding up others. Care must be taken when calling this,
     * however, because it can cause your code to be re-entered if a message
     * causes an event to fire.
     *
     * @param message The message to process.
     */
    public static void doEvents(int message) {}

    /**
     * Processes Windows messages currently in the message queue.   The only
     * messages that are processed are those in the range of <i>messageStart</i>
     * to <i>messageEnd</i>.  This allows a program to only let a narrow
     * range of messages through, such as WM_MOUSEFIRST to WM_MOUSELAST.
     * Care must be taken when calling this, however, because it can cause
     * code to be re-entered if a message causes an event to fire.
     *
     * @param messageStart The starting range for messages to process.
     * @param messageEnd   The ending range for messages to process.
     */
    public static void doEvents(int messageStart, int messageEnd) {}

    /**
     * Quits the message loops of all threads in the application.   This will revoke all running message loops on all
     * threads and will close all windows.  If you only want to exit a message
     * loop for the current thread, call exitThread instead.  This does
     * not actually force the application to exit, but will cause all calls to
     * run to return.
     */
    public static synchronized void exit() {}

    /**
     * Quits the message loop on the current thread and closes all windows on the thread.   Use this to exit the message loop of the current thread.
     * Use exit to exit the entire application.  This will cause the
     * call to run to return for the current thread.
     */
    public static void exitThread() {}

    /**
     * Frees the specified thread's storage slot.   If an object is currently stored
     * in the slot, the slot will be set to null before freeing it.
     *
     * @param index The index to the thread storage slot.  This index
     *              must have been previously obtained by calling
     *              allocThreadStorage.
     */
    public static void freeThreadStorage(int index) {}

    /**
     * Retrieves a reference to the currently active form for the application. 
     *
     * @return the currently active form, or <b>null</b> if there is no
     *         active form.
     *
     * @see com.ms.wfc.ui.Form
     */
    public static  Form getActiveForm() {}

    /**
     * Retrieves a Locale object that represents the
     * locale settings for the current thread.
     *
     * @return a Locale object.
     */
    public static Locale getCurrentLocale() {}

    /**
     * Determines if a message loop exists on this thread.
     * 
     * @return <b>true</b> if a message loop exists, or <b>false</b>
     *         if not.
     * 
     * @hidden
     * @internalonly
     */
    public static boolean getMessageLoop() {}
    
    /**
     * Retrieves the parking form for the curernt thread.  The parking
     * form is an internal form that is used by WFC as a
     * temporary holding place for controls that have no parent.  It
     * is also used internally to process system-level messages.
     *
     * @return a com.ms.wfc.ui.Form object.
     * @hidden
     * @internalonly
     */
    public static Form getParkingForm() {}

    /**
     * Retrieves the parking form for thread owning the given control.
     * The parking form is an internal form that is used by the framework
     * as a holding place for controls that have no parent.
     *
     * @param control The control to get the parking form for.
     * @return a Form object.
     * @hidden
     * @internalonly
     */
    public static synchronized Form getParkingForm(Control control) {}

    /**
     * Retrieves the path that the application was run from.   The startup path is the
     * path to the executable file that started the program.
     *
     * @return a String containing the executable's full path.
     */
    public static String getStartupPath() {}

    /**
     * Retrieves an object that has been stored in the specified thread's storage slot. 
     *
     * @param index The index to the thread storage slot.  This index
     *              must have been previously obtained by calling
     *              allocThreadStorage.
     * @return an object that the caller has previously stored in the slot,
     *         or <b>null</b> of no object has ever been stored in the slot.
     */
    public static Object getThreadStorage(int index) {}

    /**
     * Initializes OLE in your application. This will verify that
     * OLE has been initialized on the current thread. The Application object
     * will automatically uninitialize OLE when the thread is torn down.
     * <p>
     * Unless you are calling OLE functions directly, you do not need to call
     * this method.
     */
    public static void OLERequired() {}

    /**
     * Called by a window procedure when it recieves a thread exception.  Java catches these
     * if they go back into the message loop, so we sling it to here, which passes
     * it to the proper thread mechanism.
     *
     * @param t The exception that has occurred.
     * @hidden
     * @internalonly
     */
    public static void onThreadException(Throwable t) {}

    /**
     * Removes an applicationExit event handler that was previously added
     * with addOnApplicationExit.  An application exit event will fire just before the
     * application exits.  This gives an application the chance
     * to cleanup objects that may not otherwise get garbage collected.
     *
     * @param value The com.ms.wfc.core.EventHandler to remove.
     * @see #addOnApplicationExit
     */
    public static void removeOnApplicationExit(EventHandler value) {}

    
    private static synchronized void removeEventHandler(Object event, Delegate value) {}

    /**
     * Removes a message filter previously added through addMessageFilter.
     * A message filter allows a program to monitor Windows messages as they are
     * routed to their appropriate destinations.  Message filters are
     * unique to a specific thread.
     *
     * @param value The IMessageFilter you want to remove.
     * @see #addMessageFilter
     */
    public static void removeMessageFilter(IMessageFilter value) {}

    /**
     * Removes an idle event handler previously added through addOnIdle.
     * An idle event will fire each time the application returns from
     * processing and is about to enter the idle state.  Idle events are unique
     * to a specific thread.
     *
     * @param value The com.ms.wfc.core.EventHandler for the idle event.
     * @see #addOnIdle
     */
    public static void removeOnIdle(EventHandler value) {}

    /**
     * Removes a settingChange event handler that was previously added with addSettingChangeHandler.  A settingChange event
     * will fire when the user has changed one or more Windows settings.  The
     * framework uses this event, for example, to update brush colors when the
     * user has changed the desktop color settings.
     *
     * @param value The com.ms.wfc.core.EventHandler to remove.
     * @see #addOnSettingChange
     */
    public static void removeOnSettingChange(EventHandler value) {}

    /**
     * Removes a systemShutdown event handler from the application that was
     * previously added with addOnSystemShutdown. A system
     * shut down event will fire just before the user logs off or
     * shuts down the computer.  This event may be canceled, which will
     * abort the shutdown request.
     *
     * @param value A com.ms.wfc.core.CancelEventHandler that will
     *              get called before the system shuts down.
     */
    public static void removeOnSystemShutdown(CancelEventHandler value) {}

    /**
     * Removes a threadException event handler that was previously added
     * through addOnThreadException.
     * A thread exception handler will fire when an untrapped Java exception has
     * been thrown.  This allows an application to intelligently handle
     * the problem, rather than just abruptly terminate.  Thread exception
     * handlers are unique to a specific thread.
     *
     * @param value Value of the ThreadExceptionEventHandler to remove.
     * @see #addOnThreadException
     */
    public static void removeOnThreadException(ThreadExceptionEventHandler value) {}

    /**
     * Begins running a standard application and its associated message loop in the current
     * thread.   If a
     * form is specified here, it will be set to visible and an OnClose handler
     * will be added to the form.  The close handler will call Application.exit
     * for you, which will clean up the application.  If you do not pass a form
     * into this call, the message loop will run until exit or
     * exitThread is called.
     */
    public static void run() {}

    /**
     * Begins running a standard application and its associated message loop in the current
     * thread.   If a
     * form is specified here, it will be set to visible and an OnClose handler
     * will be added to the form.  The close handler will call Application.exit
     * for you, which will clean up the application.  If you do not pass a form
     * into this call, the message loop will run until exit or
     * threadExit is called. Generally, the main function
     * of an application calls this with the main window of the application.
     *
     * @param mainForm Main form to run.  If this is <b>null</b>, then this
     *                 function behaves the same as the run() method.
     */
    public static void run(Form mainForm) {}

    /**
     * Runs a modal dialog.  This starts a special type of message loop that runs until
     * the dialog has a valid DialogResult.  This is called internally by a form
     * when an application calls com.ms.wfc.ui.Form.showDialog().
     *
     * @param form The com.ms.wfc.ui.Form to show modally.
     * @hidden
     * @internalonly
     */
    public static void runDialog(Form form) {}

    /**
     * Sets the locale for the current thread. 
     *
     * @param locale New Locale for the current thread.
     */
    public static void setCurrentLocale(Locale locale) {}

    /**
     * Sets an object in a specific thread's storage slot.
     *
     * @param index  The index to the thread storage slot.  This index
     *               must have been previously obtained by calling
     *               allocThreadStorage.
     * @param object The object to store.  This can be null.
     */
    public static void setThreadStorage(int index, Object object) {}

    
    private static final class ApplicationThread extends Thread {
        Delegate method;
        Object   args[];

        public ApplicationThread(Delegate method, Object args[]) {}

        public void run() {}
    }

    
    private static final class ThreadContext {

        private static final int STATE_OLEINITIALIZED       = 0x00000001;
        private static final int STATE_INTHREADEXCEPTION    = 0x00000002;

        private static int              tlsSlot = -1;
        private static ThreadContext [] threadContexts;
        private static boolean []       threadStorageMap;
        private static int              threadStorageCount;
        
        
        
        
        private static int              totalMessageLoopCount;

        private ThreadExceptionEventHandler  threadException;
        private EventHandler                 idleEvent;
        private Form                         mainForm;
        private Form                         parkingForm;
        private Locale                       locale;
        private List                         messageFilters;
        private Object []                    threadStorage;
        private int                          handle;
        private int                          id;
        private int                          messageLoopCount;
        private int                          messageStart;
        private int                          messageEnd;
        private int                          threadState = 0;

        
        
        
        public static final int MAIN_LOOP      = 0x01;
        public static final int DOEVENTS_LOOP  = 0x02;
        public static final int MODAL_LOOP     = 0x03;

        /**
         * Creates a new thread context object.
         */
        public ThreadContext() {}

        
        void addMessageFilter(IMessageFilter f) {}

        
        void addOnThreadException(ThreadExceptionEventHandler value) {}

        
        void addOnIdle(EventHandler value) {}

        
        static synchronized int allocThreadStorage() {}

        
        private static synchronized void coalesceThreadContexts() {}

        
        private static void collectAllGarbage() {}
        
        
        void dispose() {}

        
        void disposeParkingForm() {}

                
        private void disposeThreadWindows() {}

        
        private synchronized void ensureThreadStorage(int index) {}

        
        static synchronized void exit() {}

        /**
         * Our finalization.  All we do here is dispose ourselves.
         *
         * @internalonly
         */
        protected void finalize() {}

        
        private synchronized static int findFreeContextSlot() {}

        
        static synchronized void freeThreadStorage(int index) {}

        
        static synchronized ThreadContext fromCurrent() {}

        
        static synchronized ThreadContext fromId(int id) {}

        
        int getHandle() {}

        
        int getId() {}

        
        Locale getLocale() {}

        
        boolean getMessageLoop() {}

        
        synchronized Form getParkingForm() {}

        private boolean getState(int bit) {}

        
        synchronized Object getThreadStorage(int index) {}

        
        private boolean hasMessage(MSG msg, int reason, Form form) {}

        void OLERequired() {}


        
        private void onIdle() {}

        
        final void onThreadException(Throwable t) {}

        
        private boolean preProcessMessage(MSG msg) {}

        
        private void postProcessMessage(MSG msg) {}

        
        void removeMessageFilter(IMessageFilter f) {}

        
        void removeOnThreadException(ThreadExceptionEventHandler value) {}

        
        void removeOnIdle(EventHandler value) {}

        
        void runMessageLoop(int reason) {}

        
        void runMessageLoop(int reason, int messageStart, int messageEnd) {}

        
        void runMessageLoop(int reason, Form form) {}

        
        void setLocale(Locale locale) {}

        private void setState(int bit, boolean value) {}

        
        synchronized void setThreadStorage(int index, Object object) {}
    }

    
    private static final class ParkingForm extends Form {

        public ParkingForm() {}
        
        private Delegate getEvent(Object event) {}

        private boolean onWmQueryEndSession() {}

        private void onWmSettingChange() {}

        protected void wndProc(Message m) {}
    }

    
    private static final class ThreadWindows extends Callback {
        int[] windows;
        int windowCount;
        int parentHandle;

        ThreadWindows(Control parent) {}

        public boolean callback(int hWnd, int lParam) {}

        void dispose() {}

        void enable(boolean state) {}
    }
}


class MainFormCloseProxy {
    void onMainFormClose(Object sender, Event e) {}
}