//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.wfc.core.*;

/**
 * Encapsulates the different character sets a Font  object can use. 
 *
 * @security(checkClassLinking=on)
 */
public class CharacterSet extends Enum {
    
    /**
     * Specifies the standard Windows American National Standards Institute (ANSI) character
     * set.
     */
    public static final int ANSI            = 0;
    
    /**
     * Specifies the Arabic character set.
     */
    public static final int ARABIC          = 178;
    
    /**
     * Specifies the Baltic character set.
     */
    public static final int BALTIC          = 186;
    
    /**
     * Specifies the Chinese BIG 5 character set.
     */
    public static final int CHINESEBIG5     = 136;
    
    /**
     * Specifies the default character set.  This will use the appropriate character 
     * set for the thread.
     */
    public static final int DEFAULT         = 1;
    
    /**
     * Specifies the Eastern Europe character set.
     */
    public static final int EASTEUROPE      = 238;
    
    /**
     * Specifies the Great Britain 2312 character set.
     */
    public static final int GB2312          = 134;
    
    /**
     * Specifies the Greek character set.
     */
    public static final int GREEK           = 161;
    
    /**
     * Specifies the Korean Hangeul character set.
     */
    public static final int HANGEUL         = 129;
    
    /**
     * Specifies the Hebrew character set.
     */
    public static final int HEBREW          = 177;
    
    /**
     * Specifies the Johab character set.
     */
    public static final int JOHAB           = 130;
    
    /**
     * Specifies the Macintosh character set.
     */
    public static final int MAC             = 77;
    
    /**
     * Specifies the original equipment manufacturer (OEM) character set.  This is the character set that is
     * built into the ROM of most computers.
     */
    public static final int OEM             = 255;
    
    /**
     * Specifies the Russian character set.
     */
    public static final int RUSSIAN         = 204;
    
    /**
     * Specifies the Symbol character set.  This character set contains common symbols.
     */
    public static final int SYMBOL          = 2;
    
    /**
     * Specifies the Shift JIS character set.
     */
    public static final int SHIFTJIS        = 128;
    
    /**
     * Specifies the Thai character set.
     */
    public static final int THAI            = 222;
    
    /**
     * Specifies the Turkish character set.
     */
    public static final int TURKISH         = 162;
    
    /**
     * Specifies the Vietnamese character set.
     */
    public static final int VIETNAMESE      = 163;
    
    
    
    
    
    private static final int MIN = 0;
    private static final int MAX = 255;

    /**
     * Determines whether the value assigned to the method is a valid number for the class's
     * enumerated values. 
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}