//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.dll.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Translates between Windows Foundation Classes for Java (WFC) text-based Clipboard  formats and Win32 integer-based Clipboard formats. 
 *
 * @see com.ms.wfc.app.Clipboard
 * @see com.ms.wfc.app.DataObject
 *
 * @security(checkClassLinking=on)
 */
public class DataFormats {
    /**
     * Specifies the standard American National Standards Institute (ANSI) text format.  In WFC, you may simply pass in the
     * String class; WFC will perform conversions for you.
     */
    public static final String CF_TEXT          = "Text";
    
    /**
     * Specifies the standard Windows Unicode text format.  In WFC, you may simply pass in the
     * String class; WFC will perform conversions for you.
     */
    public static final String CF_UNICODETEXT   = "UnicodeText";
    
    /**
     * Specifies the Windows Device Independent Bitmap (DIB) format.  In WFC, you may simply pass in
     * the Bitmap class; WFC will perform conversions for you.
     */
    public static final String CF_DIB           = "DeviceIndependentBitmap";
    
    /**
     * Specifies a Windows bitmap format.  In WFC, you may simply pass in
     * the Bitmap class; WFC will perform conversions for you.
     */
    public static final String CF_BITMAP        = "Bitmap";
    
    /**
     * Specifies the Windows enhanced metafile format.  In WFC, you may simply pass in
     * the Metafile class; WFC will perform conversions for you.
     */
    public static final String CF_ENHMETAFILE   = "EnhancedMetafile";
    
    /**
     * Specifies the Windows metafile format.  This format is not used directly by
     * WFC.
     */
    public static final String CF_METAFILEPICT  = "MetaFilePict";
    
    /**
     * Specifies the Windows symbolic link format.  This format is not used directly by
     * WFC.
     */
    public static final String CF_SYLK          = "SymbolicLink";
    
    /**
     * Specifies the Windows data interchange format.  This format is not used directly by
     * WFC.
     */
    public static final String CF_DIF           = "DataInterchangeFormat";
    
    /**
     * Specifies the Tagged Image File Format (TIFF).  This format is not used directly by
     * WFC.
     */
    public static final String CF_TIFF          = "TaggedImageFileFormat";
    
    /**
     * Specifies the standard Windows original equipment manufacturer (OEM) text format.  In WFC, you may simply pass in the
     * String class; WFC will perform conversions for you.
     */
    public static final String CF_OEMTEXT       = "OEMText";
    /**
     * Specifies the Windows palette format.  WFC does not use this format directly, but it
     * may use it in conjunction with a Bitmap object.
     */
    public static final String CF_PALETTE       = "Palette";

    /**
     * Specifies the Windows pen data format.  This format consists of pen strokes for handwriting
     * software and is not used by WFC.
     */
    public static final String CF_PENDATA       = "PenData";

    /**
     * Specifies the Resource Interchange File Format (RIFF) audio format.  This format is not used directly by WFC.
     */
    public static final String CF_RIFF          = "RiffAudio";

    /**
     * Specifies the wave audio format.  This format is not used directly by WFC.
     */
    public static final String CF_WAVE          = "WaveAudio";

    /**
     * Specifies the Windows file drop format.  This format is not used directly by WFC
     * but you may use it during drag and drop operations to interact
     * with shell file drags.
     */
    public static final String CF_HDROP         = "FileDrop";

    /**
     * Specifies the Windows locale format.  This format is not used directly by WFC.
     */
    public static final String CF_LOCALE        = "Locale";

    /**
     * Specifies text consisting of Hypertext Markup Language (HTML) data.
     */
    public static final String CF_HTML          = "HTML Format";

    /**
     * Specifies text consisting of Microsoft rich text format (RTF) data.
     */
    public static final String CF_RTFTEXT       = "Rich Text Format";

    /**
     * Specifies a comma-separated value (CSV) format.  CSV is a common interchange format used by spreadsheets,
     * and is not used directly by WFC.
     */
    public static final String CF_CSV           = "CSV";

    /**
     * Specifies the standard java.lang.String class format.lang.String class format.  This format is used by WFC
     * to store String objects.
     */
    public static final String CF_STRINGCLASS   = String.class.getName();

    /**
     * Specifies a format that encapsulates a WFC object.  Any object can be stored here.
     */
    public static final String CF_WFCOBJECT     = "WFCPersistentObject";

    private static Format formatList[];
    private static int formatCount = 0;

    /**
     * Retrieves the DataFormats.Format object associated with the specified format. 
     *
     * @param format    String format type.
     * @return a format object.  If the given format is new, this will create a new
     *         format and return it.
     */
    public static Format getFormat(String format) {}

    /**
     * Retrieves the DataFormats.Format object associated with the specified format. 
     *
     * @param id    Windows clipboard format ID 
     * @return a format object.  If the given format is new, this will create a new
     *         format and return it.
     */
    public static Format getFormat(int id) {}

    
    private synchronized static Format internalGetFormat( String strName, int id ){}


    
    private static void ensureFormatSpace(int size) {}

    
    private static void ensurePredefined() {}
    
    /**
     * Translates between Windows Foundation Classes for Java (WFC) text-based Clipboard  formats and Win32 integer-based Clipboard formats.   A format is a string/ID pair that
     * defines a clipboard format.  In addition to the string and ID, we also store a
     * flag specifying if the format is expectingn a Win32 handle instead of an HGLOBAL
     *
     * @security(checkClassLinking=on)
     */
    public static class Format {
        public final String name;
        public final int id;
        public final boolean win32Handle;

        public Format(String n, int i) {}
        public Format(String n, int i, boolean fHandle) {}
    }
}