//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.com.*;
import com.ms.dll.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import java.lang.reflect.*;

/**
 * Defines a basic data transfer object.
 *
 * First, this will take any cor.IDataObject and provide the IOleDataObject 
 * implementation. Secondly, this will take any IOleDataObject interface and 
 * expose cor.IDataObject. Lastly this will store arbitrary data and expose
 * both the IDataObject and IOleDataObject interfaces.
 * 
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public class DataObject implements IDataObject, IOleDataObject {

    
    private static native int DragQueryFile(int hDrop, int iFile, StringBuffer lpszFile, int cch);

    private static final String CF_DEPRECATED_FILENAME = "FileName";
    private static final String CF_DEPRECATED_FILENAMEW = "FileNameW";

    private static final int HR_S_FALSE = 1;
    private static final int HR_S_OK = 0;
    private static final ComSuccessException S_FALSE = new ComSuccessException(HR_S_FALSE);
    private static final ComSuccessException S_OK = new ComSuccessException(HR_S_OK);

    private static final int DV_E_FORMATETC     = 0x80040064;
    private static final int DV_E_LINDEX        = 0x80040068;
    private static final int DV_E_TYMED         = 0x80040069;
    private static final int DV_E_DVASPECT      = 0x8004006B;
    private static final int OLE_E_NOTRUNNING   = 0x80040005;
    private static final int OLE_E_ADVISENOTSUPPORTED = 0x80040003;
    private static final int DATA_S_SAMEFORMATETC = 0x00040130;

    private static final int DVASPECT_CONTENT   = 1;
    private static final int DVASPECT_THUMBNAIL = 2;
    private static final int DVASPECT_ICON      = 4;
    private static final int DVASPECT_DOCPRINT  = 8;

    private static final int TYMED_HGLOBAL      = 1;
    private static final int TYMED_FILE         = 2;
    private static final int TYMED_ISTREAM      = 4;
    private static final int TYMED_ISTORAGE     = 8;
    private static final int TYMED_GDI          = 16;
    private static final int TYMED_MFPICT       = 32;
    private static final int TYMED_ENHMF        = 64;
    private static final int TYMED_NULL         = 0;

    private static final int DATADIR_GET        = 1;
    private static final int DATADIR_SET        = 2;

    private static final int[] ALLOWED_TYMEDS =
                                               new int [] { TYMED_HGLOBAL,
        TYMED_ISTREAM,
        TYMED_ENHMF,
        TYMED_MFPICT,
        TYMED_GDI};

    private IDataObject     innerData = null;

    /**
     * Creates a DataObject.
     * 
     * This data object will wrap <i>data</i>.
     * 
     * @param data IDataObject to wrap.
     */
    public DataObject(IDataObject data) {}

    /**
     * Creates a DataObject.
     * 
     * This data object will wrap <i>data</i>
     * 
     * @param data IOleDataObject to wrap.
     */
    public DataObject(IOleDataObject data) {}

    /**
     * Creates a DataObject.
     * 
     * This data object will not wrap anything, but rather provide an object
     * that can store arbitrary data.
     */
    public DataObject() {}

    /**
     * Creates a DataObject.
     * 
     * This data object will attempt to wrap <i>data</i>. It will either bind
     * to <i>data</i> as an IDataObject, IOleDataObject, or will store a reference
     * to <i>data</i> in the data object.
     *
     * @param data Data to wrap.
     */
    public DataObject(Object data) {}

    /**
     * Creates a DataObject.
     *
     * This data object will not wrap anything, and will default to containing
     * the specified data.
     * 
     * @param format Format to store the data as.
     * @param data Data to store.
     */
    public DataObject(String format, Object data) {}

    /**
     * Retrieves the data associated with the specific data format.  For a 
     * listing of predefined formats see com.ms.wfc.app.DataFormats.
     * 
     * @param format Format of the data to retrieve.
     * @return data associated with the specific format.
     * 
     * @see IDataObject
     */
    public Object getData(String format) {}

    /**
     * Retrieves the data associated with the specific data format. 
     * 
     * @param format Format of the data to retrieve.
     * @return data associated with the specific format.
     * 
     * @see IDataObject
     */
    public Object getData(Class format) {}

    /**
     * Determines whether a specific data format is stored in the data object.
     * 
     * @param format Format to check for.
     * 
     * @return true if there is data for <i>format</i>.
     * 
     * @see IDataObject
     */
    public boolean getDataPresent(Class format) {}
    
    /**
     * Determines whether a specific data format is stored in the data object.
     * 
     * @param format Format to check for.
     * 
     * @return true if there is data for <i>format</i>.
     * 
     * @see IDataObject
     */
    public boolean getDataPresent(String format) {}

    /**
     * Retrieves an array of all format types that are supported by the data stored in this Data
     * object. 
     * 
     * @return list of all formats.
     * 
     * @see IDataObject
     */
    public String[] getFormats() {}

    private String[] getMappedFormats(String format) {}

    private String[] getMappedFormats(String[] formats) {}

    
    private boolean getTymedUseable(int tymed) {}

    
    private final void getDataIntoOleStructs(FORMATETC formatetc,
        STGMEDIUM medium) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleDAdvise(FORMATETC pFormatetc, int advf, IUnknown pAdvSink, int[] pdwConnection) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleDUnadvise(int dwConnection) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleEnumDAdvise(IUnknown[] ppenumAdvise) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleEnumFormatEtc(int dwDirection, IEnumFORMATETC[] ppenumFormatEtc) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleGetCanonicalFormatEtc(FORMATETC pformatectIn, FORMATETC pformatetcOut) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleGetData(FORMATETC formatetc, STGMEDIUM medium) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleGetDataHere(FORMATETC formatetc, STGMEDIUM medium) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleQueryGetData(FORMATETC formatetc) {}

    /**
     * Part of IOleDataObject, used to interop with OLE.
     * 
     * @internalonly 
     * @see com.ms.wfc.ole32.IOleDataObject
     */
    public void OleSetData(FORMATETC pFormatectIn, STGMEDIUM pmedium, int fRelease) {}
    
    private void saveImageToHandle(int handle, Image data) {}

    private void saveObjectToHandle(int handle, Object data) {}

    
    private void saveStreamToHandle(int handle, IDataStream stream) {}

    
    private void saveFileListToHandle(int handle, String[] files) {}

    
    private void saveStringToHandle(int handle, String string, boolean unicode) {}

    /**
     * Sets the data to be stored in the Data object.  For
     * a listing of predefined formats see com.ms.wfc.app.DataFormats.
     * 
     * @param format Format of the data to store.
     * @param data Data to store.
     * 
     * @see IDataObject
     */
    public void setData(String format, Object data) {}
    
    /**
     * Sets the data to be stored in the Data object. 
     * 
     * @param format Format of the data to store.
     * @param data Data to store.
     * 
     * @see IDataObject
     */
    public void setData(Class format, Object data) {}
    
    /**
     * Sets the data to be stored in the Data object.  The format assumed is the
     * class of <i>data</i>
     * 
     * @param data Data to store.
     * 
     * @see IDataObject
     */
    public void setData(Object data) {}
    
    
    private static class FormatEnumerator implements IEnumFORMATETC {

        IDataObject parent = null;
        List formats = new List();
        int current = 0;

        public FormatEnumerator(IDataObject parent) {}

        public FormatEnumerator(IDataObject parent, FORMATETC[] formats) {}

        public FormatEnumerator(IDataObject parent, String[] formats) {}


        public void Next(int celt, FORMATETC rgelt, int[] pceltFetched) {}

        public void Skip(int celt) {}

        public void Reset() {}

        public void Clone(IEnumFORMATETC[] ppenum) {}   
    }

    
    private static class OleConverter implements IDataObject {
        IOleDataObject innerData;

        public OleConverter(IOleDataObject data) {}

        
        private boolean getTymedUseable(int tymed) {}

        
        private final Object getDataFromOleIStream(String format) {}


        
        private final Object getDataFromHGLOBLAL(String format, int hglobal) {}

        
        private final Object getDataFromOleHGLOBAL(String format) {}

        
        private final Object getDataFromOleOther(String format) {}

        
        private final Object getDataFromBoundOleDataObject(String format) {}

        
        private IDataStream readByteStreamFromHandle(int handle) {}

        
        private Object readObjectFromHandle(int handle) {}


        
        private String[] readFileListFromHandle(int hdrop) {}

        
        private String readStringFromHandle(int handle, boolean unicode) {}

        
        
        
        public Object getData(String format) {}

        public Object getData(Class format) {}

        public void setData(String format, Object data) {}

        public void setData(Class format, Object data) {}

        public void setData(Object data) {}

        public boolean getDataPresent(Class format) {}

        public boolean getDataPresent(String format) {}

        public String[] getFormats() {}
    }

    
    
    

    
    private static class DataStore implements IDataObject {
        HashTable data = new HashTable();

        public DataStore() {}

        public Object getData(String format) {}

        public Object getData(Class format) {}

        public void setData(String format, Object data) {}

        public void setData(Class format, Object data) {}

        public void setData(Object data) {}

        public boolean getDataPresent(Class format) {}

        public boolean getDataPresent(String format) {}

        public String[] getFormats() {}
    }
}