//STRIPPEDSOURCE//

package com.ms.wfc.app;

/**
 * Generic data transfer mechanism. This is used for Clipboard and Drag Drop 
 * operations.
 *
 * @security(checkClassLinking=on)
 */
public interface IDataObject {
    /**
     * Retrieves the data associated with the specific data format.  For a 
     * listing of predefined formats see com.ms.wfc.app.DataFormats.
     * 
     * @param format Format of the data to retrieve.
     * @return data associated with the specific format.
     */
    public Object getData(String format);
    
    /**
     * Retrieves the data associated with the specific data format. 
     * 
     * @param format Format of the data to retrieve.
     * @return data associated with the specific format.
     */
    public Object getData(Class format);
    
    /**
     * Sets the data to be stored in the Data object.  For
     * a listing of predefined formats see com.ms.wfc.app.DataFormats.
     * 
     * @param format Format of the data to store.
     * @param data Data to store.
     */
    public void setData(String format, Object data);

    /**
     * Sets the data to be stored in the Data object. 
     * 
     * @param format Format of the data to store.
     * @param data Data to store.
     */
    public void setData(Class format, Object data);
    
    /**
     * Sets the data to be stored in the Data object.  The format assumed is the
     * class of <i>data</i>
     * 
     * @param data Data to store.
     */
    public void setData(Object data);
    
    /**
     * Determines whether a specific data format is stored in the Data
     * object.
     * 
     * @param format Format to check for.
     * 
     * @return true if there is data for <i>format</i>.
     */
    public boolean getDataPresent(String format);

    /**
     * Determines whether a specific data format is stored in the Data
     * object.
     * 
     * @param format Format to check for.
     * 
     * @return true if there is data for <i>format</i>.
     */
    public boolean getDataPresent(Class format);
    
    /**
     * Retrieves an array of all format types that are supported by the data stored in this Data
     * object. 
     * 
     * @return list of all formats.
     */
    public String[] getFormats();
}