//STRIPPEDSOURCE//

package com.ms.wfc.app;

/**
 * Defines a message filter interface.  This interface allows an application
 * to hook a message before is dispatched to a control or form.
 *
 * @security(checkClassLinking=on)
 */
public interface IMessageFilter {

    /**
     * Filters out a message before it is dispatched.   You may return true if you
     * wish to prevent the message from being dispatched.  
     *
     * @param m  The message that is to be dispatched.  You may not 
     *           modify this message.
     * @return <b>true</b> to filter the message and prevent it from being
     *         dispatched, or <b>false</b> to allow the message to continue
     *         to the next filter / control.
     */
    public boolean preFilterMessage(Message m);

    /**
     * Filters out a message after it has been dispatched.
     *
     * @param m The message that has just been processed.
     */
    public void postFilterMessage(Message m);
}