//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.ui.*;
import com.ms.win32.*;
import com.ms.dll.*;

/**
 * Encapsulates a Win32 Locale Identifier (LCID).  You should always use the 
 * CurrentThread locale for all locale specific operations. Starting in NT5
 * each thread can easily have a different locale, and every user can also
 * have a different locale. If you can't use the thread locale for some
 * reason, then you must you the user locale.
 * 
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public final class Locale {

    private static final int TYPE_NONE = 0;
    private static final int TYPE_STRING = 1;
    private static final int TYPE_INT = 2;

    int lcid;

    
    
    
    private StringBuffer tempbuffer = null;
    #if DEBUG
    String localeInfo;
    #endif


    /**
     * Creates a new Locale object with the calling thread's current Locale.
     */
    public Locale() {}

    /**
     * Creates a clone of the specified locale
     */
    public Locale(Locale locale) {}

    /**
     * Creates a new Locale object with the specified LCID Locale.
     *
     * @param lcid The Win32 Locale ID that this locale represents
     */
    public Locale(int lcid) {}

    /**
     * Creates a new Locale object for the specified Language and SubLanguage.
     *
     * @param language LanguageID for this locale
     * @param sublanguage SubLanguageId for this locale
     *
     * @see Locale.Language
     * @see Locale.SubLanguage
     */
    public Locale(int language, int sublanguage) {}

    /**
     * Creates a new Locale object for the specified Language and SubLanguage 
     * with the specified sorting.
     *
     * @param language LanguageID for this locale
     * @param sublanguage SubLanguageId for this locale
     * @param sort SortId for this locale
     *
     * @see Locale.Language
     * @see Locale.SubLanguage
     */
    public Locale(int language, int sublanguage, int sort) {}

    /**
     * Retrieves an array of Locale objects for all of the locales that are
     * currently installed on the computer.
     *
     * @return Array of all installed locales.
     *
     * @see getSupportedLocales
     */ 
    public static Locale[] getInstalledLocales() {}

    /**
     * Retrieves an array of all the locales that are currently supported by the system.
     *
     * @return Array of all supported locales.
     *
     * @see getInstalledLocales
     */ 
    public static Locale[] getSupportedLocales() {}

    
    
    
    int compareFlags = Lang.NORM_IGNORECASE;

    
    private void setCompareBit(int bit, boolean value) {}

    /**
     * Determines if string comparisons will ignore case.
     * 
     * @return True if string comparisons will be done by ignoring case.
     * 
     * @see #setCompareIgnoreCase
     */
    public boolean getCompareIgnoreCase() {}

    /**
     * Sets the case sensitivity of string comparisons.  When set to true
     * string comparisons are done in a case insesative manor.
     * 
     * @param value New value for the CompareIgnoreCase property.
     * 
     * @see #getCompareIgnoreCase
     */
    public void setCompareIgnoreCase(boolean value) {}
    
    /**
     * Determines if string comparisons will ignore kana. 
     * 
     * @return True if string comparisons will be done by ignoring kana.
     * 
     * @see #setCompareIgnoreCase
     */
    public boolean getCompareIgnoreKana() {}
    
    /**
     * Sets the kana sensitivity of string comparisons.  When set to true
     * string comparisons will not differentiate between Hiragana and 
     * Katakana characters.
     * 
     * @param value New value for the CompareIgnoreKana property.
     * 
     * @see #getCompareIgnoreKana
     */
    public void setCompareIgnoreKana(boolean value) {}
    
    /**
     * Determines if string comparisons will ignore nonspacing characters. 
     * 
     * @return True if string comparisons will be done by ignoring nonspacing 
     * characters
     * 
     * @see #setCompareIgnoreNonSpace
     */
    public boolean getCompareIgnoreNonSpace() {}
    
    /**
     * Sets the nonspacing character sensitivity of string comparisons.  When 
     * set to true string comparisons will ignore nonspacing characters.
     * 
     * @param value New value for the CompareIgnoreNonSpace property.
     * 
     * @see #getCompareIgnoreNonSpace
     */
    public void setCompareIgnoreNonSpace(boolean value) {}
    
    /**
     * Determines if string comparisons will ignore symbols.
     * 
     * @return True if string comparisons will be done by ignoring symbols.
     * 
     * @see #setCompareIgnoreSymbols
     */
    public boolean getCompareIgnoreSymbols() {}
    
    /**
     * Sets the symbol sensitivity of string comparisons.  When set to true 
     * string comparisons will ignore symbols.
     * 
     * @param value New value for the CompareIgnoreSymbols property.
     * 
     * @see #getCompareIgnoreSymbols
     */
    public void setCompareIgnoreSymbols(boolean value) {}
    
    /**
     * Determines if string comparisons will ignore the width of characters. 
     * 
     * @return True if string comparisons will be done by ignoring width of 
     * characters.
     * 
     * @see #setCompareIgnoreWidth
     */
    public boolean getCompareIgnoreWidth() {}
    
    /**
     * Sets the width sensitivity of string comparisons.  When set to true
     * string comparisons will not differentiate between a single-byte 
     * character and the same character as a double-byte character.
     * 
     * @param value New value for the CompareIgnoreWidth property.
     * 
     * @see #getCompareIgnoreWidth
     */
    public void setCompareIgnoreWidth(boolean value) {}
    
    /**
     * Determines if string comparisons will ignore kashida.
     * 
     * @return True if string comparisons will be done by ignoring kashida.
     * 
     * @see #setCompareIgnoreKashida
     */
    public boolean getCompareIgnoreKashida() {}
    
    /**
     * Sets the kashida sensitivity of string comparisons.  When set to true
     * string comparisons will not differentiate between lengthened and
     * non-lengthened characters.
     * 
     * @param value New value for the CompareIgnoreKashida property.
     * 
     * @see #getCompareIgnoreKashida
     */
    public void setCompareIgnoreKashida(boolean value) {}

    /**
     * Compares two Strings for this locale.  The comparison can be controlled
     * by adjusting the various CompareIgnore* properties.
     * 
     * @param string1 Left string
     * @param string2 Right string
     * 
     * @return 0 if strings are equal, -1 if string1 is less than string2, 1 
     * if string1 is greater than string2.
     * 
     * @see #setCompareIgnoreCase
     * @see #setCompareIgnoreKana
     * @see #setCompareIgnoreNonSpace
     * @see #setCompareIgnoreSymbols
     * @see #setCompareIgnoreWidth
     * @see #setCompareIgnoreKashida
     */
    public int compareStrings(String string1,
        String string2) {}
    
    
    


    /**
     * Compares the current Locale object to the object assigned in the obj
     * parameter.  Returns true if obj refers to a Locale object of
     * the same locale.
     * 
     * @param obj Object to compare to.
     * 
     * @return True if the objects are logically equivalent.
     */
    public boolean equals(Object obj) {}

    
    
    

    /**
     * Retrieves the SortID for this locale. 
     *
     * @return A SortID value.
     *
     * @see com.ms.wfc.app.Locale.Sort
     */
    public int getSortId() {}

    /**
     * Retrieves the character set for this locale. 
     *
     * @return A CharacterSet value.
     *
     * @see CharacterSet
     */
    public int getCharacterSet() {}

    /**
     * Retrieves the language identifier indicating the language of the current locale. 
     * 
     * @return Language idetifier
     */
    public int getLanguageId() {}
    
    /**
     * Retrieves the full localized name of the language.
     * 
     * @return Full localized name of the language.
     */
    public String getLanguage() {}
    
    /**
     * Retrieves the full English name of the language as specified by the International
     * Organization for Standardization (ISO) Standard 639.  This is always restricted to 
     * characters mappable into the ASCII 127-character subset.
     * 
     * @return Full English name of the language.
     */
    public String getEnglishLanguage() {}
    
    /**
     * Retrieves the abbreviated name of the locale's language.
     * 
     * @return Abbreviated name of the language.
     */
    public String getAbbrevLanguage() {}
    
    /**
     * Retrieves the native name of the language used in the current locale.  
     */
    public String getNativeLanguage() {}
    
    /**
     * Retrieves the country code, based on international telephone codes.  
     * 
     * @return Country code.
     */
    public int getCountryCode() {}
    
    /**
     * Retrieves the fully localized name of the country.
     * 
     * @return Full localized name of the country.
     */
    public String getCountry() {}
    
    /**
     * Retrieves the full English name of the country. This is always restricted to characters
     * mappable into the ASCII 127-character subset.
     * 
     * @return Full English name of the country.
     */
    public String getEnglishCountry() {}
    
    /**
     * Retrieves the abbreviated name of the country from the ISO Standard 3166. 
     * 
     * @return Abbreviated name of the country.
     */
    public String getAbbrevCountry() {}
    
    /**
     * Retrieves the native name of the country.  
     */
    public String getNativeCountry() {}
    
    /**
     * Retrieves the language identifier for the principal language spoken in this locale.
     * This is provided so that partially specified locales can be completed 
     * with default values. 
     * 
     * @return Language identifier.
     */
    public int getDefaultLanguage() {}
    
    /**
     * Retrieves the country code for the principal country in this locale. This is provided 
     * so that partially specified locales can be completed with default values.
     * 
     * @return Country code.
     */ 
    public int getDefaultCountry() {}
    
    /**
     * Retrieves the American National Standards Institute (ANSI) code page associated with
     * this locale.  
     * 
     * @return ANSI Code page.
     */
    public int getDefaultAnsiCodePage() {}
    
    /**
     * Retrieves the original equipment manufacturer (OEM) code page associated with the
     * locale.
     * 
     * @return OEM Code page.
     */
    public int getDefaultOEMCodePage() {}
    
    /**
     * Retrieves the Apple Macintosh code page associated with the locale.
     * 
     * @return Mac code page.
     */
    public int getDefaultMacCodePage() {}
    
    /**
     * Retrieves the character used to separate list items in the current locale.  For example, a comma is used 
     * in many locales.
     * 
     * @return String used to separate list items.
     */
    public String getListSeparator() {}

    /**
     * Retrieves the system of measurement used in the current locale. This value is 0 if the metric system (Syste'me
     * International d'Unite's, or S.I.) is used and 1 if the U.S. system is 
     * used.
     * 
     * @return 0 for metric systems, 1 for Enlish (U.S.) systems.
     * 
     * @see Locale.MeasurementSystem
     */
    public int getMeasurementSystem() {}
    
    /**
     * Retrieves the character used as the decimal separator.
     * 
     * @return String used to separate decimals.
     */
    public String getDecimalSeparator() {}
    
    /**
     * Retrieves the symbol used to separate groups of digits to the left of the decimal. 
     * 
     * @return String used to separate digit groups.
     */
    public String getThousandSeparator() {}
    
    /**
     * Retrieves sizes for each group of digits to the left of the decimal.  An explicit 
     * size is needed for each group; sizes are separated by semicolons. If the
     * last value is zero, the preceding value is repeated. To group thousands, 
     * specify 3;0, for example.
     * 
     * @return Description of decimal grouping.
     */
    public String getDecimalGrouping() {}
    
    /**
     * Retrieves the number of fractional digits that can be specified for the current locale.
     * 
     *  
     * @return Number of fractional digits.
     */
    public int getFractionalDigits() {}
    
    /**
     * Determines whether or not a leading zero is specified for decimal values. The specifier can be one
     * of the following values:<br>
     * <table>
     *   <tr><td>false</td><td>No leading zeros</td></tr>
     *   <tr><td>true</td><td>Leading zeros</td></tr>
     * </table>
     * 
     * @return Specified for leading zeros in decimal fields.
     * 
     * @see Locale.LeadingZeros
     */
    public boolean getLeadingZero() {}
    
    /**
     * Retrieves the negative number format for the current locale. The mode can be one of these values:<br>
     * <table>
     *   <tr><td>0</td><td>(1.1)</td></tr>
     *   <tr><td>1</td><td>-1.1</td></tr>
     *   <tr><td>2</td><td>- 1.1</td></tr>
     *   <tr><td>3</td><td>1.1-</td></tr>
     *   <tr><td>4</td><td>1.1 -</td></tr>
     * </table>
     * 
     * @return Negative number mode.
     * 
     * @see Locale.NegativeNumberMode
     */
    public int getNegativeNumberMode() {}
    
    /**
     * Retrieves the native equivalents to the ASCII characters 0 through 9 used in the
     * current locale. 
     * 
     * @return Native equivalents to ASCII 0 through 9.
     */
    public String getNativeDigits() {}
    
    /**
     * Retrieves the full English name of the currency system associated with the locale.
     * 
     * @return The full English name of the currency associated with the locale.
     */
    public String getEnglishCurrencyName() {}
    
    /**
     * Retrieves the native name of the currency system associated with the locale. 
     * 
     * @return The native name of the currency associated with the locale.
     */
    public String getNativeCurrencyName() {}
    
    /**
     * Retrieves the symbol used as the local monetary symbol. 
     * 
     * @return String used as the local monetary symbol.
     */
    public String getCurrencySymbol() {}
    
    /**
     * Retrieves the three characters of the international monetary symbol specified in ISO
     * 4217. 
     * 
     * @return International current symbol.
     */
    public String getIntlCurrencySymbol() {}
    
    /**
     * Retrieves the character used as the monetary decimal separator. 
     * 
     * @return String used as the monetary decimal separator.
     */
    public String getCurrencyDecimalSeparator() {}
    
    /**
     * Retrieves the symbol used as the monetary separator between groups of digits to the
     * left of the decimal. 
     * 
     * @return String used to separate monetary digit groups.
     */
    public String getCurrencyThousandSeparator() {}
    
    /**
     * Retrieves sizes for each group of monetary digits to the left of the decimal.  An 
     * explicit size is needed for each group; sizes are separated by semicolons.
     * If the last value is zero, the preceding value is repeated. To group 
     * thousands, specify 3;0, for example.
     * 
     * @return Description of monetary decimal grouping.
     */
    public String getCurrencyDecimalGrouping() {}

    /**
     * Retrieves the number of fractional digits for the local monetary format. 
     * 
     * @return Number of fractional digits for the local monetary format.
     */
    public int getCurrencyFractionalDigits() {}
    
    /**
     * Retrieves the number of fractional digits that are used in the local monetary format.
     * 
     * @return Number of fractional digits for the local monetary format.
     */
    public int getIntlCurrencyFractionalDigits() {}
    
    /**
     * Retrieves the positive currency mode.  The mode can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>Prefix, no separation</td></tr>
     *   <tr><td>1</td><td>Suffix, no separation</td></tr>
     *   <tr><td>2</td><td>Prefix, 1-char. separation</td></tr>
     *   <tr><td>3</td><td>Suffix, 1-char. separation</td></tr>
     * </table>
     * 
     * @return Positive currency mode.
     * 
     * @see Locale.PositiveCurrencyMode
     */
    public int getPositiveCurrencyMode() {}
    
    /**
     * Retrieves the negative currency format for the current locale. The mode can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>($1.1)</td></tr>
     *   <tr><td>1</td><td>-$1.1</td></tr>
     *   <tr><td>2</td><td>$-1.1</td></tr>
     *   <tr><td>3</td><td>$1.1-</td></tr>
     *   <tr><td>4</td><td>(1.1$)</td></tr>
     *   <tr><td>5</td><td>-1.1$</td></tr>
     *   <tr><td>6</td><td>1.1-$</td></tr>
     *   <tr><td>7</td><td>1.1$-</td></tr>
     *   <tr><td>8</td><td>-1.1 $ (space before $)</td></tr>
     *   <tr><td>9</td><td>-$ 1.1 (space after $)</td></tr>
     *   <tr><td>10</td><td>1.1 $- (space before $)</td></tr>
     *   <tr><td>11</td><td>$ 1.1- (space after $)</td></tr>
     *   <tr><td>12</td><td>$ -1.1 (space after $)</td></tr>
     *   <tr><td>13</td><td>1.1- $ (space before $)</td></tr>
     *   <tr><td>14</td><td>($ 1.1) (space after $)</td></tr>
     *   <tr><td>15</td><td>(1.1 $) (space before $)</td></tr>
     * </table>
     * 
     * @return Negative currency mode.
     */
    public int getNegativeCurrencyMode() {}
    
    /**
     * Retrieves the symbol used as the locale's date separator. 
     * 
     * @return String for the date separator.
     */
    public String getDateSeparator() {}
    
    /**
     * Retrieves the symbol used for the time separator. 
     * 
     * @return String for the time separator. 
     */
    public String getTimeSeparator() {}
    
    /**
     * Retrieves a String describing the time formatting for this thread's
     * locale.  The string can consist of a 
     * combination of the hour, minute, and second format pictures defined in 
     * the Hour, Minute, and Second Format Pictures table in National Language 
     * Support Constants.
     * 
     * @return Time formatting strings for this locale.
     */
    public String getTimeFormatString() {}
    
    /**
     * Retrieves information for formatting the Year/Month for the locale.  This string shows the 
     * proper format for a date string that contains only the year and the 
     * month.
     * 
     * @return The Year/Month formatting string for the locale.
     */
    public String getYearMonthFormatString() {}
    
    /**
     * Retrieves a short date formatting string for this locale.  The string can consist of 
     * a combination of day, month, and year format pictures defined in Day, 
     * Month, Year, and Era Format Pictures table in National Language Support 
     * Constants.
     * 
     * @return Short date formatting string for this locale.
     */
    public String getShortDateFormatString() {}
    
    /**
     * Retrieves the long date formatting string for this locale.  The string can consist of a
     * combination of day, month, and year format pictures defined in the Day, 
     * Month, Year, and Era Format Pictures table in National Language Support 
     * Constants and any string of characters enclosed in single quotes. 
     * Characters in single quotes remain as given.
     * 
     * @return Long date formatting string for this locale.
     */
    public String getLongDateFormatString() {}
    
    /**
     * Retrieves a short date format-ordering specifier.  The specifier can be one of the 
     * following values:<br>
     * <table>
     *   <tr><td>0</td><td>Month-Day-Year</td></tr>
     *   <tr><td>1</td><td>Day-Month-Year</td></tr>
     *   <tr><td>2</td><td>Year-Month-Day</td></tr>
     * </table>
     * 
     * @return Short date format-ordering specifier.
     * 
     * @see Locale.DateFormatOrder
     */
    public int getShortDateOrder() {}
    
    /**
     * Retrieves the long date format order.  The specifier can be one of the 
     * following values:<br>
     * <table>
     *   <tr><td>0</td><td>Month-Day-Year</td></tr>
     *   <tr><td>1</td><td>Day-Month-Year</td></tr>
     *   <tr><td>2</td><td>Year-Month-Day</td></tr>
     * </table>
     * 
     * @return Short date format-ordering specifier.
     * 
     * @see Locale.DateFormatOrder
     */
    public int getLongDateOrder() {}
    
    /**
     * Retrieves the time format specifier.  The specified can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>AM / PM 12-hour format</td></tr>
     *   <tr><td>1</td><td>24-hours format</td></tr>
     * </table>
     * 
     * @return Time format specifier.
     */
    public int getTimeFormat() {}
    
    /**
     * Retrieves an integer value indication where the TimeMark(AM/PM) is placed. */
    public int getTimeMarkPosition() {}
    
    /**
     * Determines if the year specifier is a
     * 4-digit or a 2-digit century. The specifier can be one of the 
     * following values:<br>
     * <table>
     *   <tr><td>false</td><td>Abbreviated 2-digit century</td></tr>
     *   <tr><td>true</td><td>Full 4-digit century</td></tr>
     * </table>
     * 
     * @return Specifier for full 4-digit century.
     */
    public boolean getCenturyFormat() {}
    
    /**
     * Retrieves information that specifies whether or not there are leading zeros in the hour
     * position for a time field.  The specifier can be one of 
     * the following values:<br>
     * <table>
     *   <tr><td>false</td><td>No leading zeros for hours</td></tr>
     *   <tr><td>true</td><td>Leading zeros for hours</td></tr>
     * </table>
     * 
     * @return Specifier for leading zeros in time fields.
     * 
     * @see Locale.LeadingZeros
     */
    public boolean getTimeLeadingZero() {}
    
    /**
     * Determines whether or not a leading zero is used for dates that have single digit days. The specifier can be one of 
     * the following values:<br>
     * <table>
     *   <tr><td>false</td><td>No leading zeros for days</td></tr>
     *   <tr><td>true</td><td>Leading zeros for days</td></tr>
     * </table>
     * 
     * @return Specifier for leading zeros in day fields.
     * 
     * @see Locale.LeadingZeros
     */
    public boolean getDayLeadingZero() {}
    
    /**
     * Determines whether or not a leading zero is specified in month fields in a date. The specifier can be one of 
     * the following values:<br>
     * <table>
     *   <tr><td>false</td><td>No leading zeros for months</td></tr>
     *   <tr><td>true</td><td>Leading zeros for months</td></tr>
     * </table>
     * 
     * @return Specifier for leading zeros in month fields.
     * 
     * @see Locale.LeadingZeros
     */
    public boolean getMonthLeadingZero() {}
    
    /**
     * Retrieves a String that represents the AM designator.
     * 
     * @return String for the AM designator.
     */
    public String getAMTimeMark() {}
    
    /**
     * Retrieves the PM designator. 
     * 
     * @return String for the PM designator.
     */
    public String getPMTimeMark() {}

    /**
     * Retrieves the current calendar type.  This can be one of these values:<br>
     * <table>
     *   <tr><td>1</td><td>Gregorian (as in United States)</td></tr>
     *   <tr><td>2</td><td>Gregorian (English strings always)</td></tr>
     *   <tr><td>3</td><td>Era: Year of the Emperor (Japan)</td></tr>
     *   <tr><td>4</td><td>Era: Year of the Republic of China</td></tr>
     *   <tr><td>5</td><td>Tangun Era (Korea)</td></tr>
     * </table>
     * 
     * @return Current calendar type.
     *
     * @see Locale.CalendarType
     */
    public int getCalendarType() {}
    
    /**
     * Provides additional calendar types.  This can be a zero-separated list of one or 
     * more of these calendar type values:
     * <table>
     *   <tr><td>0</td><td>No additional types valid</td></tr>
     *   <tr><td>1</td><td>Gregorian (as in United States)</td></tr>
     *   <tr><td>2</td><td>Gregorian (English strings always)</td></tr>
     *   <tr><td>3</td><td>Era: Year of the Emperor (Japan)</td></tr>
     *   <tr><td>4</td><td>Era: Year of the Republic of China</td></tr>
     *   <tr><td>5</td><td>Tangun Era (Korea)</td></tr>
     * </table>
     * 
     * @return Additional calendar types.
     *
     * @see Locale.OptionalCalendarType
     */
    public int getOptionalCalendarType() {}

    /**
     * Retrieves the day of the week that is considered the first day of the week in the
     * current locale. The specifier can be one of these
     * values:<br>
     * <table>
     *   <tr><td>0</td><td>Monday</td></tr>
     *   <tr><td>1</td><td>Tuesday</td></tr>
     *   <tr><td>2</td><td>Wednesday</td></tr>
     *   <tr><td>3</td><td>Thursday</td></tr>
     *   <tr><td>4</td><td>Friday</td></tr>
     *   <tr><td>5</td><td>Saturday</td></tr>
     *   <tr><td>6</td><td>Sunday</td></tr>
     * </table>
     * 
     * @return Specifier for the first day in a week.
     */
    public int getFirstDayOfWeek() {}
    
    /**
     * Retrieves a value representing the first week of the year for the current locale. 
     *  The specifier can be one 
     * of these values:<br>
     * <table>
     *   <tr><td>0</td><td>Week container 1/1 is the first week of that year.</td></tr>
     *   <tr><td>1</td><td>First full week following 1/1 is the first week of that year.</td></tr>
     *   <tr><td>2</td><td>First week containg at least 4 days is the first week of that year.</td></tr>
     * </table>
     * 
     * @return Specifier for the first week of the year.
     */
    public int getFirstWeekOfYear() {}
    
    /**
     * Retrieves the native long name for the specific day of the week. 
     * 
     * @param day of the week to retrieve the name for.
     *
     * @return Native long name for <i>day</i>.
     *
     * @see com.ms.wfc.ui.Days
     */
    public String getDayName(int day) {}
    
    /**
     * Retrieves the native abbreviated name for the specific day of the week.
     * 
     * @param day of the week to retrieve the name for.
     *
     * @return Native abbreviated name for <i>day</i>.
     *
     * @see com.ms.wfc.ui.Days
     */
    public String getAbbrevDayName(int day) {}
    
    /**
     * Retrieves the native long name for a specific month.
     * 
     * @param month Month to retrieve name for. For example "1" will return
     *        "January".
     *
     * @return Native long name for <i>month</i>.
     */
    public String getMonthName(int month) {}
    
    /**
     * Retrieves the native abbreviated name for a specific month.
     *
     * @param month Month to retrieve the name for. For example "1" will return
     *        "Jan".
     *
     * @return Native abbreviated name for <i>month</i>.
     */
    public String getAbbrevMonthName(int month) {}
    
    /**
     * Retrieves the value of the positive sign. 
     * 
     * @return String value for the positive size. 
     */
    public String getPositiveSign() {}
    
    /** 
     * Retrieves the value of the negative sign. 
     * 
     * @return String value for the negative size.
     */
    public String getNegativeSign() {}
    
    /**
     * Retrieves the formatting index for positive values.  The index can be one of the 
     * following values:<br>
     * <table>
     *   <tr><td>0</td><td>Parentheses surround the amount and the monetary symbol.</td></tr>
     *   <tr><td>1</td><td>The sign string prevedes the amount and the monetary symbol.</td></tr>
     *   <tr><td>2</td><td>The sign string succeeds the amount and the monetary symbol.</td></tr>
     *   <tr><td>3</td><td>The sign string immediately precedes the monetary symbol.</td></tr>
     *   <tr><td>4</td><td>The sign string immediately succeeds the monetary symbol.</td></tr>
     * </table>
     * 
     * @return Formatting index for positive values.
     */
    public int getPositivePosition() {}
    
    /**
     * Retrieves the formatting index for negative values.  The index can be one of the 
     * following values:<br>
     * <table>
     *   <tr><td>0</td><td>Parentheses surround the amount and the monetary symbol.</td></tr>
     *   <tr><td>1</td><td>The sign string prevedes the amount and the monetary symbol.</td></tr>
     *   <tr><td>2</td><td>The sign string succeeds the amount and the monetary symbol.</td></tr>
     *   <tr><td>3</td><td>The sign string immediately precedes the monetary symbol.</td></tr>
     *   <tr><td>4</td><td>The sign string immediately succeeds the monetary symbol.</td></tr>
     * </table>
     * 
     * @return Formatting index for negative values.
     */
    public int getNegativePosition() {}
    
    /**
     * Determines the position of the monetary symbol used for a positive monetary value.  This value is 
     * 1 if the monetary symbol precedes the positive amount, 0 if it follows 
     * it.
     * 
     * @return Position of monetary symbol in a positive monetary value.
     */
    public int getCurrencyPositivePosition() {}
    
    /**
     * Separation of monetary symbol in a positive monetary value. This value 
     * is <b>true</b> if the monetary symbol is separated by a space from a positive 
     * amount, <b>false</b> if it is not.
     * 
     * @return Separation of monetary symbol in a positive monetary value.
     */
    public boolean getCurrencyPositiveSeparation() {}
    
    /**
     * Determines the position of the monetary symbol used for a negative monetary value.  This value is 
     * <b>true</b> if the monetary symbol precedes the negative amount, 
     * <b>false</b> if it follows it.
     * 
     * @return Position of monetary symbol in a negative monetary value.
     */
    public boolean getCurrencyNegativePosition() {}
    
    /**
     * Determines if a space is provided between the negative monetary symbol and its monetary
     * value.  This value 
     * is <b>true</b> if the monetary symbol is separated by a space from the 
     * negative amount, <b>false</b> if it is not.
     *  
     * @return Separation of monetary symbol in a negative monetary value.
     */
    public boolean getCurrencyNegativeSeparation() {}
    
    /**
     * Retrieves the language name as defined by the International Standards Organization's
     * (ISO) 639 standard. 
     * 
     * @return IS0 639 Language Name.
     */
    public String getISO639LanguageName() {}
    
    /**
     * Retrieves the country name as defined by the International Standards Organization's
     * (IS0) 3116 standard. 
     * 
     * @return IS0 3116 Country Name.
     */
    public String getISO3116CountryName() {}

    /**
     * Sets the current calendar type.  This can be one of these values:<br>
     * <table>
     *   <tr><td>1</td><td>Gregorian (as in United States)</td></tr>
     *   <tr><td>2</td><td>Gregorian (English strings always)</td></tr>
     *   <tr><td>3</td><td>Era: Year of the Emperor (Japan)</td></tr>
     *   <tr><td>4</td><td>Era: Year of the Republic of China</td></tr>
     *   <tr><td>5</td><td>Tangun Era (Korea)</td></tr>
     * </table>
     * 
     * @param value Current calendar type.
     *
     * @see Locale.CalendarType
     */
    public void setCalendarType(int value) {}

    /**
     * Sets the number of fractional digits used by the local monetary format. 
     * 
     * @param value Number of fractional digits for the local monetary format.
     */
    public void setCurrencyFractionalDigits(int value) {}

    /**
     * Sets the format used to display positive currency values.  The mode can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>Prefix, no separation</td></tr>
     *   <tr><td>1</td><td>Suffix, no separation</td></tr>
     *   <tr><td>2</td><td>Prefix, 1-char. separation</td></tr>
     *   <tr><td>3</td><td>Suffix, 1-char. separation</td></tr>
     * </table>
     * 
     * @param value Positive currency mode.
     * 
     * @see Locale.PositiveCurrencyMode
     */
    public void setPositiveCurrencyMode(int value) {}

    /**
     * Sets the number of digits to the right of the decimal. 
     *  
     * @param value Number of fractional digits.
     */
    public void setFractionalDigits(int value) {}

    /**
     * Sets which day to use as the first day in a week.  The specifier can be one of these
     * values:<br>
     * <table>
     *   <tr><td>0</td><td>Monday</td></tr>
     *   <tr><td>1</td><td>Tuesday</td></tr>
     *   <tr><td>2</td><td>Wednesday</td></tr>
     *   <tr><td>3</td><td>Thursday</td></tr>
     *   <tr><td>4</td><td>Friday</td></tr>
     *   <tr><td>5</td><td>Saturday</td></tr>
     *   <tr><td>6</td><td>Sunday</td></tr>
     * </table>
     * 
     * @param value Specifier for the first day in a week.
     */
    public void setFirstDayOfWeek(int value) {}

    /**
     * Sets the criteria for determing which week to use as the first week of the year.  The specifier can be one 
     * of these values:<br>
     * <table>
     *   <tr><td>0</td><td>Week container 1/1 is the first week of that year.</td></tr>
     *   <tr><td>1</td><td>First full week following 1/1 is the first week of that year.</td></tr>
     *   <tr><td>2</td><td>First week containg at least 4 days is the first week of that year.</td></tr>
     * </table>
     * 
     * @param value Specifier for the first week of the year.
     */
    public void setFirstWeekOfYear(int value) {}

    /**
     * Sets whether or not leading zeros will be in the decimal fields.  The specifier can be one
     * of the following values:<br>
     * <table>
     *   <tr><td>false</td><td>No leading zeros</td></tr>
     *   <tr><td>true</td><td>Leading zeros</td></tr>
     * </table>
     * 
     * @param value Specified for leading zeros in decimal fields.
     * 
     * @see Locale.LeadingZeros
     */
    public void setLeadingZero(boolean value) {}

    /**
     * Sets the system of measurement to be used.  This value is 0 if the metric system (Syste'me
     * International d'Unite's, or S.I.) is used and 1 if the U.S. system is 
     * used.
     * 
     * @param value 0 for metric systems, 1 for Enlish (U.S.) systems.
     * 
     * @see Locale.MeasurementSystem
     */
    public void setMeasurementSystem(int value) {}

    /**
     * Sets the mode to use when displaying negative currency values.  The mode can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>($1.1)</td></tr>
     *   <tr><td>1</td><td>-$1.1</td></tr>
     *   <tr><td>2</td><td>$-1.1</td></tr>
     *   <tr><td>3</td><td>$1.1-</td></tr>
     *   <tr><td>4</td><td>(1.1$)</td></tr>
     *   <tr><td>5</td><td>-1.1$</td></tr>
     *   <tr><td>6</td><td>1.1-$</td></tr>
     *   <tr><td>7</td><td>1.1$-</td></tr>
     *   <tr><td>8</td><td>-1.1 $ (space before $)</td></tr>
     *   <tr><td>9</td><td>-$ 1.1 (space after $)</td></tr>
     *   <tr><td>10</td><td>1.1 $- (space before $)</td></tr>
     *   <tr><td>11</td><td>$ 1.1- (space after $)</td></tr>
     *   <tr><td>12</td><td>$ -1.1 (space after $)</td></tr>
     *   <tr><td>13</td><td>1.1- $ (space before $)</td></tr>
     *   <tr><td>14</td><td>($ 1.1) (space after $)</td></tr>
     *   <tr><td>15</td><td>(1.1 $) (space before $)</td></tr>
     * </table>
     * 
     * @param value Negative currency mode.
     */
    public void setNegativeCurrencyMode(int value) {}

    /**
     * Sets the format to use to display negative numbers.  The mode can be one of these values:<br>
     * <table>
     *   <tr><td>0</td><td>(1.1)</td></tr>
     *   <tr><td>1</td><td>-1.1</td></tr>
     *   <tr><td>2</td><td>- 1.1</td></tr>
     *   <tr><td>3</td><td>1.1-</td></tr>
     *   <tr><td>4</td><td>1.1 -</td></tr>
     * </table>
     * 
     * @param value Negative number mode.
     * 
     * @see Locale.NegativeNumberMode
     */
    public void setNegativeNumberMode(int value) {}

    /**
     * Sets the time-format specifier.  The specified can be one of the following values:<br>
     * <table>
     *   <tr><td>0</td><td>AM / PM 12-hour format</td></tr>
     *   <tr><td>1</td><td>24-hours format</td></tr>
     * </table>
     * 
     * @param value Time format specifier.
     */
    public void setTimeFormat(int value) {}

    /**
     * Sets a String with the AM designator.
     * 
     * @param value String for the AM designator.
     */
    public void setAMTimeMark(String value) {}

    /**
     * Sets the value to be used as the PM designator. 
     * 
     * @param value String for the PM designator.
     */
    public void setPMTimeMark(String value) {}

    /**
     * Sets the symbol to be used as the local monetary symbol. 
     * 
     * @param value String used as the local monetary symbol.
     */
    public void setCurrencySymbol(String value) {}

    /**
     * Sets the String to be used as the date separator. 
     * 
     * @param value String for the date separator.
     */
    public void setDateSeparator(String value) {}

    /**
     * Sets the value to be used for the decimal separator. 
     * 
     * @param value String used to separate decimals.
     */
    public void setDecimalSeparator(String value) {}

    /**
     * Set the number of digits for each group of digits to the left of the decimal.  An explicit 
     * size is needed for each group; sizes are separated by semicolons. If the
     * last value is zero, the preceding value is repeated. To group thousands, 
     * specify 3;0, for example.
     * 
     * @param value Description of decimal grouping.
     */
    public void setDecimalGrouping(String value) {}

    /**
     * Sets the symbol to used to separate items in a list.  For example, a comma is used 
     * in many locales.
     * 
     * @param value String used to separate list items.
     */
    public void setListSeparator(String value) {}

    /**
     * Sets the long date formatting string for this locale.  The string can consist of a
     * combination of day, month, and year format pictures defined in the Day, 
     * Month, Year, and Era Format Pictures table in National Language Support 
     * Constants and any string of characters enclosed in single quotes. 
     * Characters in single quotes remain as given.
     * 
     * @param value Long date formatting string for this locale.
     */
    public void setLongDateFormatString(String value) {}

    /**
     * Sets the symbol to be used as the monetary decimal separator. 
     * 
     * @param value String used as the monetary decimal separator.
     */
    public void setCurrencyDecimalSeparator(String value) {}

    /**
     * Sets the size for each group of monetary digits to the left of the decimal.  An 
     * explicit size is needed for each group; sizes are separated by semicolons.
     * If the last value is zero, the preceding value is repeated. To group 
     * thousands, specify 3;0, for example.
     * 
     * @param value Description of monetary decimal grouping.
     */
    public void setCurrencyDecimalGrouping(String value) {}

    /**
     * Sets the symbol used as the monetary separator between groups of digits to the left of
     * the decimal. 
     * 
     * @param value String used to separate monetary digit groups.
     */
    public void setCurrencyThousandSeparator(String value) {}

    /** 
     * Sets the value describing the negative sign. 
     * 
     * @param value String value for the negative size.
     */
    public void setNegativeSign(String value) {}

    /**
     * Sets a value that describes the positive sign.
     * 
     * @param value String value for the positive size. 
     */
    public void setPositiveSign(String value) {}

    /**
     * Sets the short date formatting string for this locale.  The string can consist of 
     * a combination of day, month, and year format pictures defined in Day, 
     * Month, Year, and Era Format Pictures table in National Language Support 
     * Constants.
     * 
     * @param value Short date formatting string for this locale.
     */
    public void setShortDateFormatString(String value) {}

    /**
     * Sets the value used to separate groups of digits to the left of the decimal. 
     * 
     * @param value String used to separate digit groups.
     */
    public void setThousandSeparator(String value) {}

    /**
     * Sets the symbol to use for the time separator. 
     * 
     * @param value String for the time separator. 
     */
    public void setTimeSeparator(String value) {}

    /**
     * Sets the format string used to display time for this locale.  The string can consist of a 
     * combination of the hour, minute, and second format pictures defined in 
     * the Hour, Minute, and Second Format Pictures table in National Language 
     * Support Constants.
     * 
     * @param value Time formatting strings for this locale.
     */
    public void setTimeFormatString(String value) {}

    /**
     * Sets the Year/Month formatting string for the locale.  This string shows the 
     * proper format for a date string that contains only the year and the 
     * month.
     * 
     * @param value The Year/Month formatting string for the locale.
     */
    public void setYearMonthFormatString(String value) {}

    
    
    

    /**
     * Retrieves the LCID that the Locale object represents.  Provided for Win32 interop.
     *
     * @return Win32 LCID of this locale.
     */
    public int getLCID() {}

    /**
     * Retrieves the Locale object for the current thread.  This is exactly the
     * same as creating a new instance of the Locale object.
     * 
     * @return Current thread locale.
     */
    public static final Locale getCurrentThreadLocale() {}

    
    private String getLocaleInfo(int lctype) {}

    
    private String getLocaleInfoS(int lctype) {}

    private int getLocaleInfoI(int lctype) {}
    
    
    private int getLocaleInfoI(int lctype, int decBase) {}

    
    private void setLocaleInfoS(int lctype, String value) {}

    
    private void setLocaleInfoI(int lctype, int value) {}

    /**
     * Provides the parent locale for the thread calling this method.  A parent locale is the more
     * "neutral" version of a locale. For example the parent of a U.s. English
     * locale would be a Neutral English locale, the parent of that would be
     * the base Neutral locale.
     * 
     * @return Parent locale.
     */
    public Locale getParentLocale() {}

    /**
     * Retrieves the system's default locale. 
     * 
     * @return The default system locale.
     */
    public static final Locale getSystemDefaultLocale() {}

    /**
     * Retrieves the symbol for the default user locale. 
     * 
     * @return The default user locale.
     */
    public static final Locale getUserDefaultLocale() {}

    /**
     * @internalonly 
     */
    public int hashCode() {}

    public String toString() {}

    /**
     *  Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class Languages {
        public static final int NEUTRAL                     = 0x00;

        public static final int ALBANIAN                    = 0x1c;
        public static final int ARABIC                      = 0x01;
        public static final int BAHASA                      = 0x21;
        public static final int BULGARIAN                   = 0x02;
        public static final int CATALAN                     = 0x03;
        public static final int CHINESE                     = 0x04;
        public static final int CZECH                       = 0x05;
        public static final int DANISH                      = 0x06;
        public static final int DUTCH                       = 0x13;
        public static final int ENGLISH                     = 0x09;
        public static final int FINNISH                     = 0x0b;
        public static final int FRENCH                      = 0x0c;
        public static final int GERMAN                      = 0x07;
        public static final int GREEK                       = 0x08;
        public static final int HEBREW                      = 0x0d;
        public static final int HUNGARIAN                   = 0x0e;
        public static final int ICELANDIC                   = 0x0f;
        public static final int ITALIAN                     = 0x10;
        public static final int JAPANESE                    = 0x11;
        public static final int KOREAN                      = 0x12;
        public static final int NORWEGIAN                   = 0x14;
        public static final int POLISH                      = 0x15;
        public static final int PORTUGUESE                  = 0x16;
        public static final int RHAETO_ROMAN                = 0x17;
        public static final int ROMANIAN                    = 0x18;
        public static final int RUSSIAN                     = 0x19;
        public static final int SERBO_CROATIAN              = 0x1a;
        public static final int SLOVAK                      = 0x1b;
        public static final int SPANISH                     = 0x0a;
        public static final int SWEDISH                     = 0x1d;
        public static final int THAI                        = 0x1e;
        public static final int TURKISH                     = 0x1f;
        public static final int URDU                        = 0x20;
    }

    /**
     *  Encapsulates a Win32 Locale Identifier (LCID). 
     *
     *  The first part of the name dictates which primary
     *  language ID that sublanguage ID can be combined with to form a
     *  valid language ID.
     *
     * @security(checkClassLinking=on)
     */
    public static final class SubLanguages {    
        /**
         * language neutral
         */
        public static final int NEUTRAL                  = 0x00;    
        /**
         * user default
         */
        public static final int DEFAULT                  = 0x01;    
        /**
         * system default
         */
        public static final int SYS_DEFAULT              = 0x02;    
        /**
         * Chinese (Simplified)
         */
        public static final int CHINESE_SIMPLIFIED       = 0x02;    
        /**
         * Chinese (Traditional)
         */
        public static final int CHINESE_TRADITIONAL      = 0x01;    
        /**
         * Dutch
         */
        public static final int DUTCH                    = 0x01;    
        /**
         * Dutch (Belgian)
         */
        public static final int DUTCH_BELGIAN            = 0x02;    
        /**
         * English (USA)
         */
        public static final int ENGLISH_US               = 0x01;    
        /**
         * English (UK)
         */
        public static final int ENGLISH_UK               = 0x02;    
        /**
         * English (Australian)
         */
        public static final int ENGLISH_AUS              = 0x03;    
        /**
         * English (Canadian)
         */
        public static final int ENGLISH_CAN              = 0x04;    
        /**
         * English (New Zealand)
         */
        public static final int ENGLISH_NZ               = 0x05;    
        /**
         * English (Irish)
         */
        public static final int ENGLISH_EIRE             = 0x06;    
        /**
         * French
         */
        public static final int FRENCH                   = 0x01;    
        /**
         * French (Belgian)
         */
        public static final int FRENCH_BELGIAN           = 0x02;    
        /**
         * French (Canadian)
         */
        public static final int FRENCH_CANADIAN          = 0x03;    
        /**
         * French (Swiss)
         */
        public static final int FRENCH_SWISS             = 0x04;    
        /**
         * German
         */
        public static final int GERMAN                   = 0x01;    
        /**
         * German (Swiss)
         */
        public static final int GERMAN_SWISS             = 0x02;    
        /**
         * German (Austrian)
         */
        public static final int GERMAN_AUSTRIAN          = 0x03;    
        /**
         * Italian
         */
        public static final int ITALIAN                  = 0x01;    
        /**
         * Italian (Swiss)
         */
        public static final int ITALIAN_SWISS            = 0x02;    
        /**
         * Norwegian (Bokmal)
         */
        public static final int NORWEGIAN_BOKMAL         = 0x01;    
        /**
         * Norwegian (Nynorsk)
         */
        public static final int NORWEGIAN_NYNORSK        = 0x02;    
        /**
         * Portuguese
         */
        public static final int PORTUGUESE               = 0x02;    
        /**
         * Portuguese (Brazilian)
         */
        public static final int PORTUGUESE_BRAZILIAN     = 0x01;    
        /**
         * Serbo-Croatian (Cyrillic)
         */
        public static final int SERBO_CROATIAN_CYRILLIC  = 0x02;    
        /**
         * Croato-Serbian (Latin)
         */
        public static final int SERBO_CROATIAN_LATIN     = 0x01;    
        /**
         * Spanish
         */
        public static final int SPANISH                  = 0x01;    
        /**
         * Spanish (Mexican)
         */
        public static final int SPANISH_MEXICAN          = 0x02;    
        /**
         * Spanish (Modern)
         */
        public static final int SPANISH_MODERN           = 0x03;    
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     * @security(checkClassLinking=on)
     */
    public static final class Sort {
        /**
         * sorting default
         */
        public static final int DEFAULT                     =0x0; 
        /**
         * Japanese XJIS order
         */
        public static final int JAPANESE_XJIS               =0x0; 
        /**
         * Japanese Unicode order
         */
        public static final int JAPANESE_UNICODE            =0x1; 
        /**
         * Chinese BIG5 order
         */
        public static final int CHINESE_BIG5                =0x0; 
        /**
         * PRC Chinese Phonetic order
         */
        public static final int CHINESE_PRCP                =0x0; 
        /**
         * Chinese Unicode order
         */
        public static final int CHINESE_UNICODE             =0x1; 
        /**
         * PRC Chinese Stroke Count order
         */
        public static final int CHINESE_PRC                 =0x2; 
        /**
         * Korean KSC order
         */
        public static final int KOREAN_KSC                  =0x0; 
        /**
         * Korean Unicode order
         */
        public static final int KOREAN_UNICODE              =0x1; 
        /**
         * German Phone Book order
         */
        public static final int GERMAN_PHONE_BOOK           =0x1; 
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class MeasurementSystem extends Enum {
        public static final int METRIC = 0;
        public static final int US = 1;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class LeadingZeros extends Enum {
        public static final int NOLEADING = 0;
        public static final int LEADING = 1;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class NegativeNumberMode extends Enum {
        public static final int PARENS = 0;
        public static final int PREFIX_NOSEP = 1;
        public static final int PREFIX_SEP = 2;
        public static final int SUFFIX_NOSEP = 3;
        public static final int SUFFIX_SEP = 4;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class PositiveCurrencyMode extends Enum {
        public static final int PREFIX_NOSEP = 0;
        public static final int SUFFIX_NOSEP = 1;
        public static final int PREFIX_SEP = 2;
        public static final int SUFFIX_SEP = 3;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class DateFormatOrder extends Enum {
        public static final int MONTH_DAY_YEAR = 0;
        public static final int DAY_MONTH_YEAR = 1;
        public static final int YEAR_MONTH_DAY = 2;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static class CalendarType extends Enum {
        public static final int GREGORIAN_US = 1;
        public static final int GREGORIAN_ENGLISH = 2;
        public static final int ERA_EMPEROR = 3;
        public static final int ERA_REPUB_CHINA = 4;
        public static final int ERA_TANGUN = 5;
    }

    /**
     * Encapsulates a Win32 Locale Identifier (LCID). 
     *
     * @security(checkClassLinking=on)
     */
    public static final class OptionalCalendarType extends CalendarType {
        public static final int NO_ADDITIONAL_TYPES_VALID = 0;
    }

    
    private static native boolean EnumSystemLocales(com.ms.dll.Callback lpLocaleEnumProc, int dwFlags);

    
    private static class EnumCallBack extends com .ms.dll .Callback {
        List locales = new List();

        public boolean callback (int localeString) {}   

    }
    
    private static final int LCID_INSTALLED = 0x00000001;
    private static final int LCID_SUPPORTED = 0x00000002;
}