//STRIPPEDSOURCE//

package com.ms.wfc.app;

/**
 * Implements a Windows message.   This class cannot be created directly.  Rather,
 * use the create and free methods.  Messages are pooled within
 * this class to make their creation more efficient.
 *
 * @security(checkClassLinking=on)
 */
public final class Message { 
    
    
    private static Message messagePool;
    private Message next;
    
    
    private Message() {}
    
    /**
     * The window handle of the message.
     */    
    public int hWnd;
    
    /**
     * The message ID
     */
    public int msg;
    
    /**
     * The wParam of the message.  The value of this field is dependent on the
     * message.
     */
    public int wParam;
    
    /**
     * The lParam of the message.  The value of this field is dependent on the
     * message.
     */
    public int lParam;
    
    /**
     * Return value of the message.  This is the value that will be 
     * returned to Windows.
     */
    public int result;

    /**
     * Retrieves the lParam value, and converts the value to an object.  <i>cls</i> must be a 
     * class that was declared using the @dll.struct directive.
     * 
     * @param cls Class to create an instance of
     * 
     * @return Object instance of <i>cls</i> filled with the data at <i>lParam</i>.
     */
    public Object getLParam(Class cls) {}
    
    /**
     * Creates a Message object. 
     * 
     * @param hWnd   The window handle for the message.
     * @param msg    The message ID.
     * @param wParam The message wParam.
     * @param lParam The message lParam.
     * @return a Message object.
     */
    public static synchronized Message create(int hWnd, int msg, int wParam, int lParam) {}

    /**
     * Frees a Message object.   This returns the message object back to the
     * message pool for reuse.
     * 
     * @param m  The message to free.
     * @return the value of the message's <b>result</b> field.  This is
     *         the value that is typically returned to Windows.
     */
    public static synchronized int free(Message m) {}
}