//STRIPPEDSOURCE//

package com.ms.wfc.app;

/**
 * Provides a set of constants for the root keys in the system registry. Contains members representing all top level system
 * keys.
 *
 * @security(checkClassLinking=on)
 */
public class Registry {

    /**
     * Represents the HKEY_CURRENT_USER root key.
     * 
     * This key should be used as the root for all user specific settings.
     */
    public static final RegistryKey CURRENT_USER       = RegistryKey.getBaseKey(RegistryKey.HKEY_CURRENT_USER);
    
    /**
     * Represents the HKEY_LOCAL_MACHINE root key.
     * 
     * This key should be used as the root for all machine specific settings.
     */
    public static final RegistryKey LOCAL_MACHINE      = RegistryKey.getBaseKey(RegistryKey.HKEY_LOCAL_MACHINE);
    
    /**
     * Represents the HKEY_CLASSES_ROOT root key.
     * 
     * This is the root key of class information.
     */
    public static final RegistryKey CLASSES_ROOT       = RegistryKey.getBaseKey(RegistryKey.HKEY_CLASSES_ROOT);
    
    /**
     * Represents the HKEY_USERS root key.
     * 
     * This is the root of users.
     */
    public static final RegistryKey USERS              = RegistryKey.getBaseKey(RegistryKey.HKEY_USERS);
    
    /**
     * Represents the HKEY_PERFORMANCE root key.
     * 
     * This is where dynamic performance data is stored on NT.
     */
    public static final RegistryKey PERFORMANCE_DATA   = RegistryKey.getBaseKey(RegistryKey.HKEY_PERFORMANCE_DATA);
    
    /**
     * Represents the HKEY_CURRENT_CONFIG root key.
     * 
     * This is where current configuration information is stored.
     */
    public static final RegistryKey CURRENT_CONFIG     = RegistryKey.getBaseKey(RegistryKey.HKEY_CURRENT_CONFIG);
    
    /**
     * Represents the HKEY_DYN_DATA root key.
     * 
     * This is where dynamic performance data is stored on Win9X.
     */
    public static final RegistryKey DYN_DATA           = RegistryKey.getBaseKey(RegistryKey.HKEY_DYN_DATA);
}