//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.dll.*;
import com.ms.wfc.util.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Provides methods that allow you to read and write to the system registry. To get an instance of a RegistryKey use the static
 * member getBaseKey, or use the Registry class's static members.
 * 
 * @see Registry
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public final class RegistryKey {

    static final int HKEY_CLASSES_ROOT         = 0x80000000;
    static final int HKEY_CURRENT_USER         = 0x80000001;
    static final int HKEY_LOCAL_MACHINE        = 0x80000002;
    static final int HKEY_USERS                = 0x80000003;
    static final int HKEY_PERFORMANCE_DATA     = 0x80000004;
    static final int HKEY_CURRENT_CONFIG       = 0x80000005;
    static final int HKEY_DYN_DATA             = 0x80000006;

    private static final int DELETE                          = 0x00010000;
    private static final int READ_CONTROL                    = 0x00020000;
    private static final int WRITE_DAC                       = 0x00040000;
    private static final int WRITE_OWNER                     = 0x00080000;
    private static final int SYNCHRONIZE                     = 0x00100000;
    private static final int STANDARD_RIGHTS_REQUIRED        = 0x000F0000;
    private static final int STANDARD_RIGHTS_READ            = READ_CONTROL;
    private static final int STANDARD_RIGHTS_WRITE           = READ_CONTROL;
    private static final int STANDARD_RIGHTS_EXECUTE         = READ_CONTROL;
    private static final int STANDARD_RIGHTS_ALL             = 0x001F0000;
    private static final int SPECIFIC_RIGHTS_ALL             = 0x0000FFFF;
    private static final int ACCESS_SYSTEM_SECURITY          = 0x01000000;
    private static final int MAXIMUM_ALLOWED                 = 0x02000000;
    private static final int GENERIC_READ                     = 0x80000000;
    private static final int GENERIC_WRITE                    = 0x40000000;
    private static final int GENERIC_EXECUTE                  = 0x20000000;
    private static final int GENERIC_ALL                      = 0x10000000;

    private static final int KEY_QUERY_VALUE        = 0x0001;
    private static final int KEY_SET_VALUE          = 0x0002;
    private static final int KEY_CREATE_SUB_KEY     = 0x0004;
    private static final int KEY_ENUMERATE_SUB_KEYS = 0x0008;
    private static final int KEY_NOTIFY             = 0x0010;
    private static final int KEY_CREATE_LINK        = 0x0020;

    private static final int KEY_READ               =((STANDARD_RIGHTS_READ       |
                                                       KEY_QUERY_VALUE            |
                                                       KEY_ENUMERATE_SUB_KEYS     |
                                                       KEY_NOTIFY)                 
                                                      &                           
                                                      (~SYNCHRONIZE));

    private static final int KEY_WRITE              =((STANDARD_RIGHTS_WRITE      |
                                                       KEY_SET_VALUE              |
                                                       KEY_CREATE_SUB_KEY)         
                                                      &                           
                                                      (~SYNCHRONIZE));

    private static final int KEY_EXECUTE            =((KEY_READ)                   
                                                      &                           
                                                      (~SYNCHRONIZE));

    private static final int KEY_ALL_ACCESS         =((STANDARD_RIGHTS_ALL        |
                                                       KEY_QUERY_VALUE            |
                                                       KEY_SET_VALUE              |
                                                       KEY_CREATE_SUB_KEY         |
                                                       KEY_ENUMERATE_SUB_KEYS     |
                                                       KEY_NOTIFY                 |
                                                       KEY_CREATE_LINK)            
                                                      &                           
                                                      (~SYNCHRONIZE));

    
    
    

    private static final int REG_OPTION_RESERVED        = 0x00000000;    

    private static final int REG_OPTION_NON_VOLATILE    = 0x00000000;    
    

    private static final int REG_OPTION_VOLATILE        = 0x00000001;    
    

    private static final int REG_OPTION_CREATE_LINK     = 0x00000002;    
    

    private static final int REG_OPTION_BACKUP_RESTORE  = 0x00000004;    
    
    

    private static final int REG_OPTION_OPEN_LINK       = 0x00000008;    

    private static final int REG_LEGAL_OPTION           = (REG_OPTION_RESERVED            |
                                                           REG_OPTION_NON_VOLATILE        |
                                                           REG_OPTION_VOLATILE            |
                                                           REG_OPTION_CREATE_LINK         |
                                                           REG_OPTION_BACKUP_RESTORE      |
                                                           REG_OPTION_OPEN_LINK);

    
    
    

    private static final int REG_CREATED_NEW_KEY        = 0x00000001;   
    private static final int REG_OPENED_EXISTING_KEY    = 0x00000002;   


    private static final int REG_NONE                    = 0;    
    private static final int REG_SZ                      = 1;    
    private static final int REG_EXPAND_SZ               = 2;    
    
    private static final int REG_BINARY                  = 3;    
    private static final int REG_DWORD                   = 4;    
    private static final int REG_DWORD_LITTLE_ENDIAN     = 4;    
    private static final int REG_DWORD_BIG_ENDIAN        = 5;    
    private static final int REG_LINK                    = 6;    
    private static final int REG_MULTI_SZ                = 7;    
    private static final int REG_RESOURCE_LIST           = 8;    
    private static final int REG_FULL_RESOURCE_DESCRIPTOR  = 9;   
    private static final int REG_RESOURCE_REQUIREMENTS_LIST = 10; 

    
    
    
    private static final int STATE_DIRTY        = 0x0001;

    
    
    
    private static final int STATE_SYSTEMKEY    = 0x0002;

    
    
    private static final int STATE_WRITEACCESS  = 0x0004;

    
    
    private static final String hkeyNames[] = new String[] {
            "HKEY_CLASSES_ROOT",
            "HKEY_CURRENT_USER",
            "HKEY_LOCAL_MACHINE",
            "HKEY_USERS",
            "HKEY_PERFORMANCE_DATA",
            "HKEY_CURRENT_CONFIG",
            "HKEY_DYN_DATA"
            };

    private int hkey = 0;
    private int state = 0;
    private String keyName;

    
    private RegistryKey(int hkey, boolean readonly) {}

    
    private RegistryKey(int hkey, boolean readonly, boolean systemkey) {}

    /**
     * Releases all resources associated with this object. 
     */
    protected void finalize() {}

    /**
     * Closes the current key and optionally flushes the registry key back to the registry if
     * the contents have been modified. 
     *
     * @param flushCache If set to <b>true</b>, then the key is flushed to disk if
     *        modified.
     */
    public void close(boolean flushCache) {}

    /**
     * Closes the current key and optionally flushes the registry key back to the registry if
     * the contents have been modified. 
     */
    public void close() {}

    /**
     * Creates a new subkey.
     * 
     * @param subkey Name or path to subkey to create or open.
     * 
     * @return the subkey, or <b>null</b> if the operation failed.
     */
    public RegistryKey createSubKey(String subkey) {}

    /**
     * Deletes the specified subkey.  Will throw an exception if the subkey has
     * subkeys. To delete a tree of subkeys use, deleteSubKeyTree.
     *
     * @param subkey SubKey to delete.
     *
     * @throws RuntimeException thrown if the subkey has child subkeys.
     */
    public void deleteSubKey(String subkey) {}

    /**
     * Recursively deletes a subkey and any child subkeys. 
     *
     * @param subkey SubKey to delete.
     */
    public void deleteSubKeyTree(String subkey) {}

    /**
     * Deletes a value from a subkey. 
     *
     * @param name Name of value to delete.
     */
    public void deleteValue(String name) {}

    /**
     * Retrieves a new RegistryKey object that represents the requested key.  Valid
     * values are:
     *
     * HKEY_CLASSES_ROOT, 
     * HKEY_CURRENT_USER,
     * HKEY_LOCAL_MACHINE,
     * HKEY_USERS,
     * HKEY_PERFORMANCE_DATA,
     * HKEY_CURRENT_CONFIG,
     * HKEY_DYN_DATA.
     *
     * @param hKey HKEY_* to open.
     * 
     * @return the RegistryKey requested.
     */
    public static RegistryKey getBaseKey(int hKey) {}

    
    private boolean getDirty() {}

    /**
     * Retrieves the specified subkey.  If readonly is <b>true</b>, then the subkey is opened with
     * read-only access.
     * 
     * @param name Name or path of subkey to open.
     * @param readonly Set to <b>true</b> if you only need readonly access.
     * 
     * @return the Subkey requested, or <b>null</b> if the operation failed.
     */
    public RegistryKey getSubKey(String name, boolean readonly) {}

    /**
     * Retrieves the specified subkey. 
     * 
     * @param name Name or path of subkey to open.
     *  
     * @return the Subkey requested, or <b>null</b> if the operation failed.
     */
    public RegistryKey getSubKey(String name) {}

    /**
     * Retrieves the number of subkeys for a specified key.
     * 
     * @return a count of subkeys.
     */
    public int getSubKeyCount() {}

    /**
     * Retrieves an array of strings containing all the subkey names for the current key. 
     * 
     * @return all subkey names.
     */
    public String[] getSubKeyNames() {}

    /**
     * Retrieves the number of values defined in the current key. 
     * 
     * @return a count of values.
     */
    public int getValueCount() {}

    /**
     * Retrieves an array of strings containing all the value names defined for the current
     * key. 
     * 
     * @return all value names.
     */
    public String[] getValueNames() {}

    /**
     * Retrieves the specified value from the registry.  <i>defaultValue</i> is returned if the value doesn't exist.
     * 
     * @param name Name of value to retrieve.
     * @param defaultValue Value to return if <i>name</i> doesn't exist.
     * 
     * @return the data associated with the value.
     */
    public Object getValue(String name, Object defaultValue) {}

    /**
     * Retrieves the specified value from the registry.  <b>null</b> is returned if the value doesn't exist.
     * 
     * @param name Name of value to retrieve.
     * 
     * @return the data associated with the value.
     */
    public Object getValue(String name) {}

    
    private boolean getSystemKey() {}

    
    private boolean getWritable() {}

    
    private void setDirty(boolean dirty) {}

    /**
     * Sets the specified value in the registry. 
     * 
     * @param name Name of value to store data in.
     * @param value Data to store.
     */
    public void setValue(String name, Object value) {}

    /**
     * Retrieves a string representation of this key. 
     * 
     * @return a string representing the key.
     */
    public String toString() {}

    
    private void validateState(boolean needWrite) {}

    
    static class SECURITY_ATTRIBUTES {
        int nLength;
        byte[] lpSecurityDescriptor;
        int bInheritHandle;
    }

    
    private static native int RegCloseKey(int hKey);
    
    private static native int RegCreateKey(int hKey, String lpSubKey, int[] phkResult);
    
    private static native int RegCreateKeyEx(int hKey, String lpSubKey, int Reserved, String lpClass, int dwOptions, int samDesigner, SECURITY_ATTRIBUTES lpSecurityAttributes, int[] phkResult, int[] lpdwDisposition);
    
    private static native int RegDeleteKey(int hKey, String lpSubKey);
    
    private static native int RegDeleteValue(int hKey, String lpValueName);
    
    private static native int RegEnumKey(int hKey, int dwIndex, StringBuffer lpName, int cbName);
    
    private static native int RegEnumKeyEx(int hKey, int dwIndex, StringBuffer lpName, int[] lpcbName, int[] lpReserved, StringBuffer lpClass, int[] lpcbClass, long[] lpftLastWriteTime);
    
    private static native int RegEnumValue(int hKey, int dwIndex, StringBuffer lpValueName, int[] lpcbValueName, int[] lpReserved, int[] lpType, byte[] lpData, int[] lpcbData);
    
    private static native int RegFlushKey(int hKey);
    
    private static native int RegLoadKey(int hKey, String lpSubKey, String lpFile);
    
    private static native int RegOpenKey(int hKey, String lpSubKey, int[] phkResult);
    
    private static native int RegOpenKeyEx(int hKey, String lpSubKey, int ulOptions, int samDesired, int[] phkResult);
    
    private static native int RegQueryInfoKey(int hKey, StringBuffer lpClass, int[] lpcbClass, int[] lpReserved, int[] lpcSubKeys, int[] lpcbMaxSubKeyLen, int[] lpcbMaxClassLen, int[] lpcValues, int[] lpcbMaxValueNameLen, int[] lpcbMaxValueLen, int[] lpcbSecurityDescriptor, long[] lpftLastWriteTime);
    
    private static native int RegQueryValue(int hKey, String lpSubKey, StringBuffer lpValue, int[] lpcbValue);
    
    private static native int RegQueryValueEx(int hKey, String lpValueName, int[] lpReserved, int[] lpType, byte[] lpData, int[] lpcbData);
    
    private static native int RegQueryValueEx(int hKey, String lpValueName, int[] lpReserved, int[] lpType, int[] lpData, int[] lpcbData);
    
    private static native int RegQueryValueEx(int hKey, String lpValueName, int[] lpReserved, int[] lpType, char[] lpData, int[] lpcbData);
    
    private static native int RegQueryValueEx(int hKey, String lpValueName, int[] lpReserved, int[] lpType, StringBuffer lpData, int[] lpcbData);
    
    private static native int RegReplaceKey(int hKey, String lpSubKey, String lpNewFile, String lpOldFile);
    
    private static native int RegRestoreKey(int hKey, String lpFile, int dwFlags);
    
    private static native int RegSaveKey(int hKey, String lpFile, SECURITY_ATTRIBUTES lpSecuriteAttributes);
    
    private static native int RegSetValue(int hKey, String lpSubKey, int dwType, String lpData, int cbData);
    
    private static native int RegSetValueEx(int hKey, String lpValueName, int Reserved, int dwType, byte[] lpData, int cbData);
    
    private static native int RegSetValueEx(int hKey, String lpValueName, int Reserved, int dwType, int[] lpData, int cbData);
    
    private static native int RegSetValueEx(int hKey, String lpValueName, int Reserved, int dwType, int lpData, int cbData);
    
    private static native int RegSetValueEx(int hKey, String lpValueName, int Reserved, int dwType, String lpData, int cbData);
    
    private static native int RegUnLoadKey(int hKey, String lpSubKey);
}