//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.dll.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Implements a sendKeys routine that allows you to send arbitrary keys to an
 * application.
 * 
 * Each key is represented by one or more characters. To specify a single keyboard
 * character, use the character itself. For example, to represent the letter A, use 
 * "A" for string. To represent more than one character, append each additional 
 * character to the one preceding it. To represent the letters A, B, and C, use 
 * "ABC" for string.<p>
 * 
 * The plus sign (+), caret (^), percent sign (%), tilde (~), and parentheses ( )
 * have special meanings to SendKeys. To specify one of these characters, enclose 
 * it within braces ({}). For example, to specify the plus sign, use {+}. 
 * Brackets ([ ]) have no special meaning to SendKeys, but you must enclose them in 
 * braces. In other applications, brackets do have a special meaning that may be 
 * significant when dynamic data exchange (DDE) occurs. To specify brace 
 * characters, use {{} and {}}.<p>
 * 
 * To specify characters that aren't displayed when you press a key, such as ENTER 
 * or TAB, and keys that represent actions rather than characters, use the 
 * codes shown below:<p>
 * 
 * <pre>
 * Key                  Code
 * BACKSPACE            {BACKSPACE}, {BS}, or {BKSP}
 * BREAK                {BREAK}
 * CAPS LOCK            {CAPSLOCK}
 * DEL or DELETE        {DELETE} or {DEL}
 * DOWN ARROW           {DOWN}
 * END                  {END}
 * ENTER                {ENTER}or ~
 * ESC                  {ESC}
 * HELP                 {HELP}
 * HOME                 {HOME}
 * INS or INSERT        {INSERT} or {INS}
 * LEFT ARROW           {LEFT}
 * NUM LOCK             {NUMLOCK}
 * PAGE DOWN            {PGDN}
 * PAGE UP              {PGUP}
 * PRINT SCREEN         {PRTSC}
 * RIGHT ARROW          {RIGHT}
 * SCROLL LOCK          {SCROLLLOCK}
 * TAB                  {TAB}
 * UP ARROW             {UP}
 * F1                   {F1}
 * F2                   {F2}
 * F3                   {F3}
 * F4                   {F4}
 * F5                   {F5}
 * F6                   {F6}
 * F7                   {F7}
 * F8                   {F8}
 * F9                   {F9}
 * F10                  {F10}
 * F11                  {F11}
 * F12                  {F12}
 * F13                  {F13}
 * F14                  {F14}
 * F15                  {F15}
 * F16                  {F16}
 * </pre>
 * 
 * To specify keys combined with any combination of the SHIFT, CTRL, and ALT keys, 
 * precede the key code with one or more of the following codes:<p>
 * 
 * <pre>
 * Key          Code
 * SHIFT        +
 * CTRL         ^
 * ALT          %
 * </pre>
 * 
 * To specify that any combination of SHIFT, CTRL, and ALT should be held down 
 * while several other keys are pressed, enclose the code for those keys in 
 * parentheses. For example, to specify to hold down SHIFT while E and C are 
 * pressed, use "+(EC)". To specify to hold down SHIFT while E is pressed, 
 * followed by C without SHIFT, use "+EC".<p>
 * 
 * To specify repeating keys, use the form {key number}. You must put a space between 
 * key and number. For example, {LEFT 42} means press the LEFT ARROW key 42 times; 
 * {h 10} means press H 10 times.<p>
 * 
 * Note   You can't use SendKeys to send keystrokes to an application that is not 
 * designed to run in Microsoft Windows. Sendkeys also can't send the PRINT SCREEN key {
 * PRTSC} to any application.
 *
 * @security(checkClassLinking=on)
 */
public class SendKeys  {

    private static final int  HAVESHIFT = 0;
    private static final int  HAVECTRL  = 1;
    private static final int  HAVEALT   = 2;

    private static KeywordVk [] keywords = {
        new KeywordVk("ENTER",      Key.RETURN),
        new KeywordVk("TAB",        Key.TAB),
        new KeywordVk("ESC",        Key.ESCAPE),
        new KeywordVk("ESCAPE",     Key.ESCAPE),
        new KeywordVk("HOME",       Key.HOME),
        new KeywordVk("END",        Key.END),
        new KeywordVk("LEFT",       Key.LEFT),
        new KeywordVk("RIGHT",      Key.RIGHT),
        new KeywordVk("UP",         Key.UP),
        new KeywordVk("DOWN",       Key.DOWN),
        new KeywordVk("PGUP",       Key.PRIOR),
        new KeywordVk("PGDN",       Key.NEXT),
        new KeywordVk("NUMLOCK",    Key.NUMLOCK),
        new KeywordVk("SCROLLLOCK", Key.SCROLL),
        new KeywordVk("PRTSC",      Key.PRINT),
        new KeywordVk("BREAK",      Key.CANCEL),
        new KeywordVk("BACKSPACE",  Key.BACK),
        new KeywordVk("BKSP",       Key.BACK),
        new KeywordVk("BS",         Key.BACK),
        new KeywordVk("CLEAR",      Key.CLEAR),
        new KeywordVk("CAPSLOCK",   Key.CAPITAL),
        new KeywordVk("INSERT",     Key.INSERT),
        new KeywordVk("DEL",        Key.DELETE),
        new KeywordVk("DELETE",     Key.DELETE),
        new KeywordVk("HELP",       Key.HELP),
        new KeywordVk("F1",         Key.F1),
        new KeywordVk("F2",         Key.F2),
        new KeywordVk("F3",         Key.F3),
        new KeywordVk("F4",         Key.F4),
        new KeywordVk("F5",         Key.F5),
        new KeywordVk("F6",         Key.F6),
        new KeywordVk("F7",         Key.F7),
        new KeywordVk("F8",         Key.F8),
        new KeywordVk("F9",         Key.F9),
        new KeywordVk("F10",        Key.F10),
        new KeywordVk("F11",        Key.F11),
        new KeywordVk("F12",        Key.F12),
        new KeywordVk("F13",        Key.F13),
        new KeywordVk("F14",        Key.F14),
        new KeywordVk("F15",        Key.F15),
        new KeywordVk("F16",        Key.F16),
        new KeywordVk("MULTIPLY",   Key.MULTIPLY),
        new KeywordVk("ADD",        Key.ADD),
        new KeywordVk("SUBTRACT",   Key.SUBTRACT),
        new KeywordVk("DIVIDE",     Key.DIVIDE),
		new KeywordVk("+",          Key.ADD),
		new KeywordVk("%",          Key.D5 | Key.SHIFT),
		new KeywordVk("^",          Key.D6 | Key.SHIFT),
    };

    static final int  SHIFTKEYSCAN  = 0x0100;
    static final int  CTRLKEYSCAN   = 0x0200;
    static final int  ALTKEYSCAN    = 0x0400;
    
    
    static boolean stopHook;
    
    
    static int hookProcRoot;
    
    
    static int hhook;
    
    
    static List events;
    
    static boolean fStartNewChar;
    
    
    private SendKeys() {}
    
    
    private static void addEvent(SKEvent event) {}
    
    
    private static void addMsgsForVK(int vk, int repeat, boolean altnoctrldown) {}
    
    
    private static void cancelMods(int [] haveKeys, int level) {}
    
    
    private static void installHook() {}
    
    
    static void journalCancel() {}
    
    static byte[] getKeyboardState() {}

    static void setKeyboardState(byte[] keystate) {}

    
    static void clearKeyboardState() {}
    
    
    private static int matchKeyword(String keyword) {}
    
    
    private static void parseKeys(String keys) {}
    
    /**
     * Sends keystrokes to the active application.  
     *
     * @param key The string of keystrokes to send.
     */
    public static void sendKeys(String keys) {}
    
    /**
     * Sends the given keys to the active application, and then waits for
     * the messages to be processed.
     *
     * @param keys The string of keystrokes to send.
     */
    public static void sendKeysWait(String keys) {}
    
    
    static void uninstallJournalingHook() {}
}


class SKEvent {
    int wm;
    int paramL;
    int paramH;
    
    public SKEvent(int a, int b, boolean c) {}
}


class KeywordVk {
    String keyword;
    int    vk;
    
    public KeywordVk(String key, int v) {}
}


class SendKeysHookProc extends Callback {

    public int callback(int code, int wparam, int lparam) {}
}