//STRIPPEDSOURCE//
package com.ms.wfc.app;

import com.ms.wfc.win32.*;
import com.ms.wfc.util.*;
import com.ms.wfc.core.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.com.*;
import com.ms.wfc.io.*;

/**
 * Represents an element of time.
 * 
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public class Time implements IConstructable, IPersistable
{
    /**
     * Specifies the number of time units (100 nanoseconds) per millisecond.
     */
    public static final long UNITS_PER_MILLISECOND = 10000;
    /**
     * Specifies the number of time units (100 nanoseconds) units per second.
     */
    public static final long UNITS_PER_SECOND = UNITS_PER_MILLISECOND * 1000;
    /**
     * Specifies the number of time units (100 nanoseconds) units per minute.
     */
    public static final long UNITS_PER_MINUTE = UNITS_PER_SECOND * 60;
    /**
     * Specifies the number of time units (100 nanoseconds) per hour.
     */
    public static final long UNITS_PER_HOUR = UNITS_PER_MINUTE * 60;
    /**
     * Specifies the number of time units (100 nanoseconds) per day.
     */
    public static final long UNITS_PER_DAY = UNITS_PER_HOUR * 24;

    
    private static final long MILLIS_PER_DAY = UNITS_PER_DAY  10000;


    private static final long MIN_YEAR = 100;
    private static final long MAX_YEAR = 10000;
    
    private static final long DAYS_TO_1601 = 548229;
    private static final long DAYS_TO_1899 = 657434;
    private static final long DAYS_TO_10000 = 3615900;

    private static final long FILETIME_OFFSET = DAYS_TO_1601 * UNITS_PER_DAY;
    private static final long DOUBLE_OFFSET = DAYS_TO_1899 * UNITS_PER_DAY;

    public static final long MIN_UNITS = 0;
    public static final long MIN_SYSTEM_UNITS = FILETIME_OFFSET;
    public static final long MAX_UNITS = DAYS_TO_10000 * UNITS_PER_DAY - 1;

    private static final double MIN_DOUBLE = -657434.0;
    private static final double MAX_DOUBLE = 2958466;

    
    private static final int VAR_TIMEVALUEONLY = 0x00000001;
    private static final int VAR_DATEVALUEONLY = 0x00000002;
    private static final int VAR_VALIDATE      = 0x00000004;

    private static UDATE tempDate = new UDATE();
    private static long[] tempLong = new long[1];
    private static long[] tempLong2 = new long[1];
    private static double[] tempDouble = new double[1];

    private final long time;

    /**
     * Creates a new Time. This time will contain the current local time.
     */
    public Time() {}

    /**
     * Creates a new Time. This time will contain the time stored in the stream.
     *
     * @param stream Stream to depersist from.
     */
    public Time(IDataStream stream) {}    

    /**
     * Creates a new Time. This time will contain the same logical time as the
     * OLE formatted double value.
     *
     * @param d OLE formatted time value.
     */
    public Time(double d) {}

    /**
     * Creates a new Time. This time will contain the specified time.
     *
     * @param units Time value to store in the new Time object.
     */
    public Time(long units) {}

    /**
     * Creates a new Time. This time will contain the same value as <i>t</i>.
     *
     * @param t Time object to clone.
     */
    public Time(Time t) {}

    /**
     * Creates a new Time. This time will contain the same logical time as the
     * SYSTEMTIME value.
     *
     * @param st SYSTEMTIME structure to set this time to.
     */
    public Time(SYSTEMTIME st) {}

    /**
     * Creates a new Time. This time will contain the time value that is in
     * the string <i>s</i>.
     *
     * @param s String to parse.
     */
    public Time(String s) {}

    /**
     * Creates a new Time. This time will contain the date 
     * <i>day</i>/<i>month</i>/<i>year</i>. The time will be set to 12:00 
     * midnight.
     *
     * @param year Year to set this time to.
     * @param month Month to set this time to.
     * @param day Day to set this time to.
     */
    public Time(int year, int month, int day) {}

    /**
     * Creates a new Time. This time will contain the date 
     * <i>day</i>/<i>month</i>/<i>year</i>. The time will be set to 
     * <i>hour</i>:<i>min</i>:<i>sec</i>.
     *
     * @param year Year to set this time to.
     * @param month Month to set this time to.
     * @param day Day to set this time to.
     * @param hour Hour to set this time to, in 24 hour format.
     * @param min Minute to set this time to.
     * @param sec Second to set this time to.
     */
    public Time(int year, int month, int day, int hour, int min, int sec) {}

    /**
     * Creates a new Time. This time will contain the same logical time as the 
     * variant <i>v</i>.
     *
     * @param v Variant to set this time to.
     */
    public Time(Variant v) {}

    /**
     * Creates a new Time object that represents the number of time units
     * (100 nanoseconds) after the time that this Time object represents.  
     * 
     * @param interval Number of hundred nanosecond units to add to the current
     *        time
     * 
     * @return a Time object representing the new time.
     */
    public Time add(long interval) {}

    /**
     * Creates a new Time object that represents the number of days after the
     * time that this Time object represents. 
     * 
     * @param interval Number of days to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addDays(double interval) {}

    /**
     * Creates a new Time object that represents the number of days after the
     * time that this Time object represents. 
     * 
     * @param interval Number of days to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addDays(int interval) {}

    /**
     * Creates a new Time object that represents the number of hours after
     * the time that this Time object represents. 
     * 
     * @param interval Number of hours to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addHours(long interval) {}

    /**
     * Creates a new Time object that represents the number of milliseconds
     * after the time that this Time object represents. 
     * 
     * @param interval Number of milliseconds to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addMillis(long interval) {}

    /**
     * Creates a new Time object that represents the number of minutes after
     * the time that this Time object represents. 
     * 
     * @param interval Number of minutes to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addMinutes(long interval) {}

    /**
     * Creates a new Time object that represents the number of months after
     * the time that this Time object represents. 
     * 
     * @param interval Number of months to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addMonths(int interval) {}

    /**
     * Creates a new Time object that represents the number of seconds after
     * the time that this Time object represents. 
     * 
     * @param interval Number of seconds to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addSeconds(long interval) {}

    /**
     * Creates a new Time object that represents the number of years after
     * the time that this Time object represents. 
     * 
     * @param interval Number of years to add to the current time.
     * 
     * @return a Time object representing the new time.
     */
    public Time addYears(int interval) {}

    
    private static String bstrToString(int bstr) {}

    
    private Time combine(long date, long timeOfDay) {}

    /**
     * Compares two Time objects.  1 is returned if <i>t1</i> is greater
     * that <i>t2</i>, 0 is returned if the two times are equal, and
     * -1 is returned if <i>t2</i> is greater that <i>t1</i>.
     * 
     * @param t1 Time to compare
     * @param t2 Time to compare
     * 
     * @return 1, 0, or -1
     */
    public static int compare(Time t1, Time t2) {}

    /**
     * Compares this Time object to another Time object. 
     * @param t Time object to compare to.
     * 
     * @return 1, 0, or -1
     * 
     * @see #compare
     */
    public int compareTo(Time t) {}

    /**
     * Tests for equality.
     * 
     * @param object Object to compare to
     * 
     * @return <b>true</b> if the <i>object</i> is a Time object that represents
     *         the same time as this time object.
     */
    public boolean equals(Object object) {}

    
    private String format(int fmt) {}

    /**
     * Retrieves the Time object as a String using the long
     * date format. 
     * 
     * @return formatted string representing this time.
     */
    public String formatLongDate() {}

    /**
     * Retrieves the Time object as a String using the long
     * time format.
     * 
     * @return formatted string representing this time.
     */
    public String formatLongTime() {}

    /**
     * Retrieves the Time object as a String using the short
     * date format.
     * 
     * @return formatted string representing this time.
     */
    public String formatShortDate() {}

    /**
     * Retrieves the Time object as a String using the short
     * time format.
     * 
     * @return formatted string representing this time.
     */
    public String formatShortTime() {}

    /**
     * Creates a Time object based on the specified value.  <i>fileTime</i>
     * must be formatted as a Win32 FILETIME, meaning that <i>fileTime</i>
     * should contain the number of hundred nanosecond units elapsed since
     * Jan 1, 1601, in UTC. This will adjust the base time, and convert the
     * time to Local time.
     * 
     * @param fileTime Win32 FILETIME to create a new Time for.
     * 
     * @return new Time object representing <i>fileTime</i>
     */
    public static Time fromFileTime(long fileTime) {}

    /**
     * @internalonly
     */
    public ConstructorArg[] getConstructorArgs() {}

    
    private static long getCurrentTime() {}

    /**
     * Creates a Time object that represents the same date as this Time
     * object but without a time of day specified. 
     * 
     * @return a new Time object with the date of this time object.
     */
    public Time getDate() {}

    /**
     * Retrieves the day of the month that this Time object represents.  This
     * number will always be between 1 and 31.
     * 
     * @return day of month
     */
    public int getDay() {}

    /**
     * Retrieves the day of the week that this Time object represents.  This
     * number will always be between 1 and 7.
     * 
     * @return day of week
     */
    public int getDayOfWeek() {}

    /**
     * Retrieves the day of the year that this Time object represents.  This
     * number will always be between 1 and 366.
     * 
     * @return day of year
     */
    public int getDayOfYear() {}

    /**
     * @internalonly
     */
    public String getExtension() {}    

    /**
     * Retrieves the hour of the day that this Time object represents.  This
     * number will always be between 0 and 23.
     * 
     * @return hour of day
     */
    public int getHour() {}

    /**
     * Retrieves the milliseconds of the second that this Time object
     * represents.  This number will always be between 0 and 999.
     * 
     * @return millisecond of the second
     */
    public int getMillis() {}

    /**
     * Retrieves the minutes of the hour that this Time object represents. This
     * number will always be between 0 and 59.
     * 
     * @return minute of the hour
     */
    public int getMinute() {}

    /**
     * Retrieves the month of the year that this Time object represents.  This
     * number will always be between 1 and 12.
     * 
     * @return month of year
     */
    public int getMonth() {}

    /**
     * Retrieves the seconds of the minute that this Time object represents.  This
     * number will always be between 0 and 59.
     * 
     * @return second of minute
     */
    public int getSecond() {}

    /**
     * Creates a Time object that represents the same time of day as this Time
     * object, but without a date specified. 
     * 
     * @return a new Time object with the time of day of this time object.
     */
    public Time getTimeOfDay() {}

    /**
     * Retrieves the year that this Time object represents.  This
     * number will always be between 100 and 10000.
     * 
     * @returnyear
     */
    public int getYear() {}

    /**
     * @internalonly
     */
    public int hashCode() {}

    
    private static short intToWord(int value) {}

    private static void removeString(char[] upper, char[] work, String remove) {}

    public void save(IDataStream stream) {}

    /**
     * Creates a new Time object that contains the date from another Time
     * object and the time of day from this Time object. 
     * 
     * @param date Time object to retrieve the date from.
     * 
     * @return a new time object with the requested date and time.
     */
    public Time setDate(Time date) {}

    
    private static void setTempDate(long time) {}

    /**
     * Creates a new Time object that contains the date from this Time
     * object and the time of day from another Time object. 
     * 
     * @param timeOfDay Time object to retrieve the time of day from.
     * 
     * @return a new time object with the requested date and time.
     */
    public Time setTimeOfDay(Time timeOfDay) {}

    
    private static long timeFromDouble(double value) {}

    
    private static long timeFromTempDate() {}

    
    private static double timeToDouble(long value) {}

    
    private static long timeToLocalTime(long value) {}

    
    private static long timeToUniversalTime(long value) {}

    /**
     * Retrieves the Time object as an OLE-formatted double
     * value. 
     * 
     * @return an OLE formatted double value that represents this time.
     */
    public double toDouble() {}

    /**
     * Retrieves the Time object as a Win32 FILETIME value. 
     * 
     * @return a Win32 FILETIME value that represents this time.
     */
    public long toFileTime() {}

    /**
     * Retrieves this Time object as a Win32 SYSTEMTIME
     * structure. 
     * 
     * @return a Win32 SYSTEMTIME structure that represents this time.
     */
    public SYSTEMTIME toSystemTime() {}

    /**
     * Creates a Time object that represents this Time
     * object in the user's local time zone. 
     * 
     * @return a new time object that represents this time in the user's
     *          local time zone.
     */
    public Time toLocalTime() {}

    /**
     * Retrieves the number of time units (100 nanoseconds) units that are stored in this Time
     * object. 
     * 
     * @return the number of hunderd nanosecond units since Jan 1, 100 AD
     */
    public long toLong() {}

    /**
     * Retrieves this Time object as a String object. 
     * 
     * @return formatted string representing this time.
     */
    public String toString() {}

    /**
     * Creates a new Time object that represents this Time
     * object in the coordinated universal time (UTC) time zone. 
     * 
     * @return a new time object that represents this time in the UTC
     *          time zone.
     */
    public Time toUniversalTime() {}

    /**
     * Retrieves this Time object as a com.ms.com.Variant object.
     * 
     * 
     * @return a Variant that represents this time.
     */
    public Variant toVariant() {}

    /**
     * Represents an element of time.
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    public static class ArrayEditor extends com.ms.wfc.core.ArrayEditor {
        public ArrayEditor(Class type) {}

        public int getStyle(){}
    }

    /**
     * Represents an element of time.
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends ValueEditor {
        public int getStyle(){}
        
        /**
         * Given an object, retrieves a text description of 
         * it.
         * 
         * @param value The object to get a string representation of.
         * @return a string representing <i>value</i>.
         * 
         * @see com.ms.wfc.core.IValueEditor#getTextFromValue
         */
        public String getTextFromValue(Object value) {}
    
        /**
         * Given a string describing a time value, creates a new Time object
         * representing the value encoded in the string.
         * 
         * @param time The textual time representation.
         * @return an object representing <i>text</i>.
         * 
         * @see com.ms.wfc.core.IValueEditor#getValueFromText
         */
        public Object getValueFromText(String text) {}
    }

    
    static class UDATE {
        short wYear;
        short wMonth;
        short wDayOfWeek;
        short wDay;
        short wHour;
        short wMinute;
        short wSecond;
        short wMilliseconds;
        short wDayOfYear;
    }

    
    private static native boolean FileTimeToSystemTime(long[] filetime, SYSTEMTIME time);
    
    private static native boolean SystemTimeToFileTime(SYSTEMTIME time, long[] filetime);
    
    private static native boolean FileTimeToLocalFileTime(long[] fileTime, long[] localFileTime);
    
    private static native void GetSystemTimeAsFileTime(long[] fileTime);
    
    private static native boolean LocalFileTimeToFileTime(long[] localFileTime, long[] fileTime);
    
    private static final native int SysFreeString(int bstr);
    
    private static final native int VarBstrFromDate(double dateIn, int lcid, int dwFlags, int[] pbstrOut);
    
    private static native int VarDateFromStr(String in, int lcid, int dwFlags, double[] date);
    
    private static native int VarDateFromUdateEx(UDATE pudateIn, int lcid, int dwFlags, double[] pdateOut);
    
    private static native int VarFormatDateTime(Variant v, int format, int flags, int[] s);
    
    private static native int VarUdateFromDate(double dateIn, int dwFlags, UDATE pudateOut);
}