//STRIPPEDSOURCE//

package com.ms.wfc.app;

import com.ms.dll.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Provides a low-level encapsulation of a window handle and a window procedure.  The class supports creation, subclassing, and
 * superclassing of windows, and automatically manages window class
 * creation and registration.
 *
 * Following creation of a Window object, a window handle can be created using
 * the createHandle() method. Alternatively, the assignHandle() method can be
 * used to subclass an existing window handle. The window handle is destroyed
 * using the destroyHandle() method. Alternatively, the releaseHandle() method
 * can be used to un-subclass the handle. In addition, a Window automatically
 * calls the releaseHandle() method if it receives a WM_NCDESTROY window
 * message, indicating that Windows has destroyed the handle.
 *
 * A Window object is not eligible for garbage collection when it is associated
 * with a window handle. To ensure proper garbage collection, handles must
 * manually be destroyed using the destroyHandle() method or the DestroyWindow()
 * Windows API function, or released using the releaseHandle() method.
 *
 * @security(checkClassLinking=on)
 */
public class Window extends Callback
{
    private static int handleCount;
    private static int windowAtom;

    private int handle;
    private int root;
    private int defWindowProc;

    /**
     * Assigns a handle to a Window object. The given handle is subclassed such
     * that any window messages sent to the handle are intercepted by the
     * wndProc() method. The handle can later be un-subclassed using the
     * releaseHandle() method, in effect restoring the handle's window
     * procedure to its former value. The assignHandle() method calls the
     * onHandleChange() method to indicate that the value of the Handle
     * property has changed. An exception is raised if this Window already has
     * a handle.
     * 
     * @param handle The handle to assign to this object.
     * 
     * @see #wndProc
     * @see #releaseHandle
     * @see #onHandleChange
     */
    public void assignHandle(int handle) {}

    /**
     * Window message callback method. Control arrives here when a window
     * message is sent to this Window. This method packages the window message
     * in a Message object and invokes the wndProc() method. A WM_NCDESTROY
     * message automatically causes the releaseHandle() method to be called.
     * @internalonly
     * 
     * @param hWnd The hWnd of the message.
     * @param msg  The message ID.
     * @param wParam The wParam of the message.
     * @param lParam The lParam of the message.
     */
    public int callback(int hWnd, int msg, int wParam, int lParam) {}

    
    private void checkReleased() {}

    /**
     * Creates a window handle for this Window object.  The CreateParams object
     * specifies the parameter values that are passed to the CreateWindowEx
     * Windows API function. A non-null value in the className field of the
     * CreateParams object indicates that the newly created window handle
     * should subclass the given window class. For example, if className is
     * set to "BUTTON", the newly created window handle will be a subclass of
     * the BUTTON class defined by Windows. The param field of the CreateParams
     * object must be either <b>null</b> or reference an instance of a class that was
     * declared using the @dll.struct directive.
     * 
     * @param cp The creation parameters for this window.
     * @see com.ms.wfc.ui.CreateParams
     */
    public void createHandle(CreateParams cp) {}

    /**
     * Invokes the default window procedure associated with this Window
     * object.  It is
     * an error to call this method when the Handle property is zero.
     * 
     * @param m The message that is currently being processed.
     */
    protected void defWndProc(Message m) {}

    /**
     * Destroys the handle associated with a Window object.  The Handle property is
     * set to zero by destroyHandle(), and the onHandleChange() method is
     * called to reflect the change.
     * 
     * @see #onHandleChange
     */
    public void destroyHandle() {}

    
    static final void disposeWindowClassCache() {}
    
    /**
     * Retrieves the Window object associated with the specified handle.  
     * 
     * @return the Window object associated with the givenhandle.  This will
     *         be <b>null</b> if the handle does not have an associated Window
     *         object.
     */
    public static Window fromHandle(int handle) {}

    /**
     * Retrieves the handle of the Window object.  A return value of zero indicates that
     * no handle is currently associated with the Window.
     * 
     * @return the window handle, or zero if no handle is associated with this
     *         Window object.
     */
    public final int getHandle() {}

    /**
     * Specifies a notification method that is called whenever the handle for a window is
     * changed.  This method is invoked whenever the
     * value of the Handle property has changed. Subclasses of Window can
     * override this method to track changes to the handle.
     */
    protected void onHandleChange() {}

    /**
     * Releases the handle associated with the Window object.  This method does not
     * destroy the Window's handle. Instead, it sets the handle's window
     * procedure to the default window procedure, in effect un-subclassing the
     * window handle. The Handle property is set to zero by releaseHandle(),
     * and the onHandleChange() method is called to reflect the change.
     * 
     * @see #onHandleChange
     */
    public void releaseHandle() {}

    /**
     * Specifies the window procedure for the Window object. This method is invoked when a window message is sent
     * to the Window's handle. Subclasses of Window can override this method to
     * implement specific message processing. The Message object contains the
     * window handle (hWnd), the window message (msg), and the two message
     * parameters (wParam and lParam). The window procedure result is set by
     * modifying the result field in the Message object. The default result is
     * zero.
     *
     * When overriding wndProc(), always call super.wndProc() for any unhandled
     * messages.
     * 
     * @param m The Message object associated with the current Windows message.
     * 
     * @see Message
     */
    protected void wndProc(Message m) {}

    
    private static class WindowClass extends Callback
    {
        static WindowClass cache;

        WindowClass next;
        String className;
        int classStyle;
        String windowClassName;
        int hashCode;
        int defWindowProc;
        int root;
        boolean registered;
        Window targetWindow;

        WindowClass(String className, int classStyle) {}

        public int callback(int hWnd, int msg, int wParam, int lParam) {}

        
        static synchronized WindowClass create(String className, int classStyle) {}

        
        static synchronized void disposeCache() {}
        
                
        private void registerClass() {}
        
        
        private void unregisterClass() {}
    }
}