//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * BindableAttribute is an attribute that marks a property as
 * interesting to data bind to.  Data binders, when inspecting
 * a new object, will usually present to the user properties
 * marked as BindableAttribute.YES only.  When overriding a property
 * marked as bindable, a user can pass in BindableAttribute.NO to
 * remove the bindable marking.
 * <p>
 * By default, properties are only bound to in a read-only fashion.
 * To make property foo bindable as a read-write property, create an
 * event named fooChanged and fire it whenever the foo property changes.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see EventInfo
 *
 * @security(checkClassLinking=on)
 */
public class BindableAttribute extends MemberAttribute { 
    
    private BindableAttribute() {}

    /**
     * This is the attribute that marks a property as interesting to bind to.
     */
    public static final BindableAttribute YES = new BindableAttribute();
    
    /**
     * This is the attribute that marks a property as not interesting to bind to.
     */
    public static final BindableAttribute NO = new BindableAttribute();
    
    /**
     * This is the default attribute (maps to NO).
     */
    public static final BindableAttribute DEFAULT = NO;

    /**
     * @internalonly
     */
    public boolean isDefaultAttribute() {}
}