//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * BrowsableAttribute is an attribute that marks a property, event, or 
 * extender as interesting to modify at design time.  Visual designers, when 
 * looking at members to visually display, will usually present to the user
 * members that have no Browsable marking or BrowsableAttribute.YES.
 * To mark a member as not applicable to design time editing, pass 
 * BrowsableAttribute.NO into the constructor.  When overriding a member marked 
 * as not browsable, a user can pass in BrowsableAttribute.YES to make it 
 * browsable.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see EventInfo
 * @see ExtenderInfo
 *
 * @security(checkClassLinking=on)
 */
public class BrowsableAttribute extends MemberAttribute { 

    
    private BrowsableAttribute() {}

    /**
     * Marks a property, extender, or event as interesting to browse at design time.
     */
    public static final BrowsableAttribute YES = new BrowsableAttribute();
    
    /**
     * Marks a property, extender, or event as not interesting to browse at design time.
     */
    public static final BrowsableAttribute NO = new BrowsableAttribute();
    
    /**
     * The default marking. (equal to YES.)
     */
    public static final BrowsableAttribute DEFAULT = YES;

    /**
     * @internalonly
     */
    public boolean isDefaultAttribute() {}
}