//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * CategoryAttribute is an attribute that marks a property, event, or extender
 * as belonging to the given member.  Visual designers can use categories as 
 * a way of organizing members into groups of similar behavior.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see EventInfo
 * @see ExtenderInfo
 *
 * @security(checkClassLinking=on)
 */
public class CategoryAttribute extends MemberAttribute { 
    
    /**
     * This category marks properties having to do with Appearance.
     */
    public static final CategoryAttribute Appearance = new CategoryAttribute("Appearance");
    
    /**
     * This category marks properties having to do with Position.
     */
    public static final CategoryAttribute Position = new CategoryAttribute("Position");
    
    /**
     * This category marks properties having to do with Behavior.
     */
    public static final CategoryAttribute Behavior = new CategoryAttribute("Behavior");
    
    /**
     * This category marks properties having to do with data.
     */
    public static final CategoryAttribute Data = new CategoryAttribute("Data");
    
    /**
     * This category marks properties having to do with Actions.
     */
    public static final CategoryAttribute Action = new CategoryAttribute("Action");
    
    /**
     * This category marks properties having to do with the mouse.
     */
    public static final CategoryAttribute Mouse = new CategoryAttribute("Mouse");
    
    /**
     * This category marks properties having to do with the keyboard.
     */
    public static final CategoryAttribute Key = new CategoryAttribute("Key");
    
    /**
     * This category marks properties having to do with focus.
     */
    public static final CategoryAttribute Focus = new CategoryAttribute("Focus");
    
    /**
     * This category marks properties having to do with drag-drop.
     */
    public static final CategoryAttribute DragDrop = new CategoryAttribute("DragDrop");

    /**
     * This is the actual category string.
     */
    public final String category;

    /**
     * Constructs a new category.
     * 
     * @param category string that represents the name of the category.
     */
    public CategoryAttribute(String category) {}

    /**
     * Retrieves the category name.
     * 
     * @return category name.
     */
    public String getCategory() {}
    
    /**
     * @internalonly
     */
    public boolean isDefaultAttribute() {}
}