//STRIPPEDSOURCE//
package com.ms.wfc.core;

import com.ms.wfc.io.*;
import com.ms.wfc.ui.*;

/**
 * Provides metadata for a component.  If a component does not choose to
 * extend any of it's superclasses ClassInfo's, it should extend this one
 * simply to guarantee any future default ClassInfo behavior will be captured.
 * 
 * @see IClassInfo
 *
 * @security(checkClassLinking=on)
 */
public class ClassInfo implements IClassInfo
{
    /**
     * Specifies the attributes of the component class. 
     * 
     * @param attributes The attribute gathering class.
     * 
     * @see IClassInfo
     */
    public void getAttributes(IAttributes attributes)
    {}

    /**
     * Retrieves the customizer of the specified component.  This
     * may be null.
     * 
     * @param component object to get the customizer for.
     * @return the customizer for the class.
     *  
     * @see IClassInfo
     */
    public ICustomizer getCustomizer(Object component)
    {}

    /**
     * Retrieves the name of the default event of the component class. 
     * This may be null.
     * 
     * @return null.
     * 
     * @see IClassInfo 
     */
    public String getDefaultEventName()
    {}    

    /**
     * Retrieves the name of the default property of the component class. 
     * 
     * @return null.
     * 
     * @see IClassInfo
     */
    public String getDefaultPropertyName()
    {}

    /**
     * Specifies the events of the component class. 
     * 
     * @param events The events collection.
     * 
     * @see IClassInfo
     */
    public void getEvents(IEvents events)
    {}

    /**
     * Specifies the extender properties of the component class. 
     * 
     * @param extenders The extenders collection.
     * 
     * @see IClassInfo
     */
    public void getExtenders(IExtenders extenders)
    {}

    /**
     * Specifies the properties of the component class. 
     * 
     * @param extenders The properties collection.
     * 
     * @see IClassInfo
     */
    public void getProperties(IProperties props)
    {}

    /** 
     * Retrieves the image that is used to represent the component in toolboxes, list views,
     * and so on. bmp and try to instantiate a Bitmap
     * object from that file, returning it if we are successful.
     * 
     * @returns the bitmap for the class.
     * 
     * @see IClassInfo
     */
    public Bitmap getToolboxBitmap()
    {}
}