//STRIPPEDSOURCE//
package com.ms.wfc.core;


import com.ms.wfc.io.*;
import com.ms.lang.Delegate;


/**
 * Represents the base class for all components. A component can be hosted in a container. For each 
 * component in a container, the container creates a site that it uses to manage 
 * the component.
 *
 * @security(checkClassLinking=on)
 */
public class Component implements IComponent, IResourceLoader { 
    private static final Object EVENT_DISPOSE = new Object();

    IComponentSite site;
    EventEntry eventList;

    /**
     * Creates a Component object.
     */
    public Component() {}

    protected synchronized void addEventHandler(Object key, Delegate handler) {}

    /**
     * Assigns a delegate to the dispose event. The dispose event occurs when the 
     * component is disposed of through the dispose method. Components that maintain 
     * references to other components must register dispose event handlers for the 
     * referenced components so that the references can be cleared when the components 
     * are disposed of. 
     *
     * @param value The EventHandler to be notified when the event occurs.
     */
    public void addOnDispose(EventHandler value) {}

    /**
     * Appends the event handlers of the component passed in as a parameter, to this
     * component's event handler list.
     * 
     * @param   comp  Component containing the event handler list to be added to this 
     * component.
     */
    protected synchronized void appendEventHandlers(Component comp) {}

    /**
     * Specifies that the component has changed.  A component's customizer should 
     * call this method when it changes a property of the component; this ensures a 
     * property browser will display the updated property.
     */
    public synchronized void componentChanged() {}

    /**
     * Disposes of the component.  Call dispose when the component is no longer needed. 
     * This method removes the component from its container (if the component has a site) 
     * and triggers the dispose event. 
     */
    public synchronized void dispose() {}

    protected void fireEvent(Object key, Event e) {}

    /**
     * Returns the component's container.  
     *
     * @return an object implementing the IContainer interface that represents the 
     * component's container. If the component does not have a site, null is returned.
     */
    public synchronized IContainer getContainer() {}

    protected synchronized Delegate getEventHandler(Object key) {}

    /**
     * Retrieves the name of the component that is maintained by the site.
     *
     * @return the component name held by the component's site. If the 
     * component does not have a site, null is returned.
     */
    public synchronized String getName() {}

    /**
     * Retrieves a named resource.  
     *
     * @param The name of the resource to be retrieved. 
     *
     * @return an object implementing the IDataStream interface that contains 
     * the resource. If no resource with the specified name is found, null is 
     * returned. 
     */
    public IDataStream getResource(String name) {}

    /**
     * Retrieves a service provided by the site.  
     * 
     * @param service An interface that represents the service. 
     *
     * @return an object that implements the specified interface. If the site 
     * does not support this service, or if the component does not have a site, 
     * null is returned.
     */
    public synchronized Object getService(Class service) {}

    /**
     * Retrieves the site of the component.  
     *
     * @return an object implementing the IComponentSite interface that represents 
     * the component's site.
     */
    public IComponentSite getComponentSite() {}

    /**
     * Determines whether this component is a child of the specified component.  
     *
     * @return true if this component is a child of component; otherwise, returns false.
     */
    public boolean getChildOf(IComponent component) {}

    /**
     * Determines whether the component is currently in design mode.  
     *
     * @return true if the component is in design mode; otherwise, returns false. (If 
     * the component does not have a site, this method always returns false.)
     */
    public synchronized boolean getDesignMode() {}

    /**
     * Determines whether the component is currently being disposed of.  
     *
     * @return true if the component is being disposed of; otherwise, returns false.
     */
    public synchronized boolean getDisposing() {}

    /**
     * Triggers the dispose event.  The dispose event occurs when the component 
     * is disposed of through the dispose method. When overriding onDispose, be sure 
     * to call super.onDispose.
     *
     * @param e An Event object. 
     * @see addOnDispose, removeOnDispose
     */
    protected void onDispose(Event e) {}

    protected synchronized void removeEventHandler(Object key, Delegate handler) {}

    protected void removeEventHandlers() {}

    /**
     * Removes the delegate that is assigned to the dispose event.
     *
     * @param value The EventHandler delegate to be removed. 
     */
    public void removeOnDispose(EventHandler value) {}

    /**
     * Sets the name of the component that is maintained by the site.  
     * WFCException thrown if the component does not have a site.
     * 
     * @param value The component name held by the component's site. 
     */
    public synchronized void setName(String value) {}

    /**
     * Sets the site of the component.  
     * 
     * @param value An object implementing the IComponentSite interface that 
     * represents the component's site. A non-null value indicates that the 
     * component has been added to a container; a null value indicates that 
     * the component is being removed from a container. 
     */
    public void setComponentSite(IComponentSite value) {}

    /**
     * Basic Implementation of toString() for all controls.
     * @internalonly
     * @hidden
     */
    public String toString() {}

    
    private static final class EventEntry { 
        EventEntry next;
        Object key;
        Delegate handler;

        EventEntry(EventEntry next, Object key, Delegate handler) {}
    }


    /**
     * Represents the base class for all components.
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends com.ms.wfc.core.ClassInfo { 
        
        public void getAttributes(IAttributes attrs) {}
    }
}