//STRIPPEDSOURCE//

package com.ms.wfc.core;

import com.ms.wfc.util.*;

/**
 * Contains information about a component, including its properties, events, extenders,  and attributes.   It should be obtained through the 
 * ComponentManager's  getComponentInfo().
 * 
 * @see ComponentManager
 * @see PropertyInfo
 * @see EventInfo
 * @see ExtenderInfo
 * @see IClassInfo
 * @see MemberAttribute
 *
 * @security(checkClassLinking=on)
 */
public final class ComponentInfo { 
    Class componentClass;
    IClassInfo classInfo;
    PropertyInfo[] properties;
    EventInfo[] events;
    ExtenderInfo[] extenders;
    MemberAttribute[] attributes;

    
    ComponentInfo(Class componentClass, IClassInfo classInfo) {}

    
    MemberInfo[] filterMembers(Class infoType, MemberInfo[] infos, MemberAttribute[] attributes) {}

    /** 
     * Retrieves the attributes that were specified in the component's ClassInfo.
     * 
     * 
     * @return attributes The class level attributes.
     * 
     * @see IClassInfo.getAttributes 
     */
    public MemberAttribute[] getAttributes() {}
    
    /** 
     * Retrieves the attributes that were specified in the component's ClassInfo.
     *   For a class attribute to 
     * satisfy a particular attribute, the attribute must be present in the
     * class's attribute list, or the attribute must match it's own default.
     * 
     * @return attributes The class level attributes that match the given list.
     * 
     * @see IClassInfo.getAttributes 
     */
    public MemberAttribute[] getAttributes(MemberAttribute[] attributes) {}

    /**
     * Retrieves the ClassInfo of the component. 
     * 
     * @return IClassInfo The class info for this type of component.
     * 
     * @see IClassInfo
     */
    public IClassInfo getClassInfo() {}

    /**
     * Contains information about a component, including its properties, events, extenders,  and attributes. 
     * 
     * @return type
     */
    public Class getComponentClass() {}

    /**
     * Retrieves the default event of the component.
     * 
     * @return default event
     * 
     * @see EventInfo
     */
    public EventInfo getDefaultEventInfo() {}

    /**
     * Retrieves the name of the default event of the component.
     * 
     * @return default event name
     */
    public String getDefaultEventName() {}

    /**
     * Retrieves the default property of the component.
     * 
     * @return default property
     * 
     * @see PropertyInfo
     */
    public PropertyInfo getDefaultPropertyInfo() {}

    /**
     * Retrieves the name of the default property of the component.
     * 
     * @return default property name
     */
    public String getDefaultPropertyName() {}

    /**
     * Retrieves the events that were specified in the component's ClassInfo.
     * 
     * 
     * @return events
     * 
     * @see EventInfo
     */
    public EventInfo[] getEvents() {}

    /**
     * Retrieves the events that were specified in the component's ClassInfo.
     * 
     * For an event to satisfy a particular attribute, the attribute must be 
     * present in the event's attribute list, or the attribute must match it's 
     * own default.
     * 
     * @param attributes
     *
     * @return filtered events
     * 
     * @see EventInfo
     * @see MemberAttribute
     */
    public EventInfo[] getEvents(MemberAttribute[] attributes) {}

    /**
     * Retrieves the extenders that were specified in the component's ClassInfo.
     * 
     * 
     * @return extenders
     * 
     * @see ExtenderInfo
     */    
    public ExtenderInfo[] getExtenders() {}
    
    /**
     * Retrieves the extenders that were specified in the component's ClassInfo.
     * 
     * For an extender to satisfy a particular attribute, the attribute must be 
     * present in the extender's attribute list, or the attribute must match it's 
     * own default.
     * 
     * @param attributes
     * 
     * @return filtered extenders
     * 
     * @see ExtenderInfo
     * @see MemberAttribute
     */
    public ExtenderInfo[] getExtenders(MemberAttribute[] attributes) {}

    /**
     * Retrieves the properties that were specified in the component's ClassInfo.
     * 
     * 
     * @return properties
     * 
     * @see PropertyInfo
     */    
    public PropertyInfo[] getProperties() {}

    /**
     * Retrieves the properties that were specified in the component's ClassInfo.
     * 
     * For a property to satisfy a particular attribute, the attribute must be 
     * present in the property's attribute list, or the attribute must match it's 
     * own default.
     * 
     * @param attributes
     * 
     * @return filtered properties
     * 
     * @see PropertyInfo
     * @see MemberAttribute
     */
    public PropertyInfo[] getProperties(MemberAttribute[] attributes) {}

    
    boolean shouldHideMember(MemberInfo info, MemberAttribute attribute) {}

    
    final class AttributeList implements IAttributes { 
        HashTable attributeHash = new HashTable();

        /**
         * @internalonly
         */
        public void add(MemberAttribute attr) {}

        /**
         * @internalonly
         */
        public void remove(MemberAttribute attr) {}

        /**
         * Retrieves the attributes that were specified in the component's ClassInfo.
     * 
         * @internalonly
         */
        public MemberAttribute[] getAttributes() {}
    }

    
    final class MemberList implements IProperties, IEvents, IExtenders { 
        HashTable memberHash = new HashTable();
        MemberInfo[] members = new MemberInfo[64];

        int memberCount;

        /**
         * @internalonly
         */
        public void add(EventInfo e) {}

        /**
         * @internalonly
         */
        public void add(ExtenderInfo e) {}

        /**
         * @internalonly
         */
        public void add(PropertyInfo p) {}

        /**
         * @internalonly
         */
        public void addMember(MemberInfo member) {}

        EventInfo[] getEvents() {}

        ExtenderInfo[] getExtenders() {}

        PropertyInfo[] getProperties() {}
    }
}