//STRIPPEDSOURCE//

package com.ms.wfc.core;


import com.ms.wfc.util.*;
import java.lang.reflect.*;

/**
 * Provides design-time information about components.   This uses
 * a component's ClassInfo to retrieve public properties, methods and events.
 *
 * @security(checkClassLinking=on)
 */
public final class ComponentManager {
    private static HashTable contextList = new HashTable();
    private static final Object cacheEmpty = new Object();
    private static final Object sitedValueEditor = new Object();
    private static final Class[] argClass = new Class[] {Class.class};
    private static final Class[] argSitedValueEditor = new Class[] {IEditorSite.class};
    private static final Object defaultContext = new Object();

    /**
     * Provides design-time information about components.   This loads the class using the class
     * loader of the given site.  You should always use this rather than the Java
     * provided Class.forName method, because Class.forName does not always use
     * the correct class loader.
     *
     * @param cls    A class who was loaded with the same namespace
     *               (class loader) as the class you want to find.
     * @param name   The name of the class to load.
     * @return a Class object for the given class name.
     * 
     * @exception java.lang.ClassNotFoundException if the class could not be loaded.
     */
    public static Class classForName(Class cls, String name) throws ClassNotFoundException {}

    /**
     * Creates an instance of a ClassInfo class.  This may throw
     * an exception if the class could not be created.
     * 
     * @param classInfoClass The ClassInfo class to create.
     * @return an instance of the given <i>classInfoClass</i>.
     * 
     * @exception java.lang.InstantiationException if the class info could not be created.
     * @exception java.lang.IllegalAccessException if you do not have permission to create the class info.
     * @see IClassInfo
     */
    public static IClassInfo createClassInfo(Class classInfoClass) throws InstantiationException, IllegalAccessException {}

    /**
     * Creates an instance of the given value editor class, passing <i>site</i> to its
     * constructor.  If the class does not support a constructor that takes an IEditorSite,
     * this will throw an exception.
     * 
     * @param valueEditorClass The class of the value editor to create.
     * @param site             The site to pass to the value editor.
     * @return an instance of an IValueEditor for <i>valueEditorClass</i>.
     * 
     * @exception java.lang.InstantiationException if the value editor could not be created.
     * @exception java.lang.reflect.NoSuchMethodException if the value editor does not have a contstructor that
     *            takes an IEditorSite.
     * @exception java.lang.IllegalAccessException if you do not have permission to create the value editor.
     * @exception java.lang.reflect.InvocationTargetException if there was an error instantiating the class.
     * @see IEditorSite
     * @see IValueEditor
     */
    public static IValueEditor createValueEditor(Class valueEditorClass, IEditorSite site) throws InstantiationException, NoSuchMethodException, IllegalAccessException, InvocationTargetException {}

    /**
     * Creates an instance of the given value editor class.  This will try various constructors
     * of the value editor, first passing in <i>site</i> and, failing that, passing in
     * <i>valueClass</i>.
     * 
     * @param valueEditorClass  The class of the value editor to create.
     * @param valueClass        The class of the value type the editor will be editing.
     * @param site              The IEditorSite to site the editor with.
     * @return an instance of an IValueEditor for <i>valueEditorClass</i>.
     * 
     * @exception java.lang.InstantiationException if the value editor could not be created.
     * @exception java.lang.IllegalAccessException if you do not have permission to create the value editor.
     * @see IEditorSite
     * @see IValueEditor
     */
    public static IValueEditor createValueEditor(Class valueEditorClass, Class valueClass, IEditorSite site) throws InstantiationException, IllegalAccessException {}
    
    /**
     * Creates an instance of the given value editor class.  This will pass <i>valueClass</i>
     * into the constructor of <i>valueEditorClass</i>.
     * 
     * @param valueEditorClass  The class of the value editor to create.
     * @param valueClass        The class of the value type the editor will be editing.
     * @return an instance of an IValueEditor for <i>valueEditorClass</i>.
     * 
     * @exception java.lang.InstantiationException if the value editor could not be created.
     * @exception java.lang.IllegalAccessException if you do not have permission to create the value editor.
     * @see IValueEditor
     */
    public static IValueEditor createValueEditor(Class valueEditorClass, Class valueClass) throws InstantiationException, IllegalAccessException {}

    
    private static Class findClass(ComponentContext context, String name) throws ClassNotFoundException {}

    
    private static Class findClassInfoClass(ComponentContext context, Class type) throws ClassNotFoundException {}

    
    private static Class findValueEditorClass(ComponentContext context, Class type) {}

    /**
     * Retrieves an instance of ComponentInfo for the specified class.   A ComponentInfo contains information
     * about the properties, methods and events for a given class.  This will return <b>null</b>
     * if the ComponentInfo could not be created.
     * 
     * @param componentClass The class of the component to create the ComponentInfo for.
     * @return a ComponentInfo instance for the requested component.
     * 
     * @see ComponentInfo
     */
    public static synchronized ComponentInfo getComponentInfo(Class componentClass) {}
    
    /**
     * Retrieves an instance of ComponentInfo for the specified class.   A ComponentInfo contains information
     * about the properties, methods and events for a given class.  This will return <b>null</b>
     * if the ComponentInfo does not exist, and may throw an exception if the ComponentInfo
     * does exist, but could not be created.
     * 
     * @param componentClass    The class of the component to create the ComponentInfo for.
     * @param throwExceptions   If <b>true</b> this will throw an exception if a ComponentInfo
     *                          exists for a component but could not be created (which can happen
     *                          if the component's ClassInfo is bad, for example).  If <b>false</b>,
     *                          this will catch the exception and return <b>null</b>.  Throwing
     *                          the exception is handy if you want to know why a ComponentInfo
     *                          was not returned.
     * 
     * @return a ComponentInfo for the given component class.
     * 
     * @see ComponentInfo
     */
    public static synchronized ComponentInfo getComponentInfo(Class componentClass, boolean throwExceptions) {}

    
    private static ComponentContext getContext(Class cls) {}

    /**
     * Retrieves a value editor for the specified data type.
     * 
     * @param type  The class type to get the value editor for.
     * 
     * @return an IValueEditor instance for the given class type.
     * 
     * @see IValueEditor
     */
    public static synchronized IValueEditor getValueEditor(Class type) {}
    
    /**
     * Retrieves a value editor for the specified data type.
     * 
     * @param type  The class type to get the value editor for.
     * @param site  A value editor site to pass to the value editor.  This can be
     *              <b>null</b> if no site is needed.
     * 
     * @return an IValueEditor instance for the given class type.
     * 
     * @see IValueEditor
     * @see IEditorSite
     */
    public static synchronized IValueEditor getValueEditor(Class type, IEditorSite site) {}
    
    /**
     * Retrieves a value editor for the specified data type.  If a type exists, but could not be created, this
     * will throw an exception if <i>throwExceptions</i> is <b>true</b>.
     * 
     * @param type              The class type to get the value editor for.
     * @param site              A value editor site to pass to the value editor.
     * @param throwExceptions   If <b>true</b> this will throw an exception if a value editor
     *                          exists for the given type but could not be created.  If <b>false</b>,
     *                          this will catch the exception and return <b>null</b>.
     * 
     * @return an IValueEditor instance for the given class type.
     * 
     * @see IValueEditor
     */
    public static synchronized IValueEditor getValueEditor(Class type, IEditorSite site, boolean throwExceptions) {}

    
    private static void initContext(ComponentContext context) {}

    
    private static final boolean isValueEditorSited(Class valueEditorClass) {}

    public static void registerClassInfo(Class componentClass, IClassInfo classInfo) {}
    

    /**
     * Registers a value editor for the specified data type.   Normally, WFC
     * comes preloaded with a set of common value editors.  This allows you to override
     * WFC's default value editors with your own.
     * 
     * @param type              The class of the data type to register the editor for.
     * @param valueEditorClass  The class of the value editor you want to associate with
     *                          <i>type</i>.
     */

    public static void registerValueEditorClass(Class type, Class valueEditorClass) {}

    
    private static void registerValueEditorClass(ComponentContext context, Class type, Class valueEditorClass) {}

    
    static final class ComponentContext {
        HashTable componentInfoCache = new HashTable();
        HashTable valueEditorCache = new HashTable();
        HashTable valueEditorRegistry = new HashTable();
        boolean initialized;

        ClassLoader classLoader;

        public ComponentContext(ClassLoader loader) {}
    }
}