//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * DefaultValueAttribute gives a property or extender a default value.
 * This is assumed to be the initial value of the member. A visual 
 * designer can use this to allow users to reset a member.  This can also be 
 * used by a code generator to detect whether code should be generated
 * for this member.  When overriding a member that has a distinct default
 * value, a user can pass in a DefaultValueAttribute with a new value.
 * <p>
 * Common default values have statically defined DefaultValueAttributes in this class.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see ExtenderInfo
 *
 * @security(checkClassLinking=on)
 */
public class DefaultValueAttribute extends MemberAttribute { 
    /**
     * This is the default value.
     */
    public final Object value;

    /**
     * Constructs a new DefaultValueAttribute.
     * 
     * @param value default value.
     */
    public DefaultValueAttribute(Object value) {}

    /**
     * Returns the [default] value of this attribute.
     *
     * @return  an Object with the value in it.
     */
    public Object getValue() {}

    /**
     * true default value.
     */
    public static final DefaultValueAttribute TRUE = new DefaultValueAttribute(Boolean.TRUE);

    /**
     * false default value.
     */
    public static final DefaultValueAttribute FALSE = new DefaultValueAttribute(Boolean.FALSE);

    /**
     * null default value
     */
    public static final DefaultValueAttribute NULL = new DefaultValueAttribute(null);

    /**
     * 0 default value.
     */
    public static final DefaultValueAttribute ZERO = new DefaultValueAttribute(new Integer(0));

    /**
     * 1 default value.
     */
    public static final DefaultValueAttribute ONE = new DefaultValueAttribute(new Integer(1));

    /**
     * -1 default value.
     */
    public static final DefaultValueAttribute NEGATIVE_ONE = new DefaultValueAttribute(new Integer(-1));

    /**
     * "" default value.
     */
    public static final DefaultValueAttribute EMPTY_STRING = new DefaultValueAttribute("");
    
    /**
     * Color.WINDOW default value.
     */
    public static final DefaultValueAttribute COLOR_WINDOW = new DefaultValueAttribute(com.ms.wfc.ui.Color.WINDOW);
    
    /**
     * Color.CONTROL default value.
     */
    public static final DefaultValueAttribute COLOR_CONTROL = new DefaultValueAttribute(com.ms.wfc.ui.Color.CONTROL);

    /**
     * array of size 0 default value.
     */
    public static final DefaultValueAttribute EMPTY_ARRAY = new DefaultValueAttribute(new Object[] {});
}