//STRIPPEDSOURCE//
package com.ms.wfc.core;

import java.lang.reflect.*;

/** 
 * Represents the base enumerator class.   Just list a bunch of public static final ints that 
 * make up your enum.  Then, to associate a property with this enum,
 * register the property to be of the enum type in your ClassInfo.  The
 * form designer considers enum types to be integers, so the actual type
 * of the property in it's method declarations should be int. The Property Browser
 * will display a drop-down with the choices.  We also code-gen the proper 
 * enum reference instead of the underlying int.  You should override the
 * "valid" method of Enum to return <b>true</b> if the given int value
 * is valid for the enum, or <b>false</b> otherwise.  This makes it 
 * handy in your property set calls to tell if a given value is valid.
 *
 * Here's some sample code:
 *
 * class Alignment extends Enum {
 *
 *   public static final int NONE = 0;
 *   public static final int LEFT = 1;
 *   public static final int CENTER = 2;
 *   public static final int RIGHT = 3;
 *}
 *
 * foo.setAlignment(Alignment.LEFT);
 *
 * @security(checkClassLinking=on)
 */
public class Enum {

    private static final int MODIFIERS = Modifier.PUBLIC | Modifier.STATIC | Modifier.FINAL;

    /**
     * Determines whether the specified value is
     * one of the constants defined in this class.  You should
     * override this method in your own enum classes.
     * 
     * @param value The value to check.
     * 
     * @return <b>true</b> if the value is valid for this class, <b>false</b>
     *         if not.
     */
    public static boolean valid(int value) {}

    /**
     * Represents the base enumerator class.  The type returned
     * is the class of the first public static final field in the class.
     *
     * @param enumClass Class to determine the value.
     *
     * @return the class of the fields in the enum class, or <i>enumClass</i>
     *         if <i>enumClass</i> doesn't extend Enum.
     */
    public static Class getEnumType(Class enumClass) {}

    /**
     * Represents the base enumerator class.   An enum editor is an editor that supports
     * named integer values.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends FieldsEditor {
        public Editor(Class enumType) {}

        public int getStyle() {}
    }
}