//STRIPPEDSOURCE//

package com.ms.wfc.core;

import com.ms.wfc.app.*;
import com.ms.wfc.ui.*;

/**
 * The ICustomizer interface represents the implementation of a customizer for
 * a particular component. A customizer implements the ability to create a set
 * of property pages for a component, to get a list of design-time verbs for
 * the component, and to execute those verbs. Instances of objects that
 * implement the ICustomizer interface are created by the getCustomizer()
 * method of the IClassInfo interface.
 *
 * @security(checkClassLinking=on)
 */
public interface ICustomizer { 
    /**
     * Retrieves an array of classes for each design page used by the component.   Each returning class must implement IDesignPage.
     */
    public Class[] getDesignPages();

    /**
     * Determines whether the specified point is active.  A TabStrip
     * control, for example, has a design time user interface that allows the user
     * to click the tabs to change tabs.  To implement this, TabStrip returns 
     * <b>true</b> whenever the given point is within its tabs.
     *
     * @param point A point relative to the upper left of the control.
     * @return <b>true</b> if the given point should be considered "active" or <b>false</b>
     *         if it is not something the user can interact with.
     */
    public boolean getHitTest(Point point);

    /**
     * Returns the design-time verbs supported by the associated component.  The verbs returned by this method are typically displayed
     * in a right-click menu by the design-time environment. The return value may
     * be null if the component has no design-time verbs. When a user selects one
     * of the verbs, the performVerb() method is invoked with the the
     * corresponding CustomizerVerb object.
     *
     * NOTE: A design-time environment will typically provide a "Properties..."
     * entry on a component's right-click menu. The getVerbs() method should
     * therefore not include such an entry in the returned list of verbs.
     */
    public CustomizerVerb[] getVerbs();
}