//STRIPPEDSOURCE//

package com.ms.wfc.core;

import com.ms.wfc.ui.*;

/**
 * IEditorHost is a callback that the host provides through the IValueAccess 
 * interface to assist a value editor in presenting UI to the user.  
 * a dialog can be launched through the runDialog method (with the added
 * advantage of appropriate screen placement).  The host can also take a control
 * and display it in a drop down window.
 * 
 * @see IValueAccess
 * @see IValueEditor
 * @see IValueEditor.editValue
 * @see Form
 * @see Control
 *
 * @security(checkClassLinking=on)
 */
public interface IEditorHost {

    /**
     * Launches a modal dialog box.   This method will handle placing the dialog in the
     * appropriate place on the screen.
     * 
     * @param dialog to be shown
     * 
     * @return dialog result
     * 
     * @see Form
     */
    public int runDialog(Form dialog);

    /**
     * Launches a drop-down window that contains a control.   The best
     * attempt will be made to give the control it's current size, so the
     * control should set it's desired size before each invocation of this
     * method.  The dropDownDone method should be invoked when the control is 
     * done.  Finally, the dropDown may be prematurely exited through user 
     * action, in which case the control will be made invisible.
     * 
     * @param ctl Control to be displayed inside a drop down.
     * 
     * @see dropDownDone
     */
    public void dropDownControl(Control ctl);
    
    /**
     * Indicates that the control inside a drop-down window has finished editing the value. 
     * 
     * @see dropDownControl
     */
    public void dropDownDone();

    /**
     * Retrieves a handle to a window, which allows Windows dialog boxes to be parented. 
     * 
     * @return a window handle.
     */
    public int getHostHandle();
}