//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * IEditorSite is a callback through which value editors can get at the owners of the
 * values they are editing.  This is useful to get at other objects on the form.
 *
 * @security(checkClassLinking=on)
 */
public interface IEditorSite {

    /**
     * Defines a callback interface through which a value editor accesses the owner of the  values that are being edited.
     * 
     * @return type
     */
    public Class getType();

    /**
     * Retrieves the primary component that depends on the value being edited.   This is useful when an editor wishes to get at the design time
     * site information. (For example, the ReferenceEditor uses this information
     * to get at other components in the logical container.)
     * 
     * @return primary component
     */
    public IComponent getComponent();

    /**
     * Retrieves all components that depend on the value being edited.  This would
     * have more than one element in a multi-selection case.
     * 
     * @return components
     */
    public IComponent[] getComponents();

    /**
     * Retrieves the object that directly
     * depends on the value being edited.  If it is a component,
     * it will be the same object that getComponent returns.  This differs from getComponent
     * in that this editing may occur on a property of a non-component object that in turn is the 
     * current value of a component's property.
     * 
     * @return valueOwner
     */
    public Object getValueOwner();
    
    /** 
     * Retrieves all objects that directly depend on the value being edited.  This would have more
     * than one element in a multi-selection case.
     * 
     * @return valueOwners
     */
    public Object[] getValueOwners();
}