//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * This interface provides access to name properties. Each property can contain
 * any type of object. A resource set is tied to a specific resource writer that
 * can persist the resource set to disk. In turn the resource writer is also tied
 * to a specific resource reader that can understand the persisted resource set.
 *
 * @security(checkClassLinking=on)
 */
public interface IResourceSet {
    
    /**
     * Defines an interface for accessing named resource-based properties. 
     * 
     * @return resource writer associated with this resource set.
     */
    public Class getWriter();
    
    /**
     * Retrieves the value of the specified property.
     * 
     * @param name Name of property to retrieve.
     * 
     * @return the property value.
     */
    public Object getProperty(String name);
    
    /**
     * Sets the value of the specified property.
     * 
     * @param name Name of property to store.
     * @param value Value to store.
     */
    public void setProperty(String name, Object value);
    
    /**
     * Determines whether the specified property is stored in the resource set.
     * 
     * @param name Name of property to check.
     * 
     * @return <b>true</b> if the property is stored.
     */
    public boolean contains(String name);
    
    /**
     * Retrieves the names of all properties that are stored in the resource set.
     * 
     * @return array containing all the names in this resource set.
     */
    public String[] getNames();
    
    /**
     * Retrieves the values of all properties that are stored in the resource set. 
     * 
     * @return array containing all the values in this resource set.
     */
    public Object[] getProperties();
}