//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * IValueAccess is a callback through which the editValue method on value editors
 * can get and set a value and get services to assist in editing the value.
 * Typically, the editValue method will get the value, present UI so the user can modify
 * the value, and then call setValue if there is a new value. (This would happen if the 
 * values are immutable, like a font or color.)
 * <p>
 * Through the getService method, a value editor can get at services
 * that the host provides in helping display UI.  Currently, the IEditorHost interface
 * is the only available service, and it will launch a modal dialog or show a control in a 
 * drop down editor.
 * 
 * @see IValueEditor
 * @see IValueEditor.editValue
 * @see IEditorHost
 *
 * @security(checkClassLinking=on)
 */
public interface IValueAccess { 
    /**
     * Retrieves a value to be edited. 
     * 
     * @return the value to be edited.
     */
    public Object getValue();
    
    /**
     * Sets a new value that is the result of the edit. 
     * 
     * @param value The new value.
     */
    public void setValue(Object value);
    
    /**
     * Retrieves a host service to assist the value editor in displaying a user interface.   The only
     *  service currently available in IEditorHost, which will be obtained
     * by passing in IEditorHost.class.
     * 
     * @param class service to be requested
     * 
     * @return service that was requested. (returning null if service wasn't
     * available.)
     * 
     * @see IEditorHost
     */
    public Object getService(Class serviceClass);
}