//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * LocalizableAttribute is an attribute that marks a property or extender
 * as a member that would be useful to localize.  When generating code for
 * a component, members that have LocalizableAttribute.YES would prefer
 * to be localized for the different language versions of the component.
 * If the attribute is absent, it is assumed that the member does not need
 * to be localized. When overriding a member marked as localizable,
 * a user can pass in LocalizableAttribute.NO to remove the marking.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see ExtenderInfo
 *
 * @security(checkClassLinking=on)
 */
public class LocalizableAttribute extends MemberAttribute { 
    
    
    private LocalizableAttribute() {}

    /**
     * Marks a property or extender as preferrably localizable.
     */
    public static final LocalizableAttribute YES = new LocalizableAttribute();
    
    /**
     * Marks a property or extender as not needing localization.
     */
    public static final LocalizableAttribute NO = new LocalizableAttribute();
    
    /**
     * The default case for localization. (equal to NO.)
     */
    public static final LocalizableAttribute DEFAULT = NO;

    /**
     * @internalonly
     */
    public boolean isDefaultAttribute() {}
}