//STRIPPEDSOURCE//
package com.ms.wfc.core;

import com.ms.wfc.util.*;
import java.lang.reflect.*;

/** 
 * Represents the base class for property, event, and extender definitions. (They
 * all extend MemberInfo.)  It allows users to access the attributes that
 * were passed in the constructor.  All attributes must extend 
 * MemberAttribute. 
 * 
 * @see PropertyInfo
 * @see ExtenderInfo
 * @see EventInfo
 *
 * @security(checkClassLinking=on)
 */
public class MemberInfo { 
    String name;
    MemberAttribute[] attributes;
    String category;
    String description;
    String helpURL = null;
    String helpTopic = null;

    /**
     * The constructor takes the attributes and name of the member and
     * stores it for access.
     * 
     * @param name Name of the member.
     * @param attributes The attributes of the member.
     */
    public MemberInfo(String name, MemberAttribute[] attributes) {}

    
    private MemberAttribute[] filterAttributes(MemberAttribute[] attributes) {}
    
    /**
     * The constructor takes another MemberInfo and new attributes and merges them,
     * so that given attribute a1 from oldMemberInfo and attribute a2 from newAttributes,
     * if a1.getClass() == a2.getClass(), a1 will not appear in this member's attributes, while
     * a2 will. 
     *
     * @param oldMemberInfo member info to copy
     * @param attributes additional attributes of the member.
     */
    public MemberInfo(MemberInfo oldMemberInfo, MemberAttribute[] newAttributes) {}
    
    
    static Method findMethod(Class componentClass, String name, Class[] args,
        Class returnType) {}

    /**
     * Retrieves the first attribute in the attributes collection of the specified type. 
     * 
     * @param attributeClass The type of attribute we are searching for.
     * 
     * @return the attribute we've found. This will be null if we didn't
     * find an instance of attributeClass.
     */
    public MemberAttribute getAttribute(Class attributeClass) {}

    /**
     * Retrieves all attributes of the member. 
     * 
     * @return an array of attributes.
     */
    public MemberAttribute[] getAttributes() {}

    /**
     * Retrieves the category of the member.   If one is found, it returns the string inside it.
     * This may be used by tools to do a categorical view of the members.
     * 
     * @return the category of the member.
     * 
     * @see CategoryAttribute
     */
    public String getCategory() {}

    /**
     * Retrieves the description of the member.   If one is found, it returns the string inside it.
     * This may be used by tools to display a description for this member.
     * 
     * @return the description of the member.
     * 
     * @see DescriptionAttribute
     */
    public String getDescription() {}

    /**
     * Retrieves the name of the help file of the member.  If one is found, it returns the string inside it.
     * This may be used by tools to display help for this member.
     * 
     * @return the HelpURL of the member.
     * 
     * @see HelpAttribute
     */
    public String getHelpURL() {}

    /**
     * Retrieves the help topic of the member.  If one is found, it returns the string inside it.
     * This may be used by tools to display help for this member.
     * 
     * @return the HelpTopic of the member.
     * 
     * @see HelpAttribute
     */
    public String getHelpTopic() {}

    /**
     * Retrieves the name of the member. 
     * 
     * @return the name of the member.
     */
    public String getName() {}
}