//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * PersistableAttribute indicates whether a property or extender should
 * be examined when generating code.  If PersistableAttribute.NO is
 * present, a code generator for a component will not generate code for
 * this member.  If PersistableAttribute.YES is present or no 
 * PersistableAttribute marking exists, then the member will be examined
 * to see if it is necessary to generate code. When overriding a member 
 * marked as non persistable, a user can pass in PersistableAttribute.YES 
 * to make it persistable.
 * 
 * @see MemberAttribute
 * @see PropertyInfo
 * @see ExtenderInfo
 *
 * @security(checkClassLinking=on)
 */
public class PersistableAttribute extends MemberAttribute { 
    
    private PersistableAttribute() {}

    /**
     * This marks a property or extender as persistable.
     */
    public static final PersistableAttribute YES = new PersistableAttribute();
    
    /**
     * This marks a property or event as not persistable.
     */
    public static final PersistableAttribute NO = new PersistableAttribute();
    
    /**
     * This marks the default persistability. (equal to YES.)
     */
    public static final PersistableAttribute DEFAULT = YES;

    /**
     * @internalonly
     */
    public boolean isDefaultAttribute() {}
}