//STRIPPEDSOURCE//


package com.ms.wfc.core;

import com.ms.wfc.app.*;
import com.ms.wfc.io.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import java.lang.reflect.*;

/**
 * Manages resource data.  Resource data can be stored and retrieved in a locale
 * specific manor. This enables the creation of localizable applications.
 *
 * @security(checkClassLinking=on)
 */
public class ResourceManager implements IPersistable, IResourceManager {

    /**
     * Specifies the extension of all resource files.
     */
    public static final String EXTENSION = "resources";

    LocaleNode                  set = null;
    String                      baseName = "LocalizableProperties";
    private IResourceLoader     resourceLoader = null;
    private boolean             designMode = false;

    /**
     * Creates a ResourceManager.
     * 
     * The resource manager will get data relative to the specified component,
     * that has the baseName specified. The baseName should
     * be the root name of the resource files. For example, the base name for
     * the files "MyResource_enu.resources" and "MyResource_jpn.resources" is
     * "MyResource".
     *
     * @param component Component to get resources for.
     * @param baseName Base filename
     */
    public ResourceManager(IResourceLoader loader, String baseName) {}

    /**
     * Creates a read only resource manager that only contains data for the
     * specified locale. The resource data is loaded from the stream passed
     * in.
     *
     * @param locale Locale to place the resource data in.
     * @param stream IDataStream to load resource data from.
     *
     * @internalonly
     */
    public ResourceManager(Locale locale, IDataStream stream) {}

    /**
     * Creates a read only resource manager being restored due to
     * ResourceManager being IPersistable.  Right now we only do english,
     * we could use resource manager recursively to load out all locales...
     *
     * @param stream IDataStream to load resource data from.
     *
     * @internalonly
     */
    public ResourceManager(IDataStream stream) {}

    public ResourceManager() {}

    /**
     * Determines whether the specified property is stored for a given locale. 
     * 
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public boolean containsProperty(String name) {}

    /**
     * Determines whether the specified property is stored for a given locale. 
     * 
     * @param locale Locale to check
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public boolean containsProperty(Locale locale, String name) {}

    public String getBaseName() {}

    public void setBaseName(String value) {}

    public IResourceLoader getResourceLoader() {}

    public void setResourceLoader(IResourceLoader value) {}


    /**
     * Releases any cached resource data. 
     */
    public void flush() {}

    /**
     * Determines the localized name of a resource file. 
     *
     * @param locale Locale to use.
     * @param baseName base resource file name.
     *
     * @return Localized file name.
     */
    public final static String getLocaleFileNameFromBase(Locale locale, String baseName) {}
    
    /**
     * Loads a binary resource file for the specified class.  This
     * does not load a resource property file, but rather a standalone binary
     * file that is a resource for the specified class.
     *
     * @param src Class to load the resource for.
     * @param name Name of the resource to load.
     *
     * @return IDataStream for the specified resource.
     */
    public static IDataStream getResource(Class src, String name) {}

    /**
     * Sets the resource set that will store the properties for the specified locale. 
     * @internalonly
     */
    public final synchronized void setResourceSet(Locale locale, IResourceSet newSet) {}


    /**
     * Retrieves the resource set that is storing the properties for the specified locale.  This 
     * uses the same logic as getString would use to load the locale resources.
     * 
     * @param locale Locale to get the resource set for.
     */
    public final IResourceSet getResourceSet(Locale locale) {}

    
    private IResourceSet getSetFromCache(Locale locale) {}

    
    private final IResourceSet getLocaleSet(Locale locale, boolean tryParents, boolean createIfNotPresent) {}

    /**
     * Retrieves a string for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public String getString(String name) {}
    /**
     * Retrieves a string for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public String getString(Locale locale, String name) {}
    /**
     * Retrieves a boolean value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public boolean getBoolean(String name) {}
    /**
     * Retrieves a boolean value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public boolean getBoolean(Locale locale, String name) {}
    /**
     * Retrieves a character for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public char getChar(String name) {}
    /**
     * Retrieves a character for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public char getChar(Locale locale, String name) {}
    /**
     * Retrieves a byte value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public byte getByte(String name) {}
    /**
     * Retrieves a byte value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public byte getByte(Locale locale, String name) {}
    /**
     * Retrieves a short value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public short getShort(String name) {}
    /**
     * Retrieves a short value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public short getShort(Locale locale, String name) {}
    /**
     * Retrieves an integer for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public int getInt(String name) {}
    /**
     * Retrieves an integer for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public int getInt(Locale locale, String name) {}
    /**
     * Retrieves a long value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public long getLong(String name) {}
    /**
     * Retrieves a long value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public long getLong(Locale locale, String name) {}
    /**
     * Retrieves a float value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public float getFloat(String name) {}
    /**
     * Retrieves a float value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public float getFloat(Locale locale, String name) {}
    /**
     * Retrieves a double value for the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public double getDouble(String name) {}
    /**
     * Retrieves a double value for the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public double getDouble(Locale locale, String name) {}

    /** Retrieves the extension for resource file names... we should get rid of it now. */
    public String getExtension() {}

    public Object getProperty(String name) {}

    /**
     * Retrieves the value of the specified property. 
     *
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public Object getObject(String name) {}
    /**
     * Retrieves the value of the specified property. 
     * 
     * @param locale Locale to get the property for.
     * @param name Name of the property to retrieve.
     *
     * @return Property value.
     */
    public Object getObject(Locale locale, String name) {}
    
    /**
     * Retrieves the names of all properties for a given locale. 
     *
     * @return String array containing all the names for properties.
     */
    public String[] getNames() {}
    /**
     * Retrieves the names of all properties for a given locale. 
     *
     * @param locale Locale to retrieve names for.
     *
     * @return String array containing all the names for properties.
     */
    public String[] getNames(Locale locale) {}

    /**
     * Retrieves the values of all properties for a given locale. 
     *
     * @return Object array containing all the values for properties.
     */
    public Object[] getProperties() {}
    /**
     * Retrieves the values of all properties for a given locale. 
     *
     * @param locale Locale to retrieve values for.
     *
     * @return Object array containing all the values for properties.
     */
    public Object[] getProperties(Locale locale) {}
    
    /**
     * Determines whether the specified value can be stored as a resource property. 
     *
     * @param value Value to check.
     *
     * @return True if the value could be stored in a resource file.
     */
    public static boolean getValidData(Object value) {}

    /**
     * Saves this resource manager to a stream. 
     * Right now this only saves english... we could use the resourceManager
     * itself to save away all the locales... coordinates with the IDataStream
     * constructor.
     */
    public void save(IDataStream stream) {}

    public void saveAllProperties(String directory, String baseName) {}

    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, String value) {}
    public void setProperty(String name, String value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, boolean value) {}
    public void setProperty(String name, boolean value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, char value) {}
    public void setProperty(String name, char value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, byte value) {}
    public void setProperty(String name, byte value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, short value) {}
    public void setProperty(String name, short value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, int value) {}
    public void setProperty(String name, int value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, long value) {}
    public void setProperty(String name, long value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, float value) {}
    public void setProperty(String name, float value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, double value) {}
    public void setProperty(String name, double value) {}
    /**
     * Sets the value of the specified property. 
     *
     * @param locale Locale the property is for.
     * @param name Name of the property.
     * @param value Value to assign to that property.
     */
    public void setProperty(Locale locale, String name, Object value) {}
    public void setProperty(String name, Object value) {}

    private static IResourceSet getResourceSetFromStream(IDataStream stream) {}

    
    final class LocaleNode {
        LocaleNode next = null;
        IResourceSet data = null;
        Locale locale = null;
    }
}