//STRIPPEDSOURCE//
package com.ms.wfc.core;



import com.ms.wfc.app.*;
import com.ms.wfc.io.*;
import com.ms.wfc.util.*;
import java.lang.reflect.*;

/**
 * Stores resource data to a file. 
 * <p>
 * <b>NOTE:</b> The format of resource files is subject to change at anytime.
 * You should always use resource reader classes to depersist resource files
 * from disk, and resource writers to persist the files.
 * <p>
 * The resource format is a single little endian binary file per locale. Each 
 * file contains a header with a class list, followed by any number of data
 * elements.
 * <p>
 * <b>Header Format</b>
 * <table border=1><tr>
 *    <td>(2 bytes) 0xCAFE1234</td>
 *    <td>(2 bytes) String ByteLen</td>
 *    <td>UNICODE CHARS</td>
 *    <td>(2 bytes) HeaderDataSize</td>
 *    <td>Other header data</td>
 *    <td>(2 bytes) Count of class entries</td>
 *    <td>List of class entries</td>
 * </table>
 * The header contains a magic number to verify format, then contains the
 * classname of the class that should be used to read in the rest of the
 * resource file.
 * <p>
 * <b>Class Entry Format</b>
 * <table border=1><tr>
 *    <td>(2 bytes) String ByteLen</td>
 *    <td>UNICODE CHARS</td>
 * </table>
 * Each entry in the class list contains a length prefixed unicode string
 * of a class that was stored in the resource file.
 * <p>
 * <b>Data Entry Format</b>
 * <table border=1><tr>
 *    <td>(2 bytes) String ByteLen</td>
 *    <td>UNICODE CHARS</td>
 *    <td>(2 bytes) Class Index<td>
 *    <td>data</td>
 * </tr></table>
 * Each data element consists of a length prefixed unicode string 
 * containing the name of the element, followed by an int representing the 
 * class of the data that follows as as index in to the class name list, 
 * followed by the binary data for the element.
 * <p>
 * <b>Data Format</b><br>
 * Any object that implements IPersistable will be able to save itself into
 * a data element. All intrinsic data types are stored as follows:<br>
 * <table border=1>
 *   <tr><td>String</td><td>Length prefixed (int) unicode string.</td></tr>
 *   <tr><td>boolean</td><td>Byte containing 1 or 0</td></tr>
 *   <tr><td>char</td><td>Unicode char</td></tr>
 *   <tr><td>byte</td><td>Byte</td></tr>
 *   <tr><td>short</td><td>2 Bytes</td></tr>
 *   <tr><td>int</td><td>4 Bytes</td></tr>
 *   <tr><td>long</td><td>8 Bytes</td></tr>
 *   <tr><td>float</td><td>4 Bytes (IEEE 754 floating-point)</td></tr>
 *   <tr><td>double</td><td>8 Bytes (IEEE 754 floating-point)</td></tr>
 * </table>
 *
 * @security(checkClassLinking=on)
 */
public final class ResourceWriter implements IResourceWriter {
    /**
     * Writes the specified set of resources to a file. 
     */
    public synchronized void persistProperties(IDataStream data, IResourceSet properties) {}

    
    final class ResourceSetWriter {
        IResourceSet set;
        HashTable classNames = new HashTable();
        int nextId = 0;

        public ResourceSetWriter(IResourceSet set) {}

        public void save(IDataStream stream) {}

        private void writeHeader(String[] keys, Object[] values, IDataStream stream) {}

        private void writeClassNames(Object[] values, IDataStream stream) {}

        private void indexClassName(Class cls) {}

        private void writeProperty(String name, Object value, IDataStream stream) {}

        private void writeValue(IPersistable value, IDataStream stream) {}
    }
}