//STRIPPEDSOURCE//

package com.ms.wfc.core;

/**
 * Represents a subproperty of a property value.
 * This is useful primarily when the value is immutable and can not itself be
 * customized, yet has various styles that are set through its constructor.
 * These would be properties on a mutable version of the value.  
 * <p>
 * A SubProperty contains a name, a type, a value, and an optional valueEditorClass.
 * 
 * @see IValueEditor
 *
 * @security(checkClassLinking=on)
 */
public class SubProperty {

    /**
     * The name of the subproperty.
     */
    public final String name;
    
    /**
     * Represents a subproperty of a property value.
     */
    public final Class  type;
    
    /**
     * The value of the subproperty.
     */
    public final Object value;
    
    /**
     * Represents a subproperty of a property value.
     */
    public final Class  valueEditorClass;

    /**
     * Constructs a SubProperty that can be used by a visual designer to customize
     * an immutable value.  
     * 
     * @param name The name.
     * @param type The type.
     * @param value The value.
     * @param valueEditorClass The valueEditorClass.
     * 
     * @see IValueEditor
     */
    public SubProperty(String name, Class type, Object value, Class valueEditorClass) {}

    /**
     * Constructs a SubProperty that can be used by a visual designer to customize
     * an immutable value.  
     * 
     * @param name The name.
     * @param type The type.
     * @param value The value.
     * 
     * @see IValueEditor
     */
    public SubProperty(String name, Class type, Object value) {}

    /**
     * Retrieves the name of the subproperty.
     * 
     * @return the name
     */
    public String getName() {}

    /**
     * Represents a subproperty of a property value.
     */
    public Class getType() {}

    /**
     * Retrieves the value of the subproperty.
     */
    public Object getValue() {}

    /**
     * Represents a subproperty of a property value. (null if the standard value 
     * editor should be used.)
     * 
     * @return an optional valueEditorClass
     */
    public Class getValueEditorClass() {}
}