//STRIPPEDSOURCE//

package com.ms.wfc.core;

import com.ms.wfc.ui.*;

/**
 * Represents the base class for value editors.
 * 
 * @see IValueEditor
 *
 * @security(checkClassLinking=on)
 */
public class ValueEditor implements IValueEditor {
    
    /**
     * Provides a user interface for editing the property value.getValue() and modifies or replaces
     * the value, passing the result into valueAccess.setValue().  This is where
     * an editor can launch a modal dialog or create a drop down editor to allow
     * the user to modify the value.  Host assistance in presenting UI to the user
     * can be found through the valueAccess.getService function.
     * 
     * @param valueAccess The way that editValue accesses and modifies a given value.
     * 
     * @see IValueAccess
     */    
    public void editValue(IValueAccess valueAccess) {}

    /**
     * Retrieves the fully qualified name of a constant that represents the specified value. The returned value
     * must consist of a fully qualified class name followed by a period followed
     * by the identifier of a public static final field of the given class, for
     * example "com.ms.wfc.Color.BLACK". This method is typically used by a
     * design-time environment that generates source code to initialize a
     * component's properties.
     */
    public String getConstantName(Object value) {}

    /**
     * Retrieves the subproperties of the specified value.   These sub properties
     * represent values that together compose the given value.  Each of these values
     * can be edited by the user, and getValueFromSubPropertyValues() will be called to
     * see if a new set of values can compose a new value of this type. This
     * method will only be called if the STYLE_PROPERTIES style is present.
     * 
     * @param value Value to be decomposed
     * 
     * @return subproperties The decomposition of the value into editable values.
     * 
     * @see getValueFromSubPropertyValues
     */
    public SubProperty[] getSubProperties(Object value) {}

    /**
     * Retrieves the style flags for the value editor.  The returned value must be
     * a combination of the STYLE_XXX bit masks defined in this interface.
     */
    public int getStyle() {}

    /**
     * Converts the specified value to a text string.  The return value may be null
     * if the value cannot be converted to a text string.
     */
    public String getTextFromValue(Object value) {}

    /**
     * Retrieves the common values for the editor's type.  In order to
     * display these values in a drop-down list, a property editor will typically
     * call getTextFromValue() for each of the values in the list.
     */
    public Object[] getValues() {}

    /**
     * Creates a value of this editor's type from the specified values.  If it is successful, it returns the composed value, otherwise
     * it returns null. This array of values is usually a modified version of
     * the values contained in the sub properties returned by getSubProperties().
     * This method will only be called if the STYLE_PROPERTIES style is present.
     *
     * @param values array of values.
     * 
     * @return value that results from the composition of the inputs. (null if a
     * composition wasn't possible.)
     * 
     * @see getSubProperties 
     */
    public Object getValueFromSubPropertyValues(Object[] values) {}

    /**
     * Converts the specified text string to a value.  If the editor specifies the 
     * STYLE_NOEDITABLETEXT style, this function will only be called with
     * strings that were previously returned by getTextFromValue.
     */
    public Object getValueFromText(String text) {}


    /**
     * Paints a representation of the specified value.  This method will only be called if the value editor
     * specifies the STYLE_PAINTVALUE style.
     */
    public void paintValue(Object value, Graphics g, Rectangle rect) {}
}