//STRIPPEDSOURCE//

package com.ms.wfc.data;

import com.ms.wfc.app.*;
import com.ms.wfc.util.*;
import com.ms.wfc.core.*;

/**
 * Represents a data format object for formatting boolean data types. 
 *
 * @security(checkClassLinking=on)
 */
public class BooleanDataFormat extends DataFormat implements IConstructable {
    private String falseValue;
    private String trueValue;
    private String nullValue;

    /**
     * Creates a new BooleanDataFormat. This will use the default strings
     * for the false, true, and null values.
     */
    public BooleanDataFormat() {}

    /**
     * Creates a new BooleanDataFormat. This will use the specified false
     * and true values, and the default null value.
     * 
     * @param falseValue String to use for <b>false</b> values
     * @param trueValue String to use for <b>true</b> values
     */
    public BooleanDataFormat(String falseValue, String trueValue) {}

    /**
     * Creates a new BooleanDataFormat. This will use the specified false,
     * true, and null values. If any of these values are <b>null</b>, the 
     * default value will be used for that property.
     * 
     * @param falseValue String to use for <b>false</b> values
     * @param trueValue String to use for <b>true</b> values
     * @param nullValue String to use for <b>null</b> values
     */
    public BooleanDataFormat(String falseValue, String trueValue, String nullValue) {}

    /**
     * Retrieves the string that is displayed for false values. 
     * 
     * @return String that will be used for <b>false</b> values.
     */
    public String getFalseValue() {}

    /**
     * Retrieves the string that is displayed for true values. 
     * 
     * @return String that will be used for <b>true</b> values.
     */
    public String getTrueValue() {}

    /**
     * Retrieves the string that is displayed for null values. 
     * 
     * @return String that will be used for <b>null</b> values.
     */
    public String getNullValue() {}

    /**
     * @internalonly
     */
    public ConstructorArg[] getConstructorArgs() {}

    /**
     * Resets the false value to the default value.
     * 
     * @internalonly
     */
    public void resetFalseValue() {}

    /**
     * Resets the true value to the default value.
     * 
     * @internalonly
     */
    public void resetTrueValue() {}

    /**
     * Resets the null value to the default value.
     * 
     * @internalonly
     */
    public void resetNullValue() {}
    
    /**
     * Determines if the false value needs to be persisted into code.
     * 
     * @return <b>true</b> if the property needs to be persisted.
     * 
     * @internalonly
     */
    public boolean shouldPersistFalseValue() {}

    /**
     * Determines if the true value needs to be persisted into code.
     * 
     * @return <b>true</b> if the property needs to be persisted.
     * 
     * @internalonly
     */
    public boolean shouldPersistTrueValue() {}

    /**
     * Determines if the null value needs to be persisted into code.
     * 
     * @return <b>true</b> if the property needs to be persisted.
     * 
     * @internalonly
     */
    public boolean shouldPersistNullValue() {}

    /**
     * Sets the string to be displayed for false values.  If this is set to
     * <b>null</b> the default value will be used.
     * 
     * @param value new String to use for <b>false</b> values.
     */
    public void setFalseValue(String value) {}

    /**
     * Sets the string to be displayed for true values.  If this is set to
     * <b>null</b> the default value will be used.
     * 
     * @param value new String to use for <b>true</b> values.
     */
    public void setTrueValue(String value) {}

    /**
     * Sets the string to be displayed for null values.  If this is set to
     * <b>null</b> the default value will be used.
     * 
     * @param value new String to use for <b>null</b> values.
     */
    public void setNullValue(String value) {}

    /**
     * @internalonly
     */
    public Object format(Locale locale, Object data) {}
    
    /**
     * @internalonly
     */
    public Object unformat(Locale locale, Object data) {}


    /**
     * Represents a data format object for formatting boolean data types. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends DataFormat.ClassInfo {
        public static final PropertyInfo falseValue = new PropertyInfo(
            BooleanDataFormat.class, "falseValue", String.class,
            new DescriptionAttribute(Sys.getString("BooleanDataFormatFalseValueDescr")));
        
        public static final PropertyInfo trueValue = new PropertyInfo(
            BooleanDataFormat.class, "trueValue", String.class,
            new DescriptionAttribute(Sys.getString("BooleanDataFormatTrueValueDescr")));
        
        public static final PropertyInfo nullValue = new PropertyInfo(
            BooleanDataFormat.class, "nullValue", String.class,
            new DescriptionAttribute(Sys.getString("BooleanDataFormatNullValueDescr")));

        public void getProperties(IProperties props) {}
    }
}