//STRIPPEDSOURCE//

package com.ms.wfc.data;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;

/**
 * Data formatting interface. Classes that implement this interface can participate
 * in the formatting of data to be presented to the user.
 *
 * @security(checkClassLinking=on)
 */
public interface IDataFormat {
    
    /**
     * Formats data from a database format into a user-editable format.  If the locale specified is <b>null</b>, then the
     * current thread locale should be used. The type of the returned format
     * may vary between implementations, but normally it will be a String.
     * 
     * @param locale Locale to format the data for
     * @param data Data to format
     * 
     * @return a user editable format.
     */
    public Object format(Locale locale, Object data);
    
    /**
     * Removes the formatting from the user-editable data and restores the original database
     * format.  If the locale specified in <b>null</b>, then the current
     * thread locale should be used. The type of <i>data</i> must be the same
     * as the type returned from com.ms.wfc.data.IDataFormat.format.
     * 
     * @param locale Locale to unformat the data from
     * @param data User editable data to unformat
     * 
     * @return a database format.
     */
    public Object unformat(Locale locale, Object data);

    /**
     * Assigns a delegate to the formatChanged event.  The formatChanged event should
     * be fired when any property changes on the object that would affect the
     * formatting of the data.
     * 
     * @param handler Delegate to notify when the formatChanged event occurs.
     */
    public void addOnFormatChanged(EventHandler handler);

    /**
     * Removes the delegate assigned to the formatChanged event.  The formatChanged event 
     * should be fired when any property changes on the object that would 
     * affect the formatting of the data.
     * 
     * @param handler Delegate to remove.
     */
    public void removeOnFormatChanged(EventHandler handler);

    /**
     * Defines the data formatting interface.  This provides a list of known data formats for
     * the user to choose from.
     * 
     * @see com.ms.wfc.core.IValueEditor
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends ValueEditor {
        /**
         * @internalonly
         */
        public int getStyle() {}

        /**
         * @internalonly
         */
        public String getTextFromValue(Object value) {}

        /**
         * @internalonly
         */
        public Object[] getValues() {}
    }
}