//STRIPPEDSOURCE//

package com.ms.wfc.data.ui;

import com.ms.dll.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.data.*;
import com.ms.wfc.util.Root;
import com.ms.lang.Delegate;

/**
 * Implements a data-bound grid that is filled with data from an ADO recordset. The rows  and columns in the grid represent the records and fields in the recordset.  The DataGrid allows you to easily display an entire
 * recordset.<p>
 *
 * @security(checkClassLinking=on)
 */
public class DataGrid extends Control {

    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_COLUMNHEADER  = 0x00000001;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_ROWSELECTOR   = 0x00000002;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_GRID          = 0x00000004;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_SCROLL        = 0x00000008;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_BORDER        = 0x00000010;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_BLANK         = 0x00000020;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_PHANTOMROW    = 0x00000040;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_GRIDLINE      = 0x00000080;
    /**
     * @internalonly
     */
    protected static final int  LOCT_AREA_CAPTION       = 0x00000100;
    /**
     * @internalonly
     */
    protected static final int  LOCT_VERTRESIZELINE     = 0x00010000;
    /**
     * @internalonly
     */
    protected static final int  LOCT_HORIZRESIZELINE    = 0x00020000;
    /**
     * @internalonly
     */
    protected static final int  LOCT_CENTER             = 0x00040000;

    
    
    private static final int    RESIZE_START            = -1;
    private static final int    RESIZE_END              = -2;
    private static final int    RESIZE_CONTINUE         = -3;

    private static final int    RESIZE_MARGIN = 4;

    private static final int    PAGESIZE = 10;

    /**
     * Specifies the minimum width (in pixels) of the columns in the grid.
     */
    public static final int  MIN_COLUMN_WIDTH = 10;
    /**
     * Specifies the minimum height (in pixels) of the rows in the grid.
     */
    public static final int  MIN_ROW_HEIGHT = 5;

    
    
    
    
    
    
    private static final int USER_ALLOWDELETE      = 0x00000001;
    private static final int USER_ALLOWROWSIZING   = 0x00000002;
    private static final int USER_ALLOWUPDATE      = 0x00000004;
    private static final int USER_SHOWROWSELECTORS = 0x00000008;
    private static final int USER_SHOWVERTSCROLL   = 0x00000010;
    private static final int USER_SHOWHORIZSCROLL  = 0x00000020;
    private static final int USER_ALLOWARROWS      = 0x00000040;
    private static final int USER_SHOWCOLUMNHEADERS= 0x00000080;
    private static final int USER_WRAPCELLPOINTER  = 0x00000100;
    private static final int USER_ALLOWADDNEW      = 0x00000200;
    private static final int USER_DYNAMICCOLUMNS   = 0x00000400;
    private static final int STATE_ALLOWDELETE     = 0x00010000;
    private static final int STATE_ALLOWUPDATE     = 0x00020000;
    private static final int STATE_ALLOWADDNEW     = 0x00040000;
    private static final int STATE_SHOWPHANTOMROW  = 0x00080000;
    private static final int STATE_EDITMODE        = 0x00100000;
    private static final int STATE_TRACKINGRESIZE  = 0x00200000;
    private static final int STATE_INTERNALMOVE    = 0x00400000;
    private static final int STATE_DOWNONCURRENT   = 0x00800000;
    
    private int                 gridState = USER_ALLOWDELETE      
                                            | USER_ALLOWROWSIZING   
                                            | USER_ALLOWUPDATE      
                                            | USER_SHOWROWSELECTORS 
                                            | USER_SHOWVERTSCROLL   
                                            | USER_SHOWHORIZSCROLL  
                                            | USER_ALLOWARROWS      
                                            | USER_SHOWCOLUMNHEADERS
                                            | USER_ALLOWADDNEW
                                            | USER_DYNAMICCOLUMNS;
    
    
    
    private int                 displayRowCount = -1;
    private DataRow             editRowRef = null;
    private int                 editColumn = -1;
    private DataRow             currentRowRef = null;
    private int                 currentColumn = -1;
    private DataRow             lastRow = null;
    private int                 lastColumn = -1;
    private GridCell            marqueeCell = new GridCell();
    private int                 lastVisibleColumn = -1;
    private int                 firstVisibleColumn = -1;

    
    
    private int                 borderStyle = BorderStyle.FIXED_3D;
    private Font                headerFont = null;
    private int                 gridLineStyle = GridLineStyle.SINGLELINE;
    private String              caption = null;
    private int                 defaultColumnWidth = 75;
    private int                 tabAction = TabAction.CONTROLNAVIGATION;
    private int                 enterAction = EnterAction.NONE;
    private Color               selectedForeColor = Color.HIGHLIGHTTEXT;
    private Color               selectedBackColor = Color.HIGHLIGHT;
    private int                 headerLineCount = 1;

    
    
    private Column[]            columns = null;
    private int                 columnCount = 0;

    
    
    private ScrollBar           horizScrollbar = new HScrollBar();
    private ScrollBar           vertScrollbar = new VScrollBar();

    
    
    private ColumnHeaderDisplayer  captionDisplayer = new ColumnHeaderDisplayer();
    private RowSelectorDisplayer  rowSelectorDisplayer = new RowSelectorDisplayer();
    private GridLineDisplayer   gridLinesDisplayer = new GridLineDisplayer();
    private BorderDisplayer     borderDisplayer = new BorderDisplayer();
    private Rectangle           clientRect = null;
    private Rectangle           clientRectInside = null;
    private Rectangle           resizeBoxRect = null;
    private int                 rowHeight = 20;
    private int                 columnHeaderHeight = -1;
    private int                 rowSelectorWidth = 16;
    private int                 horizOffset = 0;
    private Rectangle           clipRect = null;
    private int                 mouseWheelDelta = 0;

    
    
    private ScrollableDataStore dataStore = null;
    private RecordsetProvider   recordsetProvider = new RecordsetProvider();
    private int                 dataStoreAsyncMessage = 0;

    
    
    private ICellEditor         editorCurrent = null;
    private int                 editorDefaultWndProc = 0;
    private int                 editorNewWndProc = 0;
    private ICellEditor         editorSubclassed = null;

    
    
    private int                 columnResizing = -1;
    private int                 trackXStart = -1;
    private int                 trackYStart = -1;
    private int                 lastDrawLoc = -1;

    
    
    private Selection           selection = new Selection();
    private int                 lastX = -1;
    private int                 lastY = -1;

    
    
    private static final Object EVENT_COLUMNEDITED = new Object();
    private static final Object EVENT_COLUMNUPDATED = new Object();
    private static final Object EVENT_DELETED = new Object();
    private static final Object EVENT_INSERTED = new Object();
    private static final Object EVENT_UPDATED = new Object();
    private static final Object EVENT_COLUMNEDITING = new Object();
    private static final Object EVENT_COLUMNUPDATING = new Object();
    private static final Object EVENT_DELETING = new Object();
    private static final Object EVENT_INSERTING = new Object();
    private static final Object EVENT_UPDATING = new Object();
    private static final Object EVENT_COLUMNRESIZE = new Object();
    private static final Object EVENT_ERROR = new Object();
    private static final Object EVENT_HEADERCLICK = new Object();
    private static final Object EVENT_POSITIONCHANGE = new Object();
    private static final Object EVENT_ROWRESIZE = new Object();
    private static final Object EVENT_SCROLL = new Object();
    private static final Object EVENT_SELCHANGE = new Object();

    /**
     * Creates a new DataGrid.
     */
    public DataGrid() {}

    
    private void acquireRecordset(Object sender, Event event) {}

    /**
     * Adds a column to the DataGrid control. 
     *
     * @param boundColumnName Name of the field in the recordset to bind the
     *        column to.
     *
     * @return Column that is added.
     */
    public Column addColumn(String boundColumnName) {}

    /**
     * Adds a column to the DataGrid control. 
     *
     * @param toAdd Column to add
     *
     * @return Column that is added.
     */
    public Column addColumn(Column toAdd) {}

    
    private void beginPositionChange() {}

    
    private void calcColumnBounds() {}

    
    private void calcHeaderHeight() {}

    
    private void calcRowBounds() {}

    /**
     * Removes all columns from the grid. 
     */
    public void clearColumns() {}

    /**
     * Removes any selection in the grid. 
     */
    public void clearSelection() {}

    /**
     * Callback function for all columns to use to signal that a property has
     * changed.
     *
     * @internalonly
     */
    protected void columnPropertyChange(int property, Column column) {}


    
    private int computeRowTop(int displayRow) {}

    /**
     * Deletes all selected rows.
     * 
     * @internalonly
     */
    protected void deleteSelectedRows() {}

    private final boolean getGridState(int bit) {}
    
    private boolean isPrintableChar(char ch) {}
    
    protected void onKeyPress(KeyPressEvent e) {}
    
    protected void onKeyDown(KeyEvent e) {}        
    
    /**
     * Repositions all controls, updates scrollbars, and refreshes any cached
     * information regarding the shape of the control.
     * 
     * @internalonly
     */
    protected void onLayout(LayoutEvent event) {}

    /**
     * @internalonly
     *
     * Callback wndProc used to subclass any editor that is used. It looks for
     * any key messages, and if the editor doesn't respond by saying that it
     * wants to use the key, then it calls processMoveKey.
     */
    protected int editorWndProc(int hwnd, int msg, int wparam, int lparam) {}

    
    private void endPositionChange() {}

    
    private void ensureCellVisible(GridCell cell) {}

    protected void fireErrorEvent(ErrorEvent event) {}

    /**
     * Simple wrapper around the cancelable selchange event.
     * 
     * @internalonly
     */
    protected boolean fireSelChangeEvent() {}

    /**
     * Simple wrapper around the cancelable selchange event.
     * 
     * @internalonly
     */
    protected boolean fireInserting() {}

    /**
     * Simple wrapper around the cancelable scroll event.
     * 
     * @internalonly
     */
    protected boolean fireScrollEvent() {}

    /**
     * Retrieves the approximate number of rows in the DataGrid control. 
     *
     * @return Nubmer of rows in the recordset.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public int getApproxRowCount() {}

    /**
     * Retrieves the current style of the DataGrid control's border. 
     *
     * @return Current value of the border style property.
     */
    public int getBorderStyle() {}

    /**
     * @internalonly
     *
     * Returns the display index of the row that is the last row visible.
     */
    protected int getBottomRow() {}

    /**
     * @internalonly
     *
     * Calculates the number of rows that can fit in the display at one time.
     */
    protected int calcPageSize() {}

    /**
     * @internalonly
     *
     * Returns the client rect for the control. If this value isn't already
     * cached in clientRect, then it gets the value, and also calculates
     * the values of the other various cached rects.
     */
    protected Rectangle getCachedClientRect() {}

    /**
     * @internalonly
     *
     * Returns the client rect that doesn't include the border or the
     * scrollbars. For all most of the painting code, this "inside" rect is the
     * coords where all drawing occurs.
     */
    protected Rectangle getCachedClientInsideRect() {}

    
    private Rectangle getCachedResizeBox() {}

    /**
     * Retrieves the text displayed in the caption bar at the top of the grid. 
     *
     * @return Current value of the caption property.
     */
    public String getCaption() {}


    protected boolean getShowPhantom() {}

    DataGridLocation hitTest(int x, int y) {}

    
    private Rectangle getCaptionBounds() {}

    /**
     * @internalonly
     *
     * Returns the height of the caption bar. This will be 0 if there is no
     * caption.
     */
    protected int getCaptionHeight() {}

    /**
     * @internalonly
     *
     * Returns the bounds for the cell.
     */
    protected Rectangle getCellBounds(int columnIndex, DataRow row) {}

    /**
     * @internalonly
     *
     * Returns the bounds for the cell.
     */
    protected Rectangle getCellBounds(GridCell cell) {}

    /**
     * @internalonly
     *
     * Returns the current painting clipRect.
     */
    protected Rectangle getClipRect() {}

    /**
     * Retrieves the column at the specified index. 
     *
     * @param index index of the column.
     *
     * @return Column with the specified index.
     *
     * @exception WFCInvalidArgumentException Thrown if the display index is not
     *            valid.
     */
    public Column getColumn(int index) {}

    /**
     * Retrieves the number of columns in the grid, visible or hidden.  This count includes
     * non-visible columns.
     *
     * @return Number of columns in the grid.
     */
    public int getColumnCount() {}

    /**
     * @internalonly
     *
     * Returns the height of the column headers. 0 if the column headers is
     * turned off.
     */
    protected int getColumnHeaderHeight() {}

    /**
     * Retrieves the collection of all columns in the grid.  The elements in the grid are ordered by index.
     *
     * @return Array of all the columns in the grid. Null if there are no
     *         columns present.
     */
    public Column[] getColumns() {}

    /**
     * @internalonly
     *
     * Returns the count of rows in the grid, including the phantom row.
     */
    protected int getCompleteRowCount() {}

    /**
     * Retrieves the value of the current cell. 
     *
     * @return String of formatted data that is the value of the current cell.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public String getCurrentCellValue() {}

    /**
     * Retrieves the current column in the grid. 
     *
     * @return Current column, or Null if there is no current column.
     */
    public Column getCurrentColumn() {}

    /**
     * Retrieves the bookmark associated with the current row in the grid. 
     *
     * @return Bookmark of the current row.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public Object getCurrentRow() {}

    /**
     * Retrieves the bound member of the DataGrid control's underlying data source. 
     *
     * @return Name of the DataMember.
     *
     * @see #setDataMember
     * @see #setDataSource
     */
    public String getDataMember() {}

    /**
     * @internalonly
     *
     * Returns the ScrollableDataStore.
     */
    protected ScrollableDataStore getScrollableDataStore() {}

    /**
     * Retrieves the data source underlying the DataGrid control. 
     *
     * @return DataSource of the grid.
     *
     * @see #setDataSource
     */
    public IDataSource getDataSource() {}

    /**
     * Retrieves the default width of all columns in the grid. 
     *
     * @return Default width of columns.
     */
    public int getDefaultColumnWidth() {}

    /**
     * Retrieves the display index of the row associated with the specified bookmark.  -1 is
     * returned if the row is not visible.
     *
     * @param bookmark Bookmark of the row the check
     *
     * @return displayIndex of the specified row.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public int getDisplayIndex(Object bookmark) {}

    /**
     * Retrieves a boolean value indicating whether the columns in the grid
     * are determined dynamically. If this property is set to <b>true</b>, then the columns in the
     * grid will always be determined by the columns in the bound data source.
     * Otherwise the columns in the grid will remain static and must be set by the
     * user.
     * 
     * @return boolean value indicating if the columns are determined dynamically.
     * 
     * @see #setDynamicColumns
     */
    public boolean getDynamicColumns() {}
    
    /**
     * Retrieves a value indicating the behavior of the ENTER key within the grid. 
     *
     * @return Current value of the EnterAction property.
     *
     * @see #setEnterAction
     */
    public int getEnterAction() {}

    /**
     * Retrieves the current style of the control's gridlines. 
     *
     * @return Current value of the GridLineStyle property.
     *
     * @see #setGridLineStyle
     */
    public int getGridLineStyle() {}

    /**
     * Retrieves the bookmark associated with the topmost visible row in the grid.  The value that will be returned if
     * this method is called during a scroll operation is undefined.
     *
     * @return Bookmark of the row that is the first row visible.
     */
    public Object getFirstRow() {}

    /**
     * @internalonly
     *
     * Returns the first column that is set to be visible.
     */
    protected int getFirstVisibleColumn() {}

    /**
     * Retrieves the font of the grid's column headers. 
     *
     * @return Font that will be used for drawing the headers.
     *
     * @see #setHeaderFont
     */
    public Font getHeaderFont() {}

    /**
     * Retrieves the number of lines of text that can be displayed in the grid's column
     * headers. 
     *
     * @return Current value of the HeaderLineCount property.
     */
    public int getHeaderLineCount() {}

    /**
     * @internalonly
     *
     * Returns the number of pixels to offset the grid painting horizontally.
     */
    protected int getHorizOffset() {}

    /**
     * @internalonly
     *
     * Gets the specified column. This version doesn't have any validation,
     * so it is quicker.
     */
    protected Column getInternalColumn(int nIndex) {}

    /**
     * @internalonly
     *
     * Returns the last column that is set to be visible.
     */
    protected int getLastVisibleColumn() {}

    /**
     * Retrieves the index of the leftmost visible column in the grid. 
     *
     * @return index of the leftmost column.
     */
    public int getLeftColumn() {}

    /**
     * Retrieves the height of the rows in the grid. 
     *
     * @return Height of each row in pixels.
     */
    public int getRowHeight() {}

    /**
     * @internalonly
     *
     * Returns the width of the rowheaders, 0 if they aren't displayed.
     */
    protected int getRowSelectorWidth() {}

    
    private int getScrollbarHeight() {}

    /**
     * Retrieves a value indicating which scroll bars are displayed in the grid. 
     *
     * @return Current value of the Scrollbars property.
     *
     * @see #setScrollbars.
     */
    public int getScrollbars() {}

    
    private int getScrollbarWidth() {}

    /**
     * Retrieves the background color for selected cells in the grid. 
     *
     * @return Color that will be used as the background of selected cells.
     *
     * @see #setSelectedBackColor
     */
    public Color getSelectedBackColor() {}

    /**
     * Retrieves the selected columns in the grid.  This array will be
     * not be ordered. This function will return null if the selected items
     * are Rows, or Cells.
     *
     * @return Array of selected columns
     */
    public Column[] getSelectedColumns() {}

    /**
     * Retrieves the color for selected text in the grid. 
     *
     * @return Color that will be used as the foreground of selected cells.
     *
     * @see #setSelectedForeColor
     */
    public Color getSelectedForeColor() {}

    /**
     * Retrieves the bookmarks associated with the selected rows in the grid.  The returned array will not be
     * ordered. This will return null if the selected items are Cells or
     * Columns.
     *
     * @return Array of bookmarks of the currently selected rows.
     *
     * @see #setSelectedRows
     */
    public Object[] getSelectedRows() {}

    /**
     * Retrieves a value indicating the behavior of the TAB key within the grid. 
     *
     * @return Current value of the TabAction property.
     *
     * @see #setTabAction
     */
    public int getTabAction() {}

    /**
     * @internalonly
     *
     * Returns the topmost row. This will always be the first row that has any
     * part of it visible.
     */
    protected Object getTopRow() {}

    
    private int getTotalWidth() {}

    /**
     * Retrieves the number of visible columns in the grid's current scroll position. 
     *
     * @return Number of columns that can be seen by the user.
     */
    public int getVisibleColumns() {}

    /**
     * Retrieves the number of visible rows in the grid's current scroll position. 
     *
     * @return Number of rows that can be seen by the user.
     */
    public int getVisibleRows() {}

    protected void invalidateColumn(int column) {}
    /**
     * invalidates the column with the specified index, and forces a
     * synchronous update
     * 
     * @internalonly
     */
    protected void invalidateColumn(int column, boolean update) {}

    
    private void invalidateRow(DataRow row, boolean update) {}

    
    private void invalidateRowSelector(DataRow row) {}

    /**
     * Retrieves a boolean value indicating whether the user can add rows to the grid
     * (provided the underlying recordset allows new records to be added). 
     *
     * @return Current value of the AllowAddNew property.
     *
     * @see #setAllowAddNew
     */
    public boolean getAllowAddNew() {}

    /**
     * Retrieves a boolean value indicating whether the arrow keys can be used to
     * navigate the grid. 
     *
     * @return Current value of the AllowArrows property.
     *
     * @see #setAllowArrows
     */
    public boolean getAllowArrows() {}

    /**
     * Retrieves a boolean value indicating whether the user can delete rows from the
     * grid (provided the underlying recordset allows records to be deleted). 
     *
     * @return Current value of the AllowDelete property.
     *
     * @see #setAllowDelete
     */
    public boolean getAllowDelete() {}

    /**
     * Retrieves a boolean value indicating whether the rows in the grid can be resized
     * at run time. 
     *
     * @return Current value of the AllowRowSizing property.
     *
     * @see #setAllowRowSizing
     */
    public boolean getAllowRowSizing() {}

    /**
     * Retrieves a boolean value indicating whether data can be modified in the grid
     * (provided the underlying recordset allows records to be modified). 
     *
     * @return Current value of the AllowUpdate property.
     *
     * @see #setAllowUpdate
     */
    public boolean getAllowUpdate() {}

    
    private boolean getCellVisible(GridCell cell) {}
            
    private boolean getCellPartiallyVisible(GridCell cell) {}
    

    /**
     * Retrieves a boolean value indicating whether the column headers are displayed. 
     *
     * @return Current value of the ColumnHeaders property.
     *
     * @see #setColumnHeaders
     */
    public boolean getColumnHeaders() {}

    /**
     * Retrieves a boolean value indicating whether the current cell is completely
     * visible. 
     *
     * @return True if the current cell is visible.
     *
     * @see #makeCurrentCellVisible
     */
    public boolean getCurrentCellVisible() {}

    /**
     * Retrieves a boolean value indicating whether the data in the current row has
     * been changed. 
     *
     * @return True if the current row is dirty.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public boolean getCurrentRowModified() {}

    /**
     * Retrieves a boolean value indicating whether row selectors are displayed in the
     * grid. 
     *
     * @return Current value of the RowSelectors property.
     */
    public boolean getRowSelectors() {}

    
    private boolean getValidEnterAction(int action) {}

    
    private boolean getValidTabAction(int action) {}

    
    private boolean getValidGridStyle(int style) {}

    
    private boolean getValidBorderStyle(int style) {}

    
    private boolean getValidScrollbars(int scrollbars) {}

    /**
     * Retrieves a boolean value that indicates whether the TAB, ENTER, and arrow keys
     * can be used to wrap the current cell focus around rows and columns. 
     *
     * @return Current value of the WrapCellPointer property.
     *
     * @see #setWrapCellPointer
     */
    public boolean getWrapCellPointer() {}

    /**
     * Scrolls the grid to bring the current cell completely into view. 
     *
     * @see #isCurrentCellVisible
     */
    public void makeCurrentCellVisible() {}

    
    private void notifyColumnsOfAmbientChange() {}

    /**
     * Triggers the columnEdited event. 
     * @internalonly
     */
    protected void onColumnEdited(ColumnEvent event) {}

    /**
     * Triggers the columnUpdated event. 
     * @internalonly
     */
    protected void onColumnUpdated(ColumnEvent event) {}

    /**
     * Triggers the deleted event. 
     * @internalonly
     */
    protected void onDeleted(Event event) {}

    /**
     * Triggers the inserted event. 
     * @internalonly
     */
    protected void onInserted(Event event) {}

    /**
     * Triggers the updated event. 
     * @internalonly
     */
    protected void onUpdated(Event event) {}

    /**
     * Triggers the columnEditing event. 
     * @internalonly
     */
    protected void onColumnEditing(ColumnEditingEvent event) {}

    /**
     * Triggers the columnUpdating event. 
     * @internalonly
     */
    protected void onColumnUpdating(ColumnUpdatingEvent event) {}

    /**
     * Triggers the deleting event. 
     * @internalonly
     */
    protected void onDeleting(CancelEvent event) {}

    /**
     * Triggers the inserting event. 
     * @internalonly
     */
    protected void onInserting(CancelEvent event) {}

    /**
     * Triggers the updating event. 
     * @internalonly
     */
    protected void onUpdating(CancelEvent event) {}

    /**
     * Triggers the columnResize event. 
     * @internalonly
     */
    protected void onColumnResize(ColumnResizeEvent event) {}

    /**
     * Triggers the positionChange event. 
     * @internalonly
     */
    protected void onPositionChange(PositionChangeEvent event) {}

    /**
     * Triggers the error event. 
     * @internalonly
     */
    protected void onError(ErrorEvent event) {}

    /**
     * Triggers the headerClick event. 
     * @internalonly
     */
    protected void onHeaderClick(ColumnEvent event) {}

    
    private void onHorizScroll(Object sender, ScrollEvent se) {}

    /**
     * Handles the mousedown message.
     * @internalonly
     */
    protected void onMouseDown(MouseEvent me) {}

    /**
     * Handles the mousemove messages.
     * @internalonly
     */
    protected void onMouseMove(MouseEvent me) {}

    /**
     * Handles mouseup messages
     * @internalonly
     */
    protected void onMouseUp(MouseEvent me) {}

    /**
     * Handles mousewheel messages.
     * @internalonly
     */
    protected void onMouseWheel(MouseEvent event) {}

    /**
     * Handles WM_PAINT messages.
     * @internalonly
     */
    protected void onPaint(PaintEvent e) {}

    /**
     * Handles WM_RESIZE messages
     * @internalonly
     */
    protected void onResize(Event e) {}

    /**
     * Triggers the rowResize event. 
     * @internalonly
     */
    protected void onRowResize(CancelEvent event) {}

    private void onSettingChange(Object sender, Event event) {}

    /**
     * Triggers the scroll event. 
     * @internalonly
     */
    protected void onScroll(CancelEvent event) {}

    /**
     * Triggers the selChange event. 
     * @internalonly
     */
    protected void onSelChange(CancelEvent event) {}

    
    private void onVertScroll(Object sender, ScrollEvent se) {}


    
    private boolean processInstantEditKey(int virtKeyCode) {}

    
    private boolean processMoveKey(int virtKeyCode) {}

    
    private static final int HALFWIDTH = 1;
    private void processResize(int resizeOperation, int mouseX, int mouseY) {}

    private void drawSizeLine(int x, int y, int x2, int y2) {}

    /**
     * Override of cor.Control.propertyChanged to let us catch the change in
     * ambient properties.
     * @internalonly
     */
    protected void propertyChanged(int nProp) {}

    /**
     * Reinitializes the binding between the DataGrid control and the underlying
     * recordset. 
     */
    public void rebind() {}

    
    private void releaseRecordset(Object sender, Event event) {}

    /**
     * Removes a column from the grid. 
     *
     * @param displayIndex displayIndex of the column to remove.
     *
     * @exception WFCInvalidArgumentException Thrown if the displayIndex is invalid
     */
    public void removeColumn(int index) {}

    
    private void removeEditor() {}

    
    private void removeEditor(boolean cancelUpdate) {}

    /**
     * Retrieves the bookmark associated with the row that offsets the topmost visible row by
     * the specified number of rows. 
     *
     * @param displayRow Offset from the firstRow to get the bookmark for.
     *
     * @return Bookmark for the specified row.
     *
     * @see #getBookmark
     * @exception WFCInvalidArgumentException Thrown if displayRow refers to an
     *            invalid row.
     * @exception WFCInvalidArgumentException Thrown if there is no datasource
     */
    public Object rowBookmark(int displayRow) {}

    /**
     * Retrieves the y-coordinate at the top of the specified row. 
     *
     * @param row Bookmark of the row.
     *
     * @return Client y coordinate at the top of the row.
     *
     * @exception WFCInvalidArgumentException Thrown if row refers to an invalid
     *            row.
     */
    public int rowTop(Object row) {}

    /**
     * Scrolls the grid horizontally and vertically.  A negative number will scroll the display to up and to the left.
     * In addition, scrolling by 0 columns will actually make the current left
     * column completely visible.
     *
     * @param cols Number of columns to scroll by.
     * @param rows Number of rows to scroll by.
     */
    public void scroll(int cols, int rows) {}

    /**
     * Sets a boolean value indicating whether the user can add rows to the grid
     * (provided the underlying recordset allows new records to be added).  If the underlying recordset also supports adding a new row,
     * then the new row will be displayed at the bottom of the grid.
     *
     * @param allowAddNew New value for the AllowAddNew property.
     *
     * @see #isAllowAddNew
     */
    public void setAllowAddNew(boolean allowAddNew) {}

    /**
     * Sets a boolean value indicating whether the arrow keys can be used to navigate
     * the grid.  If it is set to false, then the arrow keys
     * will be used for navigation of controls on the form.
     *
     * @param allowArrows New value for the AllowArrows property.
     *
     * @see #isAllowArrows
     */
    public void setAllowArrows(boolean allowArrows) {}

    /**
     * Sets a boolean value indicating whether the user can delete rows from the grid
     * (provided the underlying recordset allows records to be deleted).  If the underlying recordset also supports deleting rows, then
     * pressing delete with rows selected will result in the rows being deleted
     * from the recordset.
     *
     * @param allowDelete New value for the AllowDelete property.
     *
     * @see #isAllowDelete
     */
    public void setAllowDelete(boolean allowDelete) {}

    /**
     * Sets a boolean value indicating whether the rows in the grid can be resized at
     * run time.  This property will also control the ability to use
     * the RowHeight property to programatically adjust the row height.
     *
     * @param rowSizing New value for the AllowRowSizing property.
     *
     * @see #isAllowRowSizing
     */
    public void setAllowRowSizing(boolean rowSizing) {}

    /**
     * Sets a boolean value indicating whether data can be modified in the grid
     * (provided the underlying recordset allows records to be modified).  If the underlying recordset also allows
     * updates then the user will be able to edit values. This property also
     * controls the use of the CurrentCellValue property to edit the recordset.
     *
     * @param allowUpdate New value for the AllowUpdate property.
     *
     * @see #isAllowUpdate
     */
    public void setAllowUpdate(boolean allowUpdate) {}

    /**
     * Sets the style of the DataGrid control's border.  The valid border styles are:
     *
     * <ul>
     *   <li> <a href="#BorderStyle.NONE">BorderStyle.NONE</a> - No border
     *   <li> <a href="#BorderStyle.FIXED_SINGLE">BorderStyle.FIXED_SINGLE</a> - Single line
     *                                                             border
     *   <li> <a href="#BorderStyle.FIXED_3D">BorderStyle.FIXED_3D</a> - 3D sunken border
     * </ul>
     *
     * @param borderStyle New value for the BorderStyle property.
     *
     * @see #getBorderStyle
     */
    public void setBorderStyle(int borderStyle) {}

    /**
     * Sets the text displayed in the caption bar at the top of the grid.  The caption is displayed above the column
     * headers. If the caption is set to null then the caption area is not
     * displayed.
     *
     * @param caption New caption to display.
     *
     * @see #getCaption
     */
    public void setCaption(String caption) {}

    /**
     * Sets a boolean value indicating whether the column headers are displayed.  If ColumnHeaders is set to true,
     * then the column headers are displayed.
     *
     * @param columnHeaders New value for the ColumnHeaders property.
     *
     * @see #getColumnHeaders
     */
    public void setColumnHeaders(boolean columnHeaders) {}

    void setColumnValue(Column col, String val) {}
    
    /**
     * Sets the value of the current cell. 
     * @param val Value to put in the current cell.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     */
    public void setCurrentCellValue(String val) {}


    /**
     * Moves the current position to the row associated with the specified bookmark. 
     *
     * @param row Bookmark of the row.
     *
     * @exception WFCInvalidArgumentException Thrown if this method is called
     *            without a bound recordset.
     * @exception WFCInvalidArgumentException Thrown if the row refers to an
     *            invalid row.
     */
    public void setCurrentRow(Object bookmark) {}

    /**
     * Sets the current column in the grid. 
     *
     * @param column Column to make current.
     *
     * @exception WFCInvalidArgumentException Thrown if you pass in a null column.
     */
    public void setCurrentColumn(Column column) {}

    /**
     * Sets the current column in the grid. 
     *
     * @param index Display index of the column to make current.
     *
     * @exception WFCInvalidArgumentException Thrown if you pass a invalid
     *            index.
     */
    public void setCurrentColumn(int index) {}

    
    private void setCurrentColumnRow(int column, DataRow row) {}

    /**
     * Sets the collection of all columns in the grid.  You cannot pass in any columns from a
     * different grid.
     *
     * @param columns Array of column objects.
     *
     * @exception WFCInvalidArgumentException Thrown if any of the columns passed
     *            in were not created by this grid.
     */
    public void setColumns(Column[] columns) {}

    /**
     * Sets the bound member of the DataGrid control's underlying data source. 
     *
     * @param dataMember New value for the dataMember property.
     *
     * @see #getDataMember
     * @see #setDataSource
     */
    public void setDataMember(String dataMember) {}

    /**
     * Sets the data source underlying the DataGrid control.  DataBinding in WFC is done using
     * DataSource and DataMember properties. Each DataSource object can expose
     * one or more named DataMembers. Each DataMember represents one recordset.
     * Each DataSource can have one default DataMember. The default DataMember
     * has a null name.<p>
     *
     * All ADO recordsets are also DataSources. Each recordset has exactly one
     * datamember, which is itself. So, to bind a DataGrid to a simple ADO
     * recordset you simply need to do the following:<p>
     *
     * <pre>
     * this.dataGrid1.setDataMember(null);
     * this.dataGrid1.setDataSource(recordset1);
     * </pre>
     *
     * When working with more complex datasources it may be necessary to specify
     * which data member you want to bind to. For example:<p>
     *
     * <pre>
     * this.dataGrid1.setDataMember("Names");
     * this.dataGrid1.setDataSource(complexDataSource1);
     * </pre>
     *
     * @param dataSource New value for the DataSource property.
     *
     * @see #getDataSource
     * @see #setDataMember
     */
    public void setDataSource(IDataSource dataSource) {}

    /**
     * Sets the default width for all columns in the grid. 
     *
     * @param width New default width, in pixels.
     *
     * @see #getDefaultColumnWidth
     */
    public void setDefaultColumnWidth(int width) {}

    /**
     * Sets a boolean value indicating whether the columns in the grid are
     * determined dynamically. If this property is set to <b>true</b>, then the columns in the
     * grid will always be determined by the columns in the bound data source.
     * Otherwise the columns in the grid will remain static and must be set by the
     * user.
     * 
     * @param value boolean indicating if the columns in the grid should be 
     * determined dynamically.
     * 
     * @see #getDynamicColumns
     */
    public void setDynamicColumns(boolean value) {}
    
    
    private void setEditRow(DataRow row) {}

    /**
     * Sets a value indicating the behavior of the ENTER key within the grid.  EnterAction controls the behavior of the
     * grid when enter is pressed.
     *
     * @param action New value for the EnterAction property.
     *
     * @see #getEnterAction
     *
     * @exception WFCInvalidArgumentException Thrown if action is not a valid
     *            EnterAction.
     */
    public void setEnterAction(int action) {}

    /**
     * Sets the topmost visible row in the grid. 
     *
     * @param row Bookmark of the row that will become the topmost
     *        row.
     *
     * @see #getFirstRow
     *
     * @exception WFCInvalidArgumentException Thrown if row refers to an invalid
     *            row.
     */
    public void setFirstRow(Object row) {}

    private final void setGridState(int bit, boolean value) {}
    
    /**
     * Sets the style of the control's gridlines.  This can be set to a single line, raise
     * or sunken 3D line, or no border.
     *
     * @param gridLineStyle New value for the GridLineStyle property.
     *
     * @see #getGridLineStyle
     *
     * @exception WFCInvalidArgumentException Thrown if gridLineStyle is not
     *            a valid grid line style.
     */
    public void setGridLineStyle(int gridLineStyle) {}

    /**
     * Sets the font of the grid's column headers.  If this is set to null then
     * the DataGrid.Font property will be used for drawing the headers. This
     * property is implemented as an ambient, meaning that getHeaderFont will
     * always return a valid font. By calling setHeaderFont(null) the property
     * simply reverts back to an ambient state where is uses the value of Font.
     *
     * @param headerFont New value for the HeaderFont property.
     *
     * @see #getHeaderFont
     */
    public void setHeaderFont(Font headerFont) {}

    /**
     * Sets the number of lines of text that can be displayed in the grid's column headers.  The height of the column
     * headers is determined by the number of lines to display, and the
     * HeaderFont height.
     *
     * @param lines Number of lines to display.
     *
     * @exception WFCInvalidArgumentException Thrown if lines is less than 1.
     */
    public void setHeaderLineCount(int lines) {}

    
    private void setHorizOffset(int newOffset) {}

    /**
     * Sets the height of the rows. This method is called by both the mouse
     * resizing and the public method resizing functions.
     * @internalonly
     */
    protected void setInternalRowHeight(int height) {}

    /**
     * Sets the leftmost visible column in the grid.  This will force the DataGrid to be scrolled
     * so that the column with the specified index will be flush against
     * the left side of the grid.
     *
     * @param index Display index of the column to make the leftmost.
     *
     * @exception WFCInvalidArgumentException Thrown if index is invalid.
     */
    public void setLeftColumn(int index) {}

    
    private void setMarqueePosition(GridCell cell) {}

    /**
     * Assigns a delegate to the columnEdited event. 
     *
     * @param handler Delegate that will handle the ColumnEdited event;
     *
     * @see #removeOnColumnEdited
     */
    public void addOnColumnEdited(ColumnEventHandler handler) {}

    /**
     * Assigns a delegate to the columnUpdated event. 
     *
     * @param handler Delegate that will handle the ColumnUpdated event;
     *
     * @see #getOnColumnUpdated
     */
    public void addOnColumnUpdated(ColumnEventHandler handler) {}

    /**
     * Assigns a delegate to the deleted event. 
     *
     * @param handler Delegate that will handle the Deleted event;
     *
     * @see #getOnDeleted
     */
    public void addOnDeleted(EventHandler handler) {}

    /**
     * Assigns a delegate to the inserted event. 
     *
     * @param handler Delegate that will handle the Inserted event;
     *
     * @see #getOnInserted
     */
    public void addOnInserted(EventHandler handler) {}

    /**
     * Assigns a delegate to the updated event. 
     *
     * @param handler Delegate that will handle the Updated event;
     *
     * @see #getOnUpdated
     */
    public void addOnUpdated(EventHandler handler) {}

    /**
     * Assigns a delegate to the columnEditing event. 
     *
     * @param handler Delegate that will handle the ColumnEditing event;
     *
     * @see #getOnColumnEditing
     */
    public void addOnColumnEditing(ColumnEditingEventHandler handler) {}

    /**
     * Assigns a delegate to the columnUpdating event. 
     *
     * @param handler Delegate that will handle the ColumnUpdating event;
     *
     * @see #getOnColumnUpdating
     */
    public void addOnColumnUpdating(ColumnUpdatingEventHandler handler) {}

    /**
     * Assigns a delegate to the deleting event. 
     *
     * @param handler Delegate that will handle the Deleting event;
     *
     * @see #getOnDeleting
     */
    public void addOnDeleting(CancelEventHandler handler) {}

    /**
     * Assigns a delegate to the inserting event. 
     *
     * @param handler Delegate that will handle the Inserting event;
     *
     * @see #getOnInserting
     */
    public void addOnInserting(CancelEventHandler handler) {}

    /**
     * Assigns a delegate to the updating event. 
     *
     * @param handler Delegate that will handle the Updating event;
     *
     * @see #getOnUpdating
     */
    public void addOnUpdating(CancelEventHandler handler) {}

    /**
     * Assigns a delegate to the columnResize event. 
     *
     * @param handler Delegate that will handle the ColumnResize event;
     *
     * @see #getOnColumnResize
     */
    public void addOnColumnResize(ColumnResizeEventHandler handler) {}

    /**
     * Assigns a delegate to the error event. 
     *
     * @param handler Delegate that will handle the Error event;
     *
     * @see #getOnError
     */
    public void addOnError(ErrorEventHandler handler) {}

    /**
     * Assigns a delegate to the headerClick event. 
     *
     * @param handler Delegate that will handle the HeaderClick event;
     *
     * @see #getOnHeaderClick
     */
    public void addOnHeaderClick(ColumnEventHandler handler) {}

    /**
     * Assigns a delegate to the positionChange event. 
     *
     * @param handler Delegate that will handle the PositionChange event;
     *
     * @see #getOnPositionChange
     */
    public void addOnPositionChange(PositionChangeEventHandler handler) {}

    /**
     * Assigns a delegate to the rowResize event. 
     *
     * @param handler Delegate that will handle the RowResize event;
     *
     * @see #getOnRowResize
     */
    public void addOnRowResize(CancelEventHandler handler) {}

    /**
     * Assigns a delegate to the scroll event. 
     *
     * @param handler Delegate that will handle the Scroll event;
     *
     * @see #getOnScroll
     */
    public void addOnScroll(CancelEventHandler handler) {}

    /**
     * Assigns a delegate to the selChange event. 
     *
     * @param handler Delegate that will handle the SelChange event;
     *
     * @see #getOnSelChange
     */
    public void addOnSelChange(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the columnEdited event. 
     *
     * @param handler Delegate that will handle the ColumnEdited event;
     *
     * @see #getOnColumnEdited
     */
    public void removeOnColumnEdited(ColumnEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the columnUpdated event. 
     *
     * @param handler Delegate that will handle the ColumnUpdated event;
     *
     * @see #getOnColumnUpdated
     */
    public void removeOnColumnUpdated(ColumnEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the deleted event. 
     *
     * @param handler Delegate that will handle the Deleted event;
     *
     * @see #getOnDeleted
     */
    public void removeOnDeleted(EventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the inserted event. 
     *
     * @param handler Delegate that will handle the Inserted event;
     *
     * @see #getOnInserted
     */
    public void removeOnInserted(EventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the updated event. 
     *
     * @param handler Delegate that will handle the Updated event;
     *
     * @see #getOnUpdated
     */
    public void removeOnUpdated(EventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the columnEditing event. 
     *
     * @param handler Delegate that will handle the ColumnEditing event;
     *
     * @see #getOnColumnEditing
     */
    public void removeOnColumnEditing(ColumnEditingEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the columnUpdating event. 
     *
     * @param handler Delegate that will handle the ColumnUpdating event;
     *
     * @see #getOnColumnUpdating
     */
    public void removeOnColumnUpdating(ColumnUpdatingEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the deleting event. 
     *
     * @param handler Delegate that will handle the Deleting event;
     *
     * @see #getOnDeleting
     */
    public void removeOnDeleting(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the inserting event. 
     *
     * @param handler Delegate that will handle the Inserting event;
     *
     * @see #getOnInserting
     */
    public void removeOnInserting(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the updating event. 
     *
     * @param handler Delegate that will handle the Updating event;
     *
     * @see #getOnUpdating
     */
    public void removeOnUpdating(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the columnResize event. 
     *
     * @param handler Delegate that will handle the ColumnResize event;
     *
     * @see #getOnColumnResize
     */
    public void removeOnColumnResize(ColumnResizeEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the error event. 
     *
     * @param handler Delegate that will handle the Error event;
     *
     * @see #getOnError
     */
    public void removeOnError(ErrorEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the headerClick event. 
     *
     * @param handler Delegate that will handle the HeaderClick event;
     *
     * @see #getOnHeaderClick
     */
    public void removeOnHeaderClick(ColumnEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the positionChange event. 
     *
     * @param handler Delegate that will handle the PositionChange event;
     *
     * @see #getOnPositionChange
     */
    public void removeOnPositionChange(PositionChangeEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the rowResize event. 
     *
     * @param handler Delegate that will handle the RowResize event;
     *
     * @see #getOnRowResize
     */
    public void removeOnRowResize(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the scroll event. 
     *
     * @param handler Delegate that will handle the Scroll event;
     *
     * @see #getOnScroll
     */
    public void removeOnScroll(CancelEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the selChange event. 
     *
     * @param handler Delegate that will handle the SelChange event;
     *
     * @see #getOnSelChange
     */
    public void removeOnSelChange(CancelEventHandler handler) {}

    /**
     * Sets a boolean value indicating whether row selectors are displayed in the grid.
     *  Setting RowSelectors to true will
     * display the row selectors.
     *
     * @param selectors New value of the RowSelectors property.
     *
     * @see #isRowSelectors
     */
    public void setRowSelectors(boolean selectors) {}

    /**
     * Sets the height of the rows in the grid. 
     *
     * @param rowHeight New height of each row, in pixels.
     *
     * @see getRowHeight
     */
    public void setRowHeight(int rowHeight) {}

    public void setComponentSite(IComponentSite value) {}
    
    /**
     * Sets a value indicating which scroll bars are displayed. 
     *
     * @param scroll New value for the Scrollbars property.
     *
     * @see #getScrollbars
     */
    public void setScrollbars(int scroll) {}

    /**
     * Sets the background color for selected cells in the grid.  If
     * you set the SelectedBackColor to null, it will reset to the default of
     * Color.HIGHLIGHT.
     *
     * @param color BackColor for selected cells.
     *
     * @see #getSelectedBackColor
     */
    public void setSelectedBackColor(Color color) {}

    /**
     * Selects the specified columns.  This also removes any current
     * selection.
     *
     * For more information on the behavior of selection
     * see <a href="#setSelectedRows">setSelectedRows</a>.
     *
     * @param columns Array of columns to select
     *
     * @see #getSelectedColumns
     * @see #setSelectedRows
     */
    public void setSelectedColumns(Column[] columns) {}

    /**
     * Sets the color for selected text in the grid.  If
     * you set the SelectedForeColor to null, it will reset to the default of
     * Color.HIGHLIGHTTEXT.
     *
     * @param color ForeColor for selected cells.
     *
     * @see #getSelectedForeColor
     */
    public void setSelectedForeColor(Color color) {}

    /**
     * Selects the rows associated with the specified bookmarks.  This will clear any existing selection. <p>
     *
     * <b>General Selection Notes</b><p>
     * Selection in the DataGrid can be done in one of three ways. Columns,
     * Rows, or Cells can be selected. When selectings Columns or Rows,
     * there can be discontigous selection, and multiple selections. However,
     * when working with Cells, there is only one contiguous rectangular
     * selected range. This range is defined by the (StartColumn, StartRow) to
     * (EndColumn, EndRow).<p>
     *
     * @param rows Array of bookmarks of rows to select.
     *
     * @see #getSelectedRows
     */
    public void setSelectedRows(Object[] bookmarks) {}

    /**
     * Sets a value indicating the behavior of the TAB key within the grid. 
     *
     * @param action New value for the TabAction property.
     *
     * @see #getTabAction
     *
     * @exception WFCInvalidArgumentException Thrown if action is not a valid
     *            TabAction.
     */
    public void setTabAction(int action) {}

    
    private void setupBorder() {}

    /**
     * Sets a boolean value that indicates whether the TAB, ENTER, and arrow keys can
     * be used to wrap the current cell focus around rows and columns.  When wrapcell is turned on, the
     * current cell will wrap from left to right. So, pressing the LEFT button
     * when on column number zero will wrap the current cell around so it is
     * now on the last column, and a row prior.
     *
     * @param wrapCellPointer new Value for the WrapCellPointer property.
     */
    public void setWrapCellPointer(boolean wrapCellPointer) {}

    
    private void showEditor() {}

    
    private void showEditor(char pressed) {}
    
    
    private void showErrorDialog(ErrorEvent event) {}

    
    private void subclassEditor(ICellEditor editor) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void unsubclassEditor(ICellEditor editor) {}

    
    private void updateAllDataFormats() {}
    
    
    private void updateDataFormat(Column col) {}

   
    private void updateEditorVerticalPosition() {}

    
    private void updateStateFromUserSetting() {}
    
    
    private void updateVertScrollbar() {}


    /**
     * wndProc overrides
     * @internalonly
     */
    protected void wndProc(Message m) {}


    
    private class DataConsumer implements IDataConsumer {
        private boolean rowAdded = false;
        /**
         * @internalonly
         *
         * Returns the handle
         */
        public int  getAsyncPostHwnd() {}

        /**
         * Sets the message that the dataprovider will send
         * @internalonly
         */
        public void setAsyncPostMessage(int message) {}

        private void addCompleted() {}
        
        private void deleteCompleted() {}
        
        private void changeCompleted() {}            
        
        /**
         * This event is fired in response to a change on set of rows occuring.
         * Ideally we would want to just invalidate the changes rows, but
         * unfortunately there the RecordsetEvent doesn't contain any bookmark
         * information about the changes rows, so we have to repaint the entire
         * grid.
         *
         * @see IDataConsumer
         * @internalonly
         */
        public void onRecordChangeCompleteHandler(Object sender, RecordsetEvent event) {}

        /**
         * This event is fired when a "major" change occurs in the recordset.
         *
         * @see IDataConsumer
         * @internalonly
         */
        public void onRecordsetChangeCompleteHandler(Object sender, RecordsetEvent event) {}

        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onMoveCompleteHandler(Object sender, RecordsetEvent event) {}

        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onEndOfRecordsetHandler(Object sender, RecordsetEvent event) {}

        public void onError(ErrorEvent event) {}


        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onFieldChangeCompleteHandler(Object sender, RecordsetEvent event) {}

        /**
         * @internalonly
         */
        public void onViewScrolled(boolean offsetValid, int offset) {}

        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onWillChangeRecordHandler(Object sender, RecordsetEvent event) {}
        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onWillChangeRecordsetHandler(Object sender, RecordsetEvent event) {}

        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onWillMoveHandler(Object sender, RecordsetEvent event) {}
        /**
         * @see IDataConsumer
         * @internalonly
         */
        public void onWillChangeFieldHandler(Object sender, RecordsetEvent event) {}

        public void onWillViewScroll(Object sender, CancelEvent cancel) {}

    }

    
    class GridCell {
        public DataRow row = null;
        public int column = -1;

        public GridCell() {}
        public GridCell(int column, DataRow row) {}
    }

    
    class DataGridLocation {

        public int          type = 0;
        public Object       object = null;
        public DataRow      row = null;
        public int          column = -1;
        private Rectangle   bounds = null;

        /**
         * Creates a new DataGridLocation and computes for the specified
         * x,y coords
         * @internalonly
         */
        protected DataGridLocation(int x, int y) {}

        
        private void computeFromClientXY(int x, int y) {}

        /**
         * Simply return the cell bounds for the grid cell that we are over
         * @internalonly
         */
        public Rectangle getBounds() {}
    } 

    /**
     * Implements a data-bound grid that is filled with data from an ADO recordset. The rows  and columns in the grid represent the records and fields in the recordset. 
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        
        
        public static final CategoryAttribute DataCategory = new CategoryAttribute(Sys.getString("CategoryAttributeData"));
        public static final CategoryAttribute DisplayCategory = new CategoryAttribute(Sys.getString("CategoryAttributeDisplay"));

        public static final PropertyInfo allowAddNew = new PropertyInfo(
            DataGrid.class,
            "allowAddNew",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridAllowAddNewDescr")));
        public static final PropertyInfo allowArrows = new PropertyInfo(
            DataGrid.class,
            "allowArrows",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridAllowArrowsDescr")));
        public static final PropertyInfo allowDelete = new PropertyInfo(
            DataGrid.class,
            "allowDelete",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridAllowDeleteDescr")));
        public static final PropertyInfo allowRowSizing = new PropertyInfo(
            DataGrid.class,
            "allowRowSizing",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridAllowRowSizingDescr")));
        public static final PropertyInfo allowUpdate = new PropertyInfo(
            DataGrid.class,
            "allowUpdate",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridAllowUpdateDescr")));
        public static final PropertyInfo borderStyle = new PropertyInfo(
            DataGrid.class,
            "borderStyle",
            com.ms.wfc.ui.BorderStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.BorderStyle.FIXED_3D)),
            new DescriptionAttribute(Sys.getString("DataGridBorderStyleDescr")));
        public static final PropertyInfo caption = new PropertyInfo(
            DataGrid.class,
            "caption",
            String.class,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.NULL,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("DataGridCaptionDescr")));
        public static final PropertyInfo columnHeaders = new PropertyInfo(
            DataGrid.class,
            "columnHeaders",
            Boolean.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridColumnHeadersDescr")));
        public static final PropertyInfo columns = new PropertyInfo(
            DataGrid.class,
            "columns",
            Column[].class,
            
            DefaultValueAttribute.NULL,
            new DescriptionAttribute(Sys.getString("DataGridColumnsDescr")));
        public static final PropertyInfo dataMember = new PropertyInfo(
            DataGrid.class,
            "dataMember",
            String.class,
            CategoryAttribute.Data,
            DefaultValueAttribute.NULL,
            new ValueEditorAttribute(DataMemberEditor.class),
            new DescriptionAttribute(Sys.getString("DataGridDataMemberDescr")));
        public static final PropertyInfo dataSource = new PropertyInfo(
            DataGrid.class,
            "dataSource",
            IDataSource.class,
            CategoryAttribute.Data,
            DefaultValueAttribute.NULL,
            new DescriptionAttribute(Sys.getString("DataGridDataSourceDescr")));
        public static final PropertyInfo defaultColumnWidth = new PropertyInfo(
            DataGrid.class,
            "defaultColumnWidth",
            Integer.TYPE,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(75)),
            new DescriptionAttribute(Sys.getString("DataGridDefaultColumnWidthDescr")));
        public static final PropertyInfo dynamicColumns = new PropertyInfo(
            DataGrid.class,
            "dynamicColumns",
            boolean.class,
            CategoryAttribute.Behavior,
            LocalizableAttribute.NO,
            new DescriptionAttribute(Sys.getString("DataGridDynamicColumns")));
        public static final PropertyInfo enterAction = new PropertyInfo(
            DataGrid.class,
            "enterAction",
            com.ms.wfc.data.ui.EnterAction.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.data.ui.EnterAction.NONE)),
            new DescriptionAttribute(Sys.getString("DataGridEnterActionDescr")));
        public static final PropertyInfo gridLineStyle = new PropertyInfo(
            DataGrid.class,
            "gridLineStyle",
            com.ms.wfc.data.ui.GridLineStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(com.ms.wfc.data.ui.GridLineStyle.SINGLELINE)),
            new DescriptionAttribute(Sys.getString("DataGridGridLineStyleDescr")));
        public static final PropertyInfo headerFont = new PropertyInfo(
            DataGrid.class,
            "headerFont", Font.class,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("DataGridHeaderFontDescr")));
        public static final PropertyInfo headerLineCount = new PropertyInfo(
            DataGrid.class,
            "headerLineCount",
            Integer.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.ONE,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("DataGridHeaderLineCountDescr")));
        public static final PropertyInfo rowHeight = new PropertyInfo(
            DataGrid.class,
            "rowHeight",
            Integer.TYPE,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(20)),
            new DescriptionAttribute(Sys.getString("DataGridRowHeightDescr")));
        public static final PropertyInfo rowSelectors = new PropertyInfo(
            DataGrid.class,
            "rowSelectors",
            Boolean.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("DataGridRowSelectorsDescr")));
        public static final PropertyInfo scrollbars = new PropertyInfo(
            DataGrid.class,
            "scrollbars",
            com.ms.wfc.data.ui.Scrollbars.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(com.ms.wfc.data.ui.Scrollbars.BOTH)),
            new DescriptionAttribute(Sys.getString("DataGridScrollbarsDescr")));
        public static final PropertyInfo selectedBackColor = new PropertyInfo(
            DataGrid.class,
            "selectedBackColor",
            Color.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(Color.HIGHLIGHT),
            new DescriptionAttribute(Sys.getString("DataGridSelectedBackColorDescr")));
        public static final PropertyInfo selectedForeColor = new PropertyInfo(
            DataGrid.class,
            "selectedForeColor",
            Color.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(Color.HIGHLIGHTTEXT),
            new DescriptionAttribute(Sys.getString("DataGridSelectedForeColorDescr")));
        public static final PropertyInfo tabAction = new PropertyInfo(
            DataGrid.class,
            "tabAction",
            com.ms.wfc.data.ui.TabAction.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.data.ui.TabAction.CONTROLNAVIGATION)),
            new DescriptionAttribute(Sys.getString("DataGridTabActionDescr")));
        public static final PropertyInfo wrapCellPointer = new PropertyInfo(
            DataGrid.class,
            "wrapCellPointer",
            Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("DataGridWrapCellPointerDescr")));


        public static final EventInfo columnEdited =  new EventInfo(
            DataGrid.class,
            "columnEdited",
            ColumnEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnColumnEditedDescr")));

        public static final EventInfo columnUpdated = new EventInfo(
            DataGrid.class,
            "columnUpdated",
            ColumnEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnColumnUpdatedDescr")));

        public static final EventInfo deleted = new EventInfo(
            DataGrid.class,
            "deleted",
            EventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnDeletedDescr")));

        public static final EventInfo inserted = new EventInfo(
            DataGrid.class,
            "inserted",
            EventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnInsertedDescr")));

        public static final EventInfo updated = new EventInfo(
            DataGrid.class,
            "updated",
            EventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnUpdatedDescr")));

        public static final EventInfo columnEditing = new EventInfo(
            DataGrid.class,
            "columnEditing",
            ColumnEditingEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnColumnEditingDescr")));

        public static final EventInfo columnUpdating = new EventInfo(
            DataGrid.class,
            "columnUpdating",
            ColumnUpdatingEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnColumnUpdatingDescr")));

        public static final EventInfo deleting = new EventInfo(
            DataGrid.class,
            "deleting",
            CancelEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnDeletingDescr")));

        public static final EventInfo inserting = new EventInfo(
            DataGrid.class,
            "inserting",
            CancelEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnInsertingDescr")));

        public static final EventInfo updating = new EventInfo(
            DataGrid.class,
            "updating",
            CancelEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnUpdatingDescr")));

        public static final EventInfo columnResize = new EventInfo(
            DataGrid.class,
            "columnResize",
            ColumnResizeEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnColumnResizeDescr")));

        public static final EventInfo error = new EventInfo(
            DataGrid.class,
            "error",
            ErrorEventHandler.class,
            DataCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnErrorDescr")));

        public static final EventInfo headerClick = new EventInfo(
            DataGrid.class,
            "headerClick",
            ColumnEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnHeaderClickDescr")));

        public static final EventInfo positionChange = new EventInfo(
            DataGrid.class,
            "positionChange",
            PositionChangeEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnPositionChangeDescr")));

        public static final EventInfo rowResize = new EventInfo(
            DataGrid.class,
            "rowResize",
            CancelEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnRowResizeDescr")));

        public static final EventInfo scroll = new EventInfo(
            DataGrid.class,
            "scroll",
            CancelEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnScrollDescr")));

        public static final EventInfo selChange = new EventInfo(
            DataGrid.class,
            "selChange",
            CancelEventHandler.class,
            DisplayCategory,
            new DescriptionAttribute(Sys.getString("DataGridOnSelChangeDescr")));

        public String getDefaultEventName() {}

        public void getProperties(IProperties iprop) {}

        public void getEvents(IEvents ievent) {}

        public ICustomizer getCustomizer(Object component) {}

    }; 



    /**
     * Implements a data-bound grid that is filled with data from an ADO recordset. The rows  and columns in the grid represent the records and fields in the recordset. 
     * @security(checkClassLinking=on)
     */
    public static class Customizer extends com.ms.wfc.core.Customizer {
        DataGrid grid = null;

        public Customizer(DataGrid grid) {}

        public CustomizerVerb[] getVerbs() {}

        private void onAddColumn(Object sender, VerbExecuteEvent event) {}

        public boolean getHitTest(Point point) {}
    } 


    /**
     * Implements a data-bound grid that is filled with data from an ADO recordset. The rows  and columns in the grid represent the records and fields in the recordset. 
     * @security(checkClassLinking=on)
     */
    public static class DataGridErrorDialog extends ThreadExceptionDialog {
        public DataGridErrorDialog(Throwable t) {}
    } 
 
} 



class EditorWindowProc extends Callback {
    public DataGrid parent = null;

    /**
     * Creates a new instance of the editorwindowproc hook
     * @internalonly
     */
    public EditorWindowProc(DataGrid gridParent) {}

    /**
     * Callback function used to hook into the editor's windowproc
     * @internalonly
     */
    public int callback(int hwnd, int msg, int wparam, int lparam) {}
}