//STRIPPEDSOURCE//


package com.ms.wfc.data.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ui.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;


interface ICellEditor {
    /**
     * Sets the value to be displayed in the editor
     * 
     * @param value Value to display.
     */
    public void setValue(String value);

    /**
     * Returns the value from the editor.
     *
     * @return Value in the editor.
     */
    public String getValue();

    /**
     * Sets the bounds of the editor. This may be called multiple times while
     * the editor is displayed in response to the user scrolling the window.
     *
     * @param visualBounds The new bounding rectangle for the editor
     */
    public void setVisualBounds(Rectangle visualBounds);

    /**
     * This should return true if the editor wants to handle the keycode passed
     * in. This function is used to allow the DataGrid to determine which
     * keys it can use for navigation.<p>
     * In general, the DataGrid will subclass the editor and get a hook into
     * the editor's WndProc and look for key messages. When it hits a key message
     * that would normally be used for cell navigation (i.e. VK_UP, VK_LEFT,
     * etc..) it will ask the editor if it cares about that key. If the editor
     * does care, then the DataGrid will pass the message on without responding,
     * otherwise, the DataGrid will act on that keypress, and the editor will
     * never see the message.
     *
     * @param virtKeyCode The VirtualKey code of the key pressed.
     *
     * @return True if the editor uses the specified key, false if the DataGrid
     *         can safely act on the key.
     */
    public boolean getKeyUsedByEditor(int virtKeyCode);

    /**
     * Returns true if the editor wishes to be hosted as a dialog, instead of
     * as an inplace editor.
     *
     * @return True if the editor is a dialog.
     */
    public boolean getEditorDialog();

    /**
     * Forces the editor to be non-visible.
     */
    public void hideEditor();

    /**
     * Shows the editor, parenting it to the specified window, setting the bounds
     * to the rect, and setting the value.
     *
     * @param parent Control to parent the editor to.
     * @param visualBounds Bounds for the editor.
     * @param value Value to display in the editor.
     */
    public void showEditor(Control parent,
                           Rectangle visualBounds,
                           String value);


}