//STRIPPEDSOURCE//
package com.ms.wfc.html;

import com.ms.wfc.ui.Point;
import com.ms.com.IUnknown;
import com.ms.wfc.html.om.IHTMLEventObj;
import com.ms.wfc.html.om.IHTMLElement;
import com.ms.wfc.html.DhDocument;
import com.ms.wfc.html.DhElement;
import com.ms.wfc.html.DhWindow;
import com.ms.wfc.ui.MouseButton;

import com.ms.com.Variant;

/**
 * Carries event information from the event source to the event sink.  This object is the one and only
 * parameter on any HTML event callback. See <a href="commshtml_ovr.html#DhEvents>eventing overview</a>
 * for the more common usage scenarios.<p> 
 * The information relayed in this class is rich and deep. Probably the best way to
 * understand all the different information conveyed here is to experiment.
 * <p>Start with the following code snippet:
 * <pre>
 *    import com.ms.wfc.html.*;
 *    import com.ms.wfc.html.event.*;
 *    
 *    
 *    public class DumpEvent extends DhModule
 *    {
 *       DhDocument  document;
 *       DhText          text;
 *       
 *       public void documentLoad(Object sender, Event e)
 *       {
 *               document = getDocument();
 *               text = new DhText();
 *               document.add(text,DhDocument.INSERT_BEGINNING);
 *               document.addOnMouseMove( new EventHandler(this,"onMouseMove") );
 *       }
 *    
 *       public void onMouseMove( Object sender, Event event )
 *       {
 *               text.setText( event.toString() );
 *       }
 *    }
 *</pre>
 * Compile that code and put the result onto your CLASSPATH. Now put the following snippet 
 * of HTML onto any page:
 * <pre>
 * &lt;object classid="java:DumpEvent"&gt;&lt;/object&gt;
 * </pre>
 * and point Internet Explorer at that page. As you move the mouse around the page and over 
 * elements, hold various keys down (alt, control, etc.) and you will see the results of all the 
 * different flavors of keyboard and mouse position information available to you.<p>
 * You should also note the nature and effects of the event bubbling -- an effect caused by the
 * fact that all event sources in HTML trigger the same DhEvents all the way up their containment 
 * hierarchy (a.k.a. "bubbling", "broadcasting", "multicasting"). Because we sink the mouse move
 * event at the document (the top of the containment hierarchy) we see all mouse move DhEvents of
 * all elements on the screen.
 *
 * @security(checkClassLinking=on)
 */
public class DhEventInfo { 
    IHTMLEventObj   m_peer;
    DhDocument              m_document;
    DhElement               m_source;
    
    /**
     * @internalonly
     */
    public DhEventInfo(DhDocument document) {}

    /**
     * @internalonly
     */
    final public void clear() {}

    final protected IHTMLEventObj getEventPeer() {}

    /**
     * Retrieves the underlying HTML peer element for this class.  This method may return <b>null</b>
     * if the event is not bound to the document. Java code that is running in a 
     * trusted environment can freely cast the resulting reference to a specific element peer type 
     * (e.g. com.ms.wfc.html.om.IHTMLEventObj). This method will always return <b>null</b> if the
     * code is running in a Web server environment.<p>
     * <em>Note that calling this method represents a very advanced usage scenario. Normally you would
     * never use this method.</em>
     *
     * @return The element peer underlying the HTML peer for this class.
     */
    final public IUnknown getPeer() {}

    /**
     * Retrieves the document object on which this event was triggered. 
     *
     * @return The <a href="com.ms.wfc.html.DhDocument.html">document</a> object this event came from.
     */
    final public DhDocument getDocument() {}

    /**
     * Retrieves the element that the mouse was on before the mouseEnter or mouseLeave
     * event. 
     * Returns the element which the mouse was on before the event.
     * This could be an ordinary element, or the containing
     * <a href="com.ms.wfc.html.DhDocument.html">DhDocument</a>,
     * or could be <b>null</b> if the mouse has moved into the browser
     * window from outside.
     * 
     * If the event is not a mouseEnter or mouseLeave, <b>null</b> is always
     * returned.
     * 
     * @return The <a href="com.ms.wfc.html.DhElement.html">element</a> away
     * from which the mouse moved, or <b>null</b>.
     */
    final public DhElement getFromElement() {}
    
    /**
     * Retrieves the original source of the event.  This may be the object you actually hooked the 
     * event on, or it may one of its children (since all DhEvents "bubble" up the containment
     * hierarchy automatically).
     *
     * @return The <a href="com.ms.wfc.html.DhElement.html">element</a> that first triggered this event.
     */
    final public DhElement getSource() {}

    /**
     * Retrieves the element that the mouse was on following the mouseEnter
     * or mouseLeave event. 
     * Returns the element which the mouse was on after the event.
     * This could be an ordinary element, or the containing
     * <a href="com.ms.wfc.html.DhDocument.html">DhDocument</a>,
     * or could be <b>null</b> if the mouse moved out of the browser
     * window.
     * 
     * If the event is not a mouseEnter or mouseLeave, <b>null</b> is always
     * returned.
     * 
     * @return The <a href="com.ms.wfc.html.DhElement.html">element</a> onto
     * which the mouse moved, or <b>null</b>.
     */
    final public DhElement getToElement() {}
    
    /**
     * All event sources in HTML trigger the same events all the way up their containment
     * hierarchy. Calling this method tells the HTML document to stop event bubbling. k.a. "bubbling", "broadcasting", "multicasting")
     * Calling this method tells the HTML document to stop bubbling the DhEvents up. 
     */
    final public void cancelBubble() {}

    /**
     * Retrieves the current position of the mouse relative to the document client. 
     * @see #toString
     * @return The current position of the mouse.
     */
    final public Point getPoint() {}

    /**
     * Retrieves the current position of the mouse relative to the parent client area. 
     * @see #toString
     * @return The current position of the mouse relative to the parent client area.
     */
    final public Point getClientPoint() {}

    /**
     * Retrieves the current position of the mouse relative to the element's client area. 
     * @see #toString
     * @return The current position of the mouse.
     */
    final public Point getOffsetPoint() {}

    /**
     * Retrieves the current position of the mouse relative to the desktop. 
     * @see #toString
     * @return The current position of the mouse.
     */
    final public Point getScreenPoint() {}

    /**
     * Tests for the CTRL key. 
     *
     * @return <b>true</b> if the control key is pressed.
     */
    final public boolean isCtrlKey() {}

    /**
     * Tests for the SHIFT key. 
     *
     * @return <b>true</b> if the shift key is pressed.
     */
    final public boolean isShiftKey() {}

    /**
     * Tests for the ALT key. 
     *
     * @return <b>true</b> if the alt key is pressed.
     */
    final public boolean isAltKey() {}


    /**
     * Tests for the presence of any key and returns that keypress. 
     *
     * @return The key code of the currently pressed key (or <b>0</b> if no key is pressed).
     */
    final public int getChar() {}

    final public void setChar( int c ) {}

    /**
     * Sets return data for the event.  Use this method to return data
     * to the event source.
     */
    final public void setReturnValue(boolean b) {}

    /**
     * Sets return data for the event.  Use this method to return data
     * to the event source.
     */
    final public void setReturnValue(String s) {}

    /**
     * Sets return data for the event.  Use this method to return data
     * to the event source.
     */
    final public void setReturnValue(int i) {}

    /**
     * Sets return data for the event.  Use this method to return data
     * to the event source.
     */
    final public void setReturnValue( Variant v) {}

    /**
     * Determines whether return data has been set.  Use this method to see if another
     * handler has set the return data
     * to the event source.
     */
    final public Variant getReturnValue() {}

    /**
    * Indicates that no mouse button has been pressed.
    * 
    * 0  No button.  
    * 1  Left button is pressed.  
    * 2  Right button is pressed.  
    * 4  Middle button is pressed 
    */
    public static final int EVT_NOBUTTON     = 0;
    public static final int EVT_LEFTBUTTON   = 1;
    public static final int EVT_RIGHTBUTTON  = 2;
    public static final int EVT_MIDDLEBUTTON = 4;

    /**
     * Tests for mouse button events. 
     * 
     * @return One of the value <a href="#EVT_LEFTBUTTTON">mouse buttons</a> constants.
     */
    final public int getMouseButton() {}

    /**
     * Converts this event object to a string.  Use this when performing diagnostics on your code.
     */
    public String toString() {}
    
}