//STRIPPEDSOURCE//
package com.ms.wfc.html;

import com.ms.wfc.html.event.*;

import com.ms.wfc.ui.Point;
import com.ms.wfc.html.om.IHTMLImgElement;
import com.ms.wfc.core.*;
import com.ms.wfc.ui.ReadyStateEventHandler;
import com.ms.wfc.util.List;

/**
 * Implements an image object that displays a bitmap file in the document.   Use setURL to specify the location of
 * the image.  This URL can be relative to the location of the HTML document.
 *
 * @security(checkClassLinking=on)
 */
public class DhImage extends DhElement { 
    boolean m_urlSet = false;
    DhImageMap m_map = null;
    boolean m_bindMap = false;
    List m_hsList;

    /**
     * Default constuctor
     */
    public DhImage() {}

    /**
     * One step construction, the <i>url</i> refers to the location of the image file.
     *
     * @param url The URL (can be relative to the HTML document) that refers to the image file to display.
     */
    public DhImage(String url) {}
    
    /**
     *@internalonly
     */
    protected int getTagNameID() {}
    
    /**
     *@internalonly
     */
    protected DhEvents createEvents() {}
    
    /**
     * Retrieves the current URL that refers to the location of the image file. 
     *
     * @return The URL (can be relative to the HTML document) that refers to the image file to display.
     */
    final public String getURL() {}

    /**
     * Sets the URL of the image file. 
     *
     * @param url The URL (can be relative to the HTML document) that refers to the bitmap file to display.
     */
    final public void setURL(String url) {}
    
    /**
     * Adds a DhHotSpot object to this image. 
     * The hotspot coordinates must be of the appropriate form for the selected shape
     * from DhHotSpotShapes.
     * @param shape The shape of the hotspot, from DhHotSpotShapes
     * @param coords The coordinate array, in the form specified for the selected shape in DhHotSpotShape
     * @param url  The URL to navigate to when the hotspot is clicked by the user.
     */
    final public void addHotSpot( int shape, int[] coords, String url ){}
    
    /**
     * Adds a DhHotSpot object to this image. 
     * The hotspot coordinates must be of the appropriate form for the selected shape
     * from DhHotSpotShapes.
     * @param shape The shape of the hotspot, from DhHotSpotShapes
     * @param coords The coordinate array, in the form specified for the selected shape in DhHotSpotShape
     * @param h The event handler to fire when the hotspot is clicked.
     */    
    final public void addHotSpot( int shape, int[] coords, EventHandler h ){}
    
    /**
     * Adds a DhHotSpot object to this image. 
     * @param newHotSpot A DhHotSpot object to add to this image
     */
    final public void addHotSpot( DhHotSpot newHotSpot ){}
    
    /**
     * Removes the specified DhHotSpot from the
     * image. 
     * @param hotspot The DhHotspot object to remove
     */
    final public void removeHotSpot( DhHotSpot hotspot ){}
    
    /**
     * Retrieves an array of the DhHotSpot
     * objects contained in this image. 
     * @return An array of DhHotSpot objects associated with this object.
     */
    public DhHotSpot[] getHotSpots(){}
    
    final private boolean ensureMap(){}
    
    
    final String getImageMapName() {}

    final void setImageMapName(String strName) {}

    
    final DhImageMap getImageMap() {}

    
    final void setImageMap(DhImageMap im) {}
    
    
    void setDocument( DhDocument document ) {}

    /**
     * Retrieves the size of the displayed image.   If the image is in an active
     * document in the browser, its actual size will be returned (or WFCException
     * will be fired if it has not finished loading).
     * 
     * Otherwise, only the size explicitly specified for the element (via setSize)
     * will be returned.
     * 
     * @return The image size 
     * @exception WFCException If the image size is not available (usually because the image is loading).
     *
     */
    final public Point getSize() {}

    void onReadyStateChange(Object sender, com.ms.wfc.ui.ReadyStateEvent e) {}

    /** 
     * Determines whether the image has been fully loaded. 
     * @return <b>true</b> if loading of the image is complete.  See "readyStateChange" event.
     * @see #addReadyStateChange
     * @see #getReadyState
     */
    final public boolean getLoadComplete() {}

    /**
     * Returns the current state of the image object. 
     * <p>Possible values include: 
     *  <ul>
     *  <li><b>uninitialized</b>  The object is not initialized with data.  
     *  <li><b>loading</b>  The object is currently loading its data.  
     *  <li><b>interactive</b>  The object can be interacted with even though it is not fully loaded.  
     *  <li><b>complete</b>  The image is completely loaded 
     *  </ul>
     * @return the current state.
     */
    final public String getReadyState() {}

    /**
     * Assigns a delegate to the readyStateChange event. 
     * @param h The handler to be called when the ready state changes
     */
    final public void addOnReadyStateChange    (ReadyStateEventHandler h) {}
    
    /** 
     * Assigns a delegate to the gotFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the current element receives input focus.    
     * @param h A EventHandler to be invoked when this element receives input focus
     */
    public final void addOnGotFocus  ( EventHandler h ) {}
    
    /**
     * Assigns a delegate to the lostFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element loses focus
     *
     * @param h The event handler callback method.
     */
    public final void addOnLostFocus( EventHandler h ) {}

    /**
     * Assigns a delegate to the load event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the image is loaded.
     *
     * @param h The event handler callback method.
     */
    public final void addOnLoad( EventHandler h ) {}

    /**
     * Assigns a delegate to the error event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when an error occurs while loading the image.
     *
     * @param h The event handler callback method.
     */
    public final void addOnError(EventHandler h ) {}

    /**
     * Assigns a delegate to the abort event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the user aborts loading an image.
     *
     * @param h The event handler callback method.
     */
    public final void addOnAbort( EventHandler h ) {}

    /** 
     * Removes the delegate that is assigned to the gotFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the current element receives input focus.    
     * @param h  The EventHandler delegate to call on this event 
     */
    public final void removeOnGotFocus(EventHandler h) {}
    
    /**
     * Removes the delegate that is assigned to the lostFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element loses focus
     *
     * @param h  The EventHandler delegate to call on this event 
     */
    public final void removeOnLostFocus(EventHandler h) {}

    /**
     * Removes the delegate that is assigned to the readyStateChange event. 
     * @param The handler to remove.
     */
    final public void removeOnReadyStateChange    (ReadyStateEventHandler h) {}

    /**
     * Removes the delegate that is assigned to the load event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the image is loaded.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnLoad( EventHandler h ) {}

    /**
     * Removes the delegate that is assigned to the error event.ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when an error occurs while loading the image.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnError(EventHandler h ) {}

    /**
     * Removes the delegate that is assigned to the abort event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the user aborts loading an image.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnAbort( EventHandler h ) {}


/**
 * Implements an image object that displays a bitmap file in the document. 
 * @hidden
 * @internalonly
 *
 * @security(checkClassLinking=on)
 */        
    public static class ClassInfo extends DhElement.ClassInfo {
        public static final PropertyInfo URL =
                                              new PropertyInfo(DhImage.class, "URL", String.class,
                                                               CategoryAttribute.Appearance,
                                                               DefaultValueAttribute.EMPTY_STRING, 
                                                               new DescriptionAttribute("DhImageURL"));
	
        
        public static final EventInfo readyStateChange = new EventInfo(
                                                                       DhImage.class,"readyStateChange", ReadyStateEventHandler.class,
                                                                       CategoryAttribute.Behavior);
        public static final EventInfo gotFocus = new EventInfo(
                                                               DhImage.class,"gotFocus",EventHandler.class,
                                                               CategoryAttribute.Behavior);
        public static final EventInfo lostFocus = new EventInfo(
                                                                DhImage.class,"lostFocus",EventHandler.class,
                                                                CategoryAttribute.Behavior);
        public static final EventInfo load = new EventInfo(
                                                           DhImage.class,"load",EventHandler.class,
                                                           CategoryAttribute.Behavior);
        public static final EventInfo error = new EventInfo(
                                                            DhImage.class,"error",EventHandler.class,
                                                            CategoryAttribute.Behavior);
        public static final EventInfo abort = new EventInfo(
                                                            DhImage.class,"abort",EventHandler.class,
                                                            CategoryAttribute.Behavior);

        public void getProperties(IProperties props) {}
        public void getEvents(IEvents events) {}
    }
}