//STRIPPEDSOURCE//
package com.ms.wfc.html;

import com.ms.wfc.html.om.IHTMLElement;
import com.ms.wfc.html.om.IHTMLSelectElement;
import com.ms.wfc.ui.SelectionMode;

import com.ms.wfc.core.*;

/**
 * Implements an HTML list box control.   It manages adding, removing, and selecting
 * of items, as well as scrolling.  This control can be used within a form 
 * (see <a href="com.ms.wfc.html.DhForm">DhForm</a>) to transmit data.
 *
 *
 * @security(checkClassLinking=on)
 */
public class DhListBox extends DhSelectBox { 

    /**
     * The default ctor creates a DhListBox with 2 visible rows
     * and allowing only single selections
     */
    public DhListBox( ) {}

    /** 
     * Creates a DhListBox object. 
     * @param nRows The initial number of visible rows.  Must be greater than 1.
     * @param selectionMode SelectionMode value determining whether the user can select multiple rows.
     */
    public DhListBox( int nRows, int selectionMode) {}

    /** 
     * Sets the number of visible rows in the list box.  
     * @param nRows Number of rows.  Must be greater than 1.
     * @throws WFCInvalidArgumentException if nRow is less than 2
     */
    public void setVisibleRows( int nRows ) {}

    /**
     * Retrieves the number of currently visible rows. 
     * @return number of rows.
     */
    public int getVisibleRows( ) {}


    /**
     * Retrieves the current selection mode of the list box. 
     * Possible values are
     *
     * SelectionMode.ONE            [1] - Only one item at a time can be
     *                                     selected     
     * SelectionMode.MULTI_EXTENDED [3] - More than one item at a time can be
     *                                     selected and keyboard characters
     *                                     such as SHIFT and CTRL can be used
     *                                     to assist in selection.
     *
     * @return int with the current value
     */
    public int getSelectionMode() {}


    /**
     * Determines how many items at a time can be selected in the list box.  Valid
     * values are
     *
     * SelectionMode.ONE            [1] - Only one item at a time can be
     *                                     selected     
     * SelectionMode.MULTI_EXTENDED [3] - More than one item at a time can be
     *                                     selected and keyboard characters
     *                                     such as SHIFT and CTRL can be used
     *                                     to assist in selection.
     *
     * The "NONE" and "MULTI_SIMPLE" values of SelectionMode are not valid for
     * DhListBox.
     * @param value SelectionMode.ONE or SelectionMode.MULTI_EXTENDED
     * @exception WFCInvalidArgumentException if <i>value</i> is not SelectionMode.ONE or SelectionMode.MULTI_EXTENDED
     */
    public void setSelectionMode(int value) {}

    /**
     * Sets the alignment of the list box relative to the text around it. 
     *
     * @param nAlignment An alignment specification from DhAlignment
     * @see com.ms.wfc.html.DhAlignment
     */
    public void setAlignment( int nAlignment ) {}

    /**
     * Retrieves the current alignment value of the list box. 
     * @see com.ms.wfc.html.DhAlignment
     * @return The current alignment, from DhAlignment
     */
    public int getAlignment() {}

/**
 * Implements an HTML list box control. 
 * @hidden
 * @internalonly
 *
 * @security(checkClassLinking=on)
 */        
    public static class ClassInfo extends DhSelectBox.ClassInfo {
        public static final PropertyInfo visibleRows =
                                                      new PropertyInfo(DhListBox.class, "visibleRows", Integer.TYPE,
                                                                       CategoryAttribute.Appearance,
                                                                       new DescriptionAttribute(Sys.getString("DhListBoxVisibleRows")));
        public static final PropertyInfo selectionMode =
                                                        new PropertyInfo(DhListBox.class, "selectionMode", com.ms.wfc.ui.SelectionMode.class,
                                                                         CategoryAttribute.Appearance,
                                                                         new DefaultValueAttribute(new Integer(com.ms.wfc.ui.SelectionMode.ONE)),
                                                                         new DescriptionAttribute(Sys.getString("DhListBoxSelectMode")));
        public void getProperties(IProperties props) {}
    }
}