//STRIPPEDSOURCE//
package com.ms.wfc.html;

import com.ms.wfc.html.om.IHTMLElement;
import com.ms.wfc.html.event.DhEvents;
import com.ms.wfc.html.event.DhTextListener;

import com.ms.wfc.core.*;
import com.ms.wfc.ui.ScrollEventHandler;

/**
 * Represents static text in an HTML document.  This element will display in one of two
 * modes: free formatted (the default) or honoring of space. The latter means that all
 * whitespace (including carriage returns) are honored, and the element is rendered as a block element
 * with a leading and trailing line feed (unless otherwise positioned).
 *
 * @security(checkClassLinking=on)
 */
public class DhText extends DhElement { 

    int m_mode = DhStringIDs.STR_SPAN;
    boolean m_defMode;

    private String  m_text;
    
    /**
     * The default constructor -- creates a DhText with no text.
     @see #setText
     */
    public DhText() {}

    /**
     * For one step construction, the <i>text</i> is what will be displayed in this element, and
     * <i>mode</i> is the initial display mode.
     *
     * @param text The text to display.
     * @param mode The initial display mode (one of DhTextMode.FLOW, DhTextMode.RESPECT_SPACE, or DhTextMode.NO_BREAK)
     * @see com.ms.wfc.html.DhTextMode#FLOW
     * @see com.ms.wfc.html.DhTextMode#NO_BREAK
     * @see com.ms.wfc.html.DhTextMode#RESPECT_SPACE
     */
    public DhText( String text, int mode ) {}

    /**
     * For one step construction, the <i>text</i> is what will be displayed in this element.
     *
     * @param text The text to display.
     */
    public DhText( String text ) {}

    /**
     * Sets (or resets) the text to display in this element. 
     *
     * @param s The text to display. 
     */
    public void setText( String s ) {}

    /**
     * Retrieves the text this element currently displays when rendered. 
     *
     * @return The text this element displays.
     */
    public String getText() {}
    
    /**
     * Determines whether the text in the object is set to persist. 
     *
     * @return boolean.
     */
    public boolean shouldPersistText() {}

    protected void initFromPeer( IHTMLElement peer ){}
    
    /**
     * @hidden
     * @internalonly
     */
    public void mergeSettings( DhElement eSrc, boolean overWrite ) {}
    
    /**
     *@internalonly
     */
    protected StringBuffer getContent(StringBuffer sb) {}

    /**
     *@internalonly
     */
    protected int getTagNameID() {}

    /**
     *@internalonly
     */
    protected void init( DhParseInfo ph ) {}

    /**
     * Retrieves the current display mode as one of the DhTextMode constants.
     * ms.wfc.html.DhTextMode.html">DhTextMode</a>
     * constants.  DhTextMode.FLOW is the default.
     * @return The current text mode.
     * @see com.ms.wfc.html.DhTextMode
     * @see #setDisplayMode
     */
    public int getDisplayMode(){}

    /**
     * Sets the current display mode as one of the DhTextMode constants. ms.wfc.html.DhTextMode.html">DhTextMode</a>
     * constants.  DhTextMode.FLOW is the default.
     * @param The desired text mode, from DhTextMode
     * @see com.ms.wfc.html.DhTextMode
     * @see #getDisplayMode
     */
    public void setDisplayMode( int mode ){}


    /**
     *@internalonly
     */
    protected DhEvents createEvents() {}

    /** 
     * Assigns a delegate to the gotFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the current element receives input focus.    
     * @param h A EventHandler to be invoked when this element receives input focus
     */
    public final void addOnGotFocus  ( EventHandler h ) {}
    
    /**
     * Assigns a delegate to the lostFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element loses focus
     *
     * @param h The event handler callback method.
     */
    public final void addOnLostFocus    ( EventHandler h ) {}

    /**
     * Assigns a delegate to the resize event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is resized.
     *
     * @param h The event handler callback method.
     */
    public final void addOnResize( EventHandler h ) {}

    /**
     * Assigns a delegate to the scroll event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is scrolled.
     *
     * @param h The event handler callback method.
     */
    public final void addOnScroll( ScrollEventHandler h ) {}

    /**
     * Assigns a delegate to the select event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is selected.
     *
     * @param h The event handler callback method.
     */
    public final void addOnSelect( EventHandler h ) {}

    /**
     * Assigns a delegate to the change event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element's contents changed.
     *
     * @param h The event handler callback method.
     */
    public final void addOnChange( EventHandler h ) {}

    /** 
     * Removes the delegate that is assigned to the gotFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when the current element receives input focus.    
     * @param h  The EventHandler delegate to call on this event 
     */
    public final void removeOnGotFocus(EventHandler h) {}
    
    /**
     * Removes the delegate that is assigned to the lostFocus event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element loses focus
     *
     * @param h  The EventHandler delegate to call on this event 
     */
    public final void removeOnLostFocus(EventHandler h) {}

    /**
     * Removes the delegate that is assigned to the resize event.ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is resized.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnResize( EventHandler h ) {}

    /**
     * Removes the delegate that is assigned to the scroll event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is scrolled.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnScroll( ScrollEventHandler h ) {}

    /**
     * Removes the delegate that is assigned to the select event. ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element is selected.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnSelect( EventHandler h ) {}

    /**
     * Removes the delegate that is assigned to the change event.ms.wfc.html.EventHandler.html">event handler</a> method callback
     * that is triggered when this element's contents changed.
     *
     * @param h The event handler callback method.
     */
    public final void removeOnChange( EventHandler h ) {}

/**
 * Represents static text in an HTML document. 
 * @hidden
 * @internalonly
 *
 * @security(checkClassLinking=on)
 */        
    public static class ClassInfo extends DhElement.ClassInfo {
        public static final PropertyInfo text =
                                               new PropertyInfo(DhText.class, "text", String.class,
                                                                CategoryAttribute.Appearance,
                                                                new DescriptionAttribute(Sys.getString("DhTextText")));
        public static final EventInfo change = new EventInfo(
                                                               DhText.class,"change",EventHandler.class,
                                                               CategoryAttribute.Behavior);
        public static final EventInfo gotFocus = new EventInfo(
                                                               DhText.class,"gotFocus",EventHandler.class,
                                                               CategoryAttribute.Behavior);
        public static final EventInfo lostFocus = new EventInfo(
                                                                DhText.class,"lostFocus",EventHandler.class,
                                                                CategoryAttribute.Behavior);
        public static final EventInfo resize = new EventInfo(
                                                               DhText.class,"resize",EventHandler.class,
                                                               CategoryAttribute.Behavior);
        public static final EventInfo scroll = new EventInfo(
                                                               DhText.class,"scroll", ScrollEventHandler.class,
                                                               CategoryAttribute.Behavior);
        public static final EventInfo select = new EventInfo(
                                                               DhText.class,"select",EventHandler.class,
                                                               CategoryAttribute.Behavior);

        public void getProperties(IProperties props) {}

        public void getEvents(IEvents events) {}

    }

}