//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.com.*;

/**
 * Provides a base implementation of the IDataStream interface.  To
 * create an implementation of IDataStream you would typically inherit from
 * this class.<p>
 *
 * To support reading, a subclass must minimally implement the
 * <a href="#read()">read</a> and <a href="#readCore">readCore</a> methods.
 * To support writing, a subclass must minimally implement the
 * <a href="#write(int)">write</a> and <a href="#writeCore">writeCore</a> methods.
 * To support random access seeking, a subclass must implement the
 * <a href="#getLength">getLength</a>, <a href="#setLength">setLength</a>,
 * <a href="#getPosition">getPosition</a>, and
 * <a href="#setPosition">setPosition</a> methods. Finally, the
 * <a href="#close">close</a> and <a href="#flush">flush</a> methods can be
 * overridden if required.
 *
 * @see com.ms.wfc.io.BufferedStream
 * @see com.ms.wfc.io.DataStreamFromComStream
 * @see com.ms.wfc.io.File
 * @see com.ms.wfc.io.IByteStream
 * @see com.ms.wfc.io.IDataStream
 * @see com.ms.wfc.io.MemoryStream
 *
 * @security(checkClassLinking=on)
 */
public class DataStream implements IDataStream
{
    protected IStream comStream;

    /**
     * Constructs a DataStream. This constructor is protected to prevent
     * instantiation of this class.
     */
    protected DataStream() {}

    /**
     * Determines whether this stream supports reading. 
     * Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#canRead">IByteStream.canRead</a>
     * method. This default method always returns true, but descendant classes
     * can override the method to provide the appropriate functionality.
     */
    public boolean canRead() {}

    /**
     * Determines whether this stream supports seeking. 
     * Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#canSeek">IByteStream.canSeek</a>
     * method. This default method always returns true, but descendant classes
     * can override the method to provide the appropriate functionality.
     */
    public boolean canSeek() {}

    /**
     * Determines whether this stream supports reading. 
     * Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#canWrite">IByteStream.canWrite</a>
     * method. This default method always returns true, but descendant classes
     * can override the method to provide the appropriate functionality.
     */
    public boolean canWrite() {}

    /**
     * Closes this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#close">IByteStream.close</a>
     * method. This default method is empty, but descendant classes can
     * override the method to provide the appropriate functionality.
     */
    public void close() {}

    /**
     * @internalonly
     */
    protected static void eofError() {}

    /**
     * Flushes this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#flush">IByteStream.flush</a>
     * method. This default method is empty, but descendant classes can
     * override the method to provide the appropriate functionality.
     */
    public void flush() {}

    /**
     * Retrieves an IDataStream object for an IStream
     * object.  In cases where you have a COM
     * compatible com.ms.com.IStream, but need an IDataStream, you can use this
     * method to create an adapter.<p>
     *
     * If the given IStream is null, the function returns null. Otherwise, if
     * the given IStream can itself provide an IDataStream (i.e. if it
     * implements IDataStreamProvider), then that IDataStream is returned.
     * Otherwise, a
     * <a href="com.ms.wfc.io.DataStreamFromComStream.html">DataStreamFromComStream</a>
     * object is created and returned.
     *
     * @param comStream The IStream for which to create an IDataStream.
     * @return An IDataStream for the given IStream.
     * @see #getComStream
     * @see #toComStream
     */
    public static IDataStream fromComStream(IStream comStream) {}

    /**
     * Retrieves an IStream for this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#getComStream">IDataStream.getComStream</a>
     * method.<p>
     *
     * Unless one already exists, this method creates a
     * <a href="com.ms.wfc.io.ComStreamFromDataStream">ComStreamFromDataStream</a>
     * object for this IDataStream. The adapter object is cached and returned
     * by subsequent calls to <code>getComStream</code>.
     *
     * @return A COM compatible com.ms.com.IStream implementation for this
     * stream.
     * @see #fromComStream
     * @see #toComStream
     */
    public IStream getComStream() {}

    /**
     * Retrieves the length of this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#getLength">IByteStream.getLength</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public long getLength() {}

    /**
     * Retrieves the position of this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#getPosition">IByteStream.getPosition</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public long getPosition() {}

    /**
     * Reads the next byte of data from this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#read()">IByteStream.read</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public int read() {}

    /**
     * Reads the next byte of data from this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#read(byte[], int, int)">IByteStream.read</a>
     * method. This default implementation validates the arguments and then
     * calls the <a href="#readCore">readCore</a> method to read the data.
     */
    public int read(byte[] buffer, int index, int count) {}

    /**
     * Reads a boolean value from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readBoolean">IDataStream.readBoolean</a>
     * method. The method calls the <a href="#read()">read</a> method to read a
     * byte and returns <code>true</code> if the byte is non-zero or
     * <code>false</code> if the byte is zero.
     */
    public boolean readBoolean() {}

    /**
     * Reads a byte from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readByte">IDataStream.readByte</a>
     * method. The method calls the <a href="#read()">read</a> method to read
     * the byte.
     */
    public byte readByte() {}

    /**
     * Reads a block of bytes from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readBytes(int)">IDataStream.readBytes</a>
     * method. The method calls the <a href="#read(byte[], int, int)">read</a>
     * method to read the data.
     */
    public byte[] readBytes(int count) {}

    /**
     * Reads a block of bytes from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readBytes(byte[], int, int)">IDataStream.readBytes</a>
     * method. The method calls the <a href="#read(byte[], int, int)">read</a>
     * method to read the data.
     */
    public void readBytes(byte[] buffer, int index, int count) {}

    /**
     * Reads a character from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readChar">IDataStream.readChar</a>
     * method. The method calls the <a href="#read()">read</a> method to read
     * two bytes and combines them into a character.
     */
    public char readChar() {}

    /**
     * Reads the specified number of characters from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readChars(int)">IDataStream.readChars</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public char[] readChars(int count) {}

    /**
     * Reads the specified number of characters from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readChars(char[], int, int)">IDataStream.readChars</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readChars(char[] buffer, int index, int count) {}

    /**
     * Implements the core array read method.  This method is called from the other array
     * reading methods of this class. The method must read <code>count</code>
     * bytes of data into <code>buffer</code> starting at byte offset
     * <code>offset</code>. The <code>buffer</code> parameter is guaranteed to
     * be of type <code>byte[]</code>, <code>char[]</code>, <code>short[]</code>,
     * <code>int[]</code>, <code>long[]</code>, <code>float[]</code>, or
     * <code>double[]</code>. This default implementation raises an IOException,
     * but descendant classes can override the method to provide the appropriate
     * functionality.
     *
     * @param buffer An array of a primitive type.
     * @param offset Byte offset into the buffer.
     * @param count Number of bytes to read.
     * @exception IOException If an error occurs or if the stream does not
     * support reading.
     */
    protected int readCore(Object buffer, int offset, int count) {}

    /**
     * Reads a double value from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readDouble">IDataStream.readDouble</a>
     * method. The method calls the <a href="#readLong()">readLong</a> method
     * to read a <code>long</code>, and then converts the bits of the
     * <code>long</code> to a <code>double</code>.
     */
    public double readDouble() {}

    /**
     * Reads the specified number of doubles from this stream into a double
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readDoubles(int)">IDataStream.readDoubles</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public double[] readDoubles(int count) {}

    /**
     * Reads the specified number of doubles from this stream into a double
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readDoubles(double[], int, int)">IDataStream.readDoubles</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readDoubles(double[] buffer, int index, int count) {}

    /**
     * @internalonly
     */
    protected static void readError() {}

    /**
     * Reads a float value from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readFloat">IDataStream.readFloat</a>
     * method. The method calls the <a href="#readInt()">readInt</a> method
     * to read an <code>int</code>, and then converts the bits of the
     * <code>int</code> to a <code>float</code>.
     */
    public float readFloat() {}

    /**
     * Reads a specified number of float values from this stream into a float
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readFloats(int)">IDataStream.readFloats</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public float[] readFloats(int count) {}

    /**
     * Reads a specified number of float values from this stream into a float
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readFloats(float[], int, int)">IDataStream.readFloats</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readFloats(float[] buffer, int index, int count) {}

    /**
     * Reads an integer from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readInt">IDataStream.readInt</a>
     * method. The method calls the <a href="#read()">read</a> method to read
     * four bytes and combines them into an integer.
     */
    public int readInt() {}

    /**
     * Reads the specified number of integers from this stream into an integer array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readInts(int)">IDataStream.readInts</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public int[] readInts(int count) {}

    /**
     * Reads the specified number of integers from this stream into an integer array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readInts(int[], int, int)">IDataStream.readInts</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readInts(int[] buffer, int index, int count) {}

    /**
     * Reads a long value from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readLong">IDataStream.readLong</a>
     * method. The method calls the <a href="#readInt()">readInt</a> method
     * twice, and combines the two integers into a long integer.
     */
    public long readLong() {}

    /**
     * Reads the specified number of long integers from this stream into a long
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readLongs(int)">IDataStream.readLongs</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public long[] readLongs(int count) {}

    /**
     * Reads the specified number of long integers from this stream into a long
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readLongs(long[], int, int)">IDataStream.readLongs</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readLongs(long[] buffer, int index, int count) {}

    /**
     * Reads a short value from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readShort">IDataStream.readShort</a>
     * method. The method calls the <a href="#read()">read</a> method to read
     * two bytes and combines them into a short integer.
     */
    public short readShort() {}

    /**
     * Reads the specified number of short integers from this stream into a short
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readShorts(int)">IDataStream.readShorts</a>
     * method. The method calls the <a href="#readCore">readCore</a> method
     * to read the data.
     */
    public short[] readShorts(int count) {}

    /**
     * Reads the specified number of short integers from this stream into a short
     * array. Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readShorts(short[], int, int)">IDataStream.readShorts</a>
     * method. The method validates the arguments and then calls the
     * <a href="#readCore">readCore</a> method to read the data.
     */
    public void readShorts(short[] buffer, int index, int count) {}

    /**
     * Reads a length-prefixed Unicode string from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readString">IDataStream.readString</a>
     * method.
     */
    public String readString() {}

    /**
     * Reads a Unicode string from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readStringChars">IDataStream.readStringChars</a>
     * method.
     */
    public String readStringChars(int length) {}

    /**
     * Reads an American National Standards Institute (ANSI) string from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readStringCharsAnsi">IDataStream.readStringCharsAnsi</a>
     * method.
     */
    public String readStringCharsAnsi(int length) {}

    /**
     * Reads a null-terminated Unicode string from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readStringNull">IDataStream.readStringNull</a>
     * method.
     */
    public String readStringNull() {}

    /**
     * Reads a null-terminated ANSI string from this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readStringNullAnsi">IDataStream.readStringNullAnsi</a>
     * method.
     */
    public String readStringNullAnsi() {}

    /**
     * Reads all data from the current position to the end of this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readToEnd">IDataStream.readToEnd</a>
     * method.
     */
    public byte[] readToEnd() {}

    /**
     * Reads a string from this stream using a length-prefixed UTF-8 format. 
     * Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#readUTF">IDataStream.readUTF</a>
     * method.
     */
    public String readUTF() {}

    /**
     * @internalonly
     */
    protected static void seekError() {}

    /**
     * Sets the length of this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#setLength">IByteStream.setLength</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public void setLength(long length) {}

    /**
     * Sets the position of this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#setPosition">IByteStream.setPosition</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public void setPosition(long position) {}

    /**
     * Retrieves an IStream object for an IDataStream object.  In cases where you have an
     * IDataStreamm, but need a COM compatible com.ms.com.IStream, you can use
     * this method to create an adapter.<p>
     *
     * If the given IDataStream is null, the function returns null. Otherwise,
     * the <a href="#getComStream">getComStream</a> method is called to create
     * an IStream from the IDataStream.
     *
     * @param dataStream The IDataStream for which to create an IStream.
     * @return An IStream for the given IDataStream.
     * @see #fromComStream
     * @see #getComStream
     */
    public static IStream toComStream(IDataStream dataStream) {}

    /**
     * @internalonly
     */
    protected static void utfError() {}

    /**
     * Writes bytes of data to this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#write(int)">IByteStream.write</a>
     * method. This default implementation raises an IOException, but descendant
     * classes can override the method to provide the appropriate functionality.
     */
    public void write(int value) {}

    /**
     * Writes bytes of data to this stream.  Implements the
     * <a href="com.ms.wfc.io.IByteStream.html#write(byte[], int, int)">IByteStream.write</a>
     * method. This default implementation validates the arguments and then
     * calls the <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void write(byte[] buffer, int index, int count) {}

    /**
     * Writes a boolean value to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeBoolean">IDataStream.writeBoolean</a>
     * method. The method calls the <a href="#write(int)">write</a> method to
     * write a byte to the stream with the value 0 for <code>false</code> or
     * the value 1 for <code>true</code>.
     */
    public void writeBoolean(boolean value) {}

    /**
     * Writes a byte to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeByte">IDataStream.writeByte</a>
     * method. The method calls the <a href="#write(int)">write</a> method to
     * write the byte to the stream.
     */
    public void writeByte(byte value) {}

    /**
     * Writes a block of bytes to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeBytes(byte[])">IDataStream.writeBytes</a>
     * method. The method calls the <a href="#write(byte[], int, int)">write</a> method to
     * write the data.
     */
    public void writeBytes(byte[] buffer) {}

    /**
     * Writes a character to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeChar">IDataStream.writeChar</a>
     * method. The method calls the <a href="#write(int)">write</a> method to
     * write two bytes to the stream.
     */
    public void writeChar(char value) {}

    /**
     * Writes the contents of the specified character array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeChars(char[])">IDataStream.writeChars</a>
     * method. The method calls the
     * <a href="#writeChars(char[], int, int)">writeChars</a> method to write
     * the data.
     */
    public void writeChars(char[] buffer) {}

    /**
     * Writes the contents of the specified character array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeChars(char[], int, int)">IDataStream.writeChars</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeChars(char[] buffer, int index, int count) {}

    /**
     * Implements the core array write method.  This method is called from the other array
     * writing methods of this class. The method must write <code>count</code>
     * bytes of data from <code>buffer</code> starting at byte offset
     * <code>offset</code>. The <code>buffer</code> parameter is guaranteed to
     * be of type <code>byte[]</code>, <code>char[]</code>, <code>short[]</code>,
     * <code>int[]</code>, <code>long[]</code>, <code>float[]</code>, or
     * <code>double[]</code>. This default implementation raises an IOException,
     * but descendant classes can override the method to provide the appropriate
     * functionality.
     *
     * @param buffer An array of a primitive type.
     * @param offset Byte offset into the buffer.
     * @param count Number of bytes to write.
     * @exception IOException If an error occurs or if the stream does not
     * support writing.
     */
    protected void writeCore(Object buffer, int offset, int count) {}

    /**
     * Writes a double value to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeDouble">IDataStream.writeDouble</a>
     * method. The method converts the bits of the <code>double</code> to a
     * <code>long</code>, and then calls the <a href="#writeLong()">writeLong</a>
     * method to write the value to the stream.
     */
    public void writeDouble(double value) {}

    /**
     * Writes the contents of the specified double array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeDoubles(double[])">IDataStream.writeDoubles</a>
     * method. The method calls the
     * <a href="#writeDoubles(double[], int, int)">writeDoubles</a> method to
     * write the data.
     */
    public void writeDoubles(double[] buffer) {}

    /**
     * Writes the contents of the specified double array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeDoubles(double[], int, int)">IDataStream.writeDoubles</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeDoubles(double[] buffer, int index, int count) {}

    /**
     * @internalonly
     */
    protected static void writeError() {}

    /**
     * Writes a float value to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeFloat">IDataStream.writeFloat</a>
     * method. The method converts the bits of the <code>float</code> to an
     * <code>int</code>, and then calls the <a href="#writeInt()">writeInt</a>
     * method to write the value to the stream.
     */
    public void writeFloat(float value) {}

    /**
     * Writes the contents of the specified float array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeFloats(float[])">IDataStream.writeFloats</a>
     * method. The method calls the
     * <a href="#writeFloats(float[], int, int)">writeFloats</a> method to
     * write the data.
     */
    public void writeFloats(float[] buffer) {}

    /**
     * Writes the contents of the specified float array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeFloats(float[], int, int)">IDataStream.writeFloats</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeFloats(float[] buffer, int index, int count) {}

    /**
     * Writes an integer to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeInt">IDataStream.writeInt</a>
     * method. The method calls the <a href="#write(int)">write</a> method to
     * write four bytes to the stream.
     */
    public void writeInt(int value) {}

    /**
     * Writes the contents of the specified integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeInts(int[])">IDataStream.writeInts</a>
     * method. The method calls the
     * <a href="#writeInts(int[], int, int)">writeInts</a> method to write the
     * data.
     */
    public void writeInts(int[] buffer) {}

    /**
     * Writes the contents of the specified integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeInts(int[], int, int)">IDataStream.writeInts</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeInts(int[] buffer, int index, int count) {}

    /**
     * Writes a long value to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeLong">IDataStream.writeLong</a>
     * method. The method calls the <a href="#writeInt">writeInt</a> method
     * twice to write the <code>long</code> to the stream.
     */
    public void writeLong(long value) {}

    /**
     * Writes the contents of the specified long integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeLongs(long[])">IDataStream.writeLongs</a>
     * method. The method calls the
     * <a href="#writeLongs(long[], int, int)">writeLongs</a> method to write
     * the data.
     */
    public void writeLongs(long[] buffer) {}

    /**
     * Writes the contents of the specified long integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeLongs(long[], int, int)">IDataStream.writeLongs</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeLongs(long[] buffer, int index, int count) {}

    /**
     * Writes a short value to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeShort">IDataStream.writeShort</a>
     * method. The method calls the <a href="#write(int)">write</a> method to
     * write two bytes to the stream.
     */
    public void writeShort(short value) {}

    /**
     * Writes the contents of the specified short integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeShorts(short[])">IDataStream.writeShorts</a>
     * method. The method calls the
     * <a href="#writeShorts(short[], int, int)">writeShorts</a> method to
     * write the data.
     */
    public void writeShorts(short[] buffer) {}

    /**
     * Writes the contents of the specified short integer array to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeShorts(short[], int, int)">IDataStream.writeShorts</a>
     * method. The method validates the arguments and then calls the
     * <a href="#writeCore">writeCore</a> method to write the data.
     */
    public void writeShorts(short[] buffer, int index, int count) {}

    /**
     * Writes a length-prefixed Unicode string to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeString">IDataStream.writeString</a>
     * method.
     */
    public void writeString(String value) {}

    /**
     * Writes a Unicode string to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeStringChars">IDataStream.writeStringChars</a>
     * method.
     */
    public void writeStringChars(String value) {}

    /**
     * Writes an ANSI string to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeStringCharsAnsi">IDataStream.writeStringCharsAnsi</a>
     * method.
     */
    public void writeStringCharsAnsi(String value) {}

    /**
     * Writes a null-terminated Unicode string to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeStringNull">IDataStream.writeStringNull</a>
     * method.
     */
    public void writeStringNull(String value) {}

    /**
     * Writes a null-terminated ANSI string to this stream.  Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeStringNullAnsi">IDataStream.writeStringNullAnsi</a>
     * method.
     */
    public void writeStringNullAnsi(String value) {}

    /**
     * Writes a string to this stream using a length-prefixed UTF-8 format. 
     * Implements the
     * <a href="com.ms.wfc.io.IDataStream.html#writeUTF">IDataStream.writeUTF</a>
     * method.
     */
    public void writeUTF(String value) {}
}