//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.app.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.core.*;
import com.ms.dll.*;

/**
 * Implements access to files.  It implements the IDataStream
 * interface for a file, and also contains a number of methods to perform file,
 * directory, and path oriented functions.<p>
 *
 * Instances of <code>File</code> can be created using the constructors of the
 * class or the <code>create</code>, <code>open</code>, <code>openRead</code>,
 * <code>openStandardError</code>, <code>openStandardInput</code>, or
 * <code>openStandardOutput</code> static methods.<p>
 *
 * For a complete list of I/O methods supported by a file, please refer to
 * <a href="com.ms.wfc.io.IByteStream.html">IByteStream</a> and
 * <a href="com.ms.wfc.io.IDataStream.html">IDataStream</a> interfaces.<p>
 *
 * Note that File implements direct access to the underlying file with no
 * buffering. In cases where you're performing a large number of fairly small
 * read or write operations, you can increase performance by putting a
 * <a href="com.ms.wfc.io.BufferedStream.html">BufferedStream</a> in front of
 * the File object.<p>
 *
 * Any errors that originate from the operating system while performing
 * operations on a File are reported using the
 * <a href="com.ms.wfc.io.WinIOException.html">WinIOException</a> class, which
 * provides access to the underlying operating system error code.
 *
 * @security(checkClassLinking=on)
 */
public class File extends DataStream
{
    protected int handle = -1;
    boolean ownsHandle;
    private int[] temp;
    private int bytes;

    /**
     * Creates or opens a file. The <i>path</i> parameter specifies the name of
     * the file to create or open. The <i>mode</i> parameter specifies the mode
     * used to open the file, and can be any value from the <i>FileMode</i>
     * enumeration. The file is opened for read/write access with no sharing
     * allowed.
     *
     * @param path The path of the file to create or open.
     * @param mode Requested file mode. Any value from <i>FileMode</i>.
     * @exception WinIOException If an error occurs.
     * @see #File(String, int, int, int)
     */
    public File(String path, int mode) {}

    /**
     * Creates or opens a file. The <i>path</i> parameter specifies the name of
     * the file to create or open. The <i>mode</i> parameter specifies the mode
     * used to open the file, and can be any value from the <i>FileMode</i>
     * enumeration. The <i>access</i> parameter specifies the required access
     * to the file, and can be any value from the <i>FileAccess</i> enumeration.
     * If the file is opened for reading only it will support read sharing;
     * otherwise, no sharing will be allowed.
     *
     * @param path The path of the file to create or open.
     * @param mode Requested file mode. Any value from <i>FileMode</i>.
     * @param access Requested file access. Any value from <i>FileAccess</i>.
     * @exception WinIOException If an error occurs.
     * @see #File(String, int, int, int)
     */
    public File(String path, int mode, int access) {}

    /**
     * Creates or opens a file. The <i>path</i> parameter specifies the name of
     * the file to create or open. The <i>mode</i> parameter specifies the mode
     * used to open the file, and can be any value from the <i>FileMode</i>
     * enumeration. The <i>access</i> parameter specifies the required access
     * to the file, and can be any value from the <i>FileAccess</i> enumeration.
     * The <i>share</i> parameter specifies the sharing that the file will
     * support once opened, and can be any value from the <i>FileShare</i>
     * enumeration.
     *
     * <p>The specified file is created or opened according to the specified
     * options. The file remains open until the <i>close</i> method is
     * called, or until the <i>File</i> object is garbage collected.
     * Following a call to <i>close</i>, any operations on the file will
     * raise exceptions.
     *
     * @param path The path of the file to create or open.
     * @param mode requested file mode. Any value from <i>FileMode</i>.
     * @param access requested file access. Any value from <i>FileAccess</i>.
     * @param share requested file sharing. Any value from <i>FileShare</i>.
     * @exception WinIOException If an error occurs.
     * @see #close
     * @see #create
     * @see #open
     * @see #openRead
     * @see #openStandardError
     * @see #openStandardInput
     * @see #openStandardOutput
     */
    public File(String path, int mode, int access, int share) {}

    /**
     * Creates a <code>File</code> object from an existing file handle. The
     * specified handle is considered externally managed, and will not be
     * automatically closed when the <code>close</code> method is called or
     * when the <code>File</code> object is garbage collected.
     *
     * @param handle An existing file handle.
     */
    public File(int handle) {}

    /**
     * Creates a <code>File</code> object from an existing file handle. The
     * <code>owned</code> parameter specifies whether the <code>File</code>
     * object owns the given handle. An un-owned file handle is not
     * automatically closed when the <code>close</code> method is called or
     * when the <code>File</code> object is garbage collected.
     *
     * @param handle An existing file handle.
     * @param owned Indicates whether the file object owns the handle.
     */
    public File(int handle, boolean owned) {}

    /**
     * Returns a boolean indicating whether this file supports reading. The
     * resulting value is true if the file was opened with FileAccess.READ and
     * if the file has not been closed.
     *
     * @return true if the file supports reading, false otherwise.
     */
    public boolean canRead() {}

    /**
     * Returns a boolean indicating whether this file supports seeking. The
     * resulting value is true if the file represents a disk file (as opposed
     * to a communication device or a pipe) and if the file has not been closed.
     *
     * @return true if the file supports seeking, false otherwise.
     */
    public boolean canSeek() {}

    /**
     * Returns a boolean indicating whether this file supports writing. The
     * resulting value is true if the file was opened with FileAccess.WRITE and
     * if the file has not been closed.
     *
     * @return true if the file supports writing, false otherwise.
     */
    public boolean canWrite() {}

    /**
     * Changes the extension of a file path.  The <code>path</code> parameter
     * specifies a file path, and the <code>extension</code> parameter
     * specifies a file extension (with a leading period, such as
     * <code>".exe"</code> or <code>".java"</code>).<p>
     *
     * The function returns a file path with the same root, directory, and base
     * name parts as <code>path</code>, but with the file extension changed to
     * the specified extension. If <code>path</code> is null, the function
     * returns null. If <code>path</code> does not contain a file extension,
     * the new file extension is appended to the path. If <code>extension</code>
     * is null, any exsiting extension is removed from <code>path</code>.
     *
     * @param path The path for which to change file extension.
     * @param extension The new file extension (with a leading period), or
     * null to remove the extension.
     * @return Path with the new file extension.
     * @see #getExtension
     * @see #hasExtension
     */
    public static String changeExtension(String path, String extension) {}

    /**
     * Closes this file.  Unless the <code>File</code> object was created from
     * an existing file handle, the underlying file handle is closed using the
     * <code>CloseHandle</code> Windows API function. Once closed, it is an
     * error to perform operations on the file, and attempts to do so will
     * raise <code>IOException</code> exceptions. To reopen a file, a new
     * <code>File</code> object must be created.
     *
     * @see com.ms.wfc.io.IByteStream#close
     */
    public void close() {}

    /**
     * Combines two file paths.  If <code>path2</code> is not rooted (i.e. if
     * <code>path2</code> does not start with a backslash or a drive specifier),
     * the result is a concatenation of the two paths, with an intervening
     * backslash ("\") character if required. If <code>path2</code> is rooted,
     * the result is <code>path2</code>. If either <code>path1</code> or
     * <code>path2</code> is null, the result is the non-null string. If both
     * <code>path1</code> and <code>path2</code> are null, the result is null.
     *
     * @param path1 The first path.
     * @param path2 The second path.
     * @result The combined path.
     */
    public static String combine(String path1, String path2) {}

    /**
     * Copies an existing file to a new file.  An exception is raised if the
     * destination file already exists. Use the <code>copyOver</code> method
     * to allow overwriting an existing file.
     *
     * @param sourceFileName The name of the file to copy.
     * @param destFileName The name of the new file to copy to.
     * @exception WinIOException If an error occurs or if the destination file
     * already exists.
     * @see #copyOver
     */
    public static void copy(String sourceFileName, String destFileName) {}

    /**
     * Copies an existing file to a new or existing file.  Unlike the
     * <code>copy</code> method, this method does not raise an exception if the
     * destination file already exists.
     *
     * @param sourceFileName The name of the file to copy.
     * @param destFileName The name of the new file to copy to.
     * @exception WinIOException If an error occurs.
     * @see #copy
     */
    public static void copyOver(String sourceFileName, String destFileName) {}

    /**
     * Creates a new file.  If a file by the given name already exists, it is
     * truncated to zero length. The returned <code>File</code> object will
     * have both read and write access to the new file.
     *
     * @param path The name of the file to create.
     * @return A <code>File</code> object for the new file.
     * @exception WinIOException If an error occurs.
     * @see #File(String,int)
     * @see #close
     */
    public static File create(String path) {}

    /**
     * Creates all directories designated by the specified path.  Unlike the
     * <code>createDirectory</code> method, this method will create as many
     * directories as are required to guarantee that the given path is valid.
     * It is not an error if some or all of the specified directories exist.
     * The <code>path</code> argument specifies a directory path, not a file
     * path. To ensure that all directories of a file path are created, use
     * the construct
     * <code>File.createDirectories(File.getDirectory(filePath))</code>.
     *
     * @param path The path of directories to create.
     * @exception WinIOException If an error occurs.
     * @see #createDirectory
     */
    public static void createDirectories(String path) {}

    /**
     * Creates a new directory.  Except for the last element, the given path
     * must specify an existing directory. The last element of the path
     * specifies the name of the new directory to create. It is an error if
     * a file or directory with that name already exists.
     *
     * @param path Path of the directory to create.
     * @exception WinIOException If an error occurs.
     * @see #createDirectories
     * @see #removeDirectory
     */
    public static void createDirectory(String path) {}

    /**
     * Deletes a file.  The file given by the specified path is deleted. It is
     * not an error if the specified file does not exist.
     *
     * @param path The path of the file to delete.
     * @exception WinIOException If an error occurs.
     */
    public static void delete(String path) {}

    /**
     * Determines whether a file exists.  The result is <code>true</code> if the file
     * given by the specified path exists; otherwise, the result is
     * <code>false</code>.
     *
     * @param path The path of the file to test.
     * @return Boolean indicating whether the file exists.
     */
    public static boolean exists(String path) {}

    /**
     * Finalizes this File object by ensuring that the close method is
     * called. 
     */
    protected void finalize() throws Throwable {}

    /**
     * Clears the buffers for this file and causes all buffered data to be written to the
     * file.  This method calls the <code>FlushFileBuffers</code>
     * Windows API function.
     *
     * @exception WinIOException If an error occurs or if the file has been
     * closed.
     * @see com.ms.wfc.io.IByteStream#flush
     */
    public void flush() {}

    /**
     * Retrieves the attributes for the specified file or directory.  The returned
     * value is a combination of the ARCHIVE, COMPRESSED, DIRECTORY, HIDDEN,
     * OFFLINE, READONLY, SYSTEM, and TEMPORARY file attribute flags.
     *
     * @param path The path of a file or directory.
     * @return The attributes of the file or directory.
     * @exception WinIOException If an error occurs.
     * @see #setAttributes
     */
    public static int getAttributes(String path) {}

    /**
     * Returns the creation time of this file.
     *
     * @return The creation time of this file.
     * @see #setCreationTime
     * @see com.ms.wfc.app.Time
     */
    public Time getCreationTime() {}

    /**
     * Retrieves the current directory.  The returned string is the absolute path
     * of the current directory.
     *
     * @exception WinIOException If an error occurs.
     * @see #setCurrentDirectory
     */
    public static String getCurrentDirectory() {}

    /**
     * Retrieves the directory path of a file path.  This method effectively
     * removes the last element of the given file path, i.e. it returns a
     * string consisting of all characters up to but not including the last
     * backslash ("\") in the file path. The returned value is null if the file
     * path is null or if the file path denotes a root (such as "\", "C:", or
     * "\\server\share").
     *
     * @param path The path of a file or directory.
     * @return The directory path of the given path, or null if the given path
     * denotes a root.
     * @see #getExtension
     * @see #getName
     * @see #getRoot
     * @see #isRooted
     */
    public static String getDirectory(String path) {}

    /**
     * Retrieves the extension of the specified path.  The returned value includes the
     * period (".") character of the extension, such as <code>".exe"</code> or
     * <code>".java"</code>. The returned value is null if the given path is
     * null or if the given path does not include an extension.
     *
     * @param path The path of a file or directory.
     * @return The extension of the given path, or null if the given path does
     * not include an extension.
     * @see #changeExtension
     * @see #getDirectory
     * @see #getName
     * @see #getRoot
     * @see #hasExtension
     */
    public static String getExtension(String path) {}

    /**
     * Retrieves the names of the files that match the specified search path. 
     */
    public static String[] getFiles(String path) {}

    /**
     * Expands the specified path to a fully qualified path.  The resulting string
     * consists of a drive letter, a colon, and a root relative path. This
     * function does not verify that the resulting path is valid or that it
     * refers to an existing file or directory on the associated volume.
     *
     * @param path The path to fully qualify.
     * @param return The fully qualified path.
     * @exception WinIOException If an error occurs.
     */
    public static String getFullPath(String path) {}

    /**
     * Retrieves the file handle associated with this File object. 
     * The returned value is -1 if the file has been closed.
     *
     * @return The file handle for this <code>File</code> object.
     */
    public int getHandle() {}

    /**
     * Returns the last access time of this file. The last access time includes
     * the last time the file was written to, read from, or, in the case of
     * executable files, run.
     *
     * @return The last access time of this file.
     * @see #setLastAccessTime
     * @see com.ms.wfc.app.Time
     */
    public Time getLastAccessTime() {}

    /**
     * Returns the last write time of this file.
     *
     * @return The last write time of this file.
     * @see #setLastWriteTime
     * @see com.ms.wfc.app.Time
     */
    public Time getLastWriteTime() {}

    /**
     * Retrieves the length in bytes of this file. 
     *
     * @return The length of the file.
     * @exception WinIOException If the length of the file cannot be determined
     * or if the file has been closed.
     * @see com.ms.wfc.io.IByteStream#getLength
     * @see #setLength
     */
    public long getLength() {}

    public static String[] getLogicalDrives() {}

    /**
     * Retrieves the name and extension of the specified path.  The resulting
     * string contains the characters of <code>path</code> that follow the last
     * backslash ("\") or colon (":") character in <code>path</code>. The
     * resulting string is the entire path if <code>path</code> contains no
     * backslash or colon characters. The resulting string is null if
     * <code>path</code> is null.
     *
     * @param path The path of a file or directory.
     * @return The name and extension parts of the given path.
     * @see #getDirectory
     * @see #getExtension
     * @see #getRoot
     */
    public static String getName(String path) {}

    /**
     * Retrieves the current position of this file. 
     *
     * @return The current position of the file.
     * @exception WinIOException If an I/O error occurs or if the file does not
     * allow positioning.
     * @see com.ms.wfc.io.IByteStream#getPosition
     * @see #setPosition
     */
    public long getPosition() {}

    /**
     * Retrieves the root portion of the specified path.  The resulting string
     * consists of those rightmost characters of the path that constitute the
     * root of the path. Possible patterns for the resulting string are: An
     * empty string (a relative path on the current drive), "\" (an absolute
     * path on the current drive), "X:" (a relative path on a given drive,
     * where X is the drive letter), "X:\" (an absolute path on a given drive),
     * and "\\server\share" (a UNC path for a given server and share name).
     * The resulting string is null if <code>path</code> is null.
     *
     * @param path The path of a file or directory.
     * @return The root portion of the given path.
     * @see #getDirectory
     * @see #getExtension
     * @see #getName
     * @see #isRooted
     */
    public static String getRoot(String path) {}

    
    private static int getRootLength(String path) {}

    /**
     * Determines whether a path includes a file extension.  The result is
     * <code>true</code> if the characters that follow the last backslash ("\")
     * or colon (":") in the path include a period ("."). The result is
     * <code>false</code> otherwise.
     *
     * @param path The path to test.
     * @return Boolean indicating whether the path includes a file extension.
     * @see #changeExtension
     * @see #getExtension
     */
    public static boolean hasExtension(String path) {}

    
    private void initialize() {}

    /**
     * Determines whether the specified path refers to a directory. 
     *
     * @param path The path to test.
     * @return Boolean indicating whether the path refers to a directory.
     * @see #exists
     * @see #isFile
     */
    public static boolean isDirectory(String path) {}

    /**
     * Determines whether the specified path refers to a file. 
     *
     * @param path The path to test.
     * @return Boolean indicating whether the path refers to a file.
     * @see #exists
     * @see #isDirectory
     */
    public static boolean isFile(String path) {}

    /**
     * Determines whether the specified path contains a root.  A path is considered rooted
     * if it starts with a backslash ("\") or a drive letter and a colon (":").
     *
     * @param path The path to test.
     * @return Boolean indicating whether the path is rooted.
     * @see #getRoot
     */
    public static boolean isRooted(String path) {}

    /**
     * Locks a region in this file.  Locking a region of a file gives the
     * locking process exclusive access to the specified region. File locks
     * are not inherited by processes created by the locking process. Locking
     * a region of a file denies all other processes both read and write access
     * to the specified region. Locking a region that goes beyond the current
     * end-of-file position is not an error. Locks may not overlap an existing
     * locked region of the file.
     *
     * @param position Starting position of the range to be locked.
     * @param length Length of the range to be locked.
     * @exception WinIOException If an error occurs or if the file has been
     * closed.
     * @see #unlock
     */
    public void lock(long position, long length) {}

    /**
     * @internalonly
     */
    protected static void notOpenError() {}

    /**
     * Opens an existing file for read and write access.  This method is simply
     * a convenient way of constructing a new <code>File</code> object with
     * FileMode.OPEN, FileAccess.READWRITE, and FileShare.NONE.
     *
     * @param path The path of the file to open.
     * @return A <code>File</code> object for the opened file.
     * @exception WinIOException If an error occurs.
     * @see #File(String,int)
     * @see #openRead
     * @see #close
     */
    public static File open(String path) {}

    /**
     * Opens an existing file for read access only.  This method is simply a
     * convenient way of constructing a new <code>File</code> object with
     * FileMode.OPEN, FileAccess.READ, and FileShare.READ.
     *
     * @param path The path of the file to open.
     * @return A <code>File</code> object for the opened file.
     * @exception WinIOException If an error occurs.
     * @see #File(String,int)
     * @see #open
     * @see #close
     */
    public static File openRead(String path) {}

    /**
     * Opens the standard error file. 
     *
     * @return A <code>File</code> object for the standard error file.
     * @exception WinIOException If an error occurs.
     */
    public static File openStandardError() {}

    
    private static File openStandardFile(int stdHandle) {}

    /**
     * Opens the standard input file. 
     *
     * @return A <code>File</code> object for the standard input file.
     * @exception WinIOException If an error occurs.
     */
    public static File openStandardInput() {}

    /**
     * Opens the standard output file. 
     *
     * @return A <code>File</code> object for the standard output file.
     * @exception WinIOException If an error occurs.
     */
    public static File openStandardOutput() {}

    /**
     * Reads the next byte of data from this file. 
     *
     * @see com.ms.wfc.io.IByteStream#read()
     */
    public int read() {}

    /**
     * Reads a byte from this file. 
     *
     * @see com.ms.wfc.io.IDataStream#readByte
     */
    public byte readByte() {}

    /**
     * Reads a character from this file. 
     *
     * @see com.ms.wfc.io.IDataStream#readChar
     */
    public char readChar() {}

    
    private int readCore(int addr, int count) {}

    /**
     * @internalonly
     */
    protected int readCore(Object buffer, int index, int count) {}

    /**
     * Reads an integer from this file. 
     *
     * @see com.ms.wfc.io.IDataStream#readInt
     */
    public int readInt() {}

    /**
     * Reads a long value from this file. 
     *
     * @see com.ms.wfc.io.IDataStream#readLong
     */
    public long readLong() {}

    /**
     * Reads a short value from this file. 
     *
     * @see com.ms.wfc.io.IDataStream#readShort
     */
    public short readShort() {}

    /**
     * Removes an existing empty directory.  The path must specify an empty
     * directory, and the calling process must have delete access to the
     * directory.
     *
     * @param path Path of the directory to remove.
     * @exception WinIOException If an error occurs.
     * @see #createDirectory
     */
    public static void removeDirectory(String path) {}

    /**
     * Renames an existing file or directory.  The <code>curPath</code>
     * parameter must reference an existing file or directory. The
     * <code>newPath</code> parameter specifies the new name of a file or
     * directory. The new name must not already exist. A new file may be on a
     * different file system or drive. A new directory must be on the same
     * drive.
     *
     * @param curPath Path of the file or directory to rename.
     * @param newPath New path of the file or directory.
     * @exception WinIOException If an error occurs.
     */
    public static void rename(String curPath, String newPath) {}

    /**
     * Sets the attributes of a file.  The <code>path</code> parameter must
     * reference an existing file. The <code>attributes</code> parameter must
     * be a combination of the ARCHIVE, HIDDEN, OFFLINE, READONLY, SYSTEM, and
     * TEMPORARY file attribute flags.
     *
     * @param path Path of the file whose attributes to set.
     * @param attributes The new attributes for the file.
     * @exception WinIOException If an error occurs.
     * @see #getAttributes
     */
    public static void setAttributes(String path, int attributes) {}

    /**
     * Sets the creation time of this file.
     *
     * @param time The creation time to set for this file.
     * @see #getCreationTime
     * @see com.ms.wfc.app.Time
     */
    public void setCreationTime(Time time) {}

    /**
     * Sets the current directory.  The <code>path</code> parameter specifies
     * the path to the new current directory. This parameter may be a relative
     * path or a fully qualified path. In either case, the fully qualified
     * path of the specified directory is calculated and stored as the current
     * directory.
     *
     * @param path Path of the new current directory.
     * @exception WinIOException If an error occurs.
     * @see #getCurrrentDirectory
     */
    public static void setCurrentDirectory(String path) {}

    /**
     * Sets the last access time of this file.
     *
     * @param time The last access time to set for this file.
     * @see #getLastAccessTime
     * @see com.ms.wfc.app.Time
     */
    public void setLastAccessTime(Time time) {}

    /**
     * Sets the last write time of this file.
     *
     * @param time The last write time to set for this file.
     * @see #getLastWriteTime
     * @see com.ms.wfc.app.Time
     */
    public void setLastWriteTime(Time time) {}

    /**
     * Sets the length of this file to the specified value.  If the given value is
     * less than the current length of the file, the file is truncated. If the
     * given value is larger than the current length of the file, the file is
     * expanded. If the file is expanded, the contents of the file between the
     * old and the new length are undefined.
     *
     * @param value The new length of the file.
     * @exception WinIOException If an error occurs or if the file has been
     * closed.
     * @see com.ms.wfc.io.IByteStream#setLength
     * @see #getLength
     */
    public void setLength(long value) {}

    /**
     * Sets the current position of this file to the specified value.  It is not an
     * error to set the current position beyond the length of the file.
     *
     * @param value The new position of the file.
     * @exception WinIOException If an error occurs or if the file has been
     * closed.
     * @see com.ms.wfc.io.IByteStream#setPosition
     * @see #getPosition
     */
    public void setPosition(long value) {}

    /**
     * Unlocks a region in this file.  Unlocking a region enables other
     * processes to access the region. The region to unlock must correspond
     * exactly to an existing locked region. For example, two adjacent regions
     * of a file cannot be locked separately and then unlocked as a single
     * region that spans both locked regions. A process should not be
     * terminated with a portion of a file locked and a file that has locked
     * regions should not be closed. 
     *
     * @param position Starting position of the range to be unlocked.
     * @param length Length of the range to be unlocked.
     * @exception WinIOException If an error occurs or if the file has been
     * closed.
     * @see #lock
     */
    public void unlock(long position, long length) {}

    /**
     * @internalonly
     */
    protected static void winIOError() {}

    /**
     * Writes a byte of data to this file. 
     *
     * @see com.ms.wfc.io.IByteStream#write(int)
     */
    public void write(int value) {}

    /**
     * Writes a byte to this file. 
     *
     * @see com.ms.wfc.io.IDataStream#writeByte
     */
    public void writeByte(byte value) {}

    /**
     * Writes a character to this file. 
     *
     * @see com.ms.wfc.io.IDataStream#writeChar
     */
    public void writeChar(char value) {}

    
    private void writeCore(int addr, int count) {}

    /**
     * @internalonly
     */
    protected void writeCore(Object buffer, int index, int count) {}

    /**
     * Writes an integer to this file. 
     *
     * @see com.ms.wfc.io.IDataStream#writeInt
     */
    public void writeInt(int value) {}

    /**
     * Writes a long value to this file. 
     *
     * @see com.ms.wfc.io.IDataStream#writeLong
     */
    public void writeLong(long value) {}

    /**
     * Writes a short value to this file. 
     *
     * @see com.ms.wfc.io.IDataStream#writeShort
     */
    public void writeShort(short value) {}
}