//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.core.*;


/**
 * Defines constants that specify file attributes. 
 * @security(checkClassLinking=on)
 */
public class FileAttribute extends Enum {
    /**
     * Specifies that the file is read-only. Applications can read
     * the file but cannot write to it or delete it.
     */
    public static final int READONLY = 0x00000001;

    /**
     * Specifies that the file is hidden. The file is not to be
     * included in an ordinary directory listing.
     */
    public static final int HIDDEN = 0x00000002;

    /**
     * Specifies that the file is part of or is used exclusively by the operating system.
     */
    public static final int SYSTEM = 0x00000004;

    /**
     * Specifies that the file is a directory.
     */
    public static final int DIRECTORY = 0x00000010;

    /**
     * Specifies that the file is an archive file. Applications use
     * this value to mark files for backup or removal.
     */
    public static final int ARCHIVE = 0x00000020;

    /**
     * Specifies that the file is being used for temporary storage.
     * Applications should write to the file only if absolutely necessary. Most
     * of the file's data remains in memory without being flushed to the media
     * because the file will soon be deleted.
     */
    public static final int TEMPORARY = 0x00000100;

    /**
     * Specifies that the file or directory is compressed. For a
     * file, this means that all of the data in the file is compressed. For a
     * directory, this means that compression is the default for newly created
     * files and subdirectories.
     */
    public static final int COMPRESSED = 0x00000800;

    /**
     * Specifies that the data of the file is not immediately available. Indicates that the file data has been physically moved to
     * offline storage.
     */
    public static final int OFFLINE = 0x00001000;

    public static boolean valid(int value) {}
}