//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.core.*;
import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;

/**
 * Searches the file system for files that match a specified pattern.  The following example shows how to use the FileEnumerator class to
 * find and output the names of all Java files in and below a given directory.
 * <pre>
 * static void printJavaFiles(String path) {
 *     FileEnumerator e = new FileEnumerator(File.combine(path, "*.*"));
 *     while (e.hasMoreFiles()) {
 *         String name = e.getName();
 *         if ((e.getAttributes() & FileAttribute.DIRECTORY) != 0) {
 *             if (!name.equals(".") && !name.equals("..")) {
 *                 printJavaFiles(File.combine(path, name));
 *             }
 *         }
 *         else {
 *             String ext = File.getExtension(name);
 *             if (ext != null && ext.equalsIgnoreCase(".java")) {
 *                 System.out.println(File.combine(path, name));
 *             }
 *         }
 *         e.getNextFile();
 *     }
 * }
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public class FileEnumerator
{
    private WIN32_FIND_DATA data;
    private int handle;

    /**
     * Constructs a new file enumerator. The <i>path</i> parameter must specify
     * a valid directory path and filename. The filename part of the given path
     * may contain wildcard characters (* and ?). Following construction of a
     * file enumerator, the <i>hasMoreFiles</i> method will indicate if at least
     * one file was found that matches the given pattern.
     *
     * @param path The directory path and filename to enumerate.
     * @exception WinIOException If the given path is invalid.
     */
    public FileEnumerator(String path) {}

    /**
     * Closes this file enumerator.  System resources are released and any
     * pending enumeration results are discarded. Normally there is no need to
     * call this method since <i>getNextFile()</i> automatically closes the
     * enumerator when the last file has been processed.
     */
    public void close() {}

    /**
     * Ensures that the close method has been called for this file enumerator.  Ensures that the <i>close()</i> method has been called for
     * this file enumerator.
     */
    protected void finalize() {}

    /**
     * Retrieves the file attributes for the current file.  The returned value is
     * a combination of the ARCHIVE, COMPRESSED, DIRECTORY, HIDDEN, OFFLINE,
     * READONLY, SYSTEM, and TEMPORARY file attribute flags.
     */
    public int getAttributes() {}

    /**
     * Retrieves the creation time of the current file.  The returned value is
     * null if the file system containing the file does not support this time
     * information.
     *
     * @see #getLastAccessTime
     * @see #getLastWriteTime
     * @see com.ms.wfc.app.Time
     */
    public Time getCreationTime() {}

    /**
     * Retrieves the last access time of the current file.  The returned value is
     * null if the file system containing the file does not support this time
     * information.
     *
     * @see #getCreationTime
     * @see #getLastWriteTime
     * @see com.ms.wfc.app.Time
     */
    public Time getLastAccessTime() {}

    /**
     * Retrieves the last write time of the current file.  The returned value is
     * null if the file system containing the file does not support this time
     * information.
     *
     * @see #getCreationTime
     * @see #getLastAccessTime
     * @see com.ms.wfc.app.Time
     */
    public Time getLastWriteTime() {}

    /**
     * Retrieves the name of the current file. 
     */
    public String getName() {}

    /**
     * Finds the next file that matches the pattern of the file enumerator. 
     * Following a call to this method, the <i>hasMoreFiles</i> method can be
     * used to determine if more files remain in the enumeration.
     * @see #hasMoreFiles
     */
    public void getNextFile() {}

    /**
     * Retrieves the size in bytes of the current file. 
     */
    public long getSize() {}

    /**
     * Detrmines whether additional files remain to be enumerated. 
     * @return true if more files remain, false otherwise.
     * @see #getNextFile
     */
    public boolean hasMoreFiles() {}

    
    private static long makeLong(int low, int high) {}
}