//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.core.*;

/**
 * Represents a reader that can read a sequential stream of characters.  A subclass must minimally implement the peek() and
 * read() methods.
 *
 * @see com.ms.wfc.io.StringReader
 * @see com.ms.wfc.io.Text
 * @see com.ms.wfc.io.TextReader
 * @see com.ms.wfc.io.Writer
 *
 * @security(checkClassLinking=on)
 */
public abstract class Reader implements IReader
{
    /**
     * Closes this Reader object and releases any system resources associated
     * with the reader.  Following a call to close(), any operations on the Reader may
     * raise exceptions. This default method is empty, but descendant classes
     * can override the method to provide the appropriate functionality.
     */
    public void close() {}

    /**
     * Retrieves the next available character from the input stream without actually reading
     * it.  The current position of the Reader is not changed by
     * this operation. The returned value is -1 if no further characters are
     * available. This default method simply returns -1.
     *
     * @return The next character to be read, or -1 if no further characters
     * are available.
     */
    public int peek() {}

    /**
     * Reads the next character from the input stream.  The returned value is
     * -1 if no further characters are available. This default method simply
     * returns -1.
     *
     * @return The next character from the input stream, or -1 if no further
     * characters are available.
     */
    public int read() {}

    /**
     * Reads the next character from the input stream.  This method will read up to
     * <code>count</code> characters from this Reader into the
     * <code>buffer</code> character array starting at position
     * <code>index</code>. Returns the actual number of characters read.
     *
     * @param buffer The character array to read data into.
     * @param index Starting index in the buffer.
     * @param count The number of characters to read.
     * @return The total number of characters read into the buffer. This may
     * be less than the number of characters requested if that many characters
     * aren't currently available, or zero if the end of the stream is reached.
     */
    public int read(char[] buffer, int index, int count) {}

    /**
     * Reads a line.  A line is defined as a sequence of characters followed by
     * a carriage return ('\r'), a line feed ('\n'), or a carriage return
     * immediately followed by a line feed. The resulting string does not
     * contain the terminating carriage return and/or line feed. The returned
     * value is null if the end of the input stream has been reached.
     *
     * @return The next line from the input stream, or null if the end of the
     * input stream is reached.
     */
    public String readLine() {}
}