//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.core.*;

/**
 * Implements a reader that can read a sequential stream of characters from an IByteStream object or from a named file.  The class performs
 * buffering of the input, as well as conversions from the underlying
 * single-byte or double-byte character set to Unicode.
 *
 * @see com.ms.wfc.io.Reader
 * @see com.ms.wfc.io.StringReader
 * @see com.ms.wfc.io.Text
 * @see com.ms.wfc.io.TextWriter
 *
 * @security(checkClassLinking=on)
 */
public class TextReader extends Reader
{
    private static final int DEFAULTBUFFERSIZE = 1024;

    private IByteStream stream;
    private int codePage;
    private boolean[] isLeadByte;
    private byte[] byteBuffer;
    private char[] charBuffer;
    private byte lastLeadByte;
    private int charPos;
    private int charLen;

    /**
     * Constructs a TextReader for the given stream. The TextReader will use
     * the system's default ANSI code page and will have a buffer size of 1024
     * characters.
     *
     * @param stream The IByteStream to read from.
     */
    public TextReader(IByteStream stream) {}

    /**
     * Constructs a TextReader for the given stream using the given code page.
     * The <code>codePage</code> parameter must be a value from the
     * <code>CodePage</code> enumeration or the identifier of a code page that
     * is supported by the system. The TextReader will have a buffer size of
     * 1024 characters.
     *
     * @param stream The IByteStream to read from.
     * @param codePage The code page to use when converting input characters
     * to Unicode.
     * @see com.ms.wfc.io.CodePage
     */
    public TextReader(IByteStream stream, int codePage) {}

    /**
     * Constructs a TextReader for the given stream using the given code page
     * and the given input buffer size. The <code>codePage</code> parameter must
     * be a value from the <code>CodePage</code> enumeration or the identifier
     * of a code page that is supported by the system.
     *
     * @param stream The IByteStream to read from.
     * @param codePage The code page to use when converting input characters
     * to Unicode.
     * @param bufferSize Input buffer size in characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextReader(IByteStream stream, int codePage, int bufferSize) {}

    /**
     * Constructs a TextReader for the given file. The <code>path</code>
     * parameter must specify the name of an existing file. The TextReader will
     * use the system's default ANSI code page and will have a buffer size of
     * 1024 characters.
     *
     * @param path Name of the file to open.
     */
    public TextReader(String path) {}

    /**
     * Constructs a TextReader for the given file using the given code page.
     * The <code>path</code> parameter must specify the name of an existing
     * file. The <code>codePage</code> parameter must be a value from the
     * <code>CodePage</code> enumeration or the identifier of a code page that
     * is supported by the system. The TextReader will have a buffer size of
     * 1024 characters.
     *
     * @param path Name of the file to open.
     * @param codePage The code page to use when converting input characters
     * to Unicode.
     * @see com.ms.wfc.io.CodePage
     */
    public TextReader(String path, int codePage) {}

    /**
     * Constructs a TextReader for the given file using the given code page
     * and the given input buffer size. The <code>path</code> parameter must
     * specify the name of an existing file. The <code>codePage</code>
     * parameter must be a value from the <code>CodePage</code> enumeration or
     * the identifier of a code page that is supported by the system.
     *
     * @param path Name of the file to open.
     * @param codePage The code page to use when converting input characters
     * to Unicode.
     * @param bufferSize Input buffer size in characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextReader(String path, int codePage, int bufferSize) {}

    /**
     * Closes this TextReader object and the underlying IByteStream
     * object.  Following a call
     * to close(), any operations on the TextReader will raise exceptions.
     */
    public void close() {}

    /**
     * Retrieves the stream that underlies this TextReader object.  This will either be
     * the stream that was passed to the constructor, or the File object that
     * was automatically created as part of constructing this TextReader.
     *
     * @return The stream that underlies this TextReader.
     */
    public IByteStream getStream() {}

    /**
     * Retrieves the next available character without actually reading it from the input
     * stream.  The current position of the TextReader is not changed
     * by this operation. The returned value is -1 if no further characters are
     * available.
     *
     * @return The next character to be read, or -1 if no further characters
     * are available.
     */
    public int peek() {}

    /**
     * Reads the next character from the input stream.  The returned value is
     * -1 if no further characters are available.
     *
     * @return The next character from the input stream, or -1 if no further
     * characters are available.
     */
    public int read() {}

    /**
     * Reads the next character from the input stream.  This method will read up to
     * <code>count</code> characters from this TextReader into the
     * <code>buffer</code> character array starting at position
     * <code>index</code>. Returns the actual number of characters read.
     *
     * @param buffer The character array to read data into.
     * @param index Starting index in the buffer.
     * @param count The number of characters to read.
     * @return The total number of characters read into the buffer. This may
     * be less than the number of characters requested if that many characters
     * aren't currently available, or zero if the end of the stream is reached.
     */
    public int read(char[] buffer, int index, int count) {}

    
    private int readBuffer() {}

    /**
     * Reads a line.  A line is defined as a sequence of characters followed by
     * a carriage return ('\r'), a line feed ('\n'), or a carriage return
     * immediately followed by a line feed. The resulting string does not
     * contain the terminating carriage return and/or line feed. The returned
     * value is null if the end of the input stream has been reached.
     *
     * @return The next line from the input stream, or null if the end of the
     * input stream is reached.
     */
    public String readLine() {}
}