//STRIPPEDSOURCE//
package com.ms.wfc.io;

import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.core.*;

/**
 * Implements a writer that can write a sequential stream of characters to an IByteStream object or to a named file.  The class performs
 * buffering of the output, as well as conversions from Unicode to the
 * underlying single-byte or double-byte character set.
 *
 * @see com.ms.wfc.io.StringWriter
 * @see com.ms.wfc.io.Text
 * @see com.ms.wfc.io.TextReader
 * @see com.ms.wfc.io.Writer
 *
 * @security(checkClassLinking=on)
 */
public class TextWriter extends Writer
{
    private static final int DEFAULTBUFFERSIZE = 1024;

    IByteStream stream;
    int codePage;
    byte[] byteBuffer;
    char[] charBuffer;
    int charPos;
    int charLen;
    boolean autoFlush;

    /**
     * Constructs a TextWriter for the given stream. The TextWriter will use
     * the system's default ANSI code page and will have a buffer size of 1024
     * characters.
     *
     * @param stream The IByteStream to write to.
     */
    public TextWriter(IByteStream stream) {}

    /**
     * Constructs a TextWriter for the given stream using the given code page.
     * The <code>codePage</code> parameter must be a value from the
     * <code>CodePage</code> enumeration or the identifier of a code page that
     * is supported by the system. The TextWriter will have a buffer size of
     * 1024 characters.
     *
     * @param stream The IByteStream to write to.
     * @param codePage The code page to use when converting Unicode characters
     * to output characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextWriter(IByteStream stream, int codePage) {}

    /**
     * Constructs a TextWriter for the given stream using the given code page.
     * The <code>codePage</code> parameter must be a value from the
     * <code>CodePage</code> enumeration or the identifier of a code page that
     * is supported by the system.
     *
     * @param stream The IByteStream to write to.
     * @param codePage The code page to use when converting Unicode characters
     * to output characters.
     * @param bufferSize Output buffer size in characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextWriter(IByteStream stream, int codePage, int bufferSize) {}

    /**
     * Constructs a TextWriter for the given file. The <code>path</code>
     * parameter specifies the name of the new file to create. The TextWriter
     * will use the system's default ANSI code page and will have a buffer size
     * of 1024 characters.
     *
     * @param path Name of the file to create.
     */
    public TextWriter(String path) {}

    /**
     * Constructs a TextWriter for the given file. The <code>path</code>
     * parameter specifies the name of the new file to create or an existing
     * file to append to. If the <code>append</code> parameter is true, and if
     * the specified file already exists, the TextWriter will append to the
     * file instead of overwriting it. The TextWriter will use the system's
     * default ANSI code page and will have a buffer size of 1024 characters.
     *
     * @param path Name of the file to create.
     * @param append true to append to existing files, false to overwrite
     * existing files.
     */
    public TextWriter(String path, boolean append) {}

    /**
     * Constructs a TextWriter for the given file. The <code>path</code>
     * parameter specifies the name of the new file to create or an existing
     * file to append to. If the <code>append</code> parameter is true, and if
     * the specified file already exists, the TextWriter will append to the
     * file instead of overwriting it. The <code>codePage</code> parameter must
     * be a value from the <code>CodePage</code> enumeration or the identifier
     * of a code page that is supported by the system. The TextWriter will have
     * a buffer size of 1024 characters.
     *
     * @param path Name of the file to create.
     * @param append true to append to existing files, false to overwrite
     * existing files.
     * @param codePage The code page to use when converting Unicode characters
     * to output characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextWriter(String path, boolean append, int codePage) {}

    /**
     * Constructs a TextWriter for the given file. The <code>path</code>
     * parameter specifies the name of the new file to create or an existing
     * file to append to. If the <code>append</code> parameter is true, and if
     * the specified file already exists, the TextWriter will append to the
     * file instead of overwriting it. The <code>codePage</code> parameter must
     * be a value from the <code>CodePage</code> enumeration or the identifier
     * of a code page that is supported by the system.
     *
     * @param path Name of the file to create.
     * @param append true to append to existing files, false to overwrite
     * existing files.
     * @param codePage The code page to use when converting Unicode characters
     * to output characters.
     * @param bufferSize Output buffer size in characters.
     * @see com.ms.wfc.io.CodePage
     */
    public TextWriter(String path, boolean append, int codePage, int bufferSize) {}

    /**
     * Closes this TextWriter object and the underlying IByteStream
     * object.  Following a call
     * to close(), any operations on the TextWriter will raise exceptions.
     */
    public void close() {}

    
    private static IByteStream createFile(String path, boolean append) {}

    /**
     * Clears the output buffer for this TextWriter object and causes any
     * buffered data to be written to the underlying IByteStream object.  If the TextWriter's
     * <code>AutoFlush</code> property is set to true, <code>flush()</code>
     * is automatically called after every write operation.
     *
     * @see #setAutoFlush
     */
    public void flush() {}

    /**
     * Retrieves a boolean value indicating whether write operations are
     * automatically flushed to the underlying IByteStream object. 
     *
     * @see #setAutoFlush
     */
    public boolean getAutoFlush() {}

    /**
     * Retrieves the stream that underlies this TextWriter object.  This will either be
     * the stream that was passed to the constructor, or the File object that
     * was automatically created as part of constructing this TextWriter.
     *
     * @return The stream that underlies this TextWriter.
     */
    public IByteStream getStream() {}

    /**
     * Sets a boolean value indicating whether to enable the automatic
     * flushing of output characters.  When
     * automatic flushing is enabled, output is automatically written to the
     * underlying stream at the end of each write operation.
     *
     * @param value State of automatic flushing.
     * @see #flush
     * @see #getAutoFlush
     */
    public void setAutoFlush(boolean value) {}

    /**
     * Writes a character to the text stream. 
     *
     * @param value The character to write to the text stream.
     */
    public void write(char value) {}

    /**
     * Writes a character to the text stream.  This method
     * will write <code>count</code> characters of data into this TextWriter
     * from the <code>buffer</code> character array starting at position
     * <code>index</code>.
     *
     * @param buffer The character array to write data from.
     * @param index Starting index in the buffer.
     * @param count The number of characters to write.
     */
    public void write(char[] buffer, int index, int count) {}

    /**
     * Writes a character to the text stream.  If the given string is null, nothing
     * is written to the text stream.
     *
     * @param value The string to write.
     */
    public void write(String value) {}
}