//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Animation common control.  This control plays a .AVI animation file in
 * it's window.  The methods <i>start</i> and <i>stop</i> let you control
 * playback of the video, and the FileName property is how you load in new
 * files.
 *
 * @security(checkClassLinking=on)
 */
public class Animation extends Control {

    
    private EventHandler onStart;

    
    private EventHandler onStop;

    
    private boolean autoPlay = false;

    
    private boolean centered = false;

    
    private String fileName;

    
    private boolean timer = false;

    
    private boolean transparent = false;

    private Rectangle tempBounds = null;

    /**
     * Creates a new animation control with no current file.
     */
    public Animation() {}

    /**
     * Adds an event handler for the "start" event notification. This
     * notification is sent out whenever an animation starts playing.
     *
     * @param value        New Event Handler to install for this event.
     */
    public final void addOnStart(EventHandler value) {}

    /**
     * Adds an event handler for the "stop" event notification. This
     * notification is sent out whenever an animation stops playing.
     *
     * @param value        New Event Handler to install for this event.
     */
    public final void addOnStop(EventHandler value) {}

    /**
     * Indicates whether the animation control will start playing the
     * animation as soon as a video clip is opened.
     *
     * @return   <b>true</b> if the control will start playing videos
     *             as soon as they are loaded or the control is shown
     *             [whichever comes first].
     */
    public final boolean getAutoPlay() {}

    /**
     * Indicates whether the animation will be in the top-left of the
     * animation control's area, or whether it will be centred as necessary.
     *
     * @return  <b>true</b> if the video will be centred in the Animation
     *            controls client area. Otherwise, it will be shown in the
     *            upper left.
     */
    public final boolean getCentered() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a @see CreateParams object with the information for creating
     *             this Animation control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Contains the file name of the animation to be played.
     *
     * @return   the file name of the animation to be played
     */
    public final String getFileName() {}

    /**
     * Indicates if Windows will draw the animation using a transparent
     * background rather than the background color specified in the animation
     * clip.
     *
     * @return   <b>true</b> if the background will be transparent.  Otherwise
     *             the controls background will paint normally.
     */
    public final boolean getTransparent() {}

    /**
     * Indicates that a Win32 timer should be used to manage playback of the
     * animation instead of a separate thread.  By default, the Animation
     * control uses threads.
     *
     * @return   <b>true</b> if a Win32 timer will be used instead of a thread.
     */
    public final boolean getUseTimer() {}

    /**
     * Make sure that the file name is set up within the control handle.
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Actually fires the start event if anybody is listening.  Inheriting
     * classes should just override this instead of adding a listener for
     * the event.  If you do override this method, don't forget to call
     * <i>super.onStart(e)</i> to ensure that the original event still gets
     * raised.
     *
     * @param e     This event object contains no special information for this
     *                event.
     */
    protected void onStart(Event e) {}

    /**
     * Actually fires the stop event if anybody is listening.  Inheriting
     * classes should just override this instead of adding a listener for
     * the event.  If you do override this method, don't forget to call
     * "super.onStart(e)" to ensure that the original event still gets
     * raised.
     *
     * @param e     This event object contains no special information for this
     *                event.
     */
    protected void onStop(Event e) {}

    /**
     * Plays the movie from beginning to end.
     *
     * @return a boolean indicating whether or not the operation succeeded.
     */
    public final boolean start() {}

    /**
     * Plays the movie the specified number of times, with the specified start
     * and end frames.
     *
     * @param repeat    Number of times to play
     * @param start     Frame to start at.
     * @param end       Frame to stop playing at, -1 for end.
     *
     * @return a boolean indicating whether or not the operation succeeded.
     */
    public final boolean start(int repeat, int start, int end) {}

    /**
     * Removes the given handler for the <i>start</i> event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnStart(EventHandler value) {}

    /**
     * Removes the given handler for the <i>stop</i> event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnStop(EventHandler value) {}

    /**
     * Controls whether the animation control should start playing the animation
     * as soon as a video clip is opened.
     *
     * @param value        new value for this property
     */
    public final void setAutoPlay(boolean value) {}

    /**
     * Controls whether the video clip will be in the top-left of the
     * Animation control's area, or whether it will be centred as necessary.
     *
     * @param value        new value for this property
     */
    public final void setCentered(boolean value) {}

    /**
     * Sets the file name of the video clip to be played.  A file name of <b>null</b>
     * clears the controls display area.
     *
     * @return String   File name of the animation to be played, or <b>null</b>
     *                    to clear out the video.
     */
    public final void setFileName(String value) {}

    /**
     * Controls whether Windows will draw the animation using a transparent
     * background rather than the background color specified in the animation
     * clip.
     *
     * @param value        New value for this property.
     */
    public final void setTransparent(boolean value) {}

    /**
     * Controls whether a Win32 timer should be used to manage playback of the
     * animation instead of a separate thread.
     *
     * @param value        New value for this property
     */
    public final void setUseTimer(boolean value) {}

    /**
     * Stops playing the animation.
     *
     * @return a boolean indicating whether or not the operation succeeded.
     */
    public final boolean stop() {}

    /**
     * Provides some interesting information for the Animation control in
     * String form.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void wmCreate(Message m) {}


    
    private void wmReflectCommand(Message m) {}

    /**
     * The controls Window proc.  Inheriting classes can override this to
     * sniff at at messages, but should not forget to call super.wndProc(m)
     * to ensure correct functionality.
     *
     * @param m     The Windows message sent to the control.
     * @internalonly
     */
    protected void wndProc(Message m) {}


    /**
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        

        public static final PropertyInfo autoPlay = new PropertyInfo(
            Animation.class, "autoPlay", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("AnimationAutoPlayDescr")));

        public static final PropertyInfo centered = new PropertyInfo(
            Animation.class, "centered", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("AnimationCenteredDescr")));

        public static final PropertyInfo fileName = new PropertyInfo(
            Animation.class, "fileName", String.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.NULL,
            new ValueEditorAttribute(AnimationFileNameEditor.class),
            new DescriptionAttribute(Sys.getString("AnimationFileNameDescr")));

        public static final PropertyInfo transparent = new PropertyInfo(
            Animation.class, "transparent", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("AnimationTransparentDescr")));

        public static final PropertyInfo useTimer = new PropertyInfo(
            Animation.class, "useTimer", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("AnimationUseTimerDescr")));

        
        
        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final PropertyInfo font = new PropertyInfo(
            Control.ClassInfo.font, BrowsableAttribute.NO);

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO);

        public static final PropertyInfo tabIndex = new PropertyInfo(
            Control.ClassInfo.tabIndex, BrowsableAttribute.NO);

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, BrowsableAttribute.NO);

        

        public static final EventInfo start = new EventInfo(
            Animation.class, "start", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("AnimationStartDescr")));

        public static final EventInfo stop = new EventInfo(
            Animation.class, "stop", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("AnimationStopDescr")));

        
        
        public static final EventInfo enter = new EventInfo(
            Control.ClassInfo.enter, BrowsableAttribute.NO);

        public static final EventInfo keyDown = new EventInfo(
            Control.ClassInfo.keyDown, BrowsableAttribute.NO);

        public static final EventInfo keyPress = new EventInfo(
            Control.ClassInfo.keyPress, BrowsableAttribute.NO);

        public static final EventInfo keyUp = new EventInfo(
            Control.ClassInfo.keyUp, BrowsableAttribute.NO);

        public static final EventInfo leave = new EventInfo(
            Control.ClassInfo.leave, BrowsableAttribute.NO);

        public static final EventInfo lostFocus = new EventInfo(
            Control.ClassInfo.lostFocus, BrowsableAttribute.NO);

        public void getProperties(IProperties props) {}

        public void getEvents(IEvents events) {}
    }
}