//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.ax.*;
import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.IStorage;
import com.ms.wfc.ole32.ILockBytes;

import com.ms.vm.*;
import com.ms.com.*;
import com.ms.dll.*;
import com.ms.wfc.util.Root;

import java.lang.reflect.*;

/**
 * Wraps an ActiveX control and exposes the control as a WFC control.  
 * This class should not be used directly but instead should
 * be extended by you.  JactiveX is one tool which can be used to generate
 * wrappers which extende AxHost
 *
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public class AxHost 
    extends Control implements IRequireBegin 
{ 
    /**
     * Wraps an ActiveX control and exposes the control as a WFC control.
     * @security(checkClassLinking=on)
     */
    public static class Flags { 
        /**
         * Indicates that the context menu for the control should not contain an 
         * "Edit" verb unless the activeX controls itself decides to proffer it.
         * By default, all wrapped activeX controls will contain an edit verb.
         */
        public static final int PREVENT_EDIT_MODE  = 0x1;
        
        /**
         * Indicated that the context menu for the control should contain
         * a "Properties..." verb which may be used to show the property
         * pages for the control.  Note that even if this flag is
         * specified, the verb will not appear unless the control
         * proffers a set of property pages.
         * [Since most activeX controls alreay have their own properties verb
         * on the context menu, the default is not to include one specified by
         * this flag.]
         */
        public static final int INCLUDE_PROPERTIES_VERB = 0x2;

        
        /**
         * Indicates that the container should support message reflection even
         * when running in single threaded mode [ie, when it resides in one thread
         * and the activeX control in another.]  By default, when the container
         * detects that the control is single threaded it assumes that at
         * runtime it and the container will be running in different threads
         * and therefore disables message reflection support.  
         * This flag may be speficied when it is known that even though the control
         * is single threaded, it will still run in the same thread as the container.
         * The only time when this may be the case is when the container is
         * is running on the single threaded apartment thread.
         */
        public static final int FORCE_MESSAGE_REFLECTION = 0x4;

        /**
         * @hidden
         * @internalonly
         */
        public static final int IGNORE_THREAD_MODEL = 0x1000;

    }

    private static ComException E_NOTIMPL = new ComFailException(0x80000001);
    private static ComException E_INVALIDARG = new ComFailException(0x80070057);
    private static ComException S_FALSE   = new ComSuccessException();
    private static ComException E_FAIL   = new ComFailException(0x80004005);
    private static ComException E_NOINTERFACE = new ComFailException(0x80004002);
    
    private static final int OC_PASSIVE = 0;
    private static final int OC_LOADED = 1;  
    private static final int OC_RUNNING = 2; 
    private static final int OC_INPLACE = 4; 
    private static final int OC_UIACTIVE = 8;
    private static final int OC_OPEN = 16;    

    private static final int EDITM_NONE = 0;   
    private static final int EDITM_OBJECT = 1; 
    private static final int EDITM_HOST = 2;   

    private static final int STG_UNKNOWN = -1;
    private static final int STG_STREAM = 0;
    private static final int STG_STREAMINIT = 1;
    private static final int STG_STORAGE = 2;

    private static final int OLEIVERB_SHOW = -1;
    private static final int OLEIVERB_HIDE = -3;
    private static final int OLEIVERB_UIACTIVATE = -4;
    private static final int OLEIVERB_INPLACEACTIVATE =-5;
    private static final int OLEIVERB_PROPERTIES = -7;
    private static final int OLEIVERB_PRIMARY = 0;
    private static final int HOSTVERB_ABOUT = 1;
    private static final int HOSTVERB_PROPERTIES = 2;
    private static final int HOSTVERB_EDIT = 3;

    private int ocState = OC_PASSIVE;

    
    private IUnknown instance;
    private IOleInPlaceObject iOleInPlaceObject;
    private IOleObject iOleObject;
    private IOleControl iOleControl;
    private IOleInPlaceActiveObject iOleInPlaceActiveObject;
    private IPerPropertyBrowsing iPerPropertyBrowsing;
    private boolean checkedIppb = false;
    private ICategorizeProperties iCategorizeProperties;
    private boolean checkedCP = false;


    private Container container;
    private Form containingForm;

    private String clsid;

    private int miscStatusBits;

    private boolean ocxStateSet = false;
    private State ocxState;
    private int storageType = STG_UNKNOWN;
    private IPersistStream iPersistStream;
    private IPersistStreamInit iPersistStreamInit;
    private IPersistStorage iPersistStorage;    

    private boolean fNeedOwnWindow = false;
    private boolean fOwnWindow = false;
    private boolean fSimpleFrame = false;
    private boolean fFakingWindow = false;
    private boolean rejectSelection = true;
    private boolean ownDisposing = false;
    private boolean isDirtyOk = false;
    private boolean crossThread = false;
    private int freezeCount = 0;
    private boolean sinkAttached = false;
    private boolean disposed = false;
    private int wndprocAddr = 0;
    private int flags = 0;
    private AboutBoxDelegate aboutBoxDelegate = null;
    private String licenseKey = null;

    private static int logPixelsX = -1;
    private static int logPixelsY = -1; 

    private final OleInterfaces oleSite = new OleInterfaces(this);

    private static HashTable classInfos = new HashTable(); 
    private static final int REGMSG_MSG = Windows.RegisterWindowMessage("subclassCheck");
    private static final int REGMSG_RETVAL = 123;
    private boolean manualUpdate = false;

    private int editMode = EDITM_NONE;
    private EventHandler selectionChangeHandler = new EventHandler(this.onNewSelection);
    private boolean addedSelectionHandler = false;

    
    

    private static CategoryAttribute[] categoryNames = new CategoryAttribute [] {
                                                          null,
            new CategoryAttribute(""),
            new CategoryAttribute("Misc"),
            new CategoryAttribute("Font"),
            CategoryAttribute.Position,
            CategoryAttribute.Appearance,
            CategoryAttribute.Behavior,
            CategoryAttribute.Data,
            new CategoryAttribute("List"),
            new CategoryAttribute("Text"),
            new CategoryAttribute("Scale"),
            new CategoryAttribute("DDE")
            };

    private HashTable objectDefinedCategoryNames = null;
    
    /**
     * Creates a new instance of a control which wraps an activeX control given by the
     * clsid parameter and flags of 0.
     * @param clsid The CLSID of the underlying ActiveX control
     */
    protected AxHost (String clsid) {}


    /**
     * Creates a new instance of a control which wraps an activeX control given by the
     * clsid and flags parameters.
     * @param clsid The CLSID of the underlying ActiveX control
     * @param flags An or'ed collection of the members of the Flags inner class.
     * @see AxHost.Flags
     */
    protected AxHost (String clsid, int flags) {}

    /**
     * Called when the AxHost
     * object is ready to create the underlying ActiveX object.
     * Wrappers will override this and cast the pointer obtained by calling getOcx() to 
     * their own interfaces.  getOcx() should not usually be called before this function.
     * Note: calling <i>begin</i> will result in a call to this function.
     * @see begin
     */
    protected void attachInterfaces() {}

    private void realizeStyles() {}


    


    boolean getCanAccessProperties() {}

    private boolean propsValid() {}

    
    /**
     * Signals that loading of all peer
     * components and property sets is complete.
     * It should be possible to invoke any property get or set after calling this method.
     * Note that a sideeffect of this method is the creation of the parent control's
     * handle, therefore, this control must be parented before <i>begin</i> is called
     * @see IRequireBegin
     */
    public void begin() {}


    /**
     * Called by the control when a property
     * changes. Inheriting
     * controls can overide this method to get property change notification on
     * basic properties. Inherting controls must call <i>super.propertyChanged</i>.
     *
     * @param property Property that changed.
     */
    protected void propertyChanged(int property) {}


    private void ambientChanged(int dispid) {}


    /**
     * Returns the CreateParams used to create the handle for this control.
     * @return CreateParams used to create the handle for this control.
     */
    protected CreateParams getCreateParams() {}

    private boolean ownWindow() {}


    private int getHandleNoCreate() {}


    private ISelectionService getSelectionService() {}

    private static ISelectionService getSelectionService(Control ctl) {}

    private void addSelectionHandler() {}

    private boolean removeSelectionHandler() {}
    

    /**
     * Sets the control's site. A non-null value indicates that the
     * component has been added to a container, and a null value indicates that
     * the component is being removed from a container. 
     * @param site The new site, or <b>null</b> if none.
     */
    public void setComponentSite(IComponentSite site) {}

    private void onNewSelection(Object sender, Event e) {}

    /**
     * Creates a handle for this control. This method is called by the framework, this should
     * not be called. 
     */
    protected void createHandle() {}

    private tagRECT getClipRect(tagRECT clipRect) {}

    private static void setupLogPixels(boolean force) {}


    private void hiMetric2Pixel(tagSIZEL sz, tagSIZEL szout) {}

    private void pixel2hiMetric(tagSIZEL sz, tagSIZEL szout) {}

    private static int pixel2Twip(int v, boolean xDirection) {}

    private static int twip2Pixel(double v, boolean xDirection) {}
    
    private static int twip2Pixel(int v, boolean xDirection) {}


    private Point setExtent(int width, int height) {}

    
    private Point getExtent() {}

    private void setObjectRects(Rectangle bounds) {}

    /**
     * Sets the bounds of the control. 
     * User code should usually not call this function.
     *
     * @param x new left of the control.
     * @param y new right of the control.
     * @param width new width of the control.
     * @param height new height of the control.
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}


    private boolean checkSubclassing() {}

    /**
     * Destroys the handle associated with this
     * control. 
     * User code should in general not call this function.
     */
    protected void destroyHandle() {}

    private void transitionTo(int state) {}

    private void transitionDownTo(int state) {}

    private void transitionUpTo(int state) {}

    private void inPlaceActivate() {}


    private void inPlaceDeactivate() {}

    private void uiActivate() {}

    private void destroyFakeWindow() {}

    private void ensureWindowPresent() {}

    /**
     * Sets a boolean value
     * that determines whether the control is visible.
     * Note that calling <i>setVisible(true)</i> on an InvisibleAtRuntime
     * activeX control has no effect.
     * @param value Whether the controls should be visible
     */
    public void setVisible(boolean value) {}

    private void makeVisibleWithShow() {}

    private void hideAxControl() {}
    
    /**
     * Sets a boolean value
     * that determines whether this control should be a top-level window.
     * @param value In effect, whether to throw an exception.
     */
    public void setTopLevel(boolean value) {}


    /**
     * Preprocesses messages directed to this
     * control before the messages are sent to the control's window procedure. Possible values for the
     * msg.message field are WM_KEYDOWN, WM_SYSKEYDOWN, WM_CHAR, and WM_SYSCHAR.
     * If this method processes the message it must return true, in which case
     * the message loop will not dispatch the message.
     * This method should not be called directly by the user.
     * @param msg The message to forward to the ActiveX control's TranslateAccelerator function
     */
    public boolean preProcessMessage(MSG msg) {}

    /**
     * Process a mnemonic character. 
     * This is done by manufacturing a WM_SYSKEYDOWN message and passing it
     * to the ActiveX control.
     * @param charCode Character to test.
     *
     * @return <b>true</b> if the control used <i>charCode</i> as a mnemonic.
     */
    protected boolean processMnemonic(char charCode) {}

    private _Guid getPropertyPage(int dispid) {}

    private PropertyValue[] getPredefinedStrings(int dispid) {}


    

    /**
     * Sets the delegate that will be called
     * when the user clicks the About item on the control's context menu..."
     * entry on the context menu.
     * @param d the delegate to call
     */
    protected void setAboutBoxDelegate(AboutBoxDelegate d) {}

    /** 
     * Sets the persisted state of the control.
     * This should either be null, obtained from getOcxState, or
     * read from a resource.  The value of this property will
     * be used after the control is created but before it is
     * shown. 
     * @param ocxState The new persisted state of the control
     * @exception RuntimeException if the control has already been activated and 
     * setting the persisted state would never be used.
     * @see getOcxState
     * @see AxHost.State
     */
    public void setOcxState(State ocxState) {}

    /**
     * Sets the control's container.
     * By default, the parent form performs that function.  It is
     * however possible for another form higher in the parent chain
     * to serve in that role.  The logical container of this 
     * control determines the set of logical sibling control.
     * In general this property exists only to enable some speficic
     * behaviours of ActiveX controls and should in general not be set
     * by the user.
     * @param f The new containing form
     * @see getContainingForm
     */
    public void setContainingForm(Form f) {}

    private State createNewOcxState(State oldOcxState) {}

    private Control getTopLevelCtl() {}

    /**
     * Retrieves the form that contains this
     * control.
     * At design time this is always the form being designed.
     * At runtime it is either the form set with <i>setContainingForm</i> or,
     * by default, the parent form.
     * @see setContainingForm
     * @return the control's containing form.
     */
    public Form getContainingForm() {}

    /**
     * Sets a boolean value
     * that specifies whether this control should persist the property that identifies its
     * containing form.
     * @return <b>true</b> only is the containing form is different from the parent form.
     */
    public boolean shouldPersistContainingForm() {}

    /**
     * Retrieves the persisted state of the
     * ActiveX control that underlies this object.
     * If the control has been modified since it was last saved to a 
     * persisted state, it will be asked to save itself.
     * @see setOcxState
     * @return an object which encapsulates the persisted state of the control.
     */
    public State getOcxState() {}

    private boolean isDirty() {}

    private boolean canUIActivate() {}

    private boolean isUserMode() {}



    private boolean getAmbientUserMode() {}

    private boolean getAmbientMessageReflect() {}

    private boolean shouldMessageReflect() {}

    /**
     * Called by the container to obtain the value of an ambiant property.
     * This should not usually be called directly by the user but may
     * be overridden for advanced behaviour.
     * @param dispid the dispid of the ambient property
     * @param var the variant into which the value of the property should be stored
     * @return true if the property is supported by the container and it has been stored in <b>var</b>
     */
    protected boolean getAmbientProperty (int dispid, Variant var) {}


    private void doVerb(int verb) {}

    private boolean awaitingDefreezing() {}

    private void freeze(boolean v) {}

    private void uiDeactivate() {}

    private static void retHResult(ComException ce) {}

    private int getOcState() {}

    private void setOcState(int nv) {}

    
    private static native IClassFactory2 CoGetClassObject(_Guid clsid, int dwContext, int serverInfo,  _Guid refiid);

    
    private static native IUnknown CoCreateInstance(_Guid clsid, int punkouter, int dwContext, _Guid refiid);

    private String getLicenseKey() {}
    
    private void createWithoutLicense() {}
    
    private void createWithLicense(String license) {}

    private void createInstance() {}

    private CategoryAttribute getCategoryForDispid(int dispid) {}

    private void setSelectionStyle(int style) {}

    private void invokeEditMode() {}

    private static synchronized void registerClassInfo(AxHost control) {}

    private static synchronized void setupClassInfo(AxHost control) {}
    
    private boolean isSingleThreaded() {}

    private void checkThreadingModel() {}

    private void activateAxControl() {}


    private void depersistFromIStream(IStream istream) {}

    private void depersistFromIStreamInit(IStream istream) {}

    private void depersistFromIStorage(IStorage storage) {}

    private void depersistControl() {}

    /**
     * Retrieves the IUnknown
     * object for the ActiveX control that this class wraps.
     * @return the control's IUnknown
     */
    public IUnknown getOcx() {}

    private IUnknown getOcxCreate() {}

    private void startEvents() {}

    private void stopEvents() {}

    protected synchronized void createSink() {}


    protected synchronized void detachSink() {}


    private boolean canShowPropertyPages() {}
    

    private boolean hasPropertyPages() {}

    
    private static class Guid {
        
        byte b[];
    }

    
    private static class OPCHelper {
        public int pUnk;
    }

    
    private static native int SetWindowLong(int hWnd, int nIndex, IUnknown dwNewLong);
    
    private static native IUnknown GetWindowLong(int hWnd, int nIndex);


    
    private static class OPCFIPARAMS { 
        public int cbSizeOfStruct = com.ms.dll.DllLib.sizeOf(OPCFIPARAMS.class);
        public int hwndOwner;
        public int x = 0;
        public int y = 0;
        public String lpszCaption;
        public int cObjects = 1;
        public int ppUnk;
        public int pageCount = 1;
        public int uuid;
        public int lcid = Application.getCurrentLocale().getLCID();
        public int dispidInitial;
    }

    
    private static native void OleCreatePropertyFrameIndirect(OPCFIPARAMS params);

    
    private static native void OleCreatePropertyFrame(int hwnd, int x, int y, String caption, int objCount, 
        Object[] objs, int pageCount, int uuids, 
        int lcid, int res1, int res2);   

    
    private void showPropertyPageForDispid(int dispid, _Guid guid) {}

    private void makeDirty() {}

    private Customizer getCustomizer() {}

    private void showPropertyPages()  {}

    private void showPropertyPages(Control control) {}


    /**
     * Represents the window procedure for this
     * control. All messages are sent to wndProc after getting filtered
     * through the <i>preProcessMessage</i> function.
     * Certain messages are forwarder directly to the ActiveX control, 
     * others are first processed by the wndProc of Control
     *
     * @param m Win32 message
     * @see Control.wndProc
     */
    protected void wndProc(Message m) {}

    private void detachAndForward(Message m) {}
    
    private void detachWindow() {}

    private void informOfNewHandle() {}

    private void attachWindow(int hwnd) {}

    /**
     * Inheriting classes should override this method to find out when the
     * handle has been created.
     * Call super.onCreateHandle first.
     *
     * @param e event
     * @see #addOnCreateHandle
     * @see #removeOnCreateHandle
     */
    protected void onCreateHandle(Event e) {}

    
    public void setText(String value) {}
    
    
    public String getText() {}

    
    

    
    private static class OleInterfaces 
        implements IOleControlSite, IOleClientSite, IOleInPlaceSite, IDDispatch, ISimpleFrameSite, IVBGetControl, IGetVBAObject, com.ms.com.NoAutoMarshaling {
        
        private WeakReference pOwner;

        private OleInterfaces(AxHost ctl) {}

        AxHost getAxHost() {}

        

        public void GetObject(com.ms.com._Guid riid, IVBFormat[] rval, int dwReserved) {}

        

        public void EnumControls(int dwOleContF, int dwWhich, IEnumUnknown[] ppenum) {}

        


        public void PreMessageFilter(int hwnd, int msg, int wp, int lp, int[] plResult, int[] pdwCookie) {}

        public void PostMessageFilter(int hwnd, int msg, int wp, int lp, int[] plResult, int dwCookie) {}

        


        public void GetTypeInfoCount(int[] pctinfo) {}
        
        public void GetTypeInfo(int iTInfo, int lcid, IUnknown[] ppTInfo) {}
        
        public void GetIDsOfNames(com.ms.com._Guid riid, String[] rgszNames, int cNames, int lcid, int[] rgDispId) {}
        
        public void Invoke(int dispIdMember, com.ms.com._Guid riid, int lcid, int dwFlags, 
            tagDISPPARAMS pDispParams, Variant pVarResult, int[] pExcepInfo, int[] pArgErr) {}





        


        public void OnControlInfoChanged() {}

        public void LockInPlaceActive(int fLock) {}

        public void GetExtendedControl(IMyDispatch[] ppDisp) {}

        public void TransformCoords(_POINTL pPtlHimetric, tagPOINTF pPtfContainer, int dwFlags) {}

        public void TranslateAccelerator(tagMSG pMsg, int grfModifiers) {}

        public void OnFocus(int fGotFocus) {}

        public void ShowPropertyFrame() {}

        

        public void SaveObject() {}

        public void GetMoniker(int dwAssign, int dwWhichMoniker, IUnknown[] ppmk) {}

        public void GetContainer(IOleContainer[] ppContainer) {}

        
        private static native int AttachThreadInput(int myThread, int theOtherThread, int fAttach);

        public void ShowObject() {}

        public void OnShowWindow(int fShow) {}

        public void RequestNewObjectLayout() {}

        

        public void GetWindow(int[] phwnd) {}

        public void ContextSensitiveHelp(int fEnterMode) {}

        public void CanInPlaceActivate() {}

        public void OnInPlaceActivate() {}

        public void OnUIActivate() {}

        public void GetWindowContext(IOleInPlaceFrame[] ppFrame, IOleInPlaceUIWindow[] ppDoc, 
            tagRECT lprcPosRect, tagRECT lprcClipRect, tagOIFI lpFrameInfo) {}    

        public void Scroll(tagSIZE scrollExtant) {}
        
        public void OnUIDeactivate(int fUndoable) {}

        public void OnInPlaceDeactivate() {}
        
        public void DiscardUndoState() {}
        
        public void DeactivateAndUndo() {}
        
        public void OnPosRectChange(tagRECT lprcPosRect) {}
        
        

        public void OnChanged(int dispid) {}

        public void OnRequestEdit(int dispid) {}
    }
    


    private static final int HMperInch = 2540;
    private int Pix2HM(int pix, int logP) {}
    
    private int HM2Pix(int hm, int logP) {}



    private boolean quickActivate() {}

    void disposeAxControls() {}
    

    private boolean getControlEnabled() {}

    boolean canSelectCore() {}

    /**
     * Frees all resources assocaited with this control. This method may not be
     * called at runtime. Any resources used by the control should be setup to
     * be released when the control is GC'ed. Inheriting classes should always
     * call <i>super.dispose</i>.
     */
    public void dispose() {}

    private boolean getSiteOwnsDeactivation() {}

    private void disposeAxControl() {}

    private void releaseAxControl() {}

    private void parseMiscBits(int bits) {}

    private void slowActivate() {}

    private static boolean isRectEqual(tagRECT rect, Rectangle r) {}

    private static tagRECT fillInRect(tagRECT dest, Rectangle source) {}


    private Container getParentContainer() {}

    private IOleControl getOleControl() {}

    private IOleInPlaceActiveObject getInPlaceActiveObject() {}
    
    private IOleObject getOleObject() {}
    
    
    IOleInPlaceObject getInPlaceObject() {}

    private ICategorizeProperties getCategorizeProperties() {}
    
    private IPerPropertyBrowsing getPerPropertyBrowsing () {}


    
    
    
    private static class FONTDESC {
        public int cbSizeOfStruct = com.ms.dll.DllLib.sizeOf(FONTDESC.class);
        public String lpstrName;
        public long cySize;
        public short sWeight;
        public short sCharset;
        public boolean fItalic;
        public boolean fUnderline;
        public boolean fStrikethrough;
    }

    
    private static native IFont OleCreateIFontIndirect(FONTDESC fd, _Guid iid);
    
    private static native IFontDisp OleCreateIFontDispIndirect(FONTDESC fd, _Guid iid);

    
    private static native IPicture OleCreateIPictureIndirect(int pictdesc, _Guid iid, boolean fOwn);
    
    private static native IPictureDisp OleCreateIPictureDispIndirect(int pictdesc, _Guid iid, boolean fOwn);

    
    private static class PICTDESCbmp {
        int cbSizeOfStruct = 4 * 5;
        int picType = Ole.PICTYPE_BITMAP;
        int hbitmap;
        int hpalette;
        int unused;

        public PICTDESCbmp(Bitmap bitmap) {}
    }
    
    private static int copyPalette(int hPal) {}

    
    private static class PICTDESCicon {
        int cbSizeOfStruct = 4 * 5;
        int picType = Ole.PICTYPE_ICON;
        int hicon;
        int unused1;
        int unused2;
        
        public PICTDESCicon (Icon icon) {}
    }

    
    private static class PICTDESCemf {
        int cbSizeOfStruct = 4 * 5;
        int picType = Ole.PICTYPE_ENHMETAFILE;
        int hemf;
        int unused1;
        int unused2;
        
        public PICTDESCemf(Metafile metafile) {}
    }
    
    private static int getPICTDESCFromPicture(Image image) {}

    /**
     * Maps from a WFC Image to an OLE IPicture
     * @param image the image to duplicate
     * @return the resulting IPicture object
     */
    public static IPicture getIPictureFromPicture(Image image) {}

    /**
     * Maps from a WFC Image to an OLE IPictureDisp
     * @param image the image to duplicate
     * @return the resulting IPictureDisp object
     */
    public static IPictureDisp getIPictureDispFromPicture(Image image) {}

    /**
     * Maps from an OLE IPicture to a WFC Image
     * @param picture the Picture to wrap or duplicate
     * @return the resulting Image
     */
    public static Image getPictureFromIPicture(IPicture picture) {}

    /**
     * Maps from an OLE IPictureDisp to a WFC Image
     * @param picture the Picture to wrap or duplicate
     * @return the resulting Image
     */
    public static Image getPictureFromIPictureDisp(IPictureDisp picture) {}

    private static Image getPictureFromParams(IUnknown pict, int handle, int type, int paletteHandle) {}

    private static FONTDESC getFONTDESCFromFont(Font font) {}

    /**
     * Maps from an OLE COLOR to a WFC Color
     * @param color the OLE Color to convert
     * @return the resulting WFC Color object
     */
    public static Color getColorFromOleColor(int color) {}
    
    /**
     * Maps from an WFC Color to an OLE COLOR
     * @param color the WFC Color to convert
     * @return the resulting OLE COLOR
     */
    public static int getOleColorFromColor(Color color) {}

    /**
     * Maps from a WFC Font object to an OLE IFont
     * @param font the WFC Font object to convert
     * @return the resulting OLE IFont
     */
    public static IFont getIFontFromFont(Font font) {}


    /**
     * Maps from an OLE IFont to a WFC Font object
     * @param font the OLE IFont to convert
     * @return the resulting WFC Font object
     */
    public static Font getFontFromIFont(IFont font) {}


    /**
     * Maps from a WFC Font object to an OLE IFontDisp
     * @param font the WFC Font object to convert
     * @return the resulting OLE IFontDisp
     */
    public static IFontDisp getIFontDispFromFont(Font font) {}

    /**
     * Maps from an IFontDisp to a WFC Font object
     * @param font the IFontDisp to convert
     * @return the resulting Font
     */
    public static Font getFontFromIFontDisp(IFontDisp font) {}
    
    
    /**
     * Maps from a WFC Time object to an OLE DATE (expressed as a double)
     * @param time the WFC Time object to convert
     * @return the resulting OLE DATE
     */
    public static double getDATEFromTime(Time time) {}

    /**
     * Maps from an OLE DATE (expressed as a double) to a WFC Time object
     * @param date the OLE DATE to convert
     * @return the resulting Time
     */
    public static Time getTimeFromDATE(double date) {}


    /**
     * Returns the class attributes (by adding them to <b>attribs</b>) of
     * the classinfo which corresponds to the derived class given by
     * <b>axHostClass</b>  Derived controls should call this in their
     * ClassInfo's implementation of getAttributes
     * @param classInfo the classinfo whose attributes to return
     * @param axHostClass class of object whose class info is being manipulated
     * @param attribs The attributes collection to add to
     */    
    public static void getClientAttributes(AxHost.ClassInfo classInfo, Class axHostClass, IAttributes attribs) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnClick() {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnDblClick() {}
    
    
    private int combineCM(short c, short m) {}


    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyDown(short keyCode, short shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyDown(short[] keyCode, short shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyDown(short[] keyCode, short[] shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyUp(short keyCode, short shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyUp(short[] keyCode, short shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyUp(short[] keyCode, short[] shift) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyPress(short[] keyAscii) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnKeyPress(short keyAscii) {}

    
    private int convert2int(Object o, boolean xDirection) {}

    
    private short convert2short(Object o) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseMove(Object o1, Object o2, Object o3, Object o4) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseMove(short button, short shift, float x, float y) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseMove(short button, short shift, int x, int y) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseUp(Object o1, Object o2, Object o3, Object o4) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseUp(short button, short shift, float x, float y) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseUp(short button, short shift, int x, int y) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseDown(Object o1, Object o2, Object o3, Object o4) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseDown(short button, short shift, float x, float y) {}

    /**
     * @internalonly
     * @hidden
     */
    public void fireOnMouseDown(short button, short shift, int x, int y) {}


    
    private static class VBFormat implements IVBFormat {

        

        
        private static final native int VarFormat(Variant pvarIn, String pstrFormat, int iFirstDay, int iFirstWeek, int dwFlags);
        
        public void Format(Variant var, String pszFormat, int lpBuffer, short cpBuffer, int lcid, short firstD, short firstW, short[] result) {}
    }



    
    private static class EnumUnknown implements IEnumUnknown { 
        private IUnknown arr[];
        private int loc;
        private int size;

        public EnumUnknown (IUnknown arr[]) {}

        private EnumUnknown (IUnknown arr[], int loc) {}
        

        public void RemoteNext(int celt, int rgelt, int pceltFetched) {}
        
        public void Skip(int celt) {}
        
        public void Reset() {}
        
        public void Clone(IEnumUnknown[] ppenum) {}


    }


    
    static class Container implements IOleContainer, IOleInPlaceFrame, com.ms.com.NoAutoMarshaling { 

        private Form parent;
        private IContainer assocContainer; 
        
        
        private AxHost siteUIActive;
        private AxHost siteActive;
        private boolean formAlreadyCreated = false;
        private HashTable containerCache = new HashTable();  
        private HashTable addedControls = null;
        private int lockCount = 0;
        private HashTable components = null;  
        private HashTable proxyCache = null;
        private AxHost ctlInEditMode = null;
        
        private static final int GC_CHILD = 0x1;
        private static final int GC_LASTSIBLING = 0x2;
        private static final int GC_FIRSTSIBLING = 0x4;
        private static final int GC_CONTAINER = 0x20;
        private static final int GC_PREVSIBLING = 0x40;
        private static final int GC_NEXTSIBLING = 0x80;

        Container(Form parent) {}

        private IExtender getProxyForControl(Control ctl) {}
        
        private String getNameForControl(Control ctl) {}
        
        private IUnknown getProxyForContainer() {}

        private String pickName(Control ctl, String name) {}

        private synchronized void addControl(Control ctl, String name) {}

        
        private void lockComponents() {}
        
        private void unlockComponents() {}

        private IEnumUnknown enumControls(Control ctl, int dwOleContF, int dwWhich) {}

        private void maybeAdd(List l, Control ctl, boolean selected, int dwOleContF, boolean ignoreBelong) {}

        private void fillComponentsTable(IContainer container) {}
        
        private HashTable getComponents() {}

        private HashTable getComponents(IContainer cont) {}

        private boolean getControlBelongs(Control ctl) {}

        private IContainer getParentIsDesigned() {}

        private IContainer getParentsContainer() {}

        private boolean registerControl(AxHost ctl) {}

        private static Container findContainerForControl(Control ctl) {}

        void onOldActiveControl(Control valueOld, Control valueNew) {}

        private void onOldActiveControlInternal(Control valueOld) {}

        void onNewActiveControl(Control value) {}

        private void onNewActiveControlInternal(AxHost value) {}

        private void onInPlaceDeactivate(AxHost site) {}

        private void onUIDeactivate(AxHost site) {}

        private static boolean childHasFocus(Control ctl) {}

        private void onUIActivate(AxHost site) {}

        private void listAxControls(List list, boolean fuseOcx) {}
        
        private void controlCreated(AxHost invoker) {}

        void formCreated() {}


        

        public void ParseDisplayName(IUnknown pbc, String pszDisplayName, int[] pchEaten, IUnknown[] ppmkOut) {}
        

        public void EnumObjects(int grfFlags, IEnumUnknown[] ppenum) {}
        
        public void LockContainer(int fLock) {}

        

        public void GetWindow(int[] phwnd) {}

        public void ContextSensitiveHelp(int fEnterMode) {}

        public void GetBorder(tagRECT lprectBorder) {}

        public void RequestBorderSpace(tagRECT pborderwidths) {}

        public void SetBorderSpace(tagRECT pborderwidths) {}

        private void onExitEditMode(AxHost ctl) {}

        public void SetActiveObject(IOleInPlaceActiveObject pActiveObject, String pszObjName) {}

        public void InsertMenus(int hmenuShared, tagOleMenuGroupWidths lpMenuWidths) {}

        public void SetMenu(int hmenuShared, int holemenu, int hwndActiveObject) {}

        public void RemoveMenus(int hmenuShared) {}

        public void SetStatusText(String pszStatusText) {}

        public void EnableModeless(int fEnable) {}

        public void TranslateAccelerator(tagMSG lpmsg, short wID) {}


        

        
        private static class ExtenderProxy 
        implements IExtender, IVBGetControl, IMyDispatch, IGetVBAObject, IGetOleObject, com.ms.com.NoAutoMarshaling
        {
            private WeakReference pRef;
            private WeakReference pContainer;
            
            private Control getP() {}

            private Container getC() {}

            public ExtenderProxy(Control principal, Container container) {}


            public void EnumControls(int dwOleContF, int dwWhich, IEnumUnknown[] ppenum) {}

            public void GetObject(com.ms.com._Guid riid, IVBFormat[] rval, int dwReserved) {}
            
            public void GetOleObject(com.ms.com._Guid riid, int prval) {}

            
            public int getAlign() {}

            public void setAlign(int v) {}

            
            public boolean getEnabled() {}
            
            public void setEnabled(boolean v) {}
            
            public int getHeight() {}
            
            
            public void setHeight(int v) {}
            
            public int getLeft() {}
            
            public void setLeft(int v) {}
            
            public boolean getTabStop() {}
            
            public void setTabStop(boolean v) {}
            
            public int getTop() {}
            
            public void setTop(int v) {}
            
            public boolean getVisible() {}
            
            public void setVisible(boolean v) {}
            
            public int getWidth() {}
            
            public void setWidth(int v) {}
            
            public String getName() {}
            
            public Object getParent() {}
            
            public int getHwnd() {}
            
            public IUnknown getContainer() {}

        }
    }

    /**
     * Wraps an ActiveX control and exposes the control as a WFC control.
     * @see IPersistable
     * @see setOcxState
     * @see getOcxState
     *
     * @security(checkClassLinking=on)
     */
    public static class State implements IPersistable { 
        private int VERSION = 1;
        private int length;        
        private byte buffer[];        
        private int type;
        private MemoryStream ms;
        private IStorage storage;
        private ILockBytes iLockBytes;
        private boolean manualUpdate = false;
        private String licenseKey = null;
        private AxHost owner = null;
        
        /**
         * Construct a new State by reading it from the provided data stream
         * The seek pointer should be positioned at the place just before
         * save was called to this stream.
         * @param ids the data stream to read from
         * @see IPersistable
         */
        public State(IDataStream ids) {}        

        
        private State(MemoryStream ms, int storageType, AxHost ctl) {}

        
        private State(AxHost ctl) {}

        private State copy() {}

        private void createStorage() {}

        private IStorage getStorage() {}


        private IStream getStream() {}

        
        private static native void OleSave(IPersistStorage pPS, IStorage pStg, int fSameAsLoad);
        

        private State refreshStorage(IPersistStorage iPersistStorage) {}
        
        /**
         * Saves the encapsulated persisted state to an IDataStream.  
         * @param ids the date stream to save to
         * @see IDataStream
         */
        public void save(IDataStream ids) {}
        
        /**
         * Gives the suggested extension for the stream into which save is called
         * @return the file extension
         * @see save
         */
        public String getExtension() {}

    }

    private static final HostVerbData EditVerbData = new HostVerbData(Sys.getString("AXEdit"), HOSTVERB_EDIT);
    private static final HostVerbData PropertiesVerbData = new HostVerbData(Sys.getString("AXProperties"), HOSTVERB_PROPERTIES);
    private static final HostVerbData AboutVerbData = new HostVerbData(Sys.getString("AXAbout"), HOSTVERB_ABOUT);
    

    
    private static class HostVerbData { 
        final String name;
        final int id;

        HostVerbData(String name, int id) {}

        public String toString() {}

        void execute(AxHost ctl) {}
    }



    
    private static class OleVerbData extends HostVerbData { 
        private final boolean dirties;
        
        OleVerbData(tagOLEVERB oleVerb) {}
        
        void execute(AxHost ctl) {}

    }
    
    private static char editChars[] = new char[] {'e', 'd', 'i', 't'};
    

    /**
     * @security(checkClassLinking=on)
     */
    protected delegate void AboutBoxDelegate();


    
    private class Customizer extends com.ms.wfc.core.Customizer {

        private VerbExecuteEventHandler handler = new VerbExecuteEventHandler(this.onVerb);

        private boolean getOleVerbs(List rval) {}

        public CustomizerVerb[] getVerbs() {}

        public boolean getHitTest(Point p) {}

        private void onVerb(Object sender, VerbExecuteEvent event) {}                
    }


    
    private static class Bucket { 
        public static final ClassInfo ORIGINAL = new ClassInfo();

        private WeakReference classRef;
        private Bucket next;

        private Bucket(Class type, Bucket next) {}

        public static Bucket onRegisterClassInfo(Bucket bucket, Class type) {}

        public boolean isClassInfoRegistered (Class type) {}
    }


    /**
     * Wraps an ActiveX control and exposes the control as a WFC control.  Its used internally by
     * the AxHost class
     *
     * @security(checkClassLinking=on)
     */
    public static class DispidAttribute extends MemberAttribute { 

        /**
         * The actual dispatch identifier
         */
        public final int dispid;

        /**
         * Creates a new instance of this attribute
         * @param dispid the dispatch identifier to wrap
         */
        public DispidAttribute(int dispid) {}
    }

    private static Object mapVariantToObject(Variant var, Class type) {}


    
    private static class AxClassInfo implements IClassInfo { 
        private IClassInfo containedClassInfo;
        private PropertyInfo[] props;
        
        public AxClassInfo (IClassInfo ci, PropertyInfo props[]) {}

        public void getAttributes(IAttributes attributes) {}
        
        public ICustomizer getCustomizer(Object component) {}
        
        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}
        
        public void getExtenders(IExtenders extenders) {}
        
        public void getProperties(IProperties iprops) {}
        
        public Bitmap getToolboxBitmap() {}
    }

    /**
     * Wraps an ActiveX control and exposes the control as a WFC control.
     
     * @see PropertyInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class AxPropertyInfo extends com.ms.wfc.core.PropertyInfo { 

        boolean useOriginalVE = false;
        private int dispid = 0;
        private Class compClass;

        /**
         * Creates a new AxPropertyInfo object
         * @param componentClass The class from which the get and set methods will come.  This should be the class which extends AxHost
         * @param name The name for the Property
         * @param type The type of the Property
         * @param attributes The attributes of the property.  One of these should be the DispidAttribute
         * @see PropertyInfo
         * @see DispidAttribute
         */
        public AxPropertyInfo(Class componentClass, String name, Class type, MemberAttribute[] attributes) {}
        
        private AxPropertyInfo(com.ms.wfc.core.PropertyInfo oldPI, int dispid, MemberAttribute ma, Class compClass) {}

        private void commonCreate(Class compClass, Class type) {}

        /**
         * Returns the value editor for this property given an IEditorSite
         * If the attributes of this property specify a value editor, or if the
         * type of this property is Image, Color, or Font then this is equivalent
         * to calling <i>PropertyInfo.getValueEditor(site)</i>, otherwise,
         * a special value editor is returned whose behavior depends on the
         * underlying ActiveX control
         * @param site the IEditorSite to use
         * @return a new value editor
         */
        public IValueEditor getValueEditor(IEditorSite site) {}

        /**
         * Sets the value of this property on <i>component</i> to <i>value</i>.
         * The type of <i>value</i> should correspond to the type of this property
         * or be a special object returned by the value editor's <i>getValues</i> function
         * @param component the object being modified
         * @param value the new property value
         */
        public void setValue(Object component, Object value) {}



        
        private class ValueEditor implements IValueEditor { 
            private IValueEditor containedEditor;
            private IEditorSite esite;
            private PropertyValue values[];
            private AxHost host;
            private boolean styleValid = false;
            private boolean hasOleValues = false;
            private int style;
            
            public ValueEditor(IEditorSite esite, IValueEditor containedEditor) {}
            
            private _Guid getPropertyPage(IComponent comps[]) {}


            public void editValue(IValueAccess valueAccess) {}
            
            public String getConstantName(Object value) {}
            
            public SubProperty[] getSubProperties(Object value) {}

            private boolean checkValuesArray(Object comps[]) {}
            
            private PropertyValue[] getValuesArray(Object comps[]) {}

            public int getStyle() {}
            
            public String getTextFromValue(Object value) {}
            
            public Object[] getValues() {}
            
            public Object getValueFromText(String text) {}
            public Object getValueFromSubPropertyValues(Object[] values) {}
            public void paintValue(Object value, Graphics g, Rectangle rect) {}
        }
    }



    
    private static final class PropertyValue { 
        public String displayValue;
        public int cookie;
        public PropertyValue(String s, int c) {}
        public boolean equals (Object o) {}
    }

    /**
     * Wraps an ActiveX control and exposes the control as a WFC control.
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo { 
        public static final PropertyInfo ocxState = new PropertyInfo(
            AxHost.class, "ocxState", AxHost.State.class, 
            BrowsableAttribute.NO);

        public static final PropertyInfo containingForm = new PropertyInfo(
            AxHost.class, "containingForm", Form.class, 
            BrowsableAttribute.NO);


        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}

        public void getAttributes(IAttributes attribs) {}

        public String getDefaultEventName() {}

        
        public ICustomizer getCustomizer(Object component) {}
    }

    /**
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    public interface PeerInformation { 
        public void request();
    }

}