//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import java.lang.reflect.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.io.*;

/**
 * This class implements the persistence of components into a stream.  It is a helper
 * class and is not meant to be used publicly.
 * The stream has the following format: ("*" means pattern repeated 0 or more times)
 *
 * (<Property Name> <Type Byte> <Value>)* <Ending 0>
 *
 * <Property Name> is the length-prefixed UTF string describing the name of the property
 * <Type Byte> is the proprietary representation of the type of the value to come
 * <Value> is the value of the property.  Its format depends on the <Type Byte>. See below.
 * <Ending 0> is a 16-bit-wide zero to denote the end of properties.
 *
 * Here are the <Value> formats corresponding each <Type Byte> value (note that a couple
 * of 'em have recursive definitions of <Value>):
 *
 * <Type Byte>    <Value>
 * NULL         : Has no persistent representation.  The Type Byte alone is enough
 *
 * BOOLEAN to   : Platform-independent representation of the primitive value, as
 * DOUBLE       : written by the DataStream class.
 *
 * STRING       : Length-prefixed UTF string.
 *
 * PERSISTABLE  : Object that implements IPersistable.  The format is as follows:
 *              : <Class Name> <Length of data> <Data as written by IPersistable.save()>
 *
 * CONSTRUCTABLE: Object that implements IConstructable,  The format is as follows:
 *              : <Class Name> <# of args> (<Type Byte> [<Paramter Type> <Type Byte>] <Value>)*
 *
 * ARRAY|OBJECT : <Element Type> <# of elements> (<Type Byte> <Value>)*
 *
 * ARRAY|STRING : <# of elements> <UTF String>*
 *
 * ARRAY|BYTE to: <# of elements> followed by array as written by DataStream class.
 * ARRAY|DOUBLE : 
 *
 * @internalonly
 *
 * @security(checkClassLinking=on)
 */
public final class AxPersist
{





    private static final short signature = 0x4B50;
    private static final short version   = 0x01;

    private static final byte NULL          = 0;
    private static final byte BOOLEAN       = 1;
    private static final byte BYTE          = 2;
    private static final byte CHAR          = 3;
    private static final byte SHORT         = 4;
    private static final byte INT           = 5;
    private static final byte LONG          = 6;
    private static final byte FLOAT         = 7;
    private static final byte DOUBLE        = 8;
    private static final byte STRING        = 9;
    private static final byte OBJECT        = 10;
    private static final byte PERSISTABLE   = 11;
    private static final byte CONSTRUCTABLE = 12;
    private static final byte ARRAY         = -128;
    private static final Class[] primitiveMap =
            new Class[] { null, boolean.class, byte.class, char.class, short.class,
                          int.class, long.class, float.class, double.class, String.class };

    public static void saveComponent(IComponent comp, com.ms.com.IStream stream) {}

    private static void writeProperty(IComponent comp, PropertyInfo prop, IDataStream outStream) {}

    
    private static boolean willWrite(Object value) {}

    private static void writeValue(Object value, IDataStream outStream) {}

    private static void writePrimitive(Object value, IDataStream outStream) {}

    private static void writeArray(Object value, IDataStream outStream) {}

    private static void writeStringArray(Object value, IDataStream outStream) {}

    private static void writeObjectArray(Object value, IDataStream outStream) {}

    private static void writePrimitiveArray(Object value, IDataStream outStream) {}

    private static boolean isPrimitiveWrapper(Class type) {}

    
    private static boolean isPersistable(PropertyInfo prop) {}

    public static void loadComponent(IComponent comp, com.ms.com.IStream stream) {}

    private static Object readValue(IDataStream inStream) {}

    private static Object readValue(byte b, IDataStream inStream) {}

    private static Object readConstructable(IDataStream inStream) {}

    private static Object readArray(byte baseType, IDataStream inStream) {}

    private static Object readPersistable(IDataStream inStream) {}
}