//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.com.*;

/**
 * Encapsulates a Windows bitmap.   Bitmaps can be stretched, rotated and cropped in a Graphics
 * object.  Windows bitmaps do not support any form of transparancy.
 * Windows has worked around this limitation by defining that a bitmap
 * may be representated as a bitmap and a transparent color.  All colors
 * of the bitmap that are the same color as the transparent color will
 * be transparent.  By convention, the transparent color is automatically
 * generated by looking at the lower left pixel of the bitmap.
 * 
 * @see Graphics
 *
 * @security(checkClassLinking=on)
 */
public class Bitmap extends Image implements IPersistable {
    private int handle = 0;             
    private Bitmap maskBitmap = null;   
    private Bitmap colorBitmap = null;  
    private boolean ownHandle = true;
    private boolean transparent = false;
    private Color transparentColor;
    private Palette palette;
    private BitmapGraphics graphics;
    private BITMAPINFO bitmapinfo;
    private int insideDraw = 0;         

    /**
     * Creates a bitmap object from a Win32 bitmap handle.  The
     * Bitmap object does not claim ownership of the handle; you
     * are responsible for releasing it when you are done.
     * 
     * @param handle A win32 bitmap handle.
     */
    public Bitmap(int handle)  {}
    
    /**
     * Creates a bitmap object from a Win32 bitmap handle and a
     * palette object.  The new Bitmap object does not
     * claim ownership of the handle.
     * 
     * @param handle    A Win32 bitmap handle.
     * @param palette   A palette object to use with the bitmap.
     */
    public Bitmap(int handle, Palette palette) {}
    
    /**
     * Creates a bitmap object from a mask/color bitmap pair.  This is used
     * when you already have a transparency mask and you want to fabricate
     * a full bitmap out of it.  
     * 
     * @param maskBitmap    The black and white mask bitmap.
     * @param colorBitmap   The color mask bitmap.
     */
    public Bitmap(Bitmap maskBitmap, Bitmap colorBitmap) {}

    /**
     * Creates a bitmap with the given dimensions suitable for display on
     * the screen.
     * 
     * @param width  The width, in pixels, of the bitmap.
     * @param height The height, in pixels, of the bitmap.
     */
    public Bitmap(int width, int height) {}
    
    /**
     * Creates a bitmap with the given dimensions suitable for display on
     * the given Graphics object.
     * 
     * @param width  The width, in pixels, of the bitmap.
     * @param height The height, in pixels, of the bitmap.
     * @param gr     A graphics object to create the bitmap form.
     * 
     * @see Graphics
     */
    public Bitmap(int width, int height, Graphics gr) {}

    /**
     * Creates a bitmap with the given dimensions, color information, and bit
     * pattern.
     * 
     * @param width         The width, in pixels, of the bitmap.
     * @param height        The height, in pixels, of the bitmap.
     * @param planes        The number of planes the bitmap consists of.
     *                      Typicall this is one (1).
     * @param bitsPerPixel  The number of bits for each pixel.  A 256 color
     *                      bitmap would have 8, while a true color bitmap
     *                      typically has 24 or 32.
     * @param bits          The actual bits that make up the image on the bitmap.
     *                      This can be <b>null</b> if you want the bitmap to remain
     *                      uninitialized.
     */
    public Bitmap(int width, int height, int planes, int bitsPerPixel, short bits[]) {}

    /**
     * Loads a bitmap from the given filename.
     * 
     * @param fileName The filename of the bitmap to load.
     */
    public Bitmap(String fileName) {}

    /**
     * Loads a bitmap from a resource.
     * 
     * @param type      The class we will use to extract the resource.
     * @param resource  The name of the resource.
     */
    public Bitmap(Class type, String resource) {}

    /**
     * Loads a bitmap from a data stream.
     * 
     * @param stream A data stream to load the bitmap from.
     * 
     * @see com.ms.wfc.io.IDataStream
     */
    public Bitmap(IDataStream stream) {}

    /**
     * Loads a bitmap from a COM stream.
     * 
     * @param stream A data stream to load the bitmap from.
     * 
     * @see com.ms.wfc.ole32.IStream
     */
    public Bitmap(IStream stream) {}

    /**
     * Loads a bitmap from an OLE IPicture object.
     * 
     * @param picture The picture object to get the bitmap from.
     * 
     * @see com.ms.wfc.ole32.IPicture
     */
    public Bitmap(IPicture picture) {}

    
    private void beginDraw() {}

    /**
     * Clones the Bitmap object and returns a duplicate.  
     * 
     * @return an object that can be casted to a Bitmap.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of the Win32 handle for the bitmap on which this object is based.   You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 bitmap handle.
     */
    public final int copyHandle() {}

    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Frees all the resources allocated by this object.  Once called, the bitmap
     * object is no longer useful.
     */
    public void dispose() {}
    
    
    private void disposeTransparentBitmaps() {}
    
    /**
     * Renders the bitmap image (or part of it) to a Graphics object,
     * cropping the image to fit the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version crops the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to crop to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}

    /**
     * Renders the bitmap image to a Graphics object, stretching the image to
     * fill the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version stretches the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to stretch the image to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}
    
    
    private void endDraw() {}

    
    private void ensureTransparentBitmaps() {}

    /**
     * Frees the resources allocated by the Bitmap object.
     */
    protected void finalize() {}

    /**
     * Retrieves the transparency mask for a transparent bitmap.   This is useful
     * if you need to draw transparency yourself, or if you need to pass transparent
     * masks on to another application.
     * 
     * @return the color transparency mask, or null if this bitmap is not transparent.
     */
    public Bitmap getColorMask() {}

    /**
     * Retrieves the recommended file extension for files that persist this object.
     * 
     * @return the recommended file extension, without a prefixing period.
     * @see IPersistable
     */
    public String getExtension() {}

    /**
     * Retrieves a Graphics object that you can use to paint to this image.  This will create a graphics
     * object if none exists, or will return the existing one if it was created.
     *
     * @return Graphics
     */
    public final Graphics getGraphics() {}

    /**
     * Retrieves the Win32 handle to this bitmap.   This is not a copy of the handle; do
     * not free it.
     * 
     * @return the handle to this bitmap.
     */
    public int getHandle() {}
    
    /**
     * Retrieves the monochrome mask for a transparent bitmap.   This is useful
     * if you need to draw transparency yourself, or if you need to pass transparent
     * masks on to another application.
     * 
     * @return the monochrome transparency mask, or null if this bitmap is not transparent.
     */
    public Bitmap getMonochromeMask() {}

    /**
     * Retrieves this Bitmap object's palette.
     * 
     * @return a Palette object, or <b>null</b>.
     */
    public final Palette getPalette() {}

    /**
     * Retrieves a PICTDESC (Picture Descriptor) for this bitmap.   PICTDESCs are
     * used by OLE.
     * 
     * @return a PICDESC object.
     */
    public final PICTDESC getPICTDESC() {}
    
    /**
     * Retrieves the size of this Bitmap object's image.
     * 
     * @return the size of the object, in pixels.
     */
    public final Point getSize() {}

    /**
     * Retrieves a boolean value that specifies whether this object is
     * configured to be drawn transparently.  Windows does not 
     * support transparency so it is simulated by the Bitmap object.  This flag
     * determines if the bitmap's transparent color will be used when drawing.
     * <p>
     * Because the transparent color of a bitmap is not part of the Windows bitmap 
     * file specification, this information does not get persisted to files and resources.
     * 
     * @see #setTransparent
     * @see #setTransparentColor
     * @see #getTransparentColor
     */
    public final boolean getTransparent() {}

    /**
     * Retrieves the transparent color for the Bitmap object.  Windows bitmaps
     * do not support transparency, so it is simulated by creating a bitmap that uses
     * a specific color in areas that are supposed to be transparent.  This color is
     * the transparent color.  If not specified, the transparent color defaults to the
     * color of the lower left pixel in the bitmap.
     * <p>
     * Because the transparent color of a bitmap is not part of the Windows bitmap 
     * file specification, this information does not get persisted to files and resources.
     * 
     * @return the color this bitmap will consider to be the transparent color when drawing
     *                   transparently.
     * 
     * @see #setTransparentColor
     * @see #setTransparent
     * @see #getTransparent
     */
    public final Color getTransparentColor() {}

    /**
     * Initializes this image for the first time.  This should only be called once.
     * 
     * @param picture The IPicture object to initialize the bitmap with.
     *
     */
    protected void initialize(IPicture picture) {}
    
    /**
     * Specifies whether the bitmap will be drawn transparently.  Windows does not 
     * support transparency so it is simulated by the Bitmap object.  This flag
     * determines if the bitmap's transparent color will be used when drawing.
     * <p>
     * Because the transparent color of a bitmap is not part of the Windows bitmap 
     * file specification, this information does not get persisted to files and resources.
     * 
     * @see #getTransparent
     * @see #setTransparentColor
     * @see #getTransparentColor
     */
    public final void setTransparent(boolean transparent) {}

    /**
     * Specifies the transparent color for this Bitmap's image.  Windows bitmaps
     * do not support transparency, so it is simulated by creating a bitmap that uses
     * a specific color in areas that are supposed to be transparent.  This color is
     * the transparent color.  If not specified, the transparent color defaults to the
     * color of the lower left pixel in the bitmap.
     * <p>
     * Because the transparent color of a bitmap is not part of the Windows bitmap 
     * file specification, this information does not get persisted to files and resources.
     * 
     * @param color The color of transparent areas of the bitmap.  If <b>null</b>,
     *              the transparent color will be determined by the lower left
     *              pixel of the bitmap.
     * 
     * @see #getTransparentColor
     * @see #getTransparent
     * @see #setTransparent
     */
    public final void setTransparentColor(Color color) {}
    
    /**
     * Retrieves a human-readable string representation of this object.
     * 
     * @return a string describing the bitmap.
     */
    public String toString() {}

    
    private class BitmapGraphics extends Graphics {
        int oldBitmapHandle = 0;
        Palette renderedPalette = null;

        /**
         * simple constructor.  This sets up the compatible memory DC
         */
        public BitmapGraphics(int hdc) {}
        
        /**
         * Called when this object is going to destroy its Win32 handle.  
         */
        protected void destroyHandle() {}
        
        /**
         * Retrieves the Win32 handle to this bitmap.   Before we retrieve the handle,
         * we must select in the bitmap.
         */
        public int getHandle() {}

        /**
         * Called by Bitmap when it is about to give out it's bitmap
         * handle.  We must release the handle from the memory DC
         * before giving it out.
         */
        public void releaseBitmapHandle() {}
        
        public Palette renderPalette(Palette palette, boolean forceBackground) {}
    }

    /**
     * Encapsulates a Windows bitmap. bmp)
     * files.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends Image.Editor {

        public String getFileDialogDescription() {}

        public String[] getExtensions() {}

        public Image loadFromStream(IDataStream stream) {}
    }
}