//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a Windows brush, a tool that Win32-based applications use to paint the  interior of polygons and ellipses. Drawing applications use brushes to paint
 * shapes; word processing applications use brushes to paint rules; 
 * computer-aided design (CAD) applications use brushes to paint the interiors 
 * of cross-section views; and spreadsheet applications use brushes to paint 
 * the sections of pie charts and the bars in bar graphs.
 * 
 * Brushes are typically used in conjunction with a Graphics object.  In WFC,
 * Brushes composed of system colors automatically update themselves when
 * the user makes changes to his or her system color settings.
 * 
 * @see Graphics
 *
 * @security(checkClassLinking=on)
 */
public class Brush {

    /**
     * Represents a Brush object that is the color of the active caption bar.
     */
    public static final Brush ACTIVECAPTION       = new Brush(Color.ACTIVECAPTION);
    
    /**
     * Represents a Brush object that is the color of the active window
     * border.
     */
    public static final Brush ACTIVEBORDER        = new Brush(Color.ACTIVEBORDER);
    
    /**
     * Represents a Brush object that is the color of the application
     * workspace window.
     */
    public static final Brush APPWORKSPACE        = new Brush(Color.APPWORKSPACE);
    
    /**
     * Represents a Brush object that is the current color of the desktop.
     */
    public static final Brush DESKTOP             = new Brush(Color.DESKTOP);
    
    /**
     * Represents a Brush object that is the color of controls. 
     */
    public static final Brush CONTROL             = new Brush(Color.CONTROL);

    /**
     * Represents a Brush object that is the color of the lightest part of a
     * 3D element.
     */
    public static final Brush CONTROLLIGHTLIGHT   = new Brush(Color.CONTROLLIGHTLIGHT);
    
    /**
     * Represents a Brush object that is the color of the highlighted portion
     * of a 3D element.
     */
    public static final Brush CONTROLLIGHT        = new Brush(Color.CONTROLLIGHT);
    
    /**
     * Represents a Brush object that is the color of the shadow portion of a
     * 3D element.
     */
    public static final Brush CONTROLDARK         = new Brush(Color.CONTROLDARK);
    
    /**
     * Represents a Brush object that is the color of the darkest portion of
     * a 3D element.
     */
    public static final Brush CONTROLDARKDARK     = new Brush(Color.CONTROLDARKDARK);
    
    /**
     * Represents a Brush object that is the color of a standard halftone
     * brush.
     */
    public static final Brush HALFTONE            = Brush.createHalftoneBrush();
    
    /**
     * Represents a Brush object that is the color of the background of
     * highlighted elements.
     */
    public static final Brush HIGHLIGHT           = new Brush(Color.HIGHLIGHT);
    
    /**
     * Represents a hollow brush.  This brush paints nothing.
     */
    public static final Brush HOLLOW              = new Brush(Color.BLACK,BrushStyle.HOLLOW);
    
    /**
     * Represents a Brush object that is the color used to indicate hot
     * tracking.
     */
    public static final Brush HOTTRACK            = new Brush(Color.HOTTRACK);
    
    /**
     * Represents a Brush object that is the color of an inactive caption
     * bar.
     */
    public static final Brush INACTIVECAPTION     = new Brush(Color.INACTIVECAPTION);
    
    /**
     * Represents a Brush object that is the color of an inactive window
     * border.
     */
    public static final Brush INACTIVEBORDER      = new Brush(Color.INACTIVEBORDER);
    
    /**
     * Represents a Brush object that is the color of the background of an
     * information ToolTip.
     */
    public static final Brush INFO                = new Brush(Color.INFO);
    
    /**
     * Represents a Brush object that is the color of the menu background.
     */
    public static final Brush MENU                = new Brush(Color.MENU);
    
    /**
     * Represents a null brush.  The behavior of this brush is identical to a hollow brush.
     */
    public static final Brush NULL                = Brush.HOLLOW;
    
    /**
     * Represents a Brush object that is the color of a scrollbar background.
     */
    public static final Brush SCROLLBAR           = new Brush(Color.SCROLLBAR);
    
    /**
     * Represents a Brush object that is the color of the window background.
     */
    public static final Brush WINDOW              = new Brush(Color.WINDOW);
    
    private BrushEntry entry;

    
    private Brush() {}

    /**
     * Creates a new solid brush of the given color.
     *
     * @param color The color of the brush.
     */
    public Brush(Color color) {}

    /**
     * Creates a new brush of the given style in the given color.
     *
     * @param color The color of the brush.
     * @param style One of the BrushStyle enum values.
     * 
     * @see BrushStyle
     */
    public Brush(Color color, int style) {}

    /**
     * Creates a brush out of the given bitmap.  
     *
     * @param bmp The bitmap to create the brush from.
     * 
     * @see Bitmap
     */
    public Brush(Bitmap bmp) {}

    /**
     * Creates a brush based on an existing Win32 handle.  The brush does
     * not own the handle.
     *
     * @param handle The Win32 brush handle.
     */
    public Brush(int handle) {}

    /**
     * Clones the brush object, creating a duplicate brush.
     * 
     * @return an object that can be casted to a Brush.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of the Win32 handle for the brush on which this object is based.   You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 brush handle.
     */
    public final int copyHandle() {}

    
    private static final Brush createHalftoneBrush() {}

    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}
    
    /**
     * Frees all the resources allocated by this object.  You do not have to call dispose; the
     * garbage collector will do it for you.  However, you may expedite
     * the process by calling dispose manually.
     */
    public void dispose() {}

    /**
     * Retrieves a boolean value that indicates whether the specified object
     * is equivalent to this Brush object.
     *
     * @param obj Object to compare equality to.
     * @return <b>true</b> if the given object is equivalent  to this object.
     */
    public boolean equals(Object obj) {}

    /**
     * Frees the Win32 resources associated with this Brush object.
     * 
     * @exception Throwable may be thrown.
     */
    protected void finalize() throws Throwable {}

    /**
     * Retrieves the color of this brush.
     *
     * @return the brush color.
     * @see Color
     */
    public final Color getColor() {}

    /**
     * Retrieves the Win32 handle of the brush.
     *
     * @return a Win32 handle value.
     */
    public final int getHandle() {}

    /**
     * Retrieves the style of the brush. 
     *
     * @return one of the BrushStyle enum values.
     * @see BrushStyle
     */
    public final int getStyle() {}

    /**
     * Computes and returns the hash code for this Brush object. 
     *
     * @return an integer hash code value.
     */
    public int hashCode() {}
    
    /**
     * Determines if this brush will render with a solid set of pixels
     * on the given graphics object.  
     * 
     * @param gr The graphics object to test the brush against.
     * @return <b>true</b> if the brush will be rendered with a single
     *		   solid color against the given Graphics object, or 
     *		   <b>false</b> if it will render with a dithered 
     *                 color or pattern.
     */
    public boolean isSolid(Graphics gr) {}

    /**
     * Determines if this brush will render with a solid set of pixels
     * on the screen.  If you don't already have a graphics object handy,
     * this will be more efficient than creating a new graphics object.
     * 
     * @return <b>true</b> if the brush will be rendered with a single
     *		   solid color against the screen, or 
     *		   <b>false</b> if it will render with a dithered 
     *                 color or pattern.
     */
    public boolean isSolid() {}

    
    private boolean isSolid(int dc) {}

    
    private static String stringFromStyle(int value) {}

    /**
     * Returns a String representation of this Brush object.
     *
     * @return  a String that has the info for this brush.
     * @internalonly
     */
    public String toString() {}
}


final class BrushEntry {

    private static BrushEntry   cache;
    private static boolean fSysEvent;

    private BrushEntry next;
    private int refCount;
    private int handle;
    private int hashCode;
    private boolean ownHandle = false;
    private boolean noDerivation = false;
    
    Bitmap bmp;
    int style;
    Color color;

    /**
     * Clones this brush entry.  This will return itself if feasable.
     */
    public Object clone() {}
    
    
    private static int computeHash(Color color, int style, Bitmap bmp) {}

    
    static BrushEntry create(int handle) {}

    
    static synchronized BrushEntry create(Color color, int style, Bitmap bmp) {}

    /**
     * Called when this object is going to destroy its Win32 handle.  This is called in a somewhat round-about
     * fashion so that we can allow the user to implement his own destroy
     * semantics.
     */
    public void destroyHandle() {}
    
    
    static void fillHandle(BrushEntry e) {}

    
    static synchronized void free(Brush brush, BrushEntry entry) {}

    /**
     * Retrieves the Win32 handle of the brush.
     * @return a Win32 brush handle.
     * @internalonly
     */
    public int getHandle() {}

    /**
     * This event gets fired when a system color change happens and we have brushes
     * that consist of system colors.  Here we recreate all the brush handles that
     * consist of system colors.
     * 
     * @internalonly
     */
    public static void onSettingChange() {}
}


class BrushEntrySettingChangeProxy {
    void onSettingChange(Object sender, Event evt) {}
}