//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;

/**
 * Encapsulates a Windows button control.   You can set the
 * text, and receive click events on it.
 *
 * One interesting piece of functionality is the ability to set the
 * button up as a "default" button on a Form, to receive either default
 * "OK" notifications, or default "Cancel" notifications.  Forms have the
 * properties @see Form#defaultButton and @see Form#cancelButton, which, using the 
 * @see IButtonControl interface, let you set up a button such that when the
 * user hits <i>Enter</i> or <i>Escape</i> [respectively] in a dialog-like form, a click
 * event is sent to the button.  See the @see IButtonControl interface for
 * more details.
 * 
 * One other thing a Button will let you do is set the <i>dialogResult</i> property.
 * When you set this property to some value, and the button is on a form that is 
 * being shown through the @see Form#showDialog method, the form is automatically
 * closed with the dialog result that was specified in the button, without the
 * user having to hook up any events by hand.  For example, to write a
 * "Yes/No/Cancel" dialog, you could just add three buttons, and set their
 * <i>dialogResult</i>  properties to <b>DialogResult.YES</b>,
 * <b>DialogResult.NO</b>, and  <b>DialogResult.CANCEL</b>, and you'd be done.
 *
 * @security(checkClassLinking=on)
 */
public class Button extends Control implements IButtonControl { 

    
    private int dialogResult;
    
    
    private boolean isDefault;

    /**
     * Creates a new instance of a Button control.  By default there is no
     * text caption set in the @see Button#text property.  However, in the
     * forms deisgner, it will set the text to the name of the control.
     */
    public Button() {}

    /**
     * Retrieves the button's current background color.   Note that users are
     * unable to change this.  It is always <b>Color.CONTROL</b>
     * 
     * @return        the current background color [Color.CONTROL]
     */
    public final Color getBackColor() {}
    
    /**
     * Retrieves the brush used to display this control. 
     * 
     * @return        the default system brush.
     */
    public final Brush getBrush() {}

    
    /**
     * Retrieves the button's current foreground color.   Note that users
     * are unable to change this.  It is always <b>Color.WINDOWTEXT</b>
     * 
     * @return        the current foreground color [Color.WINDOWTEXT]
     */
    public final Color getForeColor() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return     a CreateParams object with the information for creating
     *             this Control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the dialog box result generated by clicking the button.   The
     * programmer can set this on the button, such that whenever the button
     * is clicked, a parent form acting as a dialog will automatically be
     * given the result [ie, you could set up an "OK" value for one button,
     * and a "Cancel" value for another button"].  The possible values are
     * all obtained from the @see com.ms.wfc.ui.DialogResult enumeration.
     *
     * @return     an Integer value which is the current dialog result
     *           value.
     */
    public final int getDialogResult() {}

    /**
     * Notifies the button whether it is the default button so that it can adjust its
     * appearance accordingly.   The button changes it's style, by putting
     * a thick border around itself.  If the control is no longer the default
     * "OK" button, then it removes the extra thick border.
     *
     * @param value     Indicates if the control should be the default OK 
     *                  button or not.
     */
    public void notifyDefault(boolean value) {}

    /**
     * This method actually fires the Click Event.  Inheriting classes should
     * override this if they wish to be notified of a Click event [this is far
     * preferable to actually adding an event handler].  They should not, 
     * however, forget to call super.onClick(e); before exiting, to ensure that
     * other recipients do actually get the event.
     * 
     * @param e       This event has no additional information besides the
     *             sender.
     * @internalonly
     */
    protected void onClick(Event e) {}

    /**
     * Generates a click event for the button, simulating a click by a user. 
     */
    public final void performClick() {}

    /**
     * Lets a control process mnmemonic characters.  Inheriting classes can
     * override this to add extra functionality, but should not forget to call
     * <i>super.processMnmenonic(charCode);</i> to ensure basic functionality
     * remains unchanged
     *
     * @param charCode      The mnemonic character entered.
     *
     * @return boolean      a boolean indicating whether the mnmemonic was
     *                      processsed [consumed] or not.
     * @internalonly
     */
    protected boolean processMnemonic(char charCode) {}

    /**
     * @internalonly
     */
    protected void propertyChanged(int property) {}

    /**
     * NO-OP.  You are unable to change the background color of a Button
     * control.
     * 
     * @param value     This parameter is ignored.
     */
    public final void setBackColor(Color value) {}

    /**
     * Since you are unable to set the background color for Button controls,
     * this routine just NO-OPs any attempt to set a background brush as well.
     * 
     * @param value     A new brush value, which is ignored.
     */
    public final void setBrush(Brush value) {}

    /**
     * NO-OP.  You are unable to change the foreground color of a Button
     * control.
     * 
     * @param value     This parameter is ignored.
     */
    public final void setForeColor(Color value) {}

    /**
     * Sets the dialog box result generated by clicking the button.   The
     * programmer can set this on the button, such that whenever the button
     * is clicked, a parent form acting as a dialog will automatically be
     * given the result [ie, you could set up an "OK" value for one button,
     * and a "Cancel" value for another button"].  This saves the programmer
     * from having to set this result every time manually.  Common Values for this
     * property can come from the @see DialogResult enumeration.
     *
     * @return      an Integer value which is the current dialog result
     *              value.
     */
    public final void setDialogResult(int value) {}

    /**
     * Provides some interesting information for the Button control in
     * String form.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * The button's window procedure.  Inheriting classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the button continues to function properly.
     *
     * @param m     A Windows Message Object.
     * @internalonly
     */
    protected void wndProc(Message m) {}

    /**
     * Encapsulates a Windows button control.   This is used by design environments to determine
     * properties of the Button.
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo dialogResult = new PropertyInfo(
            Button.class, "dialogResult", DialogResult.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.DialogResult.NONE)),
            new DescriptionAttribute(Sys.getString("ButtonDialogResultDescr")));

        public static final PropertyInfo backColor = new PropertyInfo(
            Control.ClassInfo.backColor, BrowsableAttribute.NO);

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO);

        public static final EventInfo doubleClick = new EventInfo(
            Control.ClassInfo.doubleClick, BrowsableAttribute.NO);

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}