//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * This is a class that wraps a regular windows checkbox/button control. The
 * selected nature of the checkbox is tested via the Checked property or the
 * CheckState property.  The former is a convenience property for those
 * CheckBoxes that are not tri-state enabled.
 *
 * @security(checkClassLinking=on)
 */
public class CheckBox extends Control { 
    private static final Object EVENT_CHECKEDCHANGED = new Object();
    private static final Object EVENT_CHECKSTATECHANGED = new Object();

    private byte checkState;
    private boolean autoCheck;
    private int appearance;
    private boolean threeState;
    private byte textAlign;

    /**
     * Creates a new CheckBox control.  By default, it is not checked.
     */
    public CheckBox() {}

    /**
     * Adds an event handler for the "checkedChanged" event notification. This
     * event is fired whenever the value for the CheckBox control changes.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnCheckedChanged(EventHandler value) {}

    /**
     * Adds an event handler for the "checkStateChanged" event notification. This
     * event is fired whenever the value for the CheckBox control changes.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnCheckStateChanged(EventHandler value) {}

    /**
     * Controls whether the check value is changed automatically when the user
     * clicks on the control.
     * 
     * @return  <b>true</b> if the CheckBox will automatically check the box
     *          when the user clicks on the control.
     */
    public final boolean getAutoCheck() {}

    /**
     * Indicates whether the CheckBox is in some way checked.  Note that if
     * this is a threeState CheckBox, then this will return <b>true</b> for
     * either checked or indeterminately checked values.
     * 
     * @return  <b>true</b> if the CheckBox is in some way checked.
     */
    public final boolean getChecked() {}

    /**
     * Indicates the exact check state for this CheckBox control.  Values
     * for this come from the @see CheckState enumeration.  If the
     * <i>threeState</b> property is set to <b>false</b>, then this value
     * will never return <b>CheckState.INDETERMINATE</b>
     * 
     * @return      the current state of the check box.
     */
    public final int getCheckState() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a @see CreateParams object with the information for creating
     *             this Control.
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the value of a group of CheckBoxes.
     * 
     * @return int
     */
    public static int getGroupValue(Control group) {}

    /**
     * Indicates if the CheckBox will appear as a push-button looking control
     * instead of some text with a little checkable box next to it.  The 
     * toggled state of the button reflects the same information that the little
     * checkable box does.
     *
     * @return      a value from the com.ms.wfc.ui.Appearance enumeration, which will
     *              indicate whether this control draws normally or as a push-
     *              button like control.
     * 
     * @see com.ms.wfc.ui.Appearance
     */
    public final int getAppearance() {}

    /**
     * Indicates where the text is aligned with regards the little check box
     * in the control.  Values are obtained from the @see LeftRightAlignment
     * enumeration
     * 
     * @return      the current alignment of the text in this CheckBox.
     */
    public final int getTextAlign() {}

    /**
     * Indicates whether this CheckBox will allow three check values instead
     * of just two.  The third value, <b>CheckState.INDETERMINATE</b> is allowed
     * only when this property is set to true.
     * 
     * @return  <b>true</b> if indeterminate checks are allowed.
     */
    public final boolean getThreeState() {}

    /**
     * Fires the event indicating that the Checked property has been changed.
     * Inheriting controls should use this in favour of actually listening to 
     * the event, but should not forget to call super.onCheckedChanged() to
     * ensure that the event is still fired for external listeners.
     *
     * @param   e       Event to send
     */
    protected void onCheckedChanged(Event e) {}

    /**
     * Fires the event indicating that the checkState property has been changed.
     * Inheriting controls should use this in favour of actually listening to 
     * the event, but should not forget to call super.onCheckStateChanged() to
     * ensure that the event is still fired for external listeners.
     *
     * @param   e       Event to send
     */
    protected void onCheckStateChanged(Event e) {}
    
    /**
     * Fires the event indicating that the control has been clicked.
     * Inheriting controls should use this in favour of actually listening to 
     * the event, but should not forget to call super.onClicked() to
     * ensure that the event is still fired for external listeners.
     *
     * @param   e       Event to send
     */
    protected void onClick(Event e) {}

    /**
     * We override this to ensure that the control's click values are set up
     * correctly.
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Overridden to handle mnemonics properly.
     * @internalonly
     */
    protected boolean processMnemonic(char charCode) {}

    /**
     * Removes the given handler for the "checkedChanged" event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnCheckedChanged(EventHandler value) {}

    /**
     * Removes the given handler for the "checkStateChanged" event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnCheckStateChanged(EventHandler value) {}

    /**
     * Controls whether the CheckBox will appear as a push-button looking
     * control instead of some text with a little checkable box next to it.
     * The toggled state of the button reflects the same information that 
     * the little checkable box does.
     *
     * @param value   A value from the com.ms.wfc.ui.Appearance enumeration
     *                controlling the appearance of this CheckBox.
     *
     * @see com.ms.wfc.ui.Appearance
     */
    public final void setAppearance(int value) {}

    /**
     * Controls whether the check value is changed automatically when the user
     * clicks on the control.
     * 
     * @param value  <b>true</b> if the CheckBox will automatically check the box
     *               when the user clicks on the control.
     */
    public final void setAutoCheck(boolean value) {}

    /**
     * Actually sets the checked state of this control.  You can only use
     * this property to set the control as checked or unchecked.  To set
     * up an indeterminate check on a <i>threeState</i> CheckBox, you should use the
     * <i>checkState</i> property.
     * Values for this should be taken from the @see CheckState enumeration.
     * 
     * @param value     The new check value for this control.
     */
    public final void setChecked(boolean value) {}

    /**
     * Actually sets the checked state of this control.  You can use this
     * property to set the control as indeterminately checked, provided the 
     * <i>threeState</i> property is set to <b>true</b>.  Values for this
     * property should be obtained from the @see CheckState enumeration.
     * 
     * @param value     The new check state for this control.
     */
    public final void setCheckState(int value) {}

    /**
     * Sets the new group value for this CheckBox.
     * 
     * @param group     The group this CheckBox is in.
     * @param value     the new CheckState value for this CheckBox.
     */
    public static void setGroupValue(Control group, int value) {}

    /**
     * Controls where the text is aligned with regards the little check box
     * in the control.  Values are obtained from the @see LeftRightAlignment
     * enumeration
     * 
     * @param   value  The new alignment of the text in this CheckBox.
     */
    public final void setTextAlign(int value) {}

    /**
     * Controls whether or not this control can be indeterminately checked or not.
     * By default, the control can only be fully checked or unchecked.  This
     * allows indeterminate checking, where a little gray checkmark is displayed
     * instead.
     * 
     * @param value     <b>true</b> if indeterminate checking should be allowed.
     */
    public final void setThreeState(boolean value) {}

    /**
     * Provides some interesting information for the CheckBox control in
     * String form.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * The CheckBox's window procedure.  Inheriting classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the button continues to function properly.
     *
     * @param m     A Windows Message Object.
     */
    protected void wndProc(Message m) {}

    /**
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo { 
        public static final PropertyInfo appearance = new PropertyInfo(
            CheckBox.class, "appearance", Appearance.class,
            new DefaultValueAttribute(new Integer(Appearance.NORMAL)),
            new DescriptionAttribute(Sys.getString("CheckBoxAppearanceDescr")));

        public static final PropertyInfo autoCheck = new PropertyInfo(
            CheckBox.class, "autoCheck", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("CheckBoxAutoCheckDescr")));

        public static final PropertyInfo checked = new PropertyInfo(
            CheckBox.class, "checked", Boolean.TYPE,
            BindableAttribute.YES,
            DefaultValueAttribute.FALSE,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("CheckBoxCheckedDescr")));

        public static final PropertyInfo checkState = new PropertyInfo(
            CheckBox.class, "checkState", com.ms.wfc.ui.CheckState.class,
            BindableAttribute.YES,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.CheckState.UNCHECKED)),
            new DescriptionAttribute(Sys.getString("CheckBoxCheckStateDescr")));

        public static PropertyInfo textAlign = new PropertyInfo(
            CheckBox.class, "textAlign", LeftRightAlignment.class,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(LeftRightAlignment.RIGHT)),
            new DescriptionAttribute(Sys.getString("CheckBoxTextAlignDescr")));

        public static final PropertyInfo threeState = new PropertyInfo(
            CheckBox.class, "threeState", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CheckBoxThreeStateDescr")));

        public static EventInfo checkedChanged = new EventInfo(
            CheckBox.class, "checkedChanged", EventHandler.class,
            new DescriptionAttribute(Sys.getString("CheckBoxOnCheckStateChangedDescr")));

        public static EventInfo checkStateChanged = new EventInfo(
            CheckBox.class, "checkStateChanged", EventHandler.class,
            new DescriptionAttribute(Sys.getString("CheckBoxOnCheckStateChangedDescr")));

        public void getProperties(IProperties props) {}

        public void getEvents(IEvents events) {}
    }
}