//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * This class is a subclass of the regular ListBox control, and supports
 * adding a CheckBox next to each item in the List.  Each item can then
 * be checked or unchecked.
 *
 * @security(checkClassLinking=on)
 */
public class CheckedListBox extends ListBox {

    private static final int idealCheckSize = 14;

    
    private ItemCheckEventHandler onItemCheck;

    
    private int [] checkValues;

    
    private boolean checkOnClick = false;

    
    private boolean flat = true;

    
    private int lastSelected = -1;

    
    private HashTable savedItemChecks;
    
    
    /**
     * Creates a new CheckedListBox for the user.
     */
    public CheckedListBox() {}

    /**
     * Lets the user add an item to the listbox with the given initial value
     * for the Checked portion of the item.
     *
     * @param item  New item to add to the end of the ListBox
     * @param check Initial State for the checked portion of the item.
     *
     * @return  the integer index of the added item.
     */
    public final int addItem(Object item, boolean checked) {}

    /**
     * Lets the user add an item to the listbox with the given initial value
     * for the Checked portion of the item.
     *
     * @param item  New item to add to the end of the ListBox
     * @param check Initial State for the checked portion of the item.
     *
     * @return  the integer index of the added item.
     */
    public final int addItem(Object item, int check) {}

    /**
     * Adds an event handler for the "itemCheck" event notification. This
     * event is called whenever the check state of an item changes.
     * NOTE: The value is not updated until after the event.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnItemCheck(ItemCheckEventHandler value) {}

    /**
     * Returns an array with the indices of all items whose checkboxes
     * are, in some way, shape, or form, checked.  Note that this means they
     * can be fully checked or indeterminately checked.
     *
     * @return      an array of all indices that are checked in some way.
     */
    public final int [] getCheckedIndices() {}

    /**
     * Indicates whether or not the checkbox should be toggled whenever an
     * item is selected.  The default behaviour is to just change the
     * selection, and then make the user click again to check it.  However,
     * some may prefer checking the item as soon as it is clicked.
     *
     * @return  <b>false</b> if the listbox will just change selection
     *          on the first click, or <b>true</b> if it will always
     *          toggle checking right away.
     */
    public final boolean getCheckOnClick() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a @see CreateParams object with the information for creating
     *             this Control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Gets the check value of the current item.  This value will be from the
     * @see com.ms.wfc.ui.CheckState enumeration.
     *
     * @param index     Index of the item to get the checked value of.
     *
     * @return  a value from @see com.ms.wfc.ui.CheckState indicating the
     *          current checked status of the list item.
     */
    public final int getItemCheck(int index) {}

    /**
     * Indicates if the given item is, in any way, shape, or form, checked.
     * This will return true if the item is fully or indeterminately checked.
     *
     * @param index     Index of the item to get the checked value of.
     *
     * @return  <b>true</b> if the item is, in any way, checked, otherwise
     *          <b>false</b>
     */
    public final boolean getItemChecked(int index) {}

    /**
     * Indicates if the CheckBoxes should show up as flat or 3D in appearance.
     *
     * @return    <b>true</b> meaning it's 3D, or <b>false</b> meaning flat.
     */
    public final boolean getThreeDCheckBoxes() {}

    /**
     * Adds a new item to our internal array of items with the given check
     * state.  We have to maintain these outside of win32 because of
     * marshalling issues.
     *
     * @param index     Index at which to insert the item.
     * @param item      Value of the item to save away.
     * @param check     Initial Checked State for the item.
     * @internalonly
     */
    protected void insert(int index, Object item, int check) {}

    /**
     * Adds a new item marked as unchecked.
     *
     * @param index     Where to insert it.
     * @param item      What to insert.
     * @internalonly
     */
    protected void insert(int index, Object item) {}

    
    private void invalidateItem(int index) {}

    
    private void lbnSelChange() {}

    /**
     * When the handle is created we can dump any cached item-check pairs.
     * 
     * @internalonly 
     */
    protected void onCreateHandle(Event e) {}
    
    /**
     * When the handle is destroyed we should preserce the item-check pairs
     * if it is getting recreated...
     * 
     * @internalonly
     */
    protected void onDestroyHandle(Event e) {}
    
    /**
     * This is the code that actually fires the "keyPress" event.  The Checked
     * ListBox overrides this to look for space characters, since we
     * want to use those to check or uncheck items periodically.  Don't
     * forget to call super.onKeyPress() to ensure that KeyPrese events
     * are correctly fired for all other keys.
     *
     * @param e     The KeyPressEvent that was fired.
     * @internalonly
     */
    protected void onKeyPress(KeyPressEvent e) {}

    /**
     * This is the code that actually fires the itemCheck event.  Don't
     * forget to call <i>super.onItemCheck()</i> to ensure that itemCheck vents
     * are correctly fired for all other keys.
     *
     * @param e     The KeyPressEvent that was fired.
     * @internalonly
     */
    protected void onItemCheck(ItemCheckEvent ice) {}

    /**
     * Overridden to adjust the height of the items when the font
     * changes.
     */
    protected void propertyChanged(int property) {}

    /**
     * Remove the item at the given index from our internal array of
     * items.
     * @internalonly
     */
    protected void remove(int index) {}

    /**
     * Removes all items from the listbox.  All values and item data are
     * lost.
     */
    public final void removeAll() {}

    /**
     * Removes the given handler for the <i>itemCheck</i> event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnItemCheck(ItemCheckEventHandler value) {}

    /**
     * Indicates whether or not the checkbox should be toggled whenever an
     * item is selected.  The default behaviour is to just change the
     * selection, and then make the user click again to check it.  However,
     * some may prefer checking the item as soon as it is clicked.
     *
     * @param value     <b>false</b> if the listbox will just change selection
     *                  on the first click, or <b>true</b> if it will always
     *                  toggle checking right away.
     */
    public final void setCheckOnClick(boolean value) {}

    /**
     * Sets the checked value of the given item.  This value should be from
     * the com.ms.wfc.ui.CheckState enumeration.
     *
     * @param index     Index of the item to set the checkstate for.
     * @param value     New value for displaying a check.
     *
     * @see com.ms.wfc.ui.CheckState
     */
    public final void setItemCheck(int index, int value) {}

    /**
     * Sets the checked value of the given item.  This value should be a
     * <i>boolean</i>.
     *
     * @param index     Index of the item to set the checkstate for.
     * @param value     New value for displaying a check.
     */
    public final void setItemCheck(int index, boolean value) {}

    /**
     * For CheckedListBoxes, multi-selection is not supported.  You can set
     * selection to be able to select one item or no items.
     *
     * @param value     What sort of seleciton is allowed.
     */
    public final void setSelectionMode(int value) {}

    /**
     * Tells the listbox if the checkboxes should be flat or 3D in appearance.
     *
     * @param threed    <b>true</> means make it 3D, <b>false</b> means flat.
     */
    public final void setThreeDCheckBoxes(boolean threed) {}

    /**
     * We need to get LBN_SELCHANGE notifications
     * @internalonly
     */
    protected void wmReflectCommand(Message m) {}

    
    private void wmReflectDrawItem(Message m) {}

    
    private void wmReflectMeasureItem(Message m) {}

    /**
     * The listbox's window procedure.  Inheriting classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the button continues to function properly.
     *
     * @param m     A Windows Message Object.
     * @internalonly
     */
    protected void wndProc(Message m) {}

    /**
     * this is the ClassInfo we expose for the CheckedListBox control
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        public static final PropertyInfo backColor = new PropertyInfo(
            CheckedListBox.class, "backColor", Color.class,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.COLOR_WINDOW,
            new DescriptionAttribute(Sys.getString("CheckedListBoxBackColorDescr")));

        public static final PropertyInfo borderStyle = new PropertyInfo(
            CheckedListBox.class, "borderStyle", BorderStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(BorderStyle.FIXED_3D)),
            new DescriptionAttribute(Sys.getString("CheckedListBoxBorderDescr")));

        public static final PropertyInfo checkOnClick = new PropertyInfo(
            CheckedListBox.class, "checkOnClick", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CheckedListBoxCheckOnClickDescr")));

        public static final PropertyInfo columnWidth = new PropertyInfo(
            CheckedListBox.class, "columnWidth", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("CheckedListBoxColumnWidthDescr")));

        public static final PropertyInfo items = new PropertyInfo(
            CheckedListBox.class, "items", Object[].class,
            CategoryAttribute.Behavior,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("CheckedListBoxItemsDescr")),
            new ValueEditorAttribute(com.ms.wfc.core.StringListEditor.class));

        public static final PropertyInfo integralHeight = new PropertyInfo(
            CheckedListBox.class, "integralHeight", Boolean.TYPE,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("CheckedListBoxIntegralHeightDescr")));

        public static final PropertyInfo multiColumn = new PropertyInfo(
            CheckedListBox.class, "multiColumn", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CheckedListBoxMultiColumnDescr")));

        public static final PropertyInfo sorted = new PropertyInfo(
            CheckedListBox.class, "sorted", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CheckedListBoxSortedDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final PropertyInfo threeDCheck = new PropertyInfo(
            CheckedListBox.class, "threeDCheckBoxes", Boolean.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CheckedListBoxThreeDCheckBoxesDescr")));

        public static final EventInfo itemCheck = new EventInfo(
            CheckedListBox.class, "itemCheck", ItemCheckEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("CheckedListBoxItemCheckDescr")));

        public static final EventInfo selectedIndexChanged = new EventInfo(
            ListBox.class, "selectedIndexChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("selectedIndexChangedEventDescr")));

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }


}