//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Describes the color of a screen element, using a red-green-blue (RGB) or  hue-saturation-brightness (HSB) triplet, a cyan-yellow-magenta-black (CYMK) quadruplet, or  a system color constant (the color of a command button, for example).  The color can be a simple one described
 * by a RGB (Red, Green, Blue) triplet, or it can be a system color, such as
 * the color of a command button (Color.CONTROL)
 *
 * @security(checkClassLinking=on)
 */
public class Color implements IConstructable {

    /**
     * Represents the color aqua.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color AQUA        = new Color(0x00808000);

    /**
     * Represents the color black.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute black.
     */
    public static final Color BLACK       = new Color(0x00000000);

    /**
     * Represents the color brown.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color BROWN       = new Color(0x00408080);

    /**
     * Represents the color blue.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color BLUE        = new Color(0x00FF0000);

    /**
     * Represents the color cyan.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color CYAN         = new Color(0x00FFFF00);

    /**
     * Represents the color dark gray.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.  Often Color.CONTROLDARK is what you
     * really intend, and this color will adapt itself to user
     * prefererences.
     */
    public static final Color DARKGRAY    = new Color(0x00404040);

    /**
     * Represents the color gray.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.  Often Color.CONTROL is what you
     * really intend, and this color will adapt itself to user
     * prefererences.
     */
    public static final Color GRAY        = new Color(0x00808080);

    /**
     * Represents the color green.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color GREEN       = new Color(0x0000FF00);

    /**
     * Represents the color light gray.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.  Often Color.CONTROLLIGHT is what you
     * really intend, and this color will adapt itself to user
     * prefererences.
     */
    public static final Color LIGHTGRAY   = new Color(0x00C0C0C0);

    /**
     * Represents the color magenta.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color MAGENTA     = new Color(0x00FF00FF);

    /**
     * Represents the color orange.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color ORANGE      = new Color(0x000080FF);

    /**
     * Represents the color purple.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color PURPLE      = new Color(0x00800080);

    /**
     * Represents the color red.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color RED         = new Color(0x000000FF);

    /**
     * Represents the color white.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.  Often Color.CONTROLLIGHT is what you
     * really intend, and this color will adapt itself to user
     * prefererences.
     */
    public static final Color WHITE       = new Color(0x00FFFFFF);

    /**
     * Represents the color yellow.  This color does not follow the users
     * preferences in any way, so it should only be used when you
     * want an absolute color.
     */
    public static final Color YELLOW      = new Color(0x0000FFFF);

    /**
     * Represents the color of an active window border.
     */
    public static final Color ACTIVEBORDER        = new Color(0x8000000A);

    /**
     * Represents the color of the background of an active title bar caption.
     */
    public static final Color ACTIVECAPTION       = new Color(0x80000002);

    /**
     * Represents the text color of an active title bar caption.
     */
    public static final Color ACTIVECAPTIONTEXT   = new Color(0x80000009);

    /**
     * Represents the color of the application workspace.   The application workspace
     * is the area in a multiple document view that is not being occupied
     * by documents.
     */
    public static final Color APPWORKSPACE        = new Color(0x8000000C);

    /**
     * Represents the color for controls.
     */
    public static final Color CONTROL             = new Color(0x8000000F);

    /**
     * Represents the shadow part of a 3D element.
     */
    public static final Color CONTROLDARK         = new Color(0x80000010);

    /**
     * Represents the darkest part of a 3D element.
     */
    public static final Color CONTROLDARKDARK     = new Color(0x80000015);

    /**
     * Represents the highlight part of a 3D element.
     */
    public static final Color CONTROLLIGHT        = new Color(0x80000016);

    /**
     * Represents the lightest part of a 3D element.
     */
    public static final Color CONTROLLIGHTLIGHT   = new Color(0x80000014);

    /**
     * Represents the color of control text. */
    public static final Color CONTROLTEXT         = new Color(0x80000012);

    /**
     * Represents the current desktop color.
     */
    public static final Color DESKTOP             = new Color(0x80000001);

    /**
     * Represents the color of gray disabled text.
     */
    public static final Color GRAYTEXT            = new Color(0x80000011);

    /**
     * Represents the color of highlighted objects.  This includes
     * selected menu items as well as selected text.
     */
    public static final Color HIGHLIGHT           = new Color(0x8000000D);

    /**
     * Represents the color of highlighted text.  This includes
     * selected menu items as well as selected text.
     */
    public static final Color HIGHLIGHTTEXT       = new Color(0x8000000E);

    /**
     * Represents the color of an inactive window's border.
     */
    public static final Color INACTIVEBORDER      = new Color(0x8000000B);

    /**
     * Represents the color of the background of an inactive title bar caption.
     */
    public static final Color INACTIVECAPTION     = new Color(0x80000003);

    /**
     * Represents the color of caption text displayed in the title bar of an inactive window.
     */
    public static final Color INACTIVECAPTIONTEXT = new Color(0x80000013);

    /**
     * The color for menus.
     */
    public static final Color MENU                = new Color(0x80000004);

    /**
     * The color for menu text.
     */
    public static final Color MENUTEXT            = new Color(0x80000007);

    /**
     * Represents the hottrack color.
     */
    public static final Color HOTTRACK            = new Color(0x8000000D);

    /**
     * Represents the background color of an information ToolTip.
     */
    public static final Color INFO                = new Color(0x80000018);

    /**
     * Represents the color of information ToolTip text.
     */
    public static final Color INFOTEXT            = new Color(0x80000017);

    /**
     * Represents the color of the area of a scroll bar not covered by the thumb button.
     */
    public static final Color SCROLLBAR           = new Color(0x80000000);

    /**
     * Represents the color of a window.
     */
    public static final Color WINDOW              = new Color(0x80000005);

    /**
     * Represents the color of a window frame.
     */
    public static final Color WINDOWFRAME         = new Color(0x80000006);

    /**
     * Represents the color of window text.
     */
    public static final Color WINDOWTEXT          = new Color(0x80000008);

    private int value;

    /**
     * Creates a new Color object given a full RGB triplet or System Color
     * value in an integer.
     *
     * @param <i>value</i> The value for this Color object.
     */
    public Color(int value) {}

    /**
     * Creates a new Color object given individual red, green, and blue
     * values.
     *
     * @param <i>red</i> The red component of the color.
     * @param <i>green</i> The green component of the color.
     * @param <i>blue</i> The blue component of the color.
     */
    public Color(int red, int green, int blue) {}

    private static final void checkByte(int x, String text) {}

    private static final void checkFloatSmall(float x, String text) {}

    /**
     * Retrieves a boolean value that indicates whether the specified object
     * is equivalent to this Color object.  If it is not a Color object, or the
     * colors don't match, then it returns false.
     *
     * @param <i>obj</i> Object to check our color against for a match.
     * @return <b>true</b> if the colors are the same, or <b>false</b> otherwise.
     */
    public boolean equals(Object obj) {}

    /**
     * Creates a new Color object based on the specified color values.
     *
     * @param cyan      The level of cyan in the color.
     * @param magenta   The level of magenta in the color.
     * @param yellow    The level of yellow in the color.
     * @param black     The level of black in the color.
     */
    public static final Color fromCMYK(int cyan, int magenta, int yellow, int black) {}

    /**
     * Creates a new Color object based on the specified hue, saturation, and
     * brightness values.
     *
     * @param hue           The hue of the color.  This is represented as an
     *                      angle from 0 to 360, where red is at 0 and as the
     *                      angle increases, the hue flows from red to yellow,
     *                      green, cyan, blue, magenta, and back to red.
     * @param saturation    The saturation level of the given hue.  Zero is the
     *                      least saturated hue (grey), while 1 is the most saturated.
     * @param brightness    The overall brightness of the color value.  Zero represents
     *                      black, and one represents white.
     */
    public static final Color fromHSB(float hue, float saturation, float brightness) {}

    /**
     * Returns the level of black in this color, using a CMYK color system.
     *
     * @return the level of black.
     */
    public int getBlack() {}

    /**
     * Retrieves the blue component of the color.
     *
     * @return the blue component of the color.
     */
    public int getBlue() {}

    /**
     * Retrieves the HSB brightness for this color.
     *
     * @return the brightness, where 0 is black and 1 is white.
     */
    public float getBrightness() {}

    /**
     * Retrieves an array of ConstructorArg objects that describe the
     * data types and values needed to persist this object.  For more information, see
     * @see com.ms.wfc.core.IConstructable.
     *
     * @return a @see com.ms.wfc.core.ConstructorArg array with the allowable
     * constructor arguments.
     */
    public ConstructorArg[] getConstructorArgs() {}

    /**
     * Retrieves the level of cyan in this color, using a CMYK color system.
     *
     * @return the level of cyan.
     */
    public int getCyan() {}

    /**
     * Retrieves the green component of the color.
     *
     * @return the green component of the color.
     */
    public int getGreen() {}

    
    private static int getHSBValue(float m1, float m2, float hue) {}

    /**
     * Retrieves the HSB hue value for this color.
     *
     * @return the hue, in degrees.
     */
    public float getHue() {}

    /**
     * Retrieves the level of magenta in this color, using a CMYK color system.
     *
     * @return the level of magenta.
     */
    public int getMagenta() {}

    /**
     * Retrieves the red component of the color. 
     *
     * @return the red component of the color, even if it is a system color.
     */
    public int getRed() {}

    /**
     * Retrieves the entire RGB triplet for the color.  This value is typically directly
     * consumable by Win32 calls.
     *
     * @return the RGB triplet value.
     *
     * @see #getValue
     */
    public int getRGB() {}

    /**
     * Retrieves the HSB saturation for this color.
     *
     * @return the saturation, where 0 is grey and 1 is the most
     *         saturated.
     */
    public float getSaturation() {}

    /**
     * Retrieves the current value of this Color object.   Note that if it is
     * a system color, this is not the same as getRGB.  This value
     * is generally consumable by OLE functions, but not by Win32
     * functions.
     *
     * @return the value of the Color object.
     *
     * @see #getRGB
     */
    public int getValue() {}

    /**
     * Retrieves the level of yellow in this color, using a CMYK color system.
     *
     * @return the level of yellow.
     */
    public int getYellow() {}

    /**
     * Retrieves a hash code for this object for use with various sorting and hash table
     * objects. 
     */
    public int hashCode() {}

    /**
     * Retrieves a string description of the Color object. 
     *
     * @return a string describing the Color object.
     */
    public String toString() {}

    /**
     * If the Color object represents a system color value such as
     * Color.WINDOWTEXT, returns the name of that value as a string
     * (for example, "WINDOWTEXT").
     *
     * Otherwise returns <b>null</b>.
     *
     * @return name of a system color, or <b>null</b>.
     */
    public final String toSystemColorName() {}

    /**
     * Describes the color of a screen element, using a red-green-blue (RGB) or  hue-saturation-brightness (HSB) triplet, a cyan-yellow-magenta-black (CYMK) quadruplet, or  a system color constant (the color of a command button, for example).
     * @see com.ms.wfc.core.FieldsEditor
     * implementation and can be use by a designer's property browser.
     * It allows for design time editing of a color's properties.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends FieldsEditor {

        ColorPicker colorPicker = new ColorPicker(this);
        IEditorHost iehost;
        IValueAccess iva;
        Object[] values;

        public Editor() {}

        public Object getValueFromText(String text) {}

        public Object[] getValues() {}

        public String getTextFromValue(Object value) {}

        public void editValue(IValueAccess iva) {}

        public int getStyle() {}

        public void paintValue(Object value, Graphics g, Rectangle rect) {}

        public Color[] getCustomColors() {}
			
        public void setCustomColors(Color[] customColors) {}			

        /**
         * Describes the color of a screen element, using a red-green-blue (RGB) or  hue-saturation-brightness (HSB) triplet, a cyan-yellow-magenta-black (CYMK) quadruplet, or  a system color constant (the color of a command button, for example).
         * @security(checkClassLinking=on)
         */
        public static class ColorPicker {

            Editor editor;
            TabStrip tabStrip;
            ListBox lb;
            Palette pal;
            int systemTab;
            int paletteTab;
			Color[] customColors;
            
            public ColorPicker(Editor editor) {}

            public Control getCurrentComponent() {}

            private void onListClick(Object sender, Event e) {}

            private void onListDrawItem(Object sender, DrawItemEvent die) {}

            private void onListKeyDown(Object sender, KeyEvent ke) {}

            private void onTabStripGotFocus(Object sender, Event e) {}

            private void onTabStripResize(Object sender, Event e) {}

            private void onTabStripSelChange(Object sender, Event e) {}

            public Color[] getCustomColors() {}
			
            public void setCustomColors(Color[] customColors) {}

            public void createColorPicker() {}

            public Control getColorPicker() {}


            /**
             * Describes the color of a screen element, using a red-green-blue (RGB) or  hue-saturation-brightness (HSB) triplet, a cyan-yellow-magenta-black (CYMK) quadruplet, or  a system color constant (the color of a command button, for example).
             * @security(checkClassLinking=on)
             */
            public static class Palette extends Control {

                public static final int CELLS_ACROSS = 8;
                public static final int CELLS_DOWN = 8;
                public static final int CELLS_CUSTOM = 16; 
                public static final int CELLS = CELLS_ACROSS * CELLS_DOWN;
                public static final int CELL_SIZE = 16;
                public static final int MARGIN = 1;

                static final int[] staticCells = {
                    0x00ffffff, 0x00c0c0ff, 0x00c0e0ff, 0x00c0ffff,
                    0x00c0ffc0, 0x00ffffc0, 0x00ffc0c0, 0x00ffc0ff,

                    0x00e0e0e0, 0x008080ff, 0x0080c0ff, 0x0080ffff,
                    0x0080ff80, 0x00ffff80, 0x00ff8080, 0x00ff80ff,

                    0x00c0c0c0, 0x000000ff, 0x000080ff, 0x0000ffff,
                    0x0000ff00, 0x00ffff00, 0x00ff0000, 0x00ff00ff,

                    0x00808080, 0x000000c0, 0x000040c0, 0x0000c0c0,
                    0x0000c000, 0x00c0c000, 0x00c00000, 0x00c000c0,

                    0x00404040, 0x00000080, 0x00004080, 0x00008080,
                    0x00008000, 0x00808000, 0x00800000, 0x00800080,

                    0x00000000, 0x00000040, 0x00404080, 0x00004040,
                    0x00004000, 0x00404000, 0x00400000, 0x00400040
                };

                Color[] staticColors;
                ColorPicker cp;
                Color[] customColors;

                public Palette(ColorPicker cp, Color[] customColors) {}

                public Color[] getCustomColors() {}

                private Color getColorFromCell(int index) {}

                private int getCellFromLocation(int x, int y) {}

                private final int get1DFrom2D(int x, int y) {}

                public CreateParams getCreateParams() {}

                protected void launchDialog(int customIndex) {}

                protected void onMouseUp(MouseEvent me) {}

                protected void onPaint(PaintEvent pe) {}


                /**
                 * Describes the color of a screen element, using a red-green-blue (RGB) or  hue-saturation-brightness (HSB) triplet, a cyan-yellow-magenta-black (CYMK) quadruplet, or  a system color constant (the color of a command button, for example).
                 * @security(checkClassLinking=on)
                 */
                public static class CustomColorDialog extends ColorDialog {

                    int hInstance;

                    public CustomColorDialog() {}

                    protected int getInstance() {}

                    protected int getOptions() {}
                    public static final int COLOR_HUE = 703;
                    public static final int COLOR_SAT = 704;
                    public static final int COLOR_LUM = 705;
                    public static final int COLOR_RED = 706;
                    public static final int COLOR_GREEN = 707;
                    public static final int COLOR_BLUE = 708;
                    public static final int COLOR_ADD = 712;
                    public static final int COLOR_MIX = 719;

                    protected int hookProc(int hwnd, int msg, int wParam, int lParam) {}
                }
            }
        }
    }
}