//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;

/**
 * Represents a common dialog box that displays available colors along with controls that  let the user define custom colors.  Basic usage is as
 * follows:
 *
 * ColorDialog cd = new ColorDialog();
 * int didTheyClickOK = cd.showDialog();
 * if (didTheyClickOK == DialogResult.OK) {
 *      int color = cd.getColor();
 * } else {
 *      abort();
 * }
 *
 * @security(checkClassLinking=on)
 */
public class ColorDialog extends CommonDialog {

    private int options;
    private int[] customColors;

    /**
     * @internalonly
     */
    protected Color color;

    
    

    /**
     * Creates a new ColorDialog object.  Use the showDialog() method to show it.
     * Use the getColor() method to get the value after it has been run.
     */
    public ColorDialog() {}

    /**
     * Retrieves a boolean value indicating whether the user can use the dialog box to
     * define custom colors. 
     *
     * @return      <b>true</b> if the user will be able to select the
     *              custom colors portion of the dilaog.
     */
    public final boolean getAllowFullOpen() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box displays all
     * available colors in the set of basic colors. 
     *
     * @return  <b>true</b> if it will.
     */
    public final boolean getAnyColor() {}

    /**
     * Retrieves a value indicating the color the user selected in the dialog box.   Note that
     * if the showDialog() method returned a value of DialogResult.CANCEL, then the user
     * didn't select a color, and this value will be zero [black].
     *
     * @return   the @see Color the user selected.
     */
    public final Color getColor() {}

    /**
     * Retrieves an array that represents the set of custom colors defined in the dialog box.   Users
     * can set this array themselves.
     *
     * @return  an array of integer RGB values that will be shown in the
     *          custom colors portion of the dialog.
     */
    public final int[] getCustomColors() {}

    /**
     * Retrieves a boolean value indicating whether the controls used to create custom
     * colors are visible when the dialog box is opened or if the user has to click the Define
     * Custom Colors button to display these controls.   The default is for this portion of the
     * dialog to be collapsed.  Note that if the <i>allowFullOpen</i>
     * property is <b>false</b>, then this property has no effect.
     *
     * @return  <b>true</b> if the custom color portion of the dialog will
     *          be expanded right away.
     */
    public final boolean getFullOpen() {}

    /**
     * Returns our HINSTANCE from windows.
     * @internalonly
     */
    protected int getInstance() {}

    
    private boolean getOption(int option) {}

    /**
     * Returns our CHOOSECOLOR options.
     * @internalonly
     */
    protected int getOptions() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box contains a Help
     * button. 
     *
     * @return      <b>true</b> if the "Help" button will be shown.
     */
    public final boolean getShowHelp() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box displays only solid
     * colors in the set of basic colors or whether it also offers colors that are composites of
     * other colors.   This applies on 256 or fewer color systems
     * where some colors are, in fact, composites of others.
     *
     * @return  <b>true</b> if users will only be able to select solid
     *          colors.
     */
    public final boolean getSolidColorOnly() {}

    /**
     * Resets all dialog box options, the last selected color, and the custom colors to their
     * default values. 
     */
    public final void reset() {}

    /**
     * @internalonly
     */
    protected boolean runDialog(int hwndOwner, int hookProcPtr) {}

    /**
     * Sets a boolean value indicating whether the user can use the dialog box to
     * define custom colors. 
     *
     * @param value  <b>true</b> if the user will be able to select the
     *               custom colors portion of the dilaog.
     */
    public final void setAllowFullOpen(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box displays all available
     * colors in the set of basic colors. 
     *
     * @param value   <b>true</b> if it will.
     */
    public final void setAnyColor(boolean value) {}

    /**
     * Sets a value that indicates which color is selected by default when the dialog box is
     * opened. 
     *
     * @param   value       The color that will first be selected/displayed.
     */
    public final void setColor(Color value) {}

    /**
     * Sets an array that represents the set of custom colors that are defined in the dialog
     * box. 
     *
     * @param value     An array of ints with the custom colors.
     */
    public final void setCustomColors(int[] value) {}

    /**
     * Sets a boolean value indicating whether the controls used to create custom
     * colors are visible when the dialog box is opened or if the user has to click the Define
     * Custom Colors button to display these controls.   The default is for this portion of the
     * dialog to be collapsed.  Note that if the <i>allowFullOpen</i>
     * property is <b>false</b>, then this property has no effect.
     *
     * @param value     <b>true</b> if the custom color portion of the dialog
     *                  will be expanded right away.
     */
    public final void setFullOpen(boolean value) {}

    
    private void setOption(int option, boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box contains a Help
     * button. 
     *
     * @param value     <b>true</b> if the "Help" button will be shown.
     */
    public final void setShowHelp(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box displays only solid
     * colors in the set of basic colors or whether it also offers colors that are composites of
     * other colors.   This applies on 256 or fewer color systems
     * where some colors are, in fact, composites of others.
     *
     * @param value     <b>true</b> if users will only be able to select solid
     *                  colors.
     */
    public final void setSolidColorOnly(boolean value) {}

    /**
     * Returns a String version of this object.
     * @internalonly
     * @hidden
     */
    public String toString() {}

    /**
     * Represents a common dialog box that displays available colors along with controls that  let the user define custom colors. 
     *
     * @see com.ms.wfc.core.ClassInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends CommonDialog.ClassInfo {
        public static final PropertyInfo allowFullOpen = new PropertyInfo(
            ColorDialog.class, "allowFullOpen", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("CDallowFullOpenDescr")));

        public static final PropertyInfo anyColor = new PropertyInfo(
            ColorDialog.class, "anyColor", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CDanyColorDescr")));

        public static final PropertyInfo color = new PropertyInfo(
            ColorDialog.class, "color", Color.class,
            new DefaultValueAttribute(Color.BLACK),
            new DescriptionAttribute(Sys.getString("CDcolorDescr")));

        public static final PropertyInfo fullOpen = new PropertyInfo(
            ColorDialog.class, "fullOpen", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CDfullOpenDescr")));

        public static final PropertyInfo showHelp = new PropertyInfo(
            ColorDialog.class, "showHelp", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CDshowHelpDescr")));

        public static final PropertyInfo solidColorOnly = new PropertyInfo(
            ColorDialog.class, "solidColorOnly", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("CDsolidColorOnlyDescr")));

        public void getProperties(IProperties props) {}
    }
}