//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.util.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.vm.*;
import com.ms.lang.Delegate;
import com.ms.wfc.util.Root;

/**
 * Encapsulates the Windows combo box control.   It supports
 * the three basic Combo styles, DropDown Combo [with the editable text
 * portion], DropDown List [with the read-only text portion], and Simple
 * Combo, where the DropDown is always dropped down, and the text is
 * editable.
 *
 * <p>To add items to the combobox, you just pass in an array of Objects.  The
 * ComboBox will then call "toString()" on the items.  The degenerate case is
 * where you just pass in an array of String objects.</p>
 *
 * I.e.:
 *
 * <pre>
 * ComboBox cb = new ComboBox();
 * // set up 'cb's properties here
 * cb.setItems(new String[] {
 *      "a",
 *      "b",
 *      "c"});
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public class ComboBox extends Control {

    

    private static final Object EVENT_DROPDOWN = new Object();
    private static final Object EVENT_SELECTEDINDEXCHANGED = new Object();
    private static final Object EVENT_TEXTCHANGED = new Object();

    private static final int DEFAULT_ITEM_HEIGHT = 15;

    private Object[] items;
    private int itemCount;
    private int updateCount;
    private int itemHeight = DEFAULT_ITEM_HEIGHT;
    private Object newItem;
    private boolean inserting = false;
    private int childWindowRoot;
    private int editHandle;
    private int editWndProc;
    private int listHandle;
    private int listWndProc;
    private int dropDownHandle;
    private int maxLength;
    private int maxDropDownItems = 8;
    private boolean integralHeight = true;
    private boolean mousePressed = false;

    private int style = ComboBoxStyle.DROPDOWN;
    private int drawMode = DrawMode.NORMAL;
    private boolean sorted;

    private DrawItemEventHandler onDrawItem;
    private MeasureItemEventHandler onMeasureItem;

    /**
     * Creates a new ComboBox control.  The default style for the combo is
     * a regular DropDown Combo.
     */
    public ComboBox() {}

    /**
     * Adds an item to the combo box and returns the index of the new item. 
     * For an unsorted combo box, the item is added to the end of the existing
     * list of items. For a sorted combo box, the item is inserted into the
     * list according to its sorted position. The item's toString() method is
     * called to obtain the string that is displayed in the combo box.
     * A RuntimeException occurs if there is insufficient space available to
     * store the new item.
     *
     * @param item The item to insert.
     * @return Index at which the item was inserted.
     */
    public final int addItem(Object item) {}

    /**
     * Assigns a delegate to the drawItem event.  This
     * event is called for list boxes whose <i>drawMode</i> property is set to
     * <b>DrawMode.OWNERDRAWFIXED</b> or <b>DrawMode.OWNERDRAWVARIABLE</b>,
     * and contains a Graphics object in which people should paint the item.
     * Duplicates adds are not filtered out.
     *
     * @param value     New Event Handler to install for this event.
     */
    public final void addOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Assigns a delegate to the dropDown event.   This
     * event is sent whenever the dropdown portion of the combo is dropped
     * down. Duplicates are not filtered out.
     *
     * @param value     New Event Handler to install for this event.
     */
    public final void addOnDropDown(EventHandler value) {}

    /**
     * Assigns a delegate to the measureItem event.  This
     * event is called for combo boxes whose drawMode property is set to
     * <b>DrawMode.OWNERDRAWVARIABLE</b>, and asks the programmer for the size
     * of the given item in the combo box.
     *
     * @param value     New Event Handler to install for this event.
     */
    public final void addOnMeasureItem(MeasureItemEventHandler value) {}

    /**
     * Assigns a delegate to the selectedIndexChanged event.   This event is sent whenever the selection changes.
     * Duplicates are not filtered out.
     *
     * @param value     New Event Handler to install for this event.
     */
    public final void addOnSelectedIndexChanged(EventHandler value) {}

    /**
     * Assigns a delegate to the textChanged event. 
     * This event is fired whenever the text value for the text portion of
     * the control changes. Duplicates adds are not filtered out.
     *
     * @param value      New Event Handler to install for this event.
     */
    public final void addOnTextChanged(EventHandler value) {}

    /**
     * Maintains performance while items are added to the combo box one at a time by
     * preventing the control from painting until the endUpdate method
     * is called.  A call to beginUpdate() must be
     * balanced by a following call to endUpdate(). Following a call to
     * beginUpdate(), any redrawing caused by operations performed on the
     * combo box is deferred until the call to endUpdate().
     */
    public final void beginUpdate() {}

    
    private void childWndProc(Message m) {}
    
    
    private void defChildWndProc(Message m) {}

    /**
     * Resumes painting the ListBox control
     * after painting is suspended by the beginUpdate method.  A call to beginUpdate() must be
     * balanced by a following call to endUpdate(). Following a call to
     * beginUpdate(), any redrawing caused by operations performed on the
     * combo box is deferred until the call to endUpdate().
     */
    public final void endUpdate() {}

    /**
     * @internalonly
     */
    protected void finalize() throws Throwable {}

    /**
     * Finds the first item in the combo box that starts with the specified string. 
     * The search is not case sensitive.
     *
     * @param s The string to search for.
     * @return The index of the first item that starts with the given string,
     * or -1 if no match was found.
     */
    public final int findString(String s) {}

    /**
     * Finds the first item in the combo box that starts with the specified string.  The search is not case sensitive.
     *
     * @param s The string to search for.
     * @param startIndex The index of the item to start after.
     * @return The index of the first item that starts with the given string,
     * or -1 if no match was found.
     */
    public final int findString(String s, int startIndex) {}

    /**
     * Finds the first item in the list that exactly matches the string specified in the s
     * parameter. 
     * The strings must match excatly, except for differences in casing.
     *
     * @param s The string to search for.
     * @return The index of the first item that matches the given string,
     * or -1 if no match was found.
     */
    public final int findStringExact(String s) {}

    /**
     * Finds the first item in the list that exactly matches the string specified in the s
     * parameter.  The strings must match excatly, except for differences in
     * casing.
     *
     * @param s The string to search for.
     * @param startIndex The index of the item to start after.
     * @return The index of the first item that matches the given string,
     * or -1 if no match was found.
     */
    public final int findStringExact(String s, int startIndex) {}

    /**
     * Returns the parameters needed to create the handle.  Inheriting classes
     * can override this to provide extra functionality.  They should not,
     * however, forget to call super.getCreateParams() first to get the struct
     * filled up with the basic info.
     *
     * @return    a CreateParams object with all the info needed to create
     *            the control.
     *
     * @see com.ms.wfc.ui.CreateParams
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a value indicating whether the system draws the combo box, whether the combo
     * box owner draws the combo box with all items of equal height, or whether the combo box
     * owner draws the combo box with items of variable height.   The DrawMode property
     * controls whether the control is drawn by Windows or by the user.
     *
     * @return  the value of the DrawMode property, from the
     *          com.ms.wfc.ui.DrawMode enumeration.
     *
     * @see com.ms.wfc.ui.DrawMode
     */
    public final int getDrawMode() {}

    /**
     * Retrieves a boolean value indicating whether the list box of a combo box is
     * currently dropped down. 
     *
     * @return  <b>true</b> if the DropDown is, indeed, dropped down, or
     *          <b>false</b> if it's snapped up.
     */
    public final boolean getDroppedDown() {}

    /**
     * Retrieves a boolean value indicating whether the control has the focus. 
     *
     * @return <b>true</b> if this control has focus.
     *
     * @see #focus
     */
    public boolean getFocused() {}

    /**
     * Retrieves a boolean value indicating whether the combo box should resize to
     * avoid showing partial items.   If so,
     * then only full items will be displayed, and the list portion will be resized
     * to prevent partial items from being shown.  Otherwise, they will be
     * shown
     *
     * @return  a boolean indicating if only full items will be shown
     */
    public final boolean getIntegralHeight() {}

    /**
     * Retrieves the item at the specified zero-based index. 
     *
     * @param index     The index whose item we wish to get.
     *
     * @return          the item at the index specified
     */
    public final Object getItem(int index) {}

    /**
     * Retrieves the number of items in the combo box. 
     *
     * @return  the number of items this ComboBox is currently
     *          holding.
     */
    public final int getItemCount() {}

    /**
     * Retrieves the height, in pixels, of an item in the combo box.  When drawMode is NORMAL
     * or OWNERDRAWFIXED, all items have the same height. When drawMode is
     * OWNERDRAWVARIABLE, this method returns the height that will be given
     * to new items added to the combo box. To determine the actual height of
     * an item, use the getItemHeight() method with an integer parameter.
     *
     * @return The height, in pixels, of an item in the combo box.
     * @see #getItemHeight(int)
     */
    public final int getItemHeight() {}

    /**
     * Retrieves the height, in pixels, of an item in the combo box.  This method should not be used for NORMAL or OWNERDRAWFIXED
     * style combo boxes.
     *
     * @param index Item to return the height of.
     * @return The height, in pixels, of the specified item.
     */
    public final int getItemHeight(int index) {}

    /**
     * Retrieves an Object array containing all the items in the combo box. 
     *
     * @return   an array with all the items currently listed in the
     *           ComboBox
     */
    public final Object[] getItems() {}

    /**
     * Retrieves the maximum number of items that can be displayed in the drop-down list box
     * of the combo box.   This number can be between 1 and 100.
     *
     * @return   the maximum number of items to be shown in the DropDown.
     */
    public final int getMaxDropDownItems() {}

    /**
     * Retrieves the maximum number of characters the user can type into the edit control of a
     * combo box. 
     *
     * @return  the maximum lengh of text editable.
     */
    public final int getMaxLength() {}

    /**
     * Retrieves the zero-based index of the currently selected item in the combo box. 
     *
     * @return  the [zero-based] index of the currently selected item.
     */
    public final int getSelectedIndex() {}

    /**
     * Retrieves the currently selected item in the the combo box. 
     *
     * @return  the handle of the object that is currently selected.
     */
    public final Object getSelectedItem() {}

    /**
     * Retrieves the text that is selected in the edit control of the combo box.  If the
     * ComboBox has ComboBoxStyle.DROPDOWNLIST, the return is an empty
     * string ("").
     *
     * @return   the current text in the editable portion.
     */
    public final String getSelectedText() {}

    /**
     * Retrieves the zero-based index of the first character after the end of the current text
     * selection in the edit control of the combo box. 
     *
     * @return  the [zero-based] index of the character at the end of
     *          the current selection.
     */
    public final int getSelectionEnd() {}

    /**
     * Retrieves the zero-based index of the first character in the current text selection in
     * the edit control of the combo box. 
     *
     * @return   the [zero-based] index of the start of the current text
     *           selection.
     */
    public final int getSelectionStart() {}

    /**
     * Retrieves a boolean value indicating whether the items in the combo box are
     * sorted alphabetically. 
     *
     * @return boolean  true if the list is sorted, false otherwise.
     */
    public final boolean getSorted() {}

    /**
     * Retrieves a value indicating the style of the combo box (whether the combo box has an
     * edit control or a static text control and whether the list for the combo box is always
     * visible or visible only when dropped down by the user).   The value would come
     * from the com.ms.wfc.ui.ComboBoxStyle enumeration.
     *
     * @return   the current style of combo that we're using.
     *
     * @see com.ms.wfc.ui.ComboBoxStyle
     */
    public final int getStyle() {}

    /**
     * @internalonly
     */
    protected void insert(int index, Object item) {}

    /**
     * Adds an item to the combo box at the specified position. 
     *
     * @param index     Inserts the item at this index.
     * @param item      The item to insert.
     */
    public final void insertItem(int index, Object item) {}

    /**
     * Determines if <i>keyData</i> is in input key that the control wants.
     * Overridden to return true for RETURN and ESCAPE when the combo box is
     * dropped down.
     *
     * @internalonly
     */
    protected boolean isInputKey(int keyData) {}

    /**
     * Overridden to make sure all the items and styles get set up correctly.
     * Inheriting classes should not forget to call
     * <i>super.onCreateHandle()</i>
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * We need to un-subclasses everything here.  Inheriting classes should
     * not forget to call <i>super.onDestroyHandle()</i>
     * @internalonly
     */
    protected void onDestroyHandle(Event e) {}

    /**
     * Triggers the drawItem event.   Don't
     * forget to call <i>super.onDrawItem()</i> to ensure that drawItem events
     * are correctly fired at all other times.
     *
     * @param e     The DrawItemEvent that was fired.
     *
     * @see com.ms.wfc.ui.DrawItemEvent
     */
    protected void onDrawItem(DrawItemEvent e) {}

    /**
     * Triggers the dropDown event.   Don't
     * forget to call <i>super.onDropDown()</i> to ensure that dropDown events
     * are correctly fired at all other times.
     *
     * @param e     The Event that was fired.
     */
    protected void onDropDown(Event e) {}

    /**
     * Key press event handler. Overridden to close up the combo box when the
     * user presses RETURN or ESCAPE.
     *
     * @internalonly
     */
    protected void onKeyPress(KeyPressEvent e) {}

    /**
     * Triggers the measureItem event.   Don't
     * forget to call <i>super.onMeasureItem()</i> to ensure that measureItem
     * events are correctly fired at all other times.
     *
     * @param e     The MeasureItemEvent that was fired.
     *
     * @see com.ms.wfc.ui.MeasureItemEvent
     */
    protected void onMeasureItem(MeasureItemEvent e) {}

    /**
     * Triggers the selectedIndexChanged event. 
     * Don't forget to call <i>super.onSelectedIndexChanged()</i> to ensure
     * that selectedIndexChanged events are correctly fired at all other times.
     *
     * @param e     The Event that was fired.
     */
    protected void onSelectedIndexChanged(Event e) {}

    /**
     * Triggers the textChanged event. 
     * Inheriting controls should use this in favour of actually listening to
     * the event, but should not forget to call super.onTextChanged() to
     * ensure that the event is still fired for external listeners.
     *
     * @param   e       Event to send
     */
    protected void onTextChanged(Event e) {}

    /**
     *  Indicates that a critical property, such as color or font has
     * changed.
     * @internalonly
     */
    protected void propertyChanged(int property) {}

    
    private void releaseChildWindow() {}

    /**
     * Removes the given item from our internal array of items
     * @internalonly
     */
    protected void remove(int index) {}

    /**
     * Removes all items from the list box. 
     */
    public final void removeAll() {}

    /**
     * Removes the specified item from the list box. 
     * @param index     The index at which to remove the item.
     */
    public final void removeItem(int index) {}

    /**
     * Removes the specified item from the list box. 
     *
     * @param value     Object to remove from the ListBox.
     *
     * @return    the integer [zero-based] index of the item removed,
     *            or -1 if it did not exist
     */
    public final int removeItem(Object value) {}

    /**
     * Removes the delegate that is assigned to the drawItem event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the dropDown event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnDropDown(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the measureItem event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnMeasureItem(MeasureItemEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the selectedIndexChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnSelectedIndexChanged(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the textChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnTextChanged(EventHandler value) {}

    /**
     * Resets the itemHeight property.
     */
    public final void resetItemHeight() {}

    /**
     * Selects a range of text in the edit control of the combo box. 
     *
     * @param start     Where to start selecting [zero-based]
     * @param end       Where to stop selectin [zero-based]
     */
    public final void select(int start, int end) {}

    /**
     * Selects all the text in the edit control of the combo box. 
     */
    public final void selectAll() {}

    
    private int sendInsertMessage(int message, int index, Object item) {}

    /**
     * Sets a value indicating whether the system draws the combo box, whether the combo box
     * owner draws the combo box with all items of equal height, or whether the combo box owner
     * draws the combo box with items of variable height.   This lets the user control whether
     * or not they paint the items themselves [default is not] and whether
     * or not the items are all the same height [default yes]
     *
     * @param value      New Value of the drawing mode.
     *
     * @see com.ms.wfc.ui.DrawMode
     */
    public final void setDrawMode(int value) {}

    /**
     * Sets a boolean value indicating whether the list box of the combo box is
     * currently dropped down. 
     *
     * @param value     If this is true, the dropdown is forced down,
     *                  otherwise it is snapped up.
     */
    public final void setDroppedDown(boolean value) {}

    /**
     * Sets a boolean value indicating whether the combo box should resize to avoid
     * showing partial items.   If so,
     * then only full items will be displayed, and the list portion will be resized
     * to prevent partial items from being shown.  Otherwise, they will be
     * shown
     *
     * @param value new value for this property
     */
    public final void setIntegralHeight(boolean value) {}

    /**
     * Allows you to replace the item at the specified position in the combo box.   The existing
     * item at this index is lost.
     *
     * @param index     The index at which to set this item.
     * @param item      The item to put in at this index.
     */
    public final void setItem(int index, Object item) {}

    /**
     * Sets the height, in pixels, of an item in the combo box.   Users
     * can use this instead of the OnMeasureItem event, which is best used by
     * <b>OWNERDRAWVARIABLE</b> ComboBoxes.  This method is ignored by
     * ComboBoxes whose style is <b>DrawMode.NORMAL</b>
     *
     * @param value       The height of an item in an <b>OWNERDRAWFIXED</b>
     *                    combo
     */
    public final void setItemHeight(int value) {}

    /**
     * Adds a set of items to the combo box.   All old values in the ComboBox are
     * discarded and lost
     *
     * @param value     Array of Objects that will be inserted into the
     *                  ComboBox
     */
    public final void setItems(Object[] value) {}

    /**
     * Sets the maximum number of items that can be displayed in the drop-down list box of the
     * combo box.   This value can be between 1 and
     * 100.
     *
     * @param value     The maximum number of items to be displayed
     */
    public final void setMaxDropDownItems(int value) {}

    /**
     * Sets the maximum number of characters the user can type into the edit control of a
     * combo box. 
     * @param value     The maximum length of the edit boxs text.
     */
    public final void setMaxLength(int value) {}

    /**
     * Selects an item in a combo box. 
     * Note that if the value of <i>index</i> is -1, then the ComboBox is
     * set to have no selection.
     *
     * @param index     The [zero-based] index at which to set the selection.
     */
    public final void setSelectedIndex(int index) {}

    /**
     * Selects the first occurrence of the specified item in a single-selection combo box, and
     * returns the zero-based index of the item. 
     *
     * @param value     The object to make selected.
     *
     * @return      the integer [zero-based] index of the selected
     *              item, or -1 if it did not exist.
     */
    public final int setSelectedItem(Object value) {}

    /**
     * Replaces the currently selected text in the edit control of the combo box with the
     * specified text. 
     *
     * @param value     The text to put in place of the selected text.
     */
    public final void setSelectedText(String value) {}

    /**
     * Sets the end position of the text selection in the edit control of the combo box. 
     *
     * @param value     Index at which to stop selecting.
     */
    public final void setSelectionEnd(int value) {}

    /**
     * Sets the starting position of the text selection in the edit control of the combo box. 
     *
     * @param value     Index at which to start selecting.
     */
    public final void setSelectionStart(int value) {}

    /**
     * Sets a boolean value indicating whether the items in the combo box are sorted
     * alphabetically.   By default, they are not.
     *
     * @param value     <b>true</b> means they should be sorted, <b>false</b>
     *                  not.
     */
    public final void setSorted(boolean value) {}

    /**
     * Sets a value indicating the style of the combo box (whether the combo box has an edit
     * control or a static text control, and whether the list for the combo box is always visible
     * or visible only when dropped down by the user).   These values are obtained from the
     * com.ms.wfc.ui.ComboBoxStyle enumeration.
     *
     * @param value     What style of ComboBox this should be.
     *
     * @see com.ms.wfc.ui.ComboBoxStyle
     */
    public final void setStyle(int value) {}

    /**
     * Indicates whether the itemHeight property should be persisted.
     *
     * @return whether the itemHeight property should be persisted.
     */
    public final boolean shouldPersistItemHeight() {}

    /**
     * Provides some interesting info about this control in String form.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void updateDropDownHeight() {}
    
    
    private void updateItemHeight() {}

    
    private void wmCtlColor(Message m) {}

    
    private void wmEraseBkgnd(Message m) {}

    
    private void wmParentNotify(Message m) {}

    
    private void wmReflectCommand(Message m) {}

    
    private void wmReflectDrawItem(Message m) {}

    
    private void wmReflectMeasureItem(Message m) {}

    /**
     * The comboboxs window procedure.  Inheritng classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the combo continues to function properly.
     *
     * @param m     A Windows Message Object.
     * @internalonly
     */
    protected void wndProc(Message m) {}

    
    private static class ChildWindow extends Callback
    {
        WeakReference ref;

        ChildWindow(ComboBox comboBox) {}

        public int callback(int hWnd, int msg, int wParam, int lParam) {}
    }

    /**
     * Encapsulates the Windows combo box control. 
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo backColor = new PropertyInfo(
            Control.ClassInfo.backColor, DefaultValueAttribute.COLOR_WINDOW);

        public static final PropertyInfo drawMode = new PropertyInfo(
            ComboBox.class, "drawMode", DrawMode.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.DrawMode.NORMAL)),
            new DescriptionAttribute(Sys.getString("ComboBoxDrawModeDescr")));

        public static final PropertyInfo integralHeight = new PropertyInfo(
            ComboBox.class, "integralHeight", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("ComboBoxIntegralHeightDescr")));

        public static final PropertyInfo itemHeight = new PropertyInfo(
            ComboBox.class, "itemHeight", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("ComboBoxItemHeightDescr")));

        public static final PropertyInfo items = new PropertyInfo(
            ComboBox.class, "items", Object[].class,
            new MemberAttribute[] {
                CategoryAttribute.Behavior,
                LocalizableAttribute.YES,
                DefaultValueAttribute.EMPTY_ARRAY,
                new DescriptionAttribute(Sys.getString("ComboBoxItemsDescr")),
                new ValueEditorAttribute(com.ms.wfc.core.StringListEditor.class)
            });

        public static final PropertyInfo maxDropDownItems = new PropertyInfo(
            ComboBox.class, "maxDropDownItems", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(8)),
            new DescriptionAttribute(Sys.getString("ComboBoxMaxDropDownItemsDescr")));

        public static final PropertyInfo maxLength = new PropertyInfo(
            ComboBox.class, "maxLength", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("ComboBoxMaxLengthDescr")));

        public static final PropertyInfo sorted = new PropertyInfo(
            ComboBox.class, "sorted", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("ComboBoxSortedDescr")));

        public static final PropertyInfo selectedItem = new PropertyInfo(
            ComboBox.class, "selectedItem", Object.class,
            BrowsableAttribute.NO,
            BindableAttribute.YES,
            PersistableAttribute.NO,
            DefaultValueAttribute.FALSE);

        public static final PropertyInfo style = new PropertyInfo(
            ComboBox.class, "style", ComboBoxStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(ComboBoxStyle.DROPDOWN)),
            new DescriptionAttribute(Sys.getString("ComboBoxStyleDescr")));

        public static final EventInfo drawItem = new EventInfo(
            ComboBox.class, "drawItem", DrawItemEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("drawItemEventDescr")));

        public static final EventInfo dropDown = new EventInfo(
            ComboBox.class, "dropDown", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("ComboBoxOnDropDownDescr")));

        public static final EventInfo measureItem = new EventInfo(
            ComboBox.class, "measureItem", MeasureItemEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("measureItemEventDescr")));

        public static final EventInfo selectedIndexChanged = new EventInfo(
            ComboBox.class, "selectedIndexChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("selectedIndexChangedEventDescr")));

        public static final EventInfo textChanged = new EventInfo(
            ComboBox.class,"textChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("textChangedEventDescr")));

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}