//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Defines the base class used for displaying dialog boxes on the screen.  Subclasses
 * of CommonDialog are required to implement the runDialog() method to create
 * a specific common dialog, and can optionally override hookProc() to
 * implement specific dialog hook functionality.
 *
 * @security(checkClassLinking=on)
 */
public abstract class CommonDialog extends Component {

    private static final Object EVENT_HELP = new Object();
    private static int helpMsg;

    int defOwnerWndProc;

    public CommonDialog() {}

    /**
     * Assigns a delegate to the help event.  This event is
     * fired when the user presses the "Help" button of the common dialog.
     *
     * @see #onHelp
     * @see #removeOnHelp
     */
    public final void addOnHelp(EventHandler value) {}

    /**
     * Defines the common dialog box hook procedure that is overridden to add specific
     * functionality to a common dialog box.  Descendant classes can override this method
     * to add specific functionality to a common dialog. By default, the hook
     * procedure centers the dialog on the screen in response to a WM_INITDIALOG
     * message.
     */
    protected int hookProc(int hWnd, int msg, int wParam, int lParam) {}

    
    static void moveToScreenCenter(int hWnd) {}

    /**
     * Triggers the help event.  Subclasses can override
     * this method to handle the event.
     */
    protected void onHelp(Event e) {}

    /**
     * Defines the owner window procedure that is overridden to add specific functionality to
     * a common dialog box.  Control arrives here when messages are sent to
     * the owner window of the common dialog. Descendant classes can override
     * this method to add specific functionality to a common dialog.
     */
    protected int ownerWndProc(int hWnd, int msg, int wParam, int lParam) {}

    /**
     * Removes the delegate that is assigned to the help event. 
     *
     * @see #addOnHelp
     * @see #onHelp
     */
    public final void removeOnHelp(EventHandler value) {}

    /**
     * Resets the properties of a common dialog box to the default values. 
     * Subclasses of CommonDialog must override this method to reset their
     * properties.
     */
    public void reset() {}

    /**
     * Called by the showDialog method to implement a specific
     * common dialog box.  This method is invoked when the user
     * of a common dialog calls the showDialog() method, and it must be overridden by
     * subclasses of CommonDialog to implement a specific common dialog. The
     * hwndOwner parameter is the window handle of the owner window for the
     * common dialog. The hookProcPtr parameter is the address of a common
     * dialog hook that will invoke the hookProc() method. An implementation of
     * runDialog() should store the hwndOwner and hookProcPtr parameters in the
     * common dialog structure's hwndOwner and lpfnHook fields.
     */
    protected abstract boolean runDialog(int hwndOwner, int hookProcPtr);

    /**
     * Displays a common dialog box and returns a value indicating whether the user clicked OK
     * in the dialog box.  The return value is DialogResult.OK if the user
     * clicked the OK button. Otherwise, the return value is DialogResult.CANCEL.
     */
    public final int showDialog() {}

    
    class HookProc extends Callback {
        public int callback(int hWnd, int msg, int wParam, int lParam) {}
    }

    
    class OwnerWndProc extends Callback {
        public int callback(int hWnd, int msg, int wParam, int lParam) {}
    }

    /**
     * Defines the base class used for displaying dialog boxes on the screen. 
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Component.ClassInfo {
        public static final EventInfo help = new EventInfo(
            CommonDialog.class, "help", EventHandler.class,
            new DescriptionAttribute("Occurs when the users clicks the Help button"));

        public void getAttributes(IAttributes attrs) {}

        public void getEvents(IEvents events) {}
    }
}