//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.ax.ActiveX;
import com.ms.dll.*;
import com.ms.vm.*;

import com.ms.lang.Delegate;

/**
 * Defines the base class used for controls, which are standardized child windows that the  user can manipulate to perform an action or display information.  Control also
 * encapsulates an HWND.
 *
 * @security(checkClassLinking=on)
 */
public class Control extends Component {
    static final int STATE_CREATED        = 0x00000001;
    static final int STATE_VISIBLE        = 0x00000002;
    static final int STATE_ENABLED        = 0x00000004;
    static final int STATE_TABSTOP        = 0x00000008;
    static final int STATE_RECREATE       = 0x00000010;
    static final int STATE_MODAL          = 0x00000020;
    static final int STATE_HANDLEHOOK     = 0x00000040;
    static final int STATE_ALLOWDROP      = 0x00000080;
    static final int STATE_DROPTARGET     = 0x00000100;
    static final int STATE_NOZORDER       = 0x00000200;
    static final int STATE_LAYOUTDEFERRED = 0x00000400;
    static final int STATE_SETFOCUS       = 0x00000800;
    static final int STATE_CREATENOTIFIED = 0x00001000;
    static final int STATE_DISPOSED       = 0x00002000;
    
    /**
     * Specifies that the control is a container for other controls.
     * @see #setStyle
     */
    protected static final int STYLE_FORM            = 0x00000001;
    /**
     * Specifies that the control does its own painting.
     * @see #setStyle
     */
    protected static final int STYLE_USERPAINT       = 0x00000002;
    /**
     * Specifies that the background will be erased when the control is repainted.
     * @see #setStyle
     */
    protected static final int STYLE_OPAQUE          = 0x00000004;
    /**
     * Specifies that the control accepts children.
     * @see #setStyle
     */
    protected static final int STYLE_ACCEPTSCHILDREN = 0x00000008;
    /**
     * Specifies that the control redraws when it is resized.
     * @see #setStyle
     */
    protected static final int STYLE_RESIZE_REDRAW   = 0x00000010;
    /**
     * Specifies that the control has a fixed width.
     * @see #setStyle
     */
    protected static final int STYLE_FIXED_WIDTH     = 0x00000020;
    /**
     * Specifies that the control has a fixed height.
     * @see #setStyle
     */
    protected static final int STYLE_FIXED_HEIGHT    = 0x00000040;
    /**
     * Specifies that the background will be erased when the control is repainted after being
     * resized.
     * @see #setStyle
     */
    protected static final int STYLE_OPTIMIZE_SIZEPAINT = 0x00000080;
    /**
     * Specifies that the control receives standard click events.
     * @see #setStyle
     */
    protected static final int STYLE_STDCLICK        = 0x00000100;
    /**
     * Indicates whether the control is selectable.
     * @see #setStyle
     */
    protected static final int STYLE_SELECTABLE = 0x00000200;

    /**
     * Specifies that the value of the visible property has changed.
     * @see #propChanged
     */
    protected static final int PROP_VISIBLE         = 1;
    /**
     * Specifies that the value of the enabled property has changed.
     * @see #propChanged
     */
    protected static final int PROP_ENABLED         = 2;
    /**
     * Specifies that the value of the location property has
     * changed.
     * @see #propChanged
     */
    protected static final int PROP_LOCATION        = 3;
    /**
     * Specifies that the value of the size property has changed.
     * @see #propChanged
     */
    protected static final int PROP_SIZE            = 4;
    /**
     * Specifies that the value of the text property has changed.
     * @see #propChanged
     */
    protected static final int PROP_TEXT            = 5;
    /**
     * Specifies that the value of the font property has changed.
     * @see #propChanged
     */
    protected static final int PROP_FONT            = 6;
    /**
     * Specifies that the value of the parent's font property has
     * changed.
     * @see #propChanged
     */
    protected static final int PROP_PARENTFONT      = 7;
    /**
     * Specifies that the value of the foreColor property has
     * changed.
     * @see #propChanged
     */
    protected static final int PROP_FORECOLOR       = 8;
    /**
     * Specifies that the value of the parent's foreColor property
     * has changed.
     * @see #propChanged
     */
    protected static final int PROP_PARENTFORECOLOR = 9;
    /**
     * Specifies that the value of the backColor property has
     * changed.
     * @see #propChanged
     */
    protected static final int PROP_BACKCOLOR       = 10;
    /**
     * Specifies that the value of the parent's backColor property
     * has changed.
     * @see #propChanged
     */
    protected static final int PROP_PARENTBACKCOLOR = 11;
    /**
     * Specifies that the value of the tabStop property has changed.
     * @see #propChanged
     */
    protected static final int PROP_TABSTOP         = 12;
    /**
     * Specifies that the value of the cursor property has changed.
     * @see #propChanged
     */
    protected static final int PROP_CURSOR          = 13;

    private static final Object EVENT_HELP              = new Object();
    private static final Object EVENT_KEYDOWN           = new Object();
    private static final Object EVENT_KEYPRESS          = new Object();
    private static final Object EVENT_KEYUP             = new Object();
    private static final Object EVENT_MOUSEDOWN         = new Object();
    private static final Object EVENT_MOUSEENTER        = new Object();
    private static final Object EVENT_MOUSELEAVE        = new Object();
    private static final Object EVENT_MOUSEMOVE         = new Object();
    private static final Object EVENT_MOUSEUP           = new Object();
    private static final Object EVENT_CLICK             = new Object();
    private static final Object EVENT_DOUBLECLICK       = new Object();
    private static final Object EVENT_MOVE              = new Object();
    private static final Object EVENT_RESIZE            = new Object();
    private static final Object EVENT_RESIZE_CLIENT     = new Object();
    private static final Object EVENT_PAINT             = new Object();
    private static final Object EVENT_GOTFOCUS          = new Object();
    private static final Object EVENT_LAYOUT            = new Object();
    private static final Object EVENT_LOSTFOCUS         = new Object();
    static final Object EVENT_CREATEHANDLE      = new Object();
    private static final Object EVENT_DESTROYHANDLE     = new Object();
    private static final Object EVENT_MOUSEWHEEL        = new Object();
    private static final Object EVENT_QUERYCONTINUEDRAG = new Object();
    private static final Object EVENT_GIVEFEEDBACK      = new Object();
    private static final Object EVENT_DRAGENTER         = new Object();
    private static final Object EVENT_DRAGLEAVE         = new Object();
    private static final Object EVENT_DRAGOVER          = new Object();
    private static final Object EVENT_DRAGDROP          = new Object();
    private static final Object EVENT_ENTER             = new Object();
    private static final Object EVENT_LEAVE             = new Object();

    private static final int DRAGDROP_S_DROP    = 0x00040100;
    private static final int DRAGDROP_S_CANCEL  = 0x00040101;
    private static final int DRAGDROP_S_USEDEFAULTCURSORS = 0x00040102;

    protected static final Brush defaultBrush = Brush.CONTROL;

    /**
     * This message is used to determine when to make a cleanup pass
     * through the list of graphics objects for a given control.
     * @internalonly
     */
    protected static final int graphicsTrackingMessage = Windows.RegisterWindowMessage("WFCGraphicsHDCTracking");

    
    private static final int creationTrackingMessage = Windows.RegisterWindowMessage("WFCCreationTracking");

    private static int mouseWheelMessage = win.WM_MOUSEWHEEL;
    private static boolean mouseWheelRoutingNeeded = false;
    private static boolean mouseWheelInit = false;
    private static int threadCallbackMessage = 0;
    private int charsToIgnore = 0;
    private List threadCallbackList = new List();

    private static final int ADJUST_LEFT   = 1;
    private static final int ADJUST_TOP    = 2;
    private static final int ADJUST_RIGHT  = 4;
    private static final int ADJUST_BOTTOM = 8;

    private static int[] anchorAdjustments = {
        0,                                                          
        ADJUST_LEFT | ADJUST_RIGHT,                                 
        ADJUST_TOP | ADJUST_BOTTOM,                                 
        ADJUST_LEFT | ADJUST_TOP | ADJUST_RIGHT | ADJUST_BOTTOM,    
        ADJUST_BOTTOM,                                              
        ADJUST_RIGHT,                                               
        ADJUST_LEFT | ADJUST_RIGHT | ADJUST_BOTTOM,                 
        ADJUST_TOP | ADJUST_RIGHT | ADJUST_BOTTOM,                  
        ADJUST_RIGHT | ADJUST_BOTTOM                                
    };

    
    ControlWindow window;
    
    int parentHandle;


    private int handle;
    private Control parent;
    private Control[] controls;       
    private Control[] tabList;        
    private int controlCount;
    private int tabHint;              
    private int state;
    private int style;

    private int x;
    private int y;
    private int width;
    private int height;
    private int clientWidth;
    private int clientHeight;
    private DockInfo dock;
    private AnchorInfo anchor;
    private int layoutSuspendCount;

    private ContextMenu contextMenu;

    private String text;
    private Font font;
    private Brush brush;
    private Color color;
    private Region region;
    private Cursor cursor = null;

    private boolean trackingMouseEvent = false;
    private TRACKMOUSEEVENT trackMouseEvent;

    #if DEBUG
    
    static public HashTable dbgControls = new HashTable();
    #endif

    /**
     * Creates a new Control. This constructor is typically not called
     * directly, but rather from a the constructor of a descendant class.
     */
    public Control() {}

    /**
     * Adds a child control to this control.  The control becomes the last control
     * in the child control list. If the control is already a child of another
     * control it is first removed from that control.
     * @param control the child control to be added
     * @exception RuntimeException if the specified control is a toplevel control,
     * or if a circular control reference would result
     * @see #remove
     * @see #setParent
     */
    public void add(Control control) {}

    /**
     * Assigns a delegate to the click event.  The click event occurs
     * when the user clicks in the client area of the control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnClick
     */
    public void addOnClick(EventHandler value) {}

    /**
     * Assigns a delegate to the createHandle event.  The createHandle event occurs
     * immediately after the control's handle is created.
     *
     * @param value New handler to install for this event.
     * @see #removeOnCreateHandle
     */
    public final void addOnCreateHandle(EventHandler value) {}

    /**
     * Assigns a delegate to the destroyHandle event.  The destroyHandle event occurs
     * immediately before the control's handle is destroyed.
     *
     * @param value New handler to install for this event.
     * @see #removeOnDestroyHandle
     */
    public final void addOnDestroyHandle(EventHandler value) {}

    /**
     * Assigns a delegate to the doubleClick event.  The doubleClick
     * event occurs when the user double clicks in the client area of the
     * control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnDoubleClick
     */
    public final void addOnDoubleClick(EventHandler value) {}

    /**
     * Assigns a delegate to the dragDrop event. 
     * The dragDrop evnet occurs when the user releases the mouse button
     * while dragging some object over the control.
     *
     * @param value     New handler to install for this event.
     * @see #removeOnDragDrop
     */
    public final void addOnDragDrop(DragEventHandler value) {}

    /**
     * Assigns a delegate to the dragEnter event. 
     * The drawEnter event occurs when the user first moves the
     * mouse over the control while dragging some object.
     *
     * @param value New handler to install for this event.
     * @see #removeOnDragEnter
     */
    public final void addOnDragEnter(DragEventHandler value) {}

    /**
     * Assigns a delegate to the dragOver event. 
     * The dragOver event occurs whenever the user moves the mouse
     * over the control while draggin some object.
     *
     * @param value New handler to install for this event.
     * @see #removeOnDragOver
     */
    public final void addOnDragOver(DragEventHandler value) {}

    /**
     * Assigns a delegate to the dragLeave event. 
     * The dragLeave event occurs when the user first moves the
     * mouse out of the control while dragging some object.
     *
     * @param value New handler to install for this event.
     * @see #removeOnDragLeave
     */
    public final void addOnDragLeave(EventHandler value) {}

    /**
     * Assigns a delegate to the enter event. 
     * The enter event occurs when focus enters this control. This doesn't
     * imply that this control has focus, but rather that this control or
     * some child control of this control has gotten focus.
     *
     * @param value New handler to install for this event.
     * @see #removeOnEnter
     */
    public final void addOnEnter(EventHandler value) {}

    /**
     * Assigns a delegate to the giveFeedback event. 
     * The giveFeedback event occurs during a drag operation. This allows the
     * source of a drag event to modify the mouse pointer to give the user
     * visual feedback as to what would happen if they droped.
     *
     * @param value New handler to install for this event.
     * @see #removeOnGiveFeedback
     */
    public final void addOnGiveFeedback(GiveFeedbackEventHandler value) {}

    /**
     * Assigns a delegate to the gotFocus event. 
     * The gotFocus event occurs when the this control gains focus.
     *
     * @param value New handler to install for this event.
     * @see #removeOnGotFocus
     */
    public final void addOnGotFocus(EventHandler value) {}

    /**
     * Assigns a delegate to the help event.  The help event occurs
     * when the user requests help for this control. This may be caused by
     * the user pressing F1, or used "Whats This Help".
     *
     * @param value New handler to install for this event.
     * @see #removeOnHelp
     */
    public final void addOnHelp(HelpEventHandler value) {}

    /**
     * Assigns a delegate to the keyDown event.  The keyDown event occurs
     * when the user presses a key down.
     *
     * @param value New handler to install for this event.
     * @see #removeOnKeyDown
     */
    public final void addOnKeyDown(KeyEventHandler value) {}

    /**
     * Assigns a delegate to the keyPress event.  The keyPress event occurs
     * when the user presses a key.
     *
     * @param value New handler to install for this event.
     * @see #removeOnKeyPress
     */
    public final void addOnKeyPress(KeyPressEventHandler value) {}

    /**
     * Assigns a delegate to the keyUp event.  The keyUp event occurs
     * when the user releases a key.
     *
     * @param value New handler to install for this event.
     * @see #removeOnKeyUp
     */
    public final void addOnKeyUp(KeyEventHandler value) {}

    /**
     * Assigns a delegate to the layout event.  The layout event occurs when
     * any event occurs that would cause the control to layout child controls.
     * These events include; resize, show/hide child controls, add/remove
     * child controls. This event should be used to perform any custom layout
     * logic.
     *
     * @param value New handler to install for this event.
     * @see #removeOnLayout
     */
    public final void addOnLayout(LayoutEventHandler value) {}

    /**
     * Assigns a delegate to the leave event.  The leave event occurs when
     * focus leaves this control. This doesn't imply that this control lost focus,
     * but rather that focus has been moved out of this control and any child
     * controls.
     *
     * @param value New handler to install for this event.
     * @see #removeOnLeave
     */
    public final void addOnLeave(EventHandler value) {}

    /**
     * Assigns a delegate to the lostFocus event.  The lostFocus event occurs
     * when this control looses focus.
     *
     * @param value New handler to install for this event.
     * @see #removeOnLostFocus
     */
    public final void addOnLostFocus(EventHandler value) {}

    /**
     * Assigns a delegate to the mouseDown event.  The mouseDown event
     * occurs when the user presses the mouseDown over this control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseDown
     */
    public final void addOnMouseDown(MouseEventHandler value) {}

    /**
     * Assigns a delegate to the mouseEnter event.  The mouseEnter event
     * occurs when the mouse first moves over this control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseEnter
     */
    public final void addOnMouseEnter(EventHandler value) {}

    /**
     * Assigns a delegate to the mouseLeave event.  The mouseLeave event
     * occurs when the mouse first moves out of this control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseLeave
     */
    public final void addOnMouseLeave(EventHandler value) {}

    /**
     * Assigns a delegate to the mouseMove event.  The mouseMove event
     * occurs whenever the user moves the mouse over this control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseMove
     */
    public final void addOnMouseMove(MouseEventHandler value) {}

    /**
     * Assigns a delegate to the mouseUp event.  The mouseUp event occurs
     * when the user releases a mouse button inside the control.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseUp
     */
    public final void addOnMouseUp(MouseEventHandler value) {}

    /**
     * Assigns a delegate to the mouseWheel event.  The mouseWheel event occurs
     * when the user scrolls the mouse wheel up or down. The <i>delta</i> value in
     * the event data indicates the amount that the mouse wheel has moved. The
     * Microsoft standards indicate that the view should scroll by
     * <I>com.ms.wfc.app.SystemInformation.getMouseWheelScrollLines()</i> when the delta
     * value has reach <i>win.WHEEL_DELTA</i>. If a mouseWheel event occurs with
     * a value less that WHEEL_DELTA, the control should either increment a stored
     * value and wait until the total delta is an increment of WHEEL_DELTA, or scroll
     * the view a percentage of MouseWheelScrollLines.
     *
     * NOTE: A press of the mouseWheel will generate a mouseDown event with the middle
     * button pressed.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMouseWheel
     */
    public final void addOnMouseWheel(MouseEventHandler value) {}

    /**
     * Assigns a delegate to the move event.  The move event occurs when
     * the controls location changes.
     *
     * @param value New handler to install for this event.
     * @see #removeOnMove
     */
    public final void addOnMove(EventHandler value) {}

    /**
     * Assigns a delegate to the paint event.  The paint event occurs when
     * the control needs to paint some part of it's client area.
     *
     * @param value New handler to install for this event.
     * @see #removeOnPaint
     */
    public final void addOnPaint(PaintEventHandler value) {}

    /**
     * Assigns a delegate to the queryContinueDrag event.  The
     * queryContinueDrag event occurs during a drag operation. This allows the drag
     * source to determine if the drag operation should be canceled.
     *
     * @param value New handler to install for this event.
     * @see #removeOnQueryContinueDrag
     */
    public final void addOnQueryContinueDrag(QueryContinueDragEventHandler value) {}

    /**
     * Assigns a delegate to the resize event.  The resize event occurs when
     * the bounds of the control change. This event may be fired from the
     * constructor of base controls.
     *
     * @param value New handler to install for this event.
     * @see #removeOnResize
     */
    public final void addOnResize(EventHandler value) {}

    /**
     * Assigns a new parent control.  Sends out the appropriate property change
     * notifications for properties that are affected by the change of parent.
     * @param value The new parent control.
     */
    protected final void assignParent(Control value) {}

    private boolean translateAxAccelerator(MSG msg) {}

    /**
     * Brings this control to the front of the z-order. 
     */
    public final void bringToFront() {}

    /**
     * Retrieves a boolean value indicating whether this control can receive the focus.
     *  The result is true if the
     * control has a handle and if it and all of its parent controls are both
     * visible and enabled.
     * @return whether this control can receive focus.
     * @see #focus
     * @see #isFocused
     */
    public final boolean canFocus() {}

    /**
     * Retrieves a boolean value indicating whether this control can be selected.  The result is true if the control
     * is contained in a form and if all of its parent controls are both visible
     * and enabled.
     * @return whether this control can be selected.
     * @see #isSelected
     * @see #select
     */
    public final boolean canSelect() {}

    
    
    boolean canSelectCore() {}

    /**
     * @internalonly
     */
    protected void childGotFocus(Control child) {}

    /**
     * This is called by the message loop when it has determined that the given
     * window handle has finished processing messages.  It calls on the
     * @see Graphics object to clean up any objects that are tied to the
     * given window handle.
     *
     * @param hwnd A window handle of the window that is re-entering the
     *                    message loop.
     * @internalonly
     */
    protected static final void cleanupOutstandingGraphics(int hwnd) {}

    /**
     * Retrieves a value indicating whether the specified control is a child of this control. 
     * @param ctl the control to check
     * @return whether ctl is a child of this control.
     */
    public final boolean contains(Control ctl) {}

    /**
     * Creates a Graphics object that can be used to
     * draw in the client area of the control.  The control's brush, font, foreground
     * color and background color become the default values for the Graphics.
     * The returned Graphics must be disposed through a call to its dispose()
     * method when it is no longer needed.  The Graphics object is only valid for
     * the duration of the current window's message.
     *
     * @return the @see Graphics for this control.
     */
    public final Graphics createGraphics() {}

    /**
     * Creates a Graphics object that can be used to
     * draw in the client area of the control.   This version wraps an existing
     * Windows HDC.  The Graphics object does not claim ownership of the DC; you
     * are responsible for freeing it.  The Graphics object is only valid for
     * the duration of the current window's message.
     *
     * @param dc HDC to wrap
     */
    public final Graphics createGraphics(int dc) {}

    /**
     * Creates a handle for this control.  This method is called by the framework, this should
     * not be called. Inheriting classes should always call <i>super.createHandle</i> when
     * overriding this method.
     */
    protected void createHandle() {}

    /**
     * Forces the creation of the control, including the creation of the control handle and
     * any child controls.  This includes the creation of the handle,
     * and any child controls.
     */
    public final void createControl() {}


    final void createControl(boolean force) {}

    /**
     * Creates a Graphics object that can be used to
     * draw in the entire window of the control rather than just the client area of the control.   The controls foreground color and background color
     * become the default values for the Graphics.
     * The returned Graphics must be disposed through a call to its dispose()
     * method when it is no longer needed.  The Graphics object is only valid for
     * the duration of the current window's message.
     *
     * @return the @see Graphics for this control.
     */
    public final Graphics createWindowGraphics() {}

    /**
     * Sends the message to the default window proc.
     *
     * @param m Win32 Message
     */
    protected void defWndProc(Message m) {}

    /**
     * This method should be called only by the framework. Destroys the handle associated with
     * this control.  Inheriting classes should
     * always call <i>super.destroyHandle</i>.
     */
    protected void destroyHandle() {}

    /**
     * Frees all resources allocated for this control.  This method may not be
     * called at runtime. Any resources used by the control should be setup to
     * be released when the control is GC'ed. Inheriting classes should always
     * call <i>super.dispose</i>.
     */
    public void dispose() {}

    
    
    void disposeAxControls() {}

    /**
     * Begins a drag-and-drop operation.  The <i>allowedEffects</i> determine which
     * drag operations can occur. If the drag operation needs to interop
     * with applications in another process, <i>data</i> should either be
     * a base WFC class (String, Bitmap, or Metafile) or some object
     * that implements com.ms.wfc.core.IPersistable. <i>data</i> can also be any object that
     * implements com.ms.wfc.app.IDataObject.
     *
     * @param data Data to drag.
     * @param allowedEffects Mask specifying the allowed drag effects.
     *
     * @return final effect of the drag operation. Usually DragDropEffect.NONE,
     *         DragDropEffect.COPY, or DragDropEffect.MOVE.
     */
    public final int doDragDrop(Object data, int allowedEffects) {}

    protected void finalize() throws Throwable {}
    
    
    private synchronized final Control findMarshalingControl() {}
    
    /**
     * Triggers a drag event. 
     *
     * @param key Event to fire
     * @param e Event data to send to the event.
     */
    protected final void fireDragEvent(Object key, DragEvent e) {}

    /**
     * Triggers a key event. 
     *
     * @param key Event to fire
     * @param e Event data to send to the event.
     */
    protected final void fireKeyEvent(Object key, KeyEvent e) {}

    /**
     * Triggers a mouse event. 
     *
     * @param key Event to fire
     * @param e Event data to send to the event.
     */
    protected final void fireMouseEvent(Object key, MouseEvent e) {}

    /**
     * Attempts to set the focus to this control and activate the form that contains this
     * control, and returns a boolean value indicating whether the attempt succeeded. 
     *
     * @return <b>true</b> if the focus request was successfull.
     */
    public final boolean focus() {}

    /**
     * Returns the control that contains the specified handle. 
     * This method will search up the HWND parent chain until it finds some
     * handle that is associated with with a control. This method is more
     * robust that <i>fromHandle</i> because it will correctly return controls
     * that own more than one handle.
     *
     * @param handle HWND to search for.
     * @return Control associated with <i>handle</i>, or <b>null</b> if no
     * control was found.
     *
     * @see #fromHandle
     */
    public static final Control fromChildHandle(int handle) {}

    /**
     * Returns the control that is currently associated with the specified handle. 
     *
     * @param handle HWND to search for.
     * @return Control associated with <i>handle</i>, or <b>null</b> if no
     * control was found.
     *
     * @see #fromChildHandle
     */
    public static final Control fromHandle(int handle) {}

    /**
     * Retrieves a boolean value indicating whether this control can contain child
     * controls.  This
     * property cannot be set, but rather inheriting controls can specify this using
     * <i>setStyle(STYLE_ACCEPTSCHILDREN, ...)</I>.
     *
     * @return <b>true</b> if this control accepts children.
     */
    public final boolean getAcceptsChildren() {}

    /**
     * Retrieves a boolean value indicating whether this control can accept data that
     * the user drags and drops into it.  If allowDrop is set to <b>true</b> then
     * this control will allow drag and drop operations and events to be used.
     *
     * @return current value of the allowDrop property.
     */
    public final boolean getAllowDrop() {}

    /**
     * Retrieves a value indicating which edges of the control are anchored to the edges of
     * its container.  The anchor property
     * determines which edges of the control are anchored to the container's
     * edges.
     *
     * @return current value of the anchor property.
     *
     * @see com.ms.wfc.ui.ControlAnchor
     */
    public final int getAnchor() {}

    
    AxHost.Container getAxContainer() {}

    /**
     * Retrieves the background color for this control.  This is an ambient proeprty and
     * will always return a non-null value.
     *
     * @return backColor of this control.
     */
    public Color getBackColor() {}

    /**
     * Retrieves the distance between the bottom edge of the control and the top edge of its
     * container's client area. 
     *
     * @return bottom coordinate of this control.
     *
     * @see #getBounds
     */
    public final int getBottom() {}

    /**
     * Retrieves the bounding rectangle for the control.  This is the window coordinates of the
     * control in parent client coordinates.
     *
     * @return bounds of this control.
     */
    public final Rectangle getBounds() {}

    /**
     * Retrieves the brush for this control.  This is an ambient property and will
     * always return a non-null value.
     *
     * @return brush for this control.
     */
    public Brush getBrush() {}

    
    boolean getCanAccessProperties() {}

    /**
     * Retrieves a boolean value indicating whether this control has captured the
     * mouse. 
     *
     * @return <b>true</b> if this control has captured the mouse.
     *
     * @see #setCapture
     */
    public final boolean getCapture() {}

    /**
     * Retrieves the child control that is located at the specified coordinates. 
     *
     * @param pt Client coordinates to look for control at.
     *
     * @return control that contains the specified point.
     */
    public final Control getChildAtPoint(Point pt) {}

    /**
     * Retrieves the rectangle that represents the client area of the control. 
     *
     * @return clientRect of control.
     */
    public final Rectangle getClientRect() {}

    /**
     * Retrieves the height and width of the client area of the control. 
     *
     * @return size of the clientRect.
     */
    public final Point getClientSize() {}

    /**
     * Retrieves the shortcut menu (also known as a context menu) associated with this
     * control.  The contextMenu
     * will be shown when the user right clicks the mouse on the control.
     *
     * @return contextMenu associated with this control.
     */
    public final ContextMenu getContextMenu() {}

    /**
     * Retrieves the child control with the specified zero-based index within the parent's
     * control array. 
     *
     * @param index Index of the control to return
     * @return control with the specified index.
     */
    public Control getControl(int index) {}

    /**
     * Retrieves the number of child controls this control contains. 
     *
     * @return count of child controls.
     */
    public int getControlCount() {}

    /**
     * Retrieves the zero-based index of this control within the parent control array. 
     *
     * @return this control's index.
     */
    public final int getControlIndex() {}

    /**
     * Retrieves an array of the child controls contained in this control. 
     *
     * @retun all of the child controls.
     */
    public Control[] getControls() {}

    /**
     * Retrieves the information used to create the handle for this control. 
     * Inheriting classes should call <i>super.getCreateParams</i> in the manor
     * below:<br>
     * <pre>
     *protected CreateParams getCreateParams() {
     *    CreateParams cp = super.getCreateParams();
     *    // modify cp here...
     *    cp.style |= win.WS_BORDER;
     *    return cp;
     *}
     * </pre>
     *
     * @return CreateParams used to create the handle for this control.
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the Win32 thread ID of the thread that created the
     * handle for this control.  If the control's handle hasn't been
     * created yet, this method will return the current thread's ID.
     * 
     * @return the Win32 thread ID of the thread that created the
     *         handle for this control, or the current thread ID
     *         if this control's handle has not yet been created.
     * 
     * @internalonly
     */
    protected final int getCreateThreadId() {}
    
    /**
     * Retrieves the cursor that is displayed when the user moves the mouse pointer over this
     * control. 
     *
     * @return current cursor.
     */
    public final Cursor getCursor() {}

    /**
     * Retrieves the rectangle that represents the display area of the control. 
     * For the base control class, this is identical to getClientRect.
     * However, inheriting controls may want to change this if their client
     * area differs from their display area.
     *
     * @return Rectangle representing the client area display region.
     */
    public Rectangle getDisplayRect() {}

    /**
     * Retrieves a value indicating which edge of its container this control is docked to.  The dock property controls to which edge
     * of the container this control is docked to. For example, when docked to
     * the top of the container, the control will be displayed flush at the
     * top of the container, extending the length of the container.
     *
     * @return current value of the dock property.
     */
    public final int getDock() {}

    /**
     * Retrieves a boolean value indicating whether this control is enabled. 
     *
     * @return current value of the enabled property.
     */
    public boolean getEnabled() {}

    /**
     * Retrieves the form that this control is on.  The control's parent
     * may not be the same as the form.
     *
     * @return form this control is contained in.
     */
    public Form getForm() {}

    /**
     * Retrieves the current font for this control, which is the font the control uses to draw
     * its text.  This will be the font used
     * by default for painting and text in the control.
     *
     * @return current font for this control.
     */
    public Font getFont() {}

    /**
     * Retrieves the current foreground color for this control, which is the color the control
     * uses to draw its text. 
     *
     * @return foreColor of the control.
     */
    public Color getForeColor() {}

    /**
     * Retrieves the window handle (HWND) that this control is bound to.  If the handle
     * has not yet been created, this will force handle creation.
     *
     * @return HWND of the control.
     */
    public final int getHandle() {}

    /**
     * Retrieves the height of this control. 
     *
     * @return height of this control.
     *
     * @see #getBounds
     */
    public final int getHeight() {}

    /**
     * Retrieves the distance between the left edge of the control and the left edge of its
     * container's client area. 
     *
     * @return left coordinate of this control.
     *
     * @see #getBounds
     */
    public final int getLeft() {}

    /**
     * Retrieves coordinates of the upper-left corner of the control relative to the
     * upper-left corner of its container's client area. 
     *
     * @return location of this control.
     *
     * @see #getBounds
     */
    public final Point getLocation() {}

    /**
     * Retrieves a value indicating the current state of the SHIFT, CTRL, and ALT keys.  This will check the
     * current state of the shift, control, and alt keys.
     *
     * @return current status of the modifier keys.
     */
    public static final int getModifierKeys() {}

    /**
     * Retrieves a value indicating the current state of the left, right, and middle mouse
     * buttons.  This will check the
     * current state of the left, right, and middle mouse buttons.
     *
     * @return current status of the mouse buttons.
     */
    public static final int getMouseButtons() {}

    /**
     * Retrieves the current position of the mouse in screen coordinates. 
     *
     * @return current position of the mouse.
     */
    public static final Point getMousePosition() {}

    /**
     * Retrieves the control that follows or precedes the specified control in the tab order. 
     *
     * @param ctl Control to start the search at
     * @param forward Determines if the search is forward or backward in the
     *        tab order.
     *
     * @return next control in the tab order.
     */
    public final Control getNextControl(Control ctl, boolean forward) {}

    /**
     * Retrieves the palette associated with this control. 
     *
     * @return palette used to render this control.
     */
    public Palette getPalette() {}

    /**
     * Retrieves the parent of this control. 
     *
     * @return parent control that contains this control.
     *
     * @see #getForm
     */
    public final Control getParent() {}

    
    
    final int getParentHandle() {}

    /**
     * Retrieves the region (the elliptical or polygonal area within a window) associated with
     * this control. 
     * @see Region associated with this control.
     *
     * @return a @see Region object corresponding to the current shape
     *         of the control.
     */
    public final Region getRegion() {}

    /**
     * Retrieves the distance between the right edge of the control and the left edge of its
     * container's client area. 
     *
     * @return right coordinate of this control.
     *
     * @see #getBounds
     */
    public final int getRight() {}

    /**
     * Retrieves the height and width of the control. 
     *
     * @return size of this control.
     *
     * @see #getBounds
     */
    public final Point getSize() {}

    
    final boolean getState(int flag) {}

    /**
     * Retrieves the current value of the specified bit field in the control's style
     * property. 
     * NOTE: This is control style, not the Win32 style of the hwnd.
     *
     * @param flag Bit to check.
     *
     * @return <b>true</b> if <i>flag</i> is set in the control's style.
     */
    protected final boolean getStyle(int flag) {}

    /**
     * Retrieves the tab order of this control within the parent form. 
     *
     * @return current tab index of this control.
     */
    public final int getTabIndex() {}

    /**
     * Retrieves all the child controls included in the tab order. 
     *
     * @return all the child controls.
     */
    public final Control[] getTabList() {}

    /**
     * Retrieves a boolean value indicating whether the user can give the focus to this
     * control using the TAB key.  tabStop must be set
     * to <b>true</b> to enable the user to use tab to select this control.
     */
    public final boolean getTabStop() {}

    
    private native static int GetWindowTextW(int hWnd, StringBuffer lpString, int nMaxCount);
    
    private native static int GetWindowTextA(int hWnd, StringBuffer lpString, int nMaxCount);

    /**
     * Retrieves the text associated with this control. 
     *
     * @return text of the control.
     */
    public String getText() {}

    /**
     * Retrieves the distance between the top edge of the control and the top edge of its
     * container's client area. 
     *
     * @return top coordinate of this control.
     *
     * @see #getBounds
     */
    public final int getTop() {}

    /**
     * Retrieves a boolean value indicating whether this control is a top-level window
     * (a window that has no parent window). 
     *
     * @return <b>true</b> if this control is a top level window.
     */
    public final boolean getTopLevel() {}

    /**
     * Retrieves the top-level control that contains this control.  This doesn't
     * have to be the same as the value returned from <i>getForm</i> since forms
     * can be parented to other controls.
     *
     * @return top level control that contains this control.
     */
    public final Control getTopLevelControl() {}

    /**
     * Retrieves a boolean value indicating whether this control is visible. 
     *
     * @return current value of the visible property.
     */
    public final boolean getVisible() {}

    /**
     * Retrieves the width of this control. 
     *
     * @return width of this control.
     *
     * @see #getBounds
     */
    public final int getWidth() {}

    
    private int getWindowExStyle() {}

    
    private int getWindowStyle() {}

    /**
     * Hides the control by setting the visible property to false.
     *  */
    public final void hide() {}
    
    
    
    private final void informOfNewHandle(int handle) {}

    
    private final void initMouseWheelSupport() {}

    /**
     * Invalidates the specified part of the control (adds it to the control's update region,
     * which is the area that will be repainted at the next paint operation), and causes a paint
     * message to be sent to the control. 
     * This will not force a synchronous paint to occur, calling <i>update</i> after
     * <i>invalidate</i> will force a synchronous paint.
     */
    public final void invalidate() {}

    /**
     * Invalidates the specified part of the control (adds it to the control's update region,
     * which is the area that will be repainted at the next paint operation), and causes a paint
     * message to be sent to the control.  This will not force a synchronous paint to
     * occur, calling <i>update</i> after <i>invalidate</i> will force a
     * synchronous paint.
     */
    public final void invalidate(Rectangle rc) {}

    /**
     * Invalidates the specified part of the control (adds it to the control's update region,
     * which is the area that will be repainted at the next paint operation), and causes a paint
     * message to be sent to the control.  This will not force a synchronous paint to
     * occur, calling <i>update</i> after <i>invalidate</i> will force a
     * synchronous paint.
     */
    public final void invalidate(Region region) {}

    /**
     * Executes the specified delegate on the thread that created the control's handle and
     * returns when the delegate has completed execution.   It is an error to call this on the same thread that
     * the control belongs to.  If the control's handle doesn't exist yet, this will
     * follow up the control's parent chain until it finds a control or form that does
     * have a window handle.  If no appropriate handle can be found, invoke will throw
     * an exception.  Exceptions that are raised during the call will be
     * propapgated back to the caller.
     * <p>
     * There are four functions on a control that are safe to call from any 
     * thread:  getInvokeRequired, invoke, invokeAsync and createGraphics.  For
     * all other metohd calls, you should use one of the invoke methods to marshal
     * the call to the control's thread.
     *
     * @param method A delegate that contains a method to be called in in the control's
     *               thread context.  The delegate can be an instance of EventHandler,
     *               in which case the <i>sender</i> parameter will contain this
     *               control, and the <i>event</i> parameter will contain Event.EMPTY.
     *               The delegate can also be an instance of MethodInvoker, or any
     *               other delegate that takes a void parameter list.  A call to 
     *               an EventHandler or MethodInvoker delegate will be faster than a
     *               call to another type of delegate.
     * @return the return value from the delegate being invoked, or <b>null</b>
     *         if the delegate has no return value.
     *
     * @throws WFCSystemException if the control's thread is blocked.
     *
     * @see com.ms.wfc.app.MethodInvoker
     */
    public final Object invoke(Delegate method) {}

    /**
     * Executes the specified delegate on the thread that created the control's handle and
     * returns when the delegate has completed execution.   It is an error to call this on the same thread that
     * the control belongs to.  If the control's handle doesn't exist yet, this will
     * follow up the control's parent chain until it finds a control or form that does
     * have a window handle.  If no appropriate handle can be found, invoke will throw
     * an exception.  Exceptions that are raised during the call will be
     * propapgated back to the caller.
     * <p>
     * There are four functions on a control that are safe to call from any 
     * thread:  getInvokeRequired, invoke, invokeAsync and createGraphics.  For
     * all other metohd calls, you should use one of the invoke methods to marshal
     * the call to the control's thread.
     *
     * @param method A delegate to a method that takes parameters of the same number
     *               and type that are contained in <i>args</i>.
     * @param args   An array of objects to pass as arguments to the given method.  This
     *               can be <b>null</b> if no arguments are needed.
     * @return the return value from the delegate being invoked, or <b>null</b>
     *         if the delegate has no return value.
     * @throws WFCSystemException if the control's thread is blocked.
     */
    public final Object invoke(Delegate method, Object args[]) {}

    /**
     * Executes the specified delegate on the thread that created the control's handle and
     * returns immediately (because the delegate is invoked asynchronously).   The delegate is called asynchronously and this
     * method returns immediately.  You may call this from any thread, even the
     * thread that owns the control's handle.  If the control's handle doesn't 
     * exist yet, this will follow up the control's parent chain until it finds a 
     * control or form that does have a window handle.  If no appropriate handle 
     * can be found, invokeAsync will throw an exception.  Exceptions within the
     * delegate method are considered untrapped and will be sent to the 
     * application's untrapped exception handler.
     * <p>
     * There are four functions on a control that are safe to call from any 
     * thread:  getInvokeRequired, invoke, invokeAsync and createGraphics.  For
     * all other metohd calls, you should use one of the invoke methods to marshal
     * the call to the control's thread.
     *
     * @param method A delegate to a method that takes no parameters.
     * @throws WFCSystemException if the control's thread is blocked.
     */
    public final void invokeAsync(Delegate method) {}

    /**
     * Executes the specified delegate on the thread that created the control's handle and
     * returns immediately (because the delegate is invoked asynchronously).   The delegate is called asynchronously and this
     * method returns immediately.  You may call this from any thread, even the
     * thread that owns the control's handle.  If the control's handle doesn't 
     * exist yet, this will follow up the control's parent chain until it finds a 
     * control or form that does have a window handle.  If no appropriate handle 
     * can be found, invokeAsync will throw an exception.  Exceptions within the
     * delegate method are considered untrapped and will be sent to the 
     * application's untrapped exception handler.
     * <p>
     * There are four functions on a control that are safe to call from any 
     * thread:  getInvokeRequired, invoke, invokeAsync and createGraphics.  For
     * all other metohd calls, you should use one of the invoke methods to marshal
     * the call to the control's thread.
     *
     * @param method A delegate to a method that takes parameters of the same number
     *               and type that are contained in <i>args</i>.
     * @param args   An array of objects to pass as arguments to the given method.  This
     *               can be <b>null</b> if no arguments are needed.
     * @throws WFCSystemException if the control's thread is blocked.
     */
    public final void invokeAsync(Delegate method, Object args[]) {}
    
    
    private void invokeMarshaledCallback() {}
    
    
    final boolean isDescendant(Control descendant) {}

    /**
     * Retrieves a boolean value indicating whether the control has been created. 
     *
     * @return <b>true</b> if the control has been created.
     */
    public final boolean getCreated() {}

    /**
     * Retrieves a boolean value indicating whether the control has the focus. 
     *
     * @return <b>true</b> if this control has focus.
     *
     * @see #focus
     */
    public boolean getFocused() {}

    /**
     * Retrieves a boolean value indicating whether this control has a handle
     * associated with it. 
     *
     * @return <b>true</b> if this control has a handle associated with it.
     */
    public final boolean getHandleCreated() {}

    /**
     * Determines if <i>charCode</i> is an input character that the control
     * wants. This method is called during window message pre-processing to
     * determine whether the given input character should be pre-processed or
     * sent directly to the control. If <i>isInputChar</i> returns true, the
     * given character is sent directly to the control. If <i>isInputChar</i>
     * returns false, the character is pre-processed and only sent to the
     * control if it is not consumed by the pre-processing phase. The
     * pre-processing of a character includes checking whether the character
     * is a mnemonic of another control.
     *
     * @param charCode character to test.
     * @return true if character should be sent directly to control, false if
     * character should first be pre-processed.
     * @see #preProcessMessage
     */
    protected boolean isInputChar(char charCode) {}

    /**
     * Determines if <i>keyData</i> is an input key that the control wants.
     * This method is called during window message pre-processing to determine
     * whether the given input key should be pre-processed or sent directly to
     * the control. If <i>isInputKey</i> returns true, the given key is sent
     * directly to the control. If <i>isInputKey</i> returns false, the key is
     * pre-processed and only sent to the control if it is not consumed by the
     * pre-processing phase. Keys that are pre-processed include TAB, RETURN,
     * ESCAPE, and arrow keys.
     *
     * @param keyData key to test.
     * @return true if key should be sent directly to control, false if key
     * should first be pre-processed.
     * @see #preProcessMessage
     */
    protected boolean isInputKey(int keyData) {}

    /**
     * Determines whether the caller must call invoke when making method calls to this
     * control.   Controls in WFC are bound to a specific thread,
     * and are not thread safe.  Therefore, if you are calling a control's method
     * from a different thread, you must use the control's <b>invoke</b> method
     * to marshal the call to the proper thread.  This function can be used to
     * determine if you must call invoke, which can be handy if you don't know
     * what thread owns a control.
     * <p>
     * There are four functions on a control that are safe to call from any 
     * thread:  getInvokeRequired, invoke, invokeAsync and createGraphics.  For
     * all other metohd calls, you should use one of the invoke methods.
     *
     * @return <b>true</b> if the control's Win32 window handle is on a 
     *         different thread than the calling thread, indicating that you
     *         should make calls to the control through the <b>invoke</b> method.
     * 
     * @see Control#invoke
     * @see Control#invokeAsync
     */
    public final synchronized boolean getInvokeRequired() {}

    /**
     * Determines if <i>charCode</i> is the mnemonic character in <i>text</i>.
     * The mnemonic character is the character imediately following the first
     * instance of "&" in <i>text</i>
     *
     * @param charCode Character to test.
     * @param text String to search.
     *
     * @return <b>true</b> if <i>charCode</i> is the mnemonic character.
     */
    public static final boolean isMnemonic(char charCode, String text) {}

    /**
     * Retrieves a boolean value indicating whether the control is currently
     * re-creating its handle. 
     *
     * @return <b>true</b> if the control is currently recreating its handle.
     */
    public final boolean getRecreatingHandle() {}

    
    private Object marshaledInvoke(Control caller, Delegate method, Object args[], boolean synchronous) {}

    
    private void moveControl(Control[] list, int fromIndex, int toIndex) {}

    
    
    final void notifyEnter() {}

    
    
    final void notifyLeave() {}

    protected void onClick(Event e) {}

    /**
     * Called when the control is first created.
     */
    protected void onCreateControl() {}

    /**
     *
     Triggers the createHandle event. 
     * Call super.onCreateHandle first.
     *
     * @param e event
     * @see #addOnCreateHandle
     * @see #removeOnCreateHandle
     */
    protected void onCreateHandle(Event e) {}

    /**
     *
     Triggers the destroyHandle event. 
     * Call super.onDestroyHandle last.
     *
     * @param e event
     * @see #addOnDestroyHandle
     * @see #removeOnDestroyHandle
     */
    protected void onDestroyHandle(Event e) {}

    /**
     *
     Triggers the doubleClick event. 
     * Call super.onDoubleClick to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnDoubleClick
     * @see #removeOnDoubleClick
     */
    protected void onDoubleClick(Event e) {}

    /**
     *
     Triggers the dragEnter event. 
     * Call super.onDragEnter to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnDragEnter
     * @see #removeOnDragEnter
     */
    protected void onDragEnter(DragEvent event) {}

    /**
     *
     Triggers the dragOver event. 
     * Call super.onDragOver to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnDragOver
     * @see #removeOnDragOver
     */
    protected void onDragOver(DragEvent event) {}
    /**
     *
     Triggers the dragLeave event. 
     * Call super.onDragLeave to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnDragLeave
     * @see #removeOnDragLeave
     */
    protected void onDragLeave(Event event) {}
    /**
     *
     Triggers the dragDrop event. 
     * Call super.onDragDrop to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnDragDrop
     * @see #removeOnDragDrop
     */
    protected void onDragDrop(DragEvent event) {}

    /**
     *
     Triggers the enter event. 
     * Call super.onEnter to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnEnter
     * @see #removeOnEnter
     */
    protected void onEnter(Event event) {}

    /**
     * Triggers the eraseBackground event.  It is not needed to call
     * <i>super.onEraseBackground</i>, however if you do not want the default
     * Windows behavior you must set <i>event.handled</i> to <b>true</b>.
     *
     * @param event Event data
     */
    protected void onEraseBackground(PaintEvent event) {}

    /**
     *
     Triggers the giveFeedback event. 
     * Call super.onGiveFeedback to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnGiveFeedback
     * @see #removeOnGiveFeedback
     */
    protected void onGiveFeedback(GiveFeedbackEvent event) {}

    /**
     *
     Triggers the gotFocus event. 
     * Call super.onGotFocus to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnGotFocus
     * @see #removeOnGotFocus
     */
    protected void onGotFocus(Event e) {}

    /**
     *
     Triggers the help event. 
     * Call super.onHelp to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnHelp
     * @see #removeOnHelp
     */
    protected void onHelp(HelpEvent event) {}

    /**
     *
     Triggers the keyDown event. 
     * Call super.onKeyDown to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnKeyDown
     * @see #removeOnKeyDown
     */
    protected void onKeyDown(KeyEvent e) {}

    /**
     *
     Triggers the keyPress event. 
     * Call super.onKeyPress to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnKeyPress
     * @see #removeOnKeyPress
     */
    protected void onKeyPress(KeyPressEvent e) {}

    /**
     *
     Triggers the keyUp event. 
     * Call super.onKeyUp to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnKeyUp
     * @see #removeOnKeyUp
     */
    protected void onKeyUp(KeyEvent e) {}

    /**
     * Triggers the layout event.  Inheriting controls should override this function
     * to do any custom layout logic. It is not neccessary to call
     * <i>super.layoutCore</i>, however for normal docking and anchoring
     * functions to work, <I>super.layoutCore</i> must be called.
     *
     * @param affectedControl New control that was affected since last layout.
     */
    protected void onLayout(LayoutEvent event) {}

    /**
     *
     Triggers the leave event. 
     * Call super.onLeave to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnLeave
     * @see #removeOnLeave
     */
    protected void onLeave(Event e) {}

    /**
     *
     Triggers the lostFocus event. 
     * Call super.onLostFocus to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnLostFocus
     * @see #removeOnLostFocus
     */
    protected void onLostFocus(Event e) {}

    /**
     *
     Triggers the mouseDown event. 
     * Call super.onMouseDown to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseDown
     * @see #removeOnMouseDown
     */
    protected void onMouseDown(MouseEvent e) {}

    /**
     *
     Triggers the mouseEnter event. 
     * Call super.onMouseEnter to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseEnter
     * @see #removeOnMouseEnter
     */
    protected void onMouseEnter(Event e) {}

    /**
     *
     Triggers the mouseLeave event. 
     * Call super.onMouseLeave to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseLeave
     * @see #removeOnMouseLeave
     */
    protected void onMouseLeave(Event e) {}

    /**
     *
     Triggers the mouseMove event. 
     * Call super.onMouseMove to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseMove
     * @see #removeOnMouseMove
     */
    protected void onMouseMove(MouseEvent e) {}

    /**
     *
     Triggers the mouseUp event. 
     * Call super.onMouseUp to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseUp
     * @see #removeOnMouseUp
     */
    protected void onMouseUp(MouseEvent e) {}

    /**
     *
     Triggers the mouseWheel event. 
     * Call super.onMouseWheel to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMouseWheel
     * @see #removeOnMouseWheel
     */
    protected void onMouseWheel(MouseEvent e) {}

    /**
     *
     Triggers the move event. 
     * Call super.onMove to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnMove
     * @see #removeOnMove
     */
    protected void onMove(Event e) {}

    /**
     *
     Triggers the paint event. 
     * Call super.onPaint to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnPaint
     * @see #removeOnPaint
     */
    protected void onPaint(PaintEvent e) {}

    /**
     *
     Triggers the queryContinueDrag event. 
     * Call super.onQueryContinueDrag to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnQueryContinueDrag
     * @see #removeOnQueryContinueDrag
     */
    protected void onQueryContinueDrag(QueryContinueDragEvent event) {}

    /**
     *
     Triggers the resize event. 
     * Call super.onResize to send this event to any registered event listeners.
     *
     * @param e event
     * @see #addOnResize
     * @see #removeOnResize
     */
    protected void onResize(Event e) {}

    
    private final void parentPropertyChanged(int property) {}

    /**
     * Forces the control to apply layout logic to all its child controls. 
     */
    public final void performLayout() {}

    /**
     * Forces the control to apply layout logic to all its child controls. 
     *
     * @param affectedControl Control that was most recently changed.
     */
    public final void performLayout(Control affectedControl) {}

    /**
     * Converts the coordinates of a point from screen coordinates to client coordinates. 
     *
     * @param p Screen coordinate point to convert.
     *
     * @return client coordinate point.
     */
    public Point pointToClient(Point p) {}

    /**
     * Converts the coordinates of a point from client coordinates to screen coordinates. 
     *
     * @param p Client coordinate point to convert.
     *
     * @return screen coordinate point.
     */
    public Point pointToScreen(Point p) {}

    /**
     * This method is called by the application's message loop to preprocess input messages
     * before they are dispatched.  Possible values for the
     * msg.message field are WM_KEYDOWN, WM_SYSKEYDOWN, WM_CHAR, and WM_SYSCHAR.
     * If this method processes the message it must return true, in which case
     * the message loop will not dispatch the message.
     *
     * <p>For WM_KEYDOWN and WM_SYSKEYDOWN messages, preProcessMessage() first
     * calls processCmdKey() to check for command keys such as accelerators and
     * menu shortcuts. If processCmdKey() doesn't process the message, then
     * isInputKey() is called to check whether the key message represents an
     * input key for the control. Finally, if isInputKey() indicates that the
     * control isn't interested in the key message, then processDialogKey() is
     * called to check for dialog keys such as TAB, arrow keys, and mnemonics.
     *
     * <p>For WM_CHAR messages, preProcessMessage() first calls isInputChar() to
     * check whether the character message represents an input character for
     * the control. If isInputChar() indicates that the control isn't interested
     * in the character message, then processDialogChar() is called to check for
     * dialog characters such as mnemonics.
     *
     * <p>For WM_SYSCHAR messages, preProcessMessage() calls processDialogChar()
     * to check for dialog characters such as mnemonics.
     *
     * <p>When overriding preProcessMessage(), a control should return true to
     * indicate that it has processed the message. For messages that aren't
     * processed by the control, the result of "super.preProcessMessage()"
     * should be returned. Controls will typically override one of the more
     * specialized methods (isInputChar(), isInputKey(), processCmdKey(),
     * processDialogChar(), or processDialogKey()) instead of overriding
     * preProcessMessage().
     * 
     * @param msg the message to pre-process.
     * @return true to consume the message, false to allow the message to be
     * dispatched.
     * @see #isInputChar
     * @see #isInputKey
     * @see #processCmdKey
     * @see #processDialogChar
     * @see #processDialogKey
     */
    public boolean preProcessMessage(MSG msg) {}

    /**
     * Processes a command key.  This method is called during message
     * pre-processing to handle command keys. Command keys are keys that always
     * take precedence over regular input keys. Examples of command keys
     * include accelerators and menu shortcuts. The method must return true to
     * indicate that it has processed the command key, or false to indicate
     * that the key is not a command key.
     *
     * <p>processCmdKey() first checks if the control has a context menu, and if
     * so calls the menu's processCmdKey() to check for menu shortcuts. If the
     * command key isn't a menu shortcut, and if the control has a parent, the
     * key is passed to the parent's processCmdKey() method. The net effect is
     * that command keys are "bubbled" up the control hierarchy.
     *
     * <p>When overriding processCmdKey(), a control should return true to
     * indicate that it has processed the key. For keys that aren't processed by
     * the control, the result of "super.processCmdKey()" should be returned.
     *
     * <p>Controls will seldom, if ever, need to override this method.
     * 
     * @param msg original window message.
     * @param keyData key code and modifier flags.
     * @return true to consume the key, false to allow further processing.
     * @see #preProcessMessage
     */
    protected boolean processCmdKey(MSG msg, int keyData) {}

    /**
     * Processes a dialog character, checking for mnemonics, and forwards the appropriate
     * messages.  This method is called during message
     * pre-processing to handle dialog characters, such as control mnemonics.
     * This method is called only if the isInputChar() method indicates that
     * the control isn't interested in the character.
     *
     * <p>processDialogChar() simply sends the character to the parent's
     * processDialogChar() method, or returns false if the control has no
     * parent. The wfc.ui.Form class overrides this method to perform actual
     * processing of dialog characters.
     *
     * <p>When overriding processDialogChar(), a control should return true to
     * indicate that it has processed the character. For characters that aren't
     * processed by the control, the result of "super.processDialogChar()"
     * should be returned.
     *
     * <p>Controls will seldom, if ever, need to override this method.
     * 
     * @param charCode character to pre-process.
     * @return true to consume the character, false to allow further
     * processing.
     * @see #preProcessMessage
     * @see wfc.ui.Form#processDialogChar
     */
    protected boolean processDialogChar(char charCode) {}

    /**
     * Processes a dialog key, checking for mnemonics, tabs, and arrows, and forwards the
     * appropriate messages.  This method is called during message
     * pre-processing to handle dialog characters, such as TAB, RETURN, ESCAPE,
     * and arrow keys. This method is called only if the isInputKey() method
     * indicates that the control isn't interested in the key.
     *
     * <p>processDialogKey() simply sends the character to the parent's
     * processDialogKey() method, or returns false if the control has no
     * parent. The wfc.ui.Form class overrides this method to perform actual
     * processing of dialog keys.
     *
     * <p>When overriding processDialogKey(), a control should return true to
     * indicate that it has processed the key. For keys that aren't processed
     * by the control, the result of "super.processDialogChar()" should be
     * returned.
     *
     * <p>Controls will seldom, if ever, need to override this method.
     * 
     * @param keyData key code and modifier flags.
     * @return true to consume the key, false to allow further processing.
     * @see #preProcessMessage
     * @see wfc.ui.Form#processDialogKey
     */
    protected boolean processDialogKey(int keyData) {}

    /**
     * Processes a key message and generates the appropriate control events.  This method is called when a control receives a
     * keyboard message. The method is responsible for generating the appropriate
     * key events for the message by calling onKeyPress(), onKeyDown(), or
     * onKeyUp(). The <i>m</i> parameter contains the window message that must
     * be processed. Possible values for the <i>m.msg</i> field are WM_CHAR,
     * WM_KEYDOWN, WM_SYSKEYDOWN, WM_KEYUP, WM_SYSKEYUP, and WM_IMECHAR.
     *
     * <p>When overriding processKeyEvent(), a control should return true to
     * indicate that it has processed the key. For keys that aren't processed
     * by the control, the result of "super.processKeyEvent()" should be
     * returned.
     *
     * <p>Controls will seldom, if ever, need to override this method.
     *
     * @param m window message to process.
     * @return true to consume the key, false to allow further processing.
     * @see #onKeyDown
     * @see #onKeyPress
     * @see #onKeyUp
     * @see #processKeyMessage
     */
    protected boolean processKeyEvent(Message m) {}

    /**
     * Processes a key message.  This method is called when a control receives a
     * keyboard message. The method first checks if the control has a parent,
     * and if so calls the parent's processKeyPreview() method. If the parent's
     * processKeyPreview() method doesn't consume the message then
     * processKeyEvent() is called to generate the appropriate keyboard events.
     * The <i>m</i> parameter contains the window message that must be
     * processed. Possible values for the <i>m.msg</i> field are WM_CHAR,
     * WM_KEYDOWN, WM_SYSKEYDOWN, WM_KEYUP, and WM_SYSKEYUP.
     *
     * <p>When overriding processKeyMessage(), a control should return true to
     * indicate that it has processed the key. For keys that aren't processed
     * by the control, the result of "super.processKeyMessage()" should be
     * returned.
     *
     * <p>Controls will seldom, if ever, need to override this method.
     *
     * @param m window message to process.
     * @return true to consume the key, false to allow further processing.
     * @see #processKeyEvent
     * @see #processKeyPreview
     */
    protected boolean processKeyMessage(Message m) {}

    /**
     * Processes key preview messages.  This method is called by a child control
     * when the child control receives a keyboard message. The child control
     * calls this method before generating any keyboard events for the message.
     * If this method returns true, the child control considers the message
     * consumed and does not generate any keyboard events. The <i>m</i>
     * parameter contains the window message to preview. Possible values for
     * the <i>m.msg</i> field are WM_CHAR, WM_KEYDOWN, WM_SYSKEYDOWN, WM_KEYUP,
     * and WM_SYSKEYUP.
     *
     * <p>processKeyPreview() simply sends the character to the parent's
     * processKeyPreview() method, or returns false if the control has no
     * parent. The wfc.ui.Form class overrides this method to perform actual
     * processing of dialog keys.
     *
     * <p>When overriding processKeyPreview(), a control should return true to
     * indicate that it has processed the key. For keys that aren't processed
     * by the control, the result of "super.processKeyEvent()" should be
     * returned.
     *
     * @param m window message to preview.
     * @return true to consume the key, false to allow further processing.
     * @see #processKeyMessage
     */
    protected boolean processKeyPreview(Message m) {}

    /**
     * Processes a mnemonic character.  This method is called to give a control
     * the opportunity to process a mnemonic character. The method should check
     * if the control is in a state to process mnemonics and if the given
     * character represents a mnemonic. If so, the method should perform the
     * action associated with the mnemonic and return true. If not, the method
     * should return false.
     *
     * <p>Implementations of this method often use the isMnemonic() method to
     * check if the given character matches a mnemonic in the control's text,
     * for example:
     * <pre>
     * if (canSelect() && isMnemonic(charCode, getText()) {
     *     // perform action associated with mnemonic
     * }
     * </pre>
     * <p>This default implementation of processMnemonic() simply returns false
     * to indicate that the control has no mnemonic.
     *
     * @param charCode character to test.
     * @return true if mnemonic was processed, false if not.
     * @see #isMnemonic
     * @see wfc.ui.Form#processDialogChar
     */
    protected boolean processMnemonic(char charCode) {}

    /**
     * This method is called by the control when any property changes.  Inheriting
     * controls can overide this method to get property change notification on
     * basic properties. Inherting controls must call <i>super.propertyChanged</i>.
     *
     * @param property Property that changed.
     */
    protected void propertyChanged(int property) {}

    /**
     * Forces the re-creation of the handle for this control.  Inheriting controls
     * must call <i>super.recreateHandle</i>.
     */
    protected synchronized void recreateHandle() {}

    /**
     * Converts the coordinates of a rectangle from screen coordinates to client coordinates. 
     *
     * @param r Screen coordinate rectangle to convert.
     *
     * @return client coordinate rectangle.
     */
    public Rectangle rectToClient(Rectangle r) {}

    /**
     * Converts the coordinates of a rectangle from client coordinates to screen coordinates. 
     *
     * @param r Client coordinate rectangle to convert.
     *
     * @return screen coordinate rectangle.
     */
    public Rectangle rectToScreen(Rectangle r) {}

    /**
     * Reflects the specified message to the control that is bound to the specified handle. 
     *
     * @param hWnd Handle to reflect the message to.
     * @param m Win32 message to reflect
     *
     * @return <b>true</b> if the message was reflected.
     */
    protected final static boolean reflectMessage(int hWnd, Message m) {}

    /**
     * Removes the specified child control from this control.  Inheriting controls should call
     * <i>super.remove</i> to ensure that the control is removed.
     *
     * @param control Control to remove from this control.
     */
    public void remove(Control control) {}

    /**
     * Removes the delegate that is assigned to the click event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnClick
     */
    public void removeOnClick(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the createHandle event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #removeOnCreateHandle
     */
    public final void removeOnCreateHandle(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the destroyHandle event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #removeOnDestroyHandle
     */
    public final void removeOnDestroyHandle(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the doubleClick event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnDoubleClick
     */
    public final void removeOnDoubleClick(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the dragEnter event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnDragEnter
     */
    public final void removeOnDragEnter(DragEventHandler value) {}

    /**Removes the delegate that is assigned to the dragOver event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnDragOver
     */
    public final void removeOnDragOver(DragEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the dragLeave event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnDragLeave
     */
    public final void removeOnDragLeave(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the dragDrop event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnDragDrop
     */
    public final void removeOnDragDrop(DragEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the enter event. 
     * If there are dfinal uplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnEnter
     */
    public final void removeOnEnter(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the giveFeedback event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnGiveFeedback
     */
    public final void removeOnGiveFeedback(GiveFeedbackEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the gotFocus event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnGotFocus
     */
    public final void removeOnGotFocus(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the help event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnHelp
     */
    public final void removeOnHelp(HelpEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the keyDown event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnKeyDown
     */
    public final void removeOnKeyDown(KeyEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the keyPress event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnKeyPress
     */
    public final void removeOnKeyPress(KeyPressEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the keyUp event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnKeyUp
     */
    public final void removeOnKeyUp(KeyEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the layout event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnLeave
     */
    public final void removeOnLayout(LayoutEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the leave event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnLeave
     */
    public final void removeOnLeave(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the lostFocus event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnLostFocus
     */
    public final void removeOnLostFocus(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseDown event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseDown
     */
    public final void removeOnMouseDown(MouseEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseEnter event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseEnter
     */
    public final void removeOnMouseEnter(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseLeave event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseLeave
     */
    public final void removeOnMouseLeave(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseMove event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseMove
     */
    public final void removeOnMouseMove(MouseEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseUp event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseUp
     */
    public final void removeOnMouseUp(MouseEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the mouseWheel event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMouseWheel
     */
    public final void removeOnMouseWheel(MouseEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the move event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnMove
     */
    public final void removeOnMove(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the paint event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnPaint
     */
    public final void removeOnPaint(PaintEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the queryContinueDrag event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnQueryContinueDrag
     */
    public final void removeOnQueryContinueDrag(QueryContinueDragEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the resize event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     * @see #addOnResize
     */
    public final void removeOnResize(EventHandler value) {}

    /**
     * Resets the background color of the control to the parent's background color. 
     */
    public void resetBackColor() {}

    /**
     * Resets the font for the control to the parent's font. 
     */
    public void resetFont() {}

    /**
     * Resets the foreground color of the control to the parent's foreground color. 
     */
    public void resetForeColor() {}

    /**
     * Resumes normal layout logic.  This will force a layout immediately
     * if there are any pending layout requests.
     */
    public final void resumeLayout() {}

    /**
     * Resumes normal layout logic.  If <i>performLayout</i> is set to <b>true</b> then
     * this will force a layout immediately if there are any pending layout requests.
     *
     * @param performLayout Determines if pending layout requests will be executed, or
     *        ignored.
     */
    protected final void resumeLayout(boolean performLayout) {}

    /**
     * Scales the entire control and any child controls. 
     *
     * @param ratio Ratio to scale the control horizontally and vertically.
     */
    public final void scale(float ratio) {}

    /**
     * Scales the entire control and any child controls. 
     *
     * @param dx Ratio to scale the control horizontally.
     * @param dy Ratio to scale the control vertically.
     */
    public final void scale(float dx, float dy) {}

    /**
     * Performs the work of scaling the entire control and any child controls. 
     *
     * @param dx Ratio to scale the control horizontally.
     * @param dy Ratio to scale the control vertically.
     */
    protected void scaleCore(float dx, float dy) {}

    /**
     * Activates this control. 
     */
    public final void select() {}

    
    void select(boolean directed, boolean forward) {}

    /**
     * Selects the control that follows or precedes the specified control in the tab order. 
     *
     * @param ctl Control to start the search at.
     * @param forward Determines if the search is forward or backward in the
     *        tabOrder
     * @param tabStopOnly Determines if only controls with tabStop set to <b>true</b>
     *        will be looked at.
     * @param nested Determines if only direct children of this control are 
     *        considered or if nested children will be looked at.
     * @param wrap Determines if the search will wrap around to the first tabindex if
     *        nothing is hit.
     * 
     * @return <b>true</b> if a control was selected.
     */
    public final boolean selectNextControl(Control ctl, boolean forward, boolean tabStopOnly,
        boolean nested, boolean wrap) {}
    
    
    private boolean selectNextIfFocused() {}

    /**
     * Sends the specified Win32 message to this control. 
     *
     * @param msg Message to send
     * @param wParam wParam to send
     * @param lParam lParam to send
     *
     * @return value returned by the control.
     */
    public final int sendMessage(int msg, int wParam, int lParam) {}

    /**
     * Sends the specified Win32 message to this control. 
     *
     * @param msg Message to send
     * @param wParam wParam to send
     * @param lParam lParam to send
     *
     * @return value returned by the control.
     */
    protected final int sendMessage(int msg, int wParam, Object lParam) {}

    /**
     * Sends the specified Win32 message to this control. 
     *
     * @param msg Message to send
     * @param wParam wParam to send
     * @param lParam lParam to send
     *
     * @return value returned by the control.
     */
    protected final int sendMessage(int msg, Object wParam, Object lParam) {}

    /**
     * Sends this control to the back of the z-order.  */
    public final void sendToBack() {}

    
    final void setAcceptDrops(boolean accept) {}

    /**
     * Sets a boolean value indicating whether this control can accept data that the
     * user drags and drops into it. 
     * 
     * @param allowDrop Set to <b>true</b> if the control is a valid drop target; 
     * otherwise, set to <b>false</b>.
     */
    public final void setAllowDrop(boolean allowDrop) {}

    /**
     * Sets a value indicating which edges of the control are anchored to the edges of its
     * container. 
     * 
     * @param value An integer that represents how a control is docked to the edges
     * of its container.
     * Possible values are constants defined in the 
     * <a HREF="wfc.ui.ControlAnchor.html">ControlAnchor</a> class.
     * 
     * @exception <b>WFCInvalidEnumException</b> thrown if the specified value is not
     * a valid <b>ControlAnchor</b> constant.
     */
    public final void setAnchor(int value) {}

    /**
     * Sets the background color for this control.  
     * 
     * @param value A <a HREF="wfc.ui.Color.html">Color</a> object that represents the 
     * background color for this control. Specifying <b>null</b> for this parameter sets the
     * control's background color to its parent's background color.
     */
    public void setBackColor(Color value) {}

    /**
     * Sets the bounding rectangle for the control. 
     *
     * @param value new bounds of the control.
     */
    public final void setBounds(Rectangle value) {}

    /**
     * Sets the bounding rectangle for the control. 
     *
     * @param x new left of the control.
     * @param y new right of the control.
     * @param width new width of the control.
     * @param height new height of the control.
     */
    public final void setBounds(int x, int y, int width, int height) {}

    /**
     * Performs the work of setting the bounds of this control.  Inheriting
     * classes can overide this function to add size restrictions. Inheriting
     * classes must call <i>super.setBoundsCore</i> to actually cause the bounds
     * of the control to change.
     *
     * @param x new left of the control.
     * @param y new right of the control.
     * @param width new width of the control.
     * @param height new height of the control.
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}

    /**
     * Sets the brush for this control.  
     * 
     * @param br A <a HREF="wfc.ui.Brush.html">Brush</a> object that represents the brush for this control.
     */
    public void setBrush(Brush br) {}

    /**
     * Sets a boolean value indicating whether this control has captured the mouse.  
     * When a control has captured the mouse, it receives mouse input whether or not the cursor
     * is within its borders.
     * 
     * @param value Set to <b>true</b> if this control has captured the mouse; 
     * otherwise, set to <b>false</b>.
     * 
     * @see #getCapture
     */
    public final void setCapture(boolean value) {}

    /**
     * Sets the height and width of the client area of the control. 
     * 
     * @param size  A <a HREF="wfc.ui.Point.html">Point</a> object that contains the dimensions of the client
     * area of the control. The <b>Point.x</b> field holds the client area width; 
     * the <b>Point.y</b> field holds the height.
     */
    public final void setClientSize(Point size) {}

    /**
     * Sets the height and width of the client area of the control. 
     * 
     * @param x An integer that represents the client area width.
     * @param y An integer that represents the client area height.
     */
    public final void setClientSize(int x, int y) {}

    /**
     * Performs the work of setting the size of the client area of the control. 
     * 
     * @param x An integer that represents the client area width.
     * @param y An integer that represents the client area height.
     */
    protected void setClientSizeCore(int x, int y) {}

    /**
     * Sets the shortcut menu (also known as a context menu) associated with this control.  
     * The shortcut menu is the menu that appears when the user right-clicks the control.
     * 
     * @param contextMenu The <a HREF="wfc.ui.ContextMenu.html">ContextMenu</a> object that represents 
     * the shortcut menu that appears when the user right-clicks this control.
     */
    public final void setContextMenu(ContextMenu contextMenu) {}

    /**
     * Sets the zero-based index of the specified child control within the parent's control
     * array.  
     * 
     * @param index The zero-based index of you want this control to have.
     */
    public final void setControlIndex(int value) {}

    /**
     * Sets the array of the child controls contained in this control. 
     * 
     * @param an array of <b>Control</b> objects that represents the child controls 
     * contained in this control. 
     */
    public final void setControls(Control[] value) {}

    /**
     * Sets the cursor that is displayed when the user moves the mouse pointer over this
     * control. 
     * 
     * @param value A <a HREF="wfc.ui.Cursor.html">Cursor</a> that represents the control cursor.
     */
    public final void setCursor(Cursor value) {}

    private void updateDockInfo() {}

    /**
     * Sets a value indicating which edge of its container this control is docked to. 
     * 
     * @param value An integer that represents which edge of its container this control is docked to.
     * Possible values are constants defined in the 
     * <a HREF="wfc.ui.ControlDock.html">ControlDock</a> class.
     * @exception <b>WFCInvalidEnumException</b> thrown if the specified value is not
     * a valid <b>ControlDock</b> constant.
     */
    public void setDock(int value) {}

    /**
     * Sets a boolean value indicating whether this control is enabled. 
     * 
     * @param enabled Set to <b>true</b> to enable the control; 
     * otherwise, set to <b>false</b>.
     */
    public void setEnabled(boolean enabled) {}

    /**
     * Sets the font for this control, which is the font the control uses to draw its text. 
     * 
     * @param enabled Set to <b>true</b> to enable the control; 
     * otherwise, set to <b>false</b>.
     */
    public void setFont(Font value) {}

    /**
     * Sets the current foreground color for this control, which is the color the control uses
     * to draw its text. 
     * 
     * @param value A <a HREF="wfc.ui.Color.html">Color</a> object that represents the color used 
     * to draw text in this control. 
     */
    public void setForeColor(Color value) {}

    
    void setHandle(int value) {}

    /**
     * Sets the height of this control. 
     *
     * @param value new height of this control.
     *
     * @see #setBounds
     */
    public final void setHeight(int value) {}

    /**
     * Sets the distance between the left edge of the control and the left edge of its
     * container's client area. 
     *
     * @param value new left of this control.
     *
     * @see #setBounds
     */
    public final void setLeft(int value) {}

    /**
     * Sets coordinates of the upper-left corner of the control relative to the upper-left
     * corner of its container's client area. 
     *
     * @param x new location of this control.
     * @param y new location of this control.
     *
     * @see #setBounds
     */
    public final void setLocation(int x, int y) {}

    /**
     * Sets coordinates of the upper-left corner of the control relative to the upper-left
     * corner of its container's client area. 
     *
     * @param value new location of this control.
     *
     * @see #setBounds
     */
    public final void setLocation(Point value) {}

    /**
     * Performs the work of setting the array of the child controls contained in this control.
     * 
     * 
     * @param value An array of <b>Control</b> objects that represents the child controls 
     * contained in this control. 
     */
    public void setNewControls(Control[] value) {}

    
    static void checkParentingCycle(Control bottom, Control toFind) {}
    
    /**
     * Sets the parent for this control. 
     * @param value An <b>Control</b> object that represents the control you want to
     * be the parent of this control. Setting this parameter to <b>null</b> removes this control
     * from the child list of its current parent. ???Please check this - I got this from the code??? 
     */
    public final void setParent(Control value) {}

    
    
    void setParentHandle(int value) {}

    /**
     * Sets the region (the elliptical or polygonal area within a window) associated with this
     * control.   This can be used to create an
     * irregular shaped control.
     *
     * @param <i>region</i> A @see Region object corresponding to the desired
     *                      control region, or <b>null</b> to remove any
     *                      existing region.
     */
    public final void setRegion(Region region) {}

    public void setComponentSite(IComponentSite value) {}

    /**
     * Sets the height and width of the control. 
     *
     * @param x new size of this control.
     * @param y new size of this control.
     *
     * @see #setBounds
     */
    public final void setSize(int width, int height) {}

    /**
     * Sets the height and width of the control. 
     *
     * @param value new size of this control.
     *
     * @see #setBounds
     */
    public final void setSize(Point value) {}

    
    final void setState(int flag, boolean value) {}

    protected final void setStyle(int flag, boolean value) {}

    /**
     * Sets the tab order of this control within the parent form.   The index must be between 0 and
     * parent.getControlCount() - 1.  A tab index determines the tabbing
     * order of child controls.
     *
     * @param index   - the index to set the control to.
     */
    public final void setTabIndex(int value) {}

    /**
     * Sets a boolean value indicating whether the user can give the focus to this
     * control using the TAB key. 
     * @param value  Set to <b>true</b> if the user can give the focus to this control using the TAB key; 
     * otherwise, set to <b>false</b>.
     */
    public final void setTabStop(boolean value) {}

    /**
     * Sets the text associated with this control. 
     * @param value  Set to <b>true</b> if the user can give the focus to this control using the TAB key; 
     * otherwise, set to <b>false</b>.
     */
    public void setText(String value) {}

    /**
     * Sets the distance between the top edge of the control and the top edge of its
     * container's client area. 
     *
     * @param value new top of this control.
     *
     * @see #setBounds
     */
    public final void setTop(int value) {}

    /**
     * Sets a boolean value indicating whether this control is a top-level window (a
     * window that has no parent window).  
     * 
     * @param value Set to <b>true</b> if this control is a top-level window; 
     * otherwise, set to <b>false</b>.
     * @exception <b>WFCException</b> thrown if this control has a parent.
     */
    public void setTopLevel(boolean value) {}

    /**
     * Sets a boolean value indicating whether this control is visible. 
     * 
     * @param value  Set to <b>true</b> if the control is visible; 
     * otherwise, set to <b>false</b>.
     */
    public void setVisible(boolean value) {}

    /**
     * Sets the width of this control. 
     *
     * @param value new width of this control.
     *
     * @see #setBounds
     */
    public final void setWidth(int value) {}

    private void setWindowExStyle(int val) {}
    private void setWindowExStyle(int flag, boolean value) {}

    private void setWindowStyle(int val) {}
    private void setWindowStyle(int flag, boolean value) {}


    /**
     * Retrieves a boolean value indicating whether the background color for the
     * control has been explicitly set. 
     *
     * @return <b>true</b> if the backColor should be persisted.
     */
    public boolean shouldPersistBackColor() {}

    /**
     * Retrieves a boolean value indicating whether the background color for the
     * control has been explicitly set. 
     *
     * @return <b>true</b> if the font should be persisted.
     */
    public boolean shouldPersistFont() {}

    /**
     * Retrieves a boolean value indicating whether the background color for the
     * control has been explicitly set. 
     *
     * @return <b>true</b> if the foreColor should be persisted.
     */
    public boolean shouldPersistForeColor() {}

    /**
     * Displays the control by setting the visible property to true.
     *  */
    public final void show() {}

    /**
     * Suspends the layout logic for the control. 
     */
    public final void suspendLayout() {}

    /**
     * Forces the control to paint its update region (regions that have been marked as needing
     * repainting). 
     */
    public final void update() {}

    
    private void updateAnchorInfo() {}

    /**
     * Updates the bounding rectangle of the control based on the handle the control is bound
     * to. 
     */
    protected final void updateBounds() {}

    /**
     * Updates the bounding rectangle of the control based on the handle the control is bound
     * to. 
     */
    protected final void updateBounds(int x, int y, int width, int height) {}

    /**
     * Updates the bounding rectangle of the control based on the handle the control is bound
     * to. 
     */
    protected final void updateBounds(int x, int y, int width, int height, int clientWidth, int clientHeight) {}

    
    private void updateChildControlIndex(Control ctl) {}

    /**
     * Updates this control's position within its parent's z-order. 
     */
    protected final void updateZOrder() {}

    
    private void updateChildZOrder(Control ctl) {}

    
    private void updateRoot() {}

    /**
     * Forces styles to be reapplied to the handle without recreating the handle.  This function will call
     * <i>getCreateParams</i> to get the styles to apply.
     *
     * @see #getCreateParams
     */
    protected final void updateStyles() {}

    
    void updateStylesCore() {}

    
    private void wmCommand(Message m) {}

    
    private void wmContextMenu(Message m) {}

    
    private void wmCreate(Message m) {}

    
    private void wmCtlColor(Message m) {}

    
    private void wmDestroy(Message m) {}

    
    private void wmEraseBkgnd(Message m) {}

    
    private void wmHelp(Message m) {}

    
    private void wmIMEChar(Message m) {}

    
    private void wmInputLangChange(Message m) {}

    
    private void wmInputLangChangeRequest(Message m) {}

    
    private void wmKeyChar(Message m) {}

    
    private void wmKillFocus(Message m) {}

    
    private void wmMenuSelect(Message m) {}

    private MenuItem getMenuItemFromHandleId(int hmenu, int item) {}

    
    private void wmMouseDown(Message m, int button, int clicks) {}

    
    private void wmMouseLeave(Message m) {}

    
    private void hookMouseLeave() {}
    
    
    private void unhookMouseLeave() {}
    
    /**
     * Resets the mouse leave listeners.
     * 
     * @internalonly
     */
    protected final void resetMouseLeave() {}
    
    
    private void wmMouseMove(Message m) {}

    
    private void wmMouseUp(Message m, int button) {}

    
    private void wmMouseWheel(Message m) {}

    
    private void wmMove(Message m) {}
    
    
    private void wmNCDestroy(Message m) {}

    
    private void wmNotify(Message m) {}

    
    private void wmNotifyFormat(Message m) {}

    
    private void wmOwnerDraw(Message m) {}

    
    private void wmPaint(Message m) {}

    
    private void wmParentNotify(Message m) {}

    
    private void wmReflectCtlColor(Message m) {}

    
    private void wmSetCursor(Message m) {}

    
    private void wmSetFocus(Message m) {}

    
    private void wmShowWindow(Message m) {}

    
    private void wmSysColorChange(Message m) {}

    
    private void wmWindowPosChanged(Message m) {}

    /**
     * Base wndProc. All messages are sent to wndProc after getting filtered
     * through the <i>preProcessMessage</i> function. Inheriting controls should
     * call <i>super.wndProc</i> for any messages that they don't handle.
     *
     * @param m Win32 message
     */
    protected void wndProc(Message m) {}


    
    private static class ControlWindow extends Window {
        WeakReference ref;
        Control rootRef;

        ControlWindow(Control control) {}

        public void defWndProc(Message m) {}

        protected void onHandleChange() {}

        protected void wndProc(Message m) {}
    }


    
    private static class DockInfo {
        int mode;
        int x;
        int y;
        int width;
        int height;
    }


    
    private static class AnchorInfo {
        int mode;
        int left;
        int top;
        int right;
        int bottom;
    }


    
    private static final class LayoutCompare implements IComparer {

        static final LayoutCompare INSTANCE = new LayoutCompare();

        public Control lastControl;

        public int compare(Object p, Object q) {}
    }


    
    private static class ThreadMethodEntry {
        public Control   caller;
        public Delegate  method;
        public Object    args[];
        public Object    retVal;
        public Throwable exception;
        public boolean   synchronous;

        public ThreadMethodEntry(Control caller, Delegate method, Object args[], boolean synchronous) {}
    }


    
    private class DropTarget implements IOleDropTarget {
        private IDataObject lastDataObject = null;

        private final DragEvent createDragEvent(IOleDataObject pDataObj, int grfKeyState, POINTL pt, int[] pdwEffect) {}

        public final void OleDragEnter(IOleDataObject pDataObj, int grfKeyState, POINTL pt, int[] pdwEffect) {}
        public final void OleDragOver(int grfKeyState, POINTL pt, int[] pdwEffect) {}
        public final void OleDragLeave() {}
        public final void OleDrop(IOleDataObject pDataObj, int grfKeyState, POINTL pt, int[] pdwEffect) {}
    }


    
    private class DropSource implements IOleDropSource {
        public final void OleQueryContinueDrag(int fEscapePressed, int grfKeyState) {}

        public final void OleGiveFeedback(int dwEffect) {}
    }


    /**
     * Defines the base class used for controls, which are standardized child windows that the  user can manipulate to perform an action or display information. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Component.ClassInfo {
        public static final PropertyInfo allowDrop = new PropertyInfo(
            Control.class, "allowDrop", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("ControlAllowDropDescr")));

        public static final PropertyInfo anchor = new PropertyInfo(
            Control.class, "anchor", int.class,
            CategoryAttribute.Position,
            LocalizableAttribute.YES,
            new ValueEditorAttribute(AnchorEditor.class),
            new DefaultValueAttribute(new Integer(ControlAnchor.TOP | ControlAnchor.LEFT)),
            new DescriptionAttribute(Sys.getString("ControlAnchorDescr")));

        public static final PropertyInfo backColor = new PropertyInfo(
            Control.class, "backColor", Color.class,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DispidAttribute(ActiveX.DISPID_BACKCOLOR),
            new DescriptionAttribute(Sys.getString("ControlBackColorDescr")));

        public static final PropertyInfo bounds = new PropertyInfo(
            Control.class, "bounds", Rectangle.class,
            CategoryAttribute.Position,
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO);

        public static final PropertyInfo contextMenu = new PropertyInfo(
            Control.class, "contextMenu", ContextMenu.class,
            DefaultValueAttribute.NULL,
            new DescriptionAttribute(Sys.getString("ControlContextMenuDescr")));

        public static final PropertyInfo cursor = new PropertyInfo(
            Control.class, "cursor", Cursor.class,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(com.ms.wfc.ui.Cursor.DEFAULT),
            new DescriptionAttribute(Sys.getString("ControlCursorDescr")));

        public static final PropertyInfo dock = new PropertyInfo(
            Control.class, "dock", ControlDock.class,
            CategoryAttribute.Position,
            LocalizableAttribute.YES,
            new ValueEditorAttribute(DockEditor.class),
            new DefaultValueAttribute(new Integer(ControlDock.NONE)),
            new DescriptionAttribute(Sys.getString("ControlDockDescr")));

        public static final PropertyInfo enabled = new PropertyInfo(
            Control.class, "enabled", boolean.class,
            DefaultValueAttribute.TRUE,
            LocalizableAttribute.YES,
            new DispidAttribute(ActiveX.DISPID_ENABLED),
            new DescriptionAttribute(Sys.getString("ControlEnabledDescr")));

        public static final PropertyInfo font = new PropertyInfo(
            Control.class, "font", Font.class,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DispidAttribute(ActiveX.DISPID_FONT),
            new DescriptionAttribute(Sys.getString("ControlFontDescr")));

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.class, "foreColor", Color.class,
            CategoryAttribute.Appearance,
            LocalizableAttribute.YES,
            new DispidAttribute(ActiveX.DISPID_FORECOLOR),
            new DescriptionAttribute(Sys.getString("ControlForeColorDescr")));

        public static final PropertyInfo location = new PropertyInfo(
            Control.class, "location", Point.class,
            CategoryAttribute.Position,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Point(0, 0)),
            new DescriptionAttribute(Sys.getString("ControlLocationDescr")));

        public static final PropertyInfo size = new PropertyInfo(
            Control.class, "size", Point.class,
            CategoryAttribute.Position,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("ControlSizeDescr")));

        public static final PropertyInfo tabIndex = new PropertyInfo(
            Control.class, "tabIndex", int.class,
            CategoryAttribute.Behavior,
            LocalizableAttribute.YES,
            DefaultValueAttribute.NEGATIVE_ONE,
            new DescriptionAttribute(Sys.getString("ControlTabIndexDescr")));

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.class, "tabStop", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DispidAttribute(ActiveX.DISPID_TABSTOP),
            new DescriptionAttribute(Sys.getString("ControlTabStopDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.class, "text", String.class, new MemberAttribute[] {
            CategoryAttribute.Appearance,
            new ValueEditorAttribute(ImmediateStringEditor.class),
            LocalizableAttribute.YES,
            BindableAttribute.YES,
            new DispidAttribute(ActiveX.DISPID_TEXT),
            new DescriptionAttribute(Sys.getString("ControlTextDescr")) } );

        public static final PropertyInfo visible = new PropertyInfo(
            Control.class, "visible", boolean.class,
            CategoryAttribute.Behavior,
            LocalizableAttribute.YES,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("ControlVisibleDescr")));

        public static final EventInfo click = new EventInfo(
            Control.class, "click", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("ControlOnClickDescr")));

        public static final EventInfo doubleClick = new EventInfo(
            Control.class, "doubleClick", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("ControlOnDoubleClickDescr")));

        public static final EventInfo enter = new EventInfo(
            Control.class, "enter", EventHandler.class,
            CategoryAttribute.Focus,
            new DescriptionAttribute(Sys.getString("ControlEnterDescr")));

        public static final EventInfo gotFocus = new EventInfo(
            Control.class, "gotFocus", EventHandler.class,
            BrowsableAttribute.NO,
            CategoryAttribute.Focus,
            new DescriptionAttribute(Sys.getString("ControlGotFocusDescr")));

        public static final EventInfo help = new EventInfo(
            Control.class, "help", HelpEventHandler.class,
            new DescriptionAttribute(Sys.getString("ControlOnHelpDescr")));

        public static final EventInfo keyDown = new EventInfo(
            Control.class, "keyDown", KeyEventHandler.class,
            CategoryAttribute.Key,
            new DescriptionAttribute(Sys.getString("ControlOnKeyDownDescr")));

        public static final EventInfo keyPress = new EventInfo(
            Control.class, "keyPress", KeyPressEventHandler.class,
            CategoryAttribute.Key,
            new DescriptionAttribute(Sys.getString("ControlOnKeyPressDescr")));

        public static final EventInfo keyUp = new EventInfo(
            Control.class, "keyUp", KeyEventHandler.class,
            CategoryAttribute.Key,
            new DescriptionAttribute(Sys.getString("ControlOnKeyUpDescr")));

        public static final EventInfo layout = new EventInfo(
            Control.class, "layout", LayoutEventHandler.class,
            CategoryAttribute.Position,
            new DescriptionAttribute(Sys.getString("ControlLayoutDescr")));

        public static final EventInfo leave = new EventInfo(
            Control.class, "leave", EventHandler.class,
            CategoryAttribute.Focus,
            new DescriptionAttribute(Sys.getString("ControlLeaveDescr")));

        public static final EventInfo lostFocus = new EventInfo(
            Control.class, "lostFocus", EventHandler.class,
            BrowsableAttribute.NO,
            CategoryAttribute.Focus,
            new DescriptionAttribute(Sys.getString("ControlLostFocusDescr")));

        public static final EventInfo mouseDown = new EventInfo(
            Control.class, "mouseDown", MouseEventHandler.class,
            CategoryAttribute.Mouse,
            new DescriptionAttribute(Sys.getString("ControlOnMouseDownDescr")));

        public static final EventInfo mouseEnter = new EventInfo(
            Control.class, "mouseEnter", EventHandler.class,
            CategoryAttribute.Mouse,
            new DescriptionAttribute(Sys.getString("ControlOnMouseEnterDescr")));

        public static final EventInfo mouseLeave = new EventInfo(
            Control.class, "mouseLeave", EventHandler.class,
            CategoryAttribute.Mouse,
            new DescriptionAttribute(Sys.getString("ControlOnMouseLeaveDescr")));

        public static final EventInfo mouseMove = new EventInfo(
            Control.class, "mouseMove", MouseEventHandler.class,
            CategoryAttribute.Mouse,
            new DescriptionAttribute(Sys.getString("ControlOnMouseMoveDescr")));

        public static final EventInfo mouseUp = new EventInfo(
            Control.class, "mouseUp", MouseEventHandler.class,
            CategoryAttribute.Mouse,
            new DescriptionAttribute(Sys.getString("ControlOnMouseUpDescr")));

        public static final EventInfo mouseWheel = new EventInfo(
            Control.class, "mouseWheel", MouseEventHandler.class,
            CategoryAttribute.Mouse,
            BrowsableAttribute.NO,
            new DescriptionAttribute(Sys.getString("ControlOnMouseWheelDescr")));

        public static final EventInfo move = new EventInfo(
            Control.class, "move", EventHandler.class,
            CategoryAttribute.Position,
            new DescriptionAttribute(Sys.getString("ControlOnMoveDescr")));

        public static final EventInfo paint = new EventInfo(
            Control.class, "paint", PaintEventHandler.class,
            new DescriptionAttribute(Sys.getString("ControlOnPaintDescr")));

        public static final EventInfo resize = new EventInfo(
            Control.class, "resize", EventHandler.class,
            CategoryAttribute.Position,
            new DescriptionAttribute(Sys.getString("ControlOnResizeDescr")));

        public static final EventInfo dragEnter = new EventInfo(
            Control.class, "dragEnter", DragEventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnDragEnterDescr")));

        public static final EventInfo dragOver = new EventInfo(
            Control.class, "dragOver", DragEventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnDragOverDescr")));

        public static final EventInfo dragLeave = new EventInfo(
            Control.class, "dragLeave", EventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnDragLeaveDescr")));

        public static final EventInfo dragDrop = new EventInfo(
            Control.class, "dragDrop", DragEventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnDragDropDescr")));

        public static final EventInfo queryContinueDrag = new EventInfo(
            Control.class, "queryContinueDrag", QueryContinueDragEventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnQueryContinueDragDescr")));

        public static final EventInfo giveFeedback = new EventInfo(
            Control.class, "giveFeedback", GiveFeedbackEventHandler.class,
            CategoryAttribute.DragDrop,
            new DescriptionAttribute(Sys.getString("ControlOnGiveFeedbackDescr")));

        public void getAttributes(IAttributes attribs) {}

        public String getDefaultPropertyName() {}

        public String getDefaultEventName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}

        public final void removeFocusEvents(IEvents events) {}

        public final void removeFocusProps(IProperties props) {}

    }
}