//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Defines the constants that identify the coordinate systems that you can associate with  a Graphics object.
 *
 * @security(checkClassLinking=on)
 */
public class CoordinateSystem extends Enum {
   
    /**
     * Specifies that logical units are converted to arbitrary units with arbitrarily scaled
     * axes. Use the @see Graphics#setPageExtent and
     * @see Graphics#setDeviceExtent functions to specify the units, orientation, 
     * and scaling that you want. 
     */
    public static final int ANISOTROPIC = 0;
    
    /**
     * Specifies that each logical unit is converted to 0.001 inch.001 inch. Positive x is to the right; positive 
     * y is up. 
     */
    public static final int HIENGLISH = 1;
    
    /**
     * Specifies that each logical unit is converted to 0.01 millimeter.01 millimeter. Positive x is to the right; 
     * positive y is up. 
     */
    public static final int HIMETRIC = 2;
    
    /**
     * Specifies that logical units are converted to arbitrary units with equally scaled axes;
     * that is, one unit along the x-axis is equal to one unit along the y-axis. 
     * Use the @see Graphics#setPageExtent and @see Graphics#setDeviceExtent 
     * functions to specify the units and the orientation of the axes that you want.
     * Win32 makes adjustments as necessary to ensure the x and y units remain the 
     * same size (for example, if you set the page extent, the device extent will be 
     * adjusted to keep the units isotropic). 
     */
    public static final int ISOTROPIC = 3;
    
    /**
     * Specifies that each logical unit is converted to 0.01 inch.01 inch. Positive x is to the right; positive
     * y is up. 
     */
    public static final int LOENGLISH = 4;
    
    /**
     * Specifies that each logical unit is converted to 0.1 millimeter.1 millimeter. Positive x is to the right; 
     * positive y is up. 
     */
    public static final int LOMETRIC = 5;
    
    /**
     * Specifies that each logical unit is converted to one device pixel. Positive x is to the right; 
     * positive y is down. Because of the left to right, top to botton orientation of
     * this coordinate system, it is called <b>text</b>.  This is the default 
     * coordinate system of a @see Graphics object.
     */
    public static final int TEXT = 6;
    
    /**
     * Specifies that each logical unit is converted to one twentieth of a point (called a twip). Positive x is to the right; 
     * positive y is up. 
     */
    public static final int TWIP = 7;

    private static final int MIN = 0;
    private static final int MAX = 7;

    /**
     * Retrieves a boolean value that indicates whether the specified value
     * is a valid member of this class.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}