//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.util.*;
import com.ms.win32.*;
import com.ms.com.*;

/**
 * Encapsulates a mouse pointer and the operations that you can perform on a cursor.  Different cursor shapes
 * are used as visual queues to inform the user what operation the mouse will
 * have.
 *
 * @security(checkClassLinking=on)
 */
public class Cursor extends Image {
    private static Point cursorSize = null;

    private int     handle = 0;       
    private boolean ownHandle = true;

    /**
     * Specifies the cursor that appears as an application is starting.   It is
     * used to signify that the system is loading information, but the user
     * interface can handle further input.
     */
    public static final Cursor APPSTARTING = new Cursor(win.IDC_APPSTARTING,0);
    
    /**
     * Specifies an arrow cursor.
     */
    public static final Cursor ARROW       = new Cursor(win.IDC_ARROW,0);
    
    /**
     * Specifies a crosshair cursor. 
     */
    public static final Cursor CROSS       = new Cursor(win.IDC_CROSS,0);
    
    /**
     * Specifies the default cursor, which is usually an arrow cursor.  Usually this is an arrow.
     */
    public static final Cursor DEFAULT     = new Cursor(win.IDC_ARROW,0);
    
    /**
     * Specifies an I-beam cursor, which is used to show where the text cursor will appear
     * when the mouse is clicked.  This cursor is used to show where the text caret will be
     * moved to when the mouse is clicked.
     */
    public static final Cursor IBEAM       = new Cursor(win.IDC_IBEAM,0);
    
    /**
     * Specifies a cursor which indicates that a particular region is invalid for a given
     * operation.   This is
     * typically used during drag and drop operations to signify places where
     * a drop is not allowed.
     */
    public static final Cursor NO          = new Cursor(win.IDC_NO,0);
    
    /**
     * Specifies a four-headed sizing cursor, which consists of four joined arrows, which
     * point north, south, east, and west.
     */
    public static final Cursor SIZEALL     = new Cursor(win.IDC_SIZEALL,0);
    
    /**
     * Specifies a two-headed northeast/southwest sizing cursor.
     */
    public static final Cursor SIZENESW    = new Cursor(win.IDC_SIZENESW,0);
    
    /**
     * Specifies a two-headed north/south sizing cursor.
     */
    public static final Cursor SIZENS      = new Cursor(win.IDC_SIZENS,0);
    
    /**
     * Specifies a two-headed northwest/southeast sizing cursor.
     */
    public static final Cursor SIZENWSE    = new Cursor(win.IDC_SIZENWSE,0);
    
    /**
     * Specifies a two-headed west/east sizing cursor.
     */
    public static final Cursor SIZEWE      = new Cursor(win.IDC_SIZEWE,0);
    
    /**
     * Specifies an up arrow, typically used to identify an insertion point.  This is sometimes used to mark an insertion point.
     */
    public static final Cursor UPARROW     = new Cursor(win.IDC_UPARROW,0);
    
    /**
     * Specifies a standard "wait" (or hourglass) cursor.  This is usually displayed when
     * an application is busy and cannot except input.
     */
    public static final Cursor WAIT        = new Cursor(win.IDC_WAIT,0);
    
    /**
     * Specifies a help cursor, which is a combination of an arrow and a question mark.   This cursor is used when context sensitive click help
     * is active.
     */
    public static final Cursor HELP        = new Cursor(win.IDC_HELP,0);
    
    /**
     * Specifies the cursor that appears when the mouse is positioned over a horizontal
     * splitter bar.
     */
    public static final Cursor HSPLIT      = new Cursor(Control.class,"hsplit.cur");
    
    /**
     * Specifies a vertical splitter bar cursor.
     */
    public static final Cursor VSPLIT      = new Cursor(Image.class,"vsplit.cur");

    
    private Cursor(int nResourceId, int hack) {}

    /**
     * Creates a cursor object given a handle.  The cursor object does not
     * claim ownership of the handle; you must free it when you are done.
     * 
     * @param handle The Win32 cursor handle to wrap.
     */
    public Cursor(int handle) {}

    /**
     * Creates a cursor given a file.  The file must be a standard disk based
     * cursor (.cur) file.
     * 
     * @param fileName The cursor file to load.
     */
    public Cursor(String fileName) {}

    /**
     * Creates a cursor object given a resource name and location.
     * 
     * @param type      The class that we will use to locate the resource.
     * @param resource  The resource name.
     */
    public Cursor(Class type, String resource) {}

    /**
     * Creates a cursor object given a data stream.  The stream must contain
     * a cursor file.
     * 
     * @param stream The data stream to load.
     */
    public Cursor(IDataStream stream) {}

    /**
     * Creates a cursor object given a COM stream.  The stream must contain
     * a cursor file.
     * 
     * @param stream The COM stream to load.
     */
    public Cursor(IStream stream) {}

    /**
     * Creates a cursor object given an OLE IPicture object.
     * 
     * @param picture The IPicture object to load the cursor from.
     */
    public Cursor(IPicture picture) {}

    /**
     * Clones the Cursor object and returns a duplicate.  
     * 
     * @return an object that can be casted to an Cursor.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of the Win32 handle for the cursor on which this object is based. When
     * you copy a cursor handle, you own the handle and are responsible for freeing it.  You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 cursor handle.
     */
    public final int copyHandle() {}

    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Frees all the resources allocated by this object.  Once called, the cursor
     * object is no longer useful.
     */
    public void dispose() {}
    
    
    private void drawImageCore(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop, boolean stretch) {}
    
    /**
     * Renders the bitmap image (or part of it) to a Graphics object,
     * cropping the image to fit specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version crops the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to crop to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}
    
    /**
     * Renders the cursor to a Graphics object, stretching the cursor to fill
     * specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version stretches the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to stretch the image to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}

    /**
     * Frees the resources allocated by the Cursor object.
     */
    protected void finalize() {}

    /**
     * Retrieves the current cursor's clipping rectangle in screen coordinates.  A
     * clipped cursor will only be allowed to move within it's rectangle.  Generally,
     * the OS only allows this if the mouse is currently captured.  If the 
     * cursor is not currently clipped, the resulting rectangle contains the
     * dimensions of the entire screen.
     */
    public final static Rectangle getClip() {}

    /**
     * Retrieves the recommended file extension for this object.
     * 
     * @return the recommended file extension, without a prefixing period.
     * @see IPersistable
     */
    public String getExtension() {}

    /**
     * Retrieves the Win32 handle to this cursor.  This is not a copy of the handle; do
     * not free it.
     * 
     * @return the handle to this cursor.
     */
    public int getHandle() {}

    /**
     * Retrieves a PICTDESC (Picture Descriptor) for this cursor. The
     * PICTDESC structure is used by OLE functions to create picture objects.  PICTDESCs are
     * used by OLE.
     * 
     * @return a PICDESC object.
     */
    public final PICTDESC getPICTDESC() {}

    /**
     * Retrieves the screen coordinates for the cursor's current position.
     * 
     * @return the cursor's current position.
     * 
     * @see #setPosition
     */
    public final static Point getPosition() {}

    /**
     * Retrieves the size of the cursor, in pixels.
     * 
     * @return the size of the object, in pixels.
     */
    public final Point getSize() {}

    /**
     * Hides the cursor. For every call to Cursor.hide() there must be a
     * balancing call to Cursor.show().
     * 
     * @see #show
     */
    public final static void hide() {}

    /**
     * Initializes this image for the first time.  This should only be called once.
     * 
     * @param picture The IPicture object to initialize the bitmap with.
     *
     */
    protected void initialize(IPicture picture) {}

    /**
     * Specifies the cursor's clipping rectangle. The cursor is confined to the given
     * rectangular area on the screen. If a subsequent cursor position (set by
     * the setClip() method or the mouse) lies outside the rectangle, Windows
     * automatically adjusts the position to keep the cursor inside the
     * rectangular area.
     *
     * @param r The clipping rectangle. If this parameter is null, the cursor is
     *          free to move anywhere on the screen.
     * 
     * @see #getClip
     */
    public final static void setClip(Rectangle r) {}

    /**
     * Sets the current system cursor as the cursor for this object. */
    public final void setCurrent() {}

    /**
     * Moves the cursor to the specified position (in screen coordinates). If the new
     * coordinates are not within the screen rectangle set by the most recent
     * setClip() call, Windows automatically adjusts the coordinates so that
     * the cursor stays within the rectangle.
     * 
     * @param p The point to move the cursor to.
     * 
     * @see #getPosition
     */
    public final static void setPosition(Point p) {}

    /**
     * Displays the cursor.  For every call to Cursor.show() there must have been
     * a previous call to Cursor.hide().
     * 
     * @see #hide
     */
    public final static void show() {}

    /**
     * Retrieves a string representation of this Cursor object.
     * 
     * @return a string describing the cursor.
     */
    public String toString() {}

    /**
     * Encapsulates a mouse pointer and the operations that you can perform on a cursor.cur)
     * files.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends Image.Editor { 

        IValueAccess iva;
        ListBox lb;
        IEditorHost iehost;

        public Editor() {}

        public void editValue(IValueAccess iva) {}

        private void onListClick(Object sender, Event e) {}

        private void onListDrawItem(Object sender, DrawItemEvent die) {}

        private void onListKeyDown(Object sender, KeyEvent ke) {}

        public String getFileDialogDescription() {}

        public String[] getExtensions() {}

        public Image loadFromStream(IDataStream stream) {}

        public int getStyle() {}
    }
}