//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a Windows edit control, which is a rectangular control that the user can  enter text into.   This control has certain extra bits
 * of functionality, such as those allowing multi-line editing, password
 * character masking, etc.
 *
 * @security(checkClassLinking=on)
 */
public class Edit extends Control {

    
    private boolean autoSize = true;

    
    private boolean hideSelection = true;

    
    private boolean multiline = false;

    
    private boolean readOnly = false;

    
    private boolean acceptsReturn = true;

    
    private boolean acceptsTab = false;

    
    private boolean wordWrap = true;

    
    private char passwordChar;

    
    private int borderStyle = BorderStyle.FIXED_3D;

    
    private int characterCasing = CharacterCasing.NORMAL;

    
    private int maxLength;

    
    int scrollBars = ScrollBars.NONE;

    
    private int textAlign = HorizontalAlignment.LEFT;

    
    private int requestedHeight;

    private boolean creatingHandle = false;
    
    private EventHandler onTextChanged;

    /**
     * Creates a new Edit control.  Uses the parent's current font and color
     * set.
     * Note: If you change this constructor, be sure to change the one below in the
     * exact same way.
     */
    public Edit() {}

    /**
     * Assigns a delegate to the textChanged event.  This
     * event is fired whenever the text value for the edit control changes.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnTextChanged(EventHandler value) {}

    
    private void adjustHeight() {}

    /**
     * Retrieves a boolean value indicating whether the edit control can undo the last
     * operation. 
     */
    public final boolean canUndo() {}

    /**
     * Clears the edit control. 
     */
    public final void clear() {}

    /**
     * Clears information about the most recent operation from the undo buffer of the edit
     * control. 
     */
    public final void clearUndo() {}

    /**
     * Copies the current selection in the edit control to the Clipboard. 
     */
    public final void copy() {}

    /**
     *  @internalonly
     *  @hidden
     */
    protected void createHandle() {}
    
    /**
     * Removes the current selection from the edit control and moves it to the Clipboard. 
     */
    public final void cut() {}

    /**
     * Retrieves a boolean value indicating whether the size of the control
     * automatically adjusts when the font is changed.   If so, then it will
     * adjust it's height to always be just big enough to hold characters
     * of the current font.
     * </p>
     *
     * <p>
     * Note that for multiline edit controls, this property is ignored.
     * </p>
     *
     * @return boolean      <b>true</b> if this control autosizes itself.
     */
    public final boolean getAutoSize() {}

    /**
     * Retrieves a value indicating the kind of border the edit control has. 
     *
     * @return int      the controls border style, taken from the
     *                  com.ms.wfc.ui.BorderStyle enumeration
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final int getBorderStyle() {}

    /**
     * Returns the parameters needed to create the handle.  Inheriting classes
     * can override this to provide extra functionality.  They should not,
     * however, forget to call super.getCreateParams() first to get the struct
     * filled up with the basic info.
     *
     * @return    a CreateParams object with all the info needed to create
     *            the control.
     *
     * @see com.ms.wfc.ui.CreateParams
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a value indicating whether the edit control modifies the case of characters
     * as they are typed into the control.   They can be converted to upper or lower case, or left
     * alone.  The values are obtained from the CharacterCasing Enumeration.
     *
     * @return    a value from the CharacterCasing enumeration
     *
     * @see com.ms.wfc.ui.CharacterCasing
     */
    public final int getCharacterCasing() {}

    /**
     * Retrieves a boolean value indicating whether the selected text in the edit
     * control remains highlighted when the control loses the focus. 
     *
     * @return boolean  <b>true</b> if the control will hide the selection when
     *                  it loses input focus.
     */
    public final boolean getHideSelection() {}

    /**
     * Retrieves the text in the edit control.  Each
     * line of the textbox is returned as a new element in the array.  For
     * Edit controls for which Multiline is false, the array just has one
     * element.
     *
     * @return   an array of String objects, in which each item contains one
     *           line of text from the original Edit text.
     */
    public final String[] getLines() {}

    /**
     * Retrieves the maximum length, in bytes, of the text the user can type into the edit
     * control.  A return value of zero indicates that the maximum capacity
     * of the edit control is limited only available memory.
     *
     * @return      the current maximum amount of allowable text.
     */
    public final int getMaxLength() {}

    /**
     * Retrieves a boolean value indicating whether this is a multiline edit control.   By default, only one line of editing is permitted
     * and ENTER characters are ignored.
     *
     * @return   a boolean whether or not editing of more than
     *           one line is allowed.
     */
    public final boolean getMultiline() {}

    /**
     * Retrieves the character used to mask characters in a single-line edit control used to
     * enter passwords.  A return value of zero indicates that the edit control is not
     * being used to enter passwords.
     *
     * @return      the current password character, or '\0' to indicate there
     *              isn't one.
     */
    public final char getPasswordChar() {}

    /**
     * Retrieves the preferred height for the edit control. 
     *
     * @return      the preferred height of this control, provided it's a
     *              single line edit.
     */
    public final int getPreferredHeight() {}

    /**
     * Retrieves a boolean value indicating whether the edit control is read-only.   If so, the computer will
     * beep whenever the user tries to type into it.
     *
     * @return  a boolean indicating whether or not it's read only
     */
    public final boolean getReadOnly() {}

    /**
     * Retrieves a boolean value indicating whether pressing ENTER in a multiline edit
     * control creates a new line of text in the edit control instead of activating the default
     * button for the form. 
     *
     * @return  <b>true</b> if ENTER keys should be processedy by
     *          this edit control.
     */
    public final boolean getAcceptsReturn() {}

    /**
     * Retrieves a boolean value indicating that pressing TAB in the edit control types
     * a TAB character in the control instead of moving the focus to the next control in the tab
     * order. 
     *
     * @return      <b>true</b> if TAB characters will be processed.
     */
    public final boolean getAcceptsTab() {}

    /**
     * Retrieves a value indicating which scroll bars appear on a multiline edit control. 
     * Possible return values are given by the ScrollBars enumeration.
     *
     * @return  which scrollbars will be visible all the time.
     *
     * @see com.ms.wfc.ui.ScrollBars
     */
    public final int getScrollBars() {}

    /**
     * Retrieves the currently selected text in the edit control. 
     *
     * @return    The currently selected text, or null if there isn't any.
     */
    public final String getSelectedText() {}

    /**
     * Retrieves the zero-based index of the first character after the end of the current text
     * selection in the edit control. 
     *
     * @return  the character index of the end of the current selection.
     */
    public final int getSelectionEnd() {}

    /**
     * Retrieves the zero-based index of the first character in the current text selection in
     * the edit control. 
     *
     * @return  the character index of the start of the current selection.
     */
    public final int getSelectionStart() {}

    /**
     * Retrieves a value indicating how text is aligned in an edit control.   Can be any of the
     * values in the HorizontalAlignment enumeration.
     * NOTE: This is only applicable for multi-line edit controls.
     *
     * @return An Integer with the value for the alignment.
     *
     * @see com.ms.wfc.ui.HorizontalAlignment
     */
    public final int getTextAlign() {}

    /**
     * Retrieves a boolean value indicating whether a multiline edit control
     * automatically wraps words to the beginning of the next line when necessary.   If this property is <b>false</b>, then
     * a horizontal scrollbar will be shown and text will be allowed to
     * continue to scroll.
     *
     * @return      <b>true</b> if lines that are too long will wrap.
     */
    public final boolean getWordWrap() {}

    /**
     * Overridden to handle RETURN and TAB keys.
     */
    protected boolean isInputKey(int keyData) {}

    /**
     * Overridden to update the newly created handle with the settings of the
     * MaxLength and PasswordChar properties.
     */
    protected void onCreateHandle(Event e) {}

    /**
     * @internalonly
     */
    protected void onDestroyHandle(Event e) {}

    /**
     * Triggers the textChanged event. 
     * Inheriting controls should use this in favour of actually listening to
     * the event, but should not forget to call super.onTextChanged() to
     * ensure that the event is still fired for external listeners.
     *
     * @param   e       Event to send
     */
    protected void onTextChanged(Event e) {}

    /**
     * Replaces the current selection in the edit control with the contents of the Clipboard. 
     */
    public final void paste() {}

    /**
     * Overridden to adjust the height of the edit control when the font
     * changes.
     */
    protected void propertyChanged(int property) {}

    /**
     * Removes the delegate that is assigned to the textChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnTextChanged(EventHandler value) {}

    /**
     * Selects a range of text in the edit control. 
     *
     * @param start     Character index of the start of the selection.
     * @param end       Character index of the end of the selection.
     */
    public final void select(int start, int end) {}

    /**
     * Selects all the text in the edit control. 
     */
    public final void selectAll() {}

    /**
     * Sets a boolean value indicating whether pressing ENTER in a multiline edit
     * control creates a new line of text in the edit control instead of activating the default
     * button for the form. 
     *
     * @param value         <b>true</b> if the ENTER key should be processed.
     */
    public final void setAcceptsReturn(boolean value) {}

    /**
     * Sets a boolean value indicating that pressing TAB in the edit control types a
     * TAB character in the control instead of moving the focus to the next control in the tab
     * order. 
     *
     * @param value         <b>true</b> if the TAB key should be procssed.
     */
    public final void setAcceptsTab(boolean value) {}

    /**
     * Sets a boolean value indicating whether the size of the control automatically
     * adjusts when the font is changed.   Note that this
     * is only applicable to single-line edit controls.
     *
     * @param value     <b>true</b> if the control should size itself.
     */
    public final void setAutoSize(boolean value) {}

    /**
     * Sets a value indicating the kind of border the edit control has.  Values should be taken
     * from the com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @param value     The new BorderStyle for this edit control.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final void setBorderStyle(int value) {}

    /**
     * Overrides Control.setBoundsCore to enforce autoSize.
     * @internalonly
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}

    /**
     * Sets a value indicating whether the edit control modifies the case of characters as
     * they are typed into the control.   They can be converted to upper or lower case, or left
     * alone.  The values are obtained from the CharacterCasing Enumeration.
     *
     * @param value     New value indicating how characters should be handled.
     *
     * @see com.ms.wfc.ui.CharacterCasing
     */
    public final void setCharacterCasing(int value) {}

    /**
     * Sets a boolean value indicating whether the selected text in the edit control
     * remains highlighted when the control loses the focus. 
     *
     * @param value     <b>true</b> if the selection should be hidden when we
     *                  lose focus.
     */
    public final void setHideSelection(boolean value) {}

    /**
     * Sets the text in the edit control.   Each element of the array is considered to be a separate
     * "line" of text, and newlines are inserted between the rows for display
     * in the Edit control.
     *
     * @param String[]      Array of Strings to display in the Edit control.
     */
    public final void setLines(String[] lines) {}

    /**
     * Sets the maximum length, in bytes, of the text the user can type into the edit control.
     *  A value of zero or less indicates that the edit control's capacity
     * should be limited only by available memory.
     *
     * @param value     The new maximum length for text in this edit control.
     */
    public final void setMaxLength(int value) {}

    /**
     * Sets a boolean value indicating whether this is a multiline edit control.   By default, only one line of editing is permitted
     * and ENTER characters are ignored.
     *
     * @param value boolean value indicating if editing on more than one line
     *              should be permitted.
     */
    public final void setMultiline(boolean value) {}

    /**
     * Sets the character used to mask characters in a single-line edit control used to enter
     * passwords.  A non-zero
     * value causes all characters in the edit control to be displayed as the
     * given password character. A zero value causes the edit control to
     * function normally.
     *
     * @param value     The new password character for this edit control.
     */
    public final void setPasswordChar(char value) {}

    /**
     * Sets a boolean value indicating whether the edit control is read-only.   If so, all user
     * input is ignored.
     *
     * @param value     <b>true</b> if this control should be read-only.
     */
    public final void setReadOnly(boolean value) {}

    /**
     * Sets a value indicating which scroll bars appear in a multiline edit control.   The values are taken from the
     * @see ScrollBars enumeration.
     *
     * @param value     Which scrollbars should be shown.
     *
     * @see com.ms.wfc.ui.ScrollBars
     */
    public final void setScrollBars(int value) {}

    /**
     * Replaces the currently selected text in the edit control with the specified text. 
     *
     * @param value     The new text to place where the current selection
     *                  is.
     */
    public final void setSelectedText(String value) {}

    /**
     * Sets the end position of the text selection in the edit control. 
     *
     * @param value     Index at which to stop selecting.
     */
    public final void setSelectionEnd(int value) {}

    /**
     * Sets the starting position of the text selection in the edit control. 
     *
     * @param value     Index at which to start selecting.
     */
    public final void setSelectionStart(int value) {}

    /**
     * Sets a value indicating how text is aligned in an edit control.   Can be any of the
     * values in the HorizontalAlignment enumeration.
     * NOTE: This is only applicable for multi-line edit controls.
     *
     * @param value The new alignment of the text
     *
     * @see com.ms.wfc.ui.HorizontalAlignment
     */
    public void setTextAlign(int value) {}

    /**
     * Sets a boolean value indicating whether a multiline edit control automatically
     * wraps words to the beginning of the next line when necessary. 
     *
     * @param value     true means we should wrap, false means continue.
     */
    public final void setWordWrap(boolean value) {}

    
    void setWordWrapInternal(boolean value) {}

    /**
     * Undoes the last operation in the edit control if the canUndo
     * property is set to true. 
     */
    public final void undo() {}

    /**
     * Retrieves a string that contains information about the edit control. 
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void wmReflectCommand(Message m) {}

    
    private void wmSetFont(Message m) {}

    /**
     * The edits window procedure.  Inheritng classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the combo continues to function properly.
     *
     * @param m     A Windows Message Object.
     */
    protected void wndProc(Message m) {}


    
    
    
    
    protected final void setSelectionRange(int start, int end) {}
    
    protected final int[] getSelectionRange() {}

    protected boolean getIsWndProcAnsi() {}

    
    
    
    private static native boolean IsDBCSLeadByte(byte ch);
    
    private static native int KernelCharNext(int ch);
    
    private static native int UserCharNext(int ch);
    
    private static native boolean IsWindowUnicode(int hwnd);
    
    private static native int WideCharToMultiByte(int acp, int p2, String src, int srclen, int dest, int destlen, int param7, int param8);
    
    private static native int lstrlen(String s);
    private static int CP_ACP = 0;
    private static int CP_THREAD_ACP = 3;

    private static boolean useUserCharNext = false;
    
    private static int CharNext(int ch) {}
    
    private static final int stringToHGlobalAnsi(String s, int byteLen) {}
    
    protected static final int[] getByteLocOfCharLoc(int charLoc1, int charLoc2, String s) {}
    
    protected static final int[] getCharLocOfByteLoc(int byteLoc1, int byteLoc2, String s) {}
    
    private static final int getAnsiStringByteLength(String s) {}
    
    private static final int getEmbededNullStringLengthAnsi(String s) {}
    
    
    
    
    
    /**
     * Encapsulates a Windows edit control, which is a rectangular control that the user can  enter text into. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo acceptsReturn = new PropertyInfo(
            Edit.class, "acceptsReturn", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("EditAcceptsReturnDescr")));

        public static final PropertyInfo acceptsTab = new PropertyInfo(
            Edit.class, "acceptsTab", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("EditAcceptsTabDescr")));

        public static final PropertyInfo autoSize = new PropertyInfo(
            Edit.class, "autoSize", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("EditAutoSizeDescr")));

        public static final PropertyInfo backColor = new PropertyInfo(
            com.ms.wfc.ui.Control.ClassInfo.backColor,
            DefaultValueAttribute.COLOR_WINDOW);

        public static final PropertyInfo borderStyle = new PropertyInfo(
            Edit.class, "borderStyle", com.ms.wfc.ui.BorderStyle.class,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.BorderStyle.FIXED_3D)),
            new DescriptionAttribute(Sys.getString("EditBorderDescr")));

        public static final PropertyInfo characterCasing = new PropertyInfo(
            Edit.class, "characterCasing", com.ms.wfc.ui.CharacterCasing.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.CharacterCasing.NORMAL)),
            new DescriptionAttribute(Sys.getString("EditCharacterCasingDescr")));

        public static final PropertyInfo cursor = new PropertyInfo(
            com.ms.wfc.ui.Control.ClassInfo.cursor,
            new DefaultValueAttribute(com.ms.wfc.ui.Cursor.IBEAM));

        public static final PropertyInfo hideSelection = new PropertyInfo(
            Edit.class, "hideSelection", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("EditHideSelectionDescr")));

        public static final PropertyInfo lines = new PropertyInfo(
            Edit.class, "lines", String[].class,
            CategoryAttribute.Appearance,
            PersistableAttribute.NO,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("EditLinesDescr")),
            new ValueEditorAttribute(com.ms.wfc.core.StringListEditor.class));

        public static final PropertyInfo maxLength = new PropertyInfo(
            Edit.class, "maxLength", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("EditMaxLengthDescr")));

        public static final PropertyInfo multiline = new PropertyInfo(
            Edit.class, "multiline", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("EditMultilineDescr")));

        public static final PropertyInfo passwordChar = new PropertyInfo(
            Edit.class, "passwordChar", Character.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Character((char)0)),
            new DescriptionAttribute(Sys.getString("EditPasswordCharDescr")));

        public static final PropertyInfo readOnly = new PropertyInfo(
            Edit.class, "readOnly", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("EditReadOnlyDescr")));

        public static final PropertyInfo scrollBars = new PropertyInfo(
            Edit.class, "scrollBars", com.ms.wfc.ui.ScrollBars.class,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.ScrollBars.NONE)),
            new DescriptionAttribute(Sys.getString("EditScrollBarsDescr")));

        public static final PropertyInfo textAlign = new PropertyInfo(
            Edit.class,"textAlign", HorizontalAlignment.class,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(HorizontalAlignment.LEFT)),
            new DescriptionAttribute(Sys.getString("EditTextAlignDescr")));

        public static final PropertyInfo wordWrap = new PropertyInfo(
            Edit.class, "wordWrap", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("EditWordWrapDescr")));

        public static final EventInfo textChanged = new EventInfo(
            Edit.class,"textChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("textChangedEventDescr")));

        
        
        
        
        
        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public String getDefaultEventName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}