//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.app.*;
import com.ms.wfc.io.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * Defines the base class for the OpenFileDialog  and SaveFileDialog classes. 
 *
 * Common usage:
 *
 * <pre>
 * FileDialog fd = new FileDialog();
 * // set up filters, default extensions, etc .
 * int didUserHitOK = fd.showDialog();
 * if (didUserHitOK == DialogResult.OK) {
 *      String s = fd.getFileName();
 *      -OR-
 *      String [] rg = fd.getFileNames();
 * }
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public abstract class FileDialog extends CommonDialog {

    private static final int FILEBUFSIZE = 8192;

    private static final Object EVENT_FILEOK = new Object();

    private static final int OPTION_ADDEXTENSION = 0x80000000;

    protected int options;

    private String title;
    private String initialDir;
    private String defaultExt;
    private String[] fileNames;
    private String filter;
    private int filterIndex;
    private CharBuffer charBuffer;
    private int dialogHWnd;

    /**
     * Constructs a new FileDialog.
     */
    protected FileDialog() {}

    /**
     * Assigns a delegate to the fileOk event.  This event is
     * fired when the user presses the "Open" or "Save" button of the file
     * dialog. An event handler can prevent a file dialog box from closing by
     * setting the "cancel" field of the event object to true.
     *
     * @param value     The new event handler.
     *
     * @see #onFileOk
     * @see #removeOnFileOk
     */
    public final void addOnFileOk(CancelEventHandler value) {}

    
    private boolean doFileOk(int lpOFN) {}

    /**
     * Retrieves a boolean value indicating whether the dialog box automatically adds
     * an extension to a file name when the user omits the extension. 
     *
     * @return  <b>true</b> if the extension will be added to the filename
     *          whenever the user does not do so.
     *
     * @see #setAddExtension
     */
    public final boolean getAddExtension() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box should display a
     * warning if the user specifies a file name that does not exist. 
     *
     * @return <b>true</b> if the dialog will refuse to let the user open a
     *          non-existant file.
     *
     * @see #setCheckFileExists
     */
    public final boolean getCheckFileExists() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box should display a
     * warning if the user specifies a path that does not exist. 
     *
     * @return <b>true</b> if the dialog will only let the user work
     *         with existing paths.
     *
     * @see #setCheckPathExists
     */
    public final boolean getCheckPathExists() {}

    /**
     * Retrieves the default file extension.   This will not contain
     * a '.' character.
     *
     * @see #setDefaultExt
     */
    public final String getDefaultExt() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box returns the path and
     * file name of the file referenced by the a shortcut or whether it returns the path and file
     * name of the shortcut (.LNK) file. 
     *
     * @return <b>true</b> if they will.
     *
     * @see #setDereferenceLinks
     */
    public final boolean getDereferenceLinks() {}

    /**
     * Retrieves the file name of the selected file.  If multiple files are
     * selected, the return value is the first filename in the list. If no
     * file is selected, the return value is an empty string.
     *
     * @see #getFileNames
     * @see #setFileName
     */
    public final String getFileName() {}

    /**
     * Retrieves the file names of all selected files in the dialog box.  If no files
     * are selected, the return value is an empty array.
     *
     * @see #getFileName
     * @see #setFileNames
     */
    public final String[] getFileNames() {}

    /**
     * Retrieves the current filter string (the string that determines the choices that appear
     * in the Save as file type or Files of type box in the dialog box and allow
     * the user to filter out the kinds of files that are shown in the dialog box). 
     *
     * @see #setFilter
     */
    public final String getFilter() {}

    
    private String[] getFilterExtensions() {}

    /**
     * Retrieves a value indicating the one-based index of the filter currently selected in
     * the dialog box. 
     *
     * @see #setFilterIndex
     */
    public final int getFilterIndex() {}

    /**
     * Retrieves the path for the directory whose contents are initially displayed in the
     * dialog box.   This is the
     * directory that the dialog will display files for when first brought
     * up.
     *
     * @see #setInitialDir
     */
    public final String getInitialDir() {}

    /**
     * @internalonly
     */
    protected int getInstance() {}

    
    private String[] getMultiselectFiles(CharBuffer charBuffer) {}

    
    final boolean getOption(int option) {}

    /**
     * @internalonly
     */
    protected int getOptions() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box restores the current
     * directory before closing. 
     *
     * @see #setRestoreDirectory
     */
    public final boolean getRestoreDirectory() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box contains a Help
     * button. 
     *
     * @see #setRestoreDirectory
     */
    public final boolean getShowHelp() {}

    /**
     * Retrieves the text that appears in the title bar of the dialog box. 
     *
     * @see #setTitle
     */
    public final String getTitle() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box accepts only valid
     * Win32 file names.   If so, then the
     * dialog will make sure that filenames entered are valid win32 filenames.
     *
     * @see #setValidateNames
     */
    public final boolean getValidateNames() {}

    /**
     * Common dialog hook procedure. Subclasses can override this method to
     * handle additional notifications.
     */
    protected int hookProc(int hWnd, int msg, int wParam, int lParam) {}

    
    private static String makeFilterString(String s) {}

    /**
     * Triggers the fileOk event. 
     * Subclasses can override this method to handle the event. Setting the
     * "cancel" field of the event object to true prevents the dialog from
     * closing.
     */
    protected void onFileOk(CancelEvent e) {}

    
    private boolean processFileNames() {}

    /**
     * Prompts the user when a file is about to be created.  This method is
     * invoked when the "createPrompt" property is true and the specified file
     * does not exist. A return value of false prevents the dialog from
     * closing.
     *
     * @see #setCreatePrompt
     */
    protected boolean promptFileCreate(String fileName) {}

    /**
     * Prompts the user when a file does not exist.  This method is invoked
     * when the "checkFileExists" property is true and the specified file
     * does not exist.
     *
     * @see #setCheckFileExists
     */
    protected void promptFileNotFound(String fileName) {}

    /**
     * Prompts the user when a file is about to be overwritten.  This method is
     * invoked when the "overwritePrompt" property is true and the specified
     * file already exists. A return value of false prevents the dialog from
     * closing.
     *
     * @see #setOverwritePrompt
     */
    protected boolean promptFileOverwrite(String fileName) {}

    /**
     * Removes the delegate that is assigned to the fileOk event. 
     *
     * @see #addOnFileOk
     * @see #onFileOk
     */
    public final void removeOnFileOk(CancelEventHandler value) {}

    /**
     * Resets all dialog box options to their default values. 
     */
    public void reset() {}

    /**
     * Implements running of a file dialog.
     * @internalonly
     */
    protected boolean runDialog(int hwndOwner, int hookProcPtr) {}

    
    abstract boolean runFileDialog(OPENFILENAME_I ofn);

    /**
     * Sets a boolean value indicating whether the dialog box automatically adds an
     * extension to a file name when the user omits the extension.  When
     * this property is true, the dialog automatically adds extensions when the
     * user omits them. The extension added to a filename depends on the
     * currently selected file filter and the value of the "checkFileExists"
     * property. If "checkFileExists" is true, the file dialog adds the first
     * extension from the current file filter that matches an existing file, or
     * the extension given by the "defaultExt" property if no files match the
     * current file filter. If "checkFileExists" is false, the file dialog adds
     * the first valid file extension from the current file filter, or the
     * extension given by the "defaultExt" property if the current file filter
     * contains no valid file extensions.<p>
     *
     * The default value of this property is true.
     *
     * @see #getAddExtension
     * @see #setCheckFileExists
     * @see #setDefaultExt
     */
    public final void setAddExtension(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box should display a warning
     * if the user specifies a file name that does not exist.  If this property is true and the user enters an invalid
     * name, the file dialog displays a warning in a message box.<p>
     *
     * The default value of this property is true for an OpenFileDialog and
     * false for a SaveFileDialog.
     *
     * @see #getCheckFileExists
     * @see #promptFileNotFound
     */
    public final void setCheckFileExists(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box should display a warning
     * if the user specifies a path that does not exist.  If this property is true and the user types an invalid path
     * in the File Name entry field, the file dialog displays a warning in a
     * message box.<p>
     *
     * The default value of this property is true.
     *
     * @see #getCheckPathExists
     */
    public final void setCheckPathExists(boolean value) {}

    /**
     * Sets the default file extension, which is appended to a file name if the user fails to
     * type an extension.  When the "addExtension" property is true,
     * the file dialog automatically appends extensions when the user omits
     * them. For further details, see the "setAddExtension" method.<p>
     *
     * The default value of this property is an empty string.
     *
     * @see #getDefaultExt
     * @see #setAddExtension
     */
    public final void setDefaultExt(String value) {}

    /**
     * Sets a boolean value indicating whether the dialog box returns the path and file
     * name of the file referenced by the a shortcut or whether it returns the path and file name
     * of the shortcut (.LNK) file. LNK files) are dereferenced or not. When
     * this property is true, the dialog box returns the path and filename of
     * the file referenced by a shortcut. When this property is false, the
     * dialog box returns the shortcut itself.<p>
     *
     * The default value of this property is true.
     *
     * @see #getDereferenceLinks
     */
    public final void setDereferenceLinks(boolean value) {}

    /**
     * Sets a value that indicates which file name is selected by default when the dialog box
     * is opened. 
     *
     * @see #getFilename
     */
    public final void setFileName(String value) {}

    /**
     * Sets the current filter string (the string that determines the choices that appear in
     * the Save as file type or Files of type box in the dialog box and allow the
     * user to filter out the kinds of files that are shown in the dialog box).  The filter string must consist of
     * a number of filter pairs, separated by "|" characters. The first string in
     * each pair is a display string that describes the filter (for example,
     * "Text files"), and the second string specifies the filter pattern (for
     * example, "*.txt"). To specify multiple filter patterns for a single
     * display string, use a semicolon to separate the patterns (for example,
     * "*.txt;*.doc;*.bak"). A pattern string can be a combination of valid
     * filename characters and the asterisk (*) wildcard character. Do not
     * include spaces in the pattern string. The following is an example of a
     * filter string:
     *
     *   "Java files (*.java)|*.java|All files (*.*)|*.*"
     *
     * The file dialog does not change the order of the filters. It displays them
     * in the File Types combo box in the order specified by setFilter().
     *
     * @see #getFilter
     * @see #setFilterIndex
     */
    public final void setFilter(String value) {}

    /**
     * Sets a value representing the one-based index of the filter that is selected by default
     * when the dialog box is opened.  The first pair of filter strings has an
     * index value of 1, the second pair 2, and so on. You can specify an index
     * on input to indicate the initial filter description and filter pattern
     * for the dialog box. When the file dialog returns, getFilterIndex() returns
     * the index of the currently displayed filter.
     *
     * @see #getFilterIndex
     * @see #setFilter
     */
    public final void setFilterIndex(int value) {}

    /**
     * Sets the path for the directory whose contents are initially displayed in the dialog
     * box.  If the specified directory is an
     * empty string, the system uses the current directory as the initial
     * directory.
     *
     * @see #getInitialDir
     */
    public final void setInitialDir(String value) {}

    
    final void setOption(int option, boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box restores the current
     * directory before closing. <p>
     *
     * The default value of this property is false.
     *
     * @see #getRestoreDirectory
     */
    public final void setRestoreDirectory(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box contains a Help
     * button.  An
     * "onHelp" event is fired when the user clicks the "Help" button.<p>
     *
     * The default value of this property is false.
     *
     * @see #getShowHelp
     * @see #onHelp
     */
    public final void setShowHelp(boolean value) {}

    /**
     * Sets the text that appears in the title bar of the dialog box.  The given string is placed in the title bar
     * of the dialog box. If specified title is an empty string, the system uses
     * the default title (that is, "Save As" or "Open").
     *
     * @see #getTitle
     */
    public final void setTitle(String value) {}

    /**
     * Sets a boolean value indicating whether the dialog box accepts only valid Win32
     * file names.  If the edit control contains anything but spaces when
     * the user clicks OK, the dialog returns the filename, whether it is valid
     * or not. No default extension is added to the text.<p>
     *
     * The default value of this property is false.
     *
     * @see #getValidateNames
     */
    public final void setValidateNames(boolean value) {}

    
    private int showMessage(String message, int flags) {}

    /**
     * Returns a String version of this object.
     * @internalonly
     * @hidden
     */
    public String toString() {}

    
    static abstract class CharBuffer {
        static CharBuffer createBuffer(int size) {}

        abstract int allocCoTaskMem();
        abstract String getString();
        abstract void putCoTaskMem(int ptr);
        abstract void putString(String s);
    }

    
    static class AnsiBuffer extends CharBuffer {
        byte[] buffer;
        int offset;

        AnsiBuffer(int size) {}

        int allocCoTaskMem() {}

        String getString() {}

        void putCoTaskMem(int ptr) {}

        void putString(String s) {}
    }

    
    static class UnicodeBuffer extends CharBuffer {
        char[] buffer;
        int offset;

        UnicodeBuffer(int size) {}

        int allocCoTaskMem() {}

        public String getString() {}

        void putCoTaskMem(int ptr) {}

        public void putString(String s) {}
    }

    /**
     * Defines the base class for the OpenFileDialog  and SaveFileDialog classes. 
     *
     * @see com.ms.wfc.core.ClassInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends CommonDialog.ClassInfo {
        public static final PropertyInfo addExtension = new PropertyInfo(
            FileDialog.class, "addExtension", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FDaddExtensionDescr")));

        public static final PropertyInfo checkFileExists = new PropertyInfo(
            FileDialog.class, "checkFileExists", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FDcheckFileExistsDescr")));

        public static final PropertyInfo checkPathExists = new PropertyInfo(
            FileDialog.class, "checkPathExists", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FDcheckPathExistsDescr")));

        public static final PropertyInfo defaultExt = new PropertyInfo(
            FileDialog.class, "defaultExt", String.class,
            DefaultValueAttribute.EMPTY_STRING,
            new DescriptionAttribute(Sys.getString("FDdefaultExtDescr")));

        public static final PropertyInfo dereferenceLinks = new PropertyInfo(
            FileDialog.class, "dereferenceLinks", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FDdereferenceLinksDescr")));

        public static final PropertyInfo fileName = new PropertyInfo(
            FileDialog.class, "fileName", String.class,
            DefaultValueAttribute.EMPTY_STRING,
            new DescriptionAttribute(Sys.getString("FDfileNameDescr")));

        public static final PropertyInfo filter = new PropertyInfo(
            FileDialog.class, "filter", String.class,
            DefaultValueAttribute.EMPTY_STRING,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("FDfilterDescr")));

        public static final PropertyInfo filterIndex = new PropertyInfo(
            FileDialog.class, "filterIndex", Integer.TYPE,
            DefaultValueAttribute.ONE,
            new DescriptionAttribute(Sys.getString("FDfilterIndexDescr")));

        public static final PropertyInfo initialDir = new PropertyInfo(
            FileDialog.class, "initialDir", String.class,
            DefaultValueAttribute.EMPTY_STRING,
            new DescriptionAttribute(Sys.getString("FDinitialDirDescr")));

        public static final PropertyInfo restoreDirectory = new PropertyInfo(
            FileDialog.class, "restoreDirectory", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FDrestoreDirectoryDescr")));

        public static final PropertyInfo showHelp = new PropertyInfo(
            FileDialog.class, "showHelp", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FDshowHelpDescr")));

        public static final PropertyInfo title = new PropertyInfo(
            FileDialog.class, "title", String.class,
            DefaultValueAttribute.EMPTY_STRING,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("FDtitleDescr")));

        public static final PropertyInfo validateNames = new PropertyInfo(
            FileDialog.class, "validateNames", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FDvalidateNamesDescr")));

        public static final EventInfo fileOk = new EventInfo(
            FileDialog.class, "fileOk", CancelEventHandler.class,
            new DescriptionAttribute(Sys.getString("FDfileOkDescr")));

        public void getAttributes(IAttributes attrs) {}

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}