//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Encapsulates a Win32 font, which is used to draw text on video displays and other  output devices.  Fonts are used to draw text on video displays
 * and other output devices.  Windows provides a rich set of font capabilities.
 *
 * @security(checkClassLinking=on)
 */
public class Font implements IConstructable, IPersistable {

    /**
     * Represents a standard ANSI fixed-width font.
     */
    public static final Font ANSI_FIXED = Font.createStock(win.ANSI_FIXED_FONT);

    /**
     * Represents a standard ANSI variable-width font.
     */
    public static final Font ANSI_VAR = Font.createStock(win.ANSI_VAR_FONT);

    /**
     * Represents the default font for the current graphical user interface.  This font will automatically
     * adapt its character set to the correct locale of the user.
     */
    public static final Font DEFAULT_GUI = Font.createStock(win.DEFAULT_GUI_FONT);

    /**
     * Represents the standard font for the current graphics device.
     */
    public static final Font DEVICE_DEFAULT = Font.createStock(win.DEVICE_DEFAULT_FONT);

    /**
     * Represents the standard original equipment manufacturer (OEM) fixed font.
     */
    public static final Font OEM_FIXED = Font.createStock(win.OEM_FIXED_FONT);

    /**
     * Represents the standard Windows variable-width system font.
     */
    public static final Font SYSTEM = Font.createStock(win.SYSTEM_FONT);

    /**
     * Represents the standard Windows fixed-width system font.
     */
    public static final Font SYSTEM_FIXED = Font.createStock(win.SYSTEM_FIXED_FONT);

    FontEntry entry;

    
    private Font() {}

    /**
     * Creates a Font object based on an existing Win32 font handle.  The handle
     * is not owned by this object.
     *
     * @param handle    The handle of the font.
     */
    public Font(int handle) {}

    /**
     * Creates a new font given a font face name and a size in points.
     *
     * @param name      The face name of the font to create.
     * @param size      The size of the font in points.
     */
    public Font(String name, float size) {}

    /**
     * Creates a new font given a font face name and a size.
     *
     * @param name      The face name of the font to create.
     * @param size      The size of the font in points.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     *
     * @see FontSize
     */
    public Font(String name, float size, int units) {}

    /**
     * Creates a new font given a font face, size, and style.
     *
     * @param name      The face name of the font to create.
     * @param size      The size of the font.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     * @param weight    The weight of the font.  This must be one of the
     *                  FontWeight enum values.
     * @param italic    <b>True</b> if the font is to be in italic,
     *                  <b>false</b> if not.
     * @param underline <b>True</b> if the font is to be in underline,
     *                  <b>false</b> if not.
     * @param strikeOut <b>True</b> if the font is to be in strike out,
     *                  <b>false</b> if not.
     *
     * @see FontSize
     * @see FontWeight
     */
    public Font(String name, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut) {}

    /**
     * Creates a new font.
     *
     * @param name          The face name of the font to create.
     * @param size          The size of the font.
     * @param units         The units the size of the font is specified in.  This must
     *                      be one of the FontSize enum values.
     * @param weight        The weight of the font.  This must be one of the
     *                      FontWeight enum values.
     * @param italic        <b>True</b> if the font is to be in italic,
     *                      <b>false</b> if not.
     * @param underline     <b>True</b> if the font is to be in underline,
     *                      <b>false</b> if not.
     * @param strikeOut     <b>True</b> if the font is to be in strike out,
     *                      <b>false</b> if not.
     * @param charSet       The caracter set of the font.  This must be one of the
     *                      com.ms.wfc.app.CharacterSet enum values.
     * @param orientation   Orientation of the font.  This is the angle, in tenths
     *                      of a degree, between a character's baseline and the
     *                      X-axis of a device.
     *
     * @see FontSize
     * @see FontWeight
     * @see com.ms.wfc.app.CharacterSet
     */
    public Font(String name, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut, int charSet, int orientation) {}

    /**
     * Creates a new font from an existing one.
     *
     * @param font      The existing font you want to use as a template.
     * @param size      The size of the new font.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     *
     * @see FontSize
     */
    public Font(Font font, float size, int units) {}

    /**
     * Creates a new font from an existing one.
     *
     * @param font      The existing font you want to use as a template.
     * @param weight    The weight of the font.  This must be one of the
     *                  FontWeight enum values.
     * @param italic    <b>True</b> if the font is to be in italic,
     *                  <b>false</b> if not.
     * @param underline <b>True</b> if the font is to be in underline,
     *                  <b>false</b> if not.
     * @param strikeOut <b>True</b> if the font is to be in strike out,
     *                  <b>false</b> if not.
     *
     * @see FontWeight
     */
    public Font(Font font, int weight, boolean italic, boolean underline, boolean strikeOut) {}

    /**
     * Creates a new font from an existing one.
     *
     * @param font      The existing font you want to use as a template.
     * @param size      The size of the new font.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     * @param weight    The weight of the font.  This must be one of the
     *                  FontWeight enum values.
     * @param italic    <b>True</b> if the font is to be in italic,
     *                  <b>false</b> if not.
     * @param underline <b>True</b> if the font is to be in underline,
     *                  <b>false</b> if not.
     * @param strikeOut <b>True</b> if the font is to be in strike out,
     *                  <b>false</b> if not.
     *
     * @see FontSize
     * @see FontWeight
     */
    public Font(Font font, float size, int units, int weight, boolean italic, boolean underline, boolean strikeOut) {}

    /**
     * Creates a new font given a font family, pitch and size.  This useful
     * if you don't know the name of the font you would like to create.
     *
     * @param family    The family of the font you would like to create.
     *                  This must be one of the FontFamily enum values.
     * @param pitch     The pitch of the font you would like to create.
     *                  This must be one of the FontPitch enum values.
     * @param size      The size of the font.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     *
     * @see FontFamily
     * @see FontPitch
     * @see FontSize
     */
    public Font(int family, int pitch, float size, int units) {}

    /**
     * Creates a new font given a font face, size, and style.  This useful
     * if you don't know the name of the font you would like to create.
     *
     * @param family    The family of the font you would like to create.
     *                  This must be one of the FontFamily enum values.
     * @param pitch     The pitch of the font you would like to create.
     *                  This must be one of the FontPitch enum values.
     * @param size      The size of the font.
     * @param units     The units the size of the font is specified in.  This must
     *                  be one of the FontSize enum values.
     * @param weight    The weight of the font.  This must be one of the
     *                  FontWeight enum values.
     * @param italic    <b>True</b> if the font is to be in italic,
     *                  <b>false</b> if not.
     * @param underline <b>True</b> if the font is to be in underline,
     *                  <b>false</b> if not.
     * @param strikeOut <b>True</b> if the font is to be in strike out,
     *                  <b>false</b> if not.
     *
     * @see FontFamily
     * @see FontPitch
     * @see FontSize
     * @see FontWeight
     */
    public Font(int family, int pitch, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut) {}

    /**
     * Creates a new font.  This useful if you don't know the name of the font
     * you would like to create.
     *
     * @param family        The family of the font you would like to create.
     * @param pitch         The pitch of the font you would like to create.
     * @param size          The size of the font.
     * @param units         The units the size of the font is specified in.  This
     *                      must be one of the FontSize enum values.
     * @param weight        The weight of the font.  This must be one of the
     *                      FontWeight enum values.
     * @param italic        True if the font is to be in italic, false if not.
     * @param underline     True if the font is to be in underline, false if not.
     * @param strikeOut     True if the font is to be in strikeOut, false if not.
     * @param charSet       The caracter set of the font.  This must be one of the
     *                      com.ms.wfc.app.CharacterSet enum values.
     * @param orientation   Orientation of the font.  This is the angle, in tenths
     *                      of a degree, between a character's baseline and the
     *                      X-axis of a device.
     *
     * @see FontFamily
     * @see FontPitch
     * @see FontSize
     * @see FontWeight
     * @see com.ms.wfc.app.CharacterSet
     */
    public Font(int family, int pitch, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut, int charSet, int orientation) {}

    /**
     * Creates a font based on the given FontMetrics object.
     *
     * @param fm A FontMetrics object to base the font on.
     *
     * @see FontMetrics
     */
    public Font(FontMetrics fm) {}

    /**
     * Creates a font based on the given FontDescriptor object.
     *
     * @param fd A FontDescriptor object to base the font on.
     *
     * @see FontDescriptor
     */
    public Font(FontDescriptor fd) {}

    /**
     * Creates a new font from a given datastream.  Used for persistence.
     *
     * @param stream The IDataStream to read the font from.
     *
     * @see IDataStream
     * @see IPersistable
     */
    public Font(IDataStream stream) {}

    /**
     * Clones the Font object, creating a duplicate font.
     *
     * @return an object that can be casted to a Font.
     */
    public Object clone() {}

    /**
     * Duplicates the Win32 font handle associated with this Font object.  You are responsible for
     * freeing the returned handle when you are done with it.
     *
     * @return a Win32 font handle.
     */
    public final int copyHandle() {}

    
    private static Font createStock(int index) {}

    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.  Note that a  Font object may have more than
     * one handle associated with it.  This method will be called when
     * all of the handles should be destroyed.
     */
    protected void destroyHandle() {}

    /**
     * Frees all the resources allocated by this object.  You do not have to call dispose; the
     * garbage collector will do it for you.  However, you may expedite
     * the process by calling dispose manually.
     */
    public void dispose() {}

    /**
     * Retrieves a boolean value that indicates whether the specified object
     * is equivalent to this one.
     *
     * @param obj Object to test.
     * @return <b>true</b> if the given object equals this object.
     */
    public boolean equals(Object obj) {}

    /**
     * Retrieves a boolean value that indicates whether the base font used by
     * the specified Font object is identical to that used by this Font
     * object.   A font
     * shares the same base font if the font has the same typeface name and
     * uses the same character set.
     *
     * @param font Font to test.
     * @return <b>true</b> if the given font has the same base characteristics
     *         as this font.
     */
    public boolean equalsBase(Font font) {}

    /**
     * Releases all resources allocated by this object.
     * @exception Throwable thrown if there was a problem cleaning up the font.
     */
    protected void finalize() throws Throwable {}

    /**
     * Retrieves a boolean value that indicates if the font is bold. 
     *
     * @return <b>true</b> if the font is bold, <b>false</b> if it is not.
     */
    public final boolean getBold() {}

    /**
     * Retrieves the character set the font is using.
     *
     * @return a @see com.ms.wfc.app.CharacterSet enum value.
     */
    public final int getCharacterSet() {}

    /**
     * Retrieves an array of ConstructorArg
     * objects that describe the data types and values needed to persist this object.
     *
     * @return a ConstructorArg array.
     *
     * @see ConstructorArg
     * @see IConstructable
     */
    public ConstructorArg[] getConstructorArgs() {}

    /**
     * Retrieves a file name extension with which to save this object's persistent data.
     *
     * @return a filename extension to use during object persistence.  Font does
     *         not use an extension, so this always returns null.
     * @see IPersistable
     */
    public String getExtension() {}

    /**
     * Retrieves the font family for the font on which this object is based.DEFAULT if no specific
     * family was requested.
     *
     * @return one of the FontFamily enum values.
     *
     * @see FontFamily
     */
    public final int getFamily() {}

    /**
     * Retrieves a FontMetrics object that
     * describes the characteristics of this Font object.  While a Font object
     * maintains the requested characteristics of a font, a FontMetrics contains
     * information about the actual font as it will be rendered to a graphics
     * object. This information may or may not match the requested characteristics,
     * depending on what font information is available.
     *
     * This function assumes a default Graphics object of the screen.
     *
     * @return a @see FontMetrics object with the physical characteristics of the font.
     *
     * @see FontMetrics
     * @see Graphics
     */
    public final FontMetrics getFontMetrics() {}

    /**
     * Retrieves a FontMetrics object that
     * describes the characteristics of this Font object.  While a Font object
     * maintains the requested characteristics of a font, a FontMetrics contains
     * information about the actual font as it will be rendered to a graphics
     * object. This information may or may not match the requested characteristics,
     * depending on what font information is available.
     *
     * @param gr The Graphics object to map the font into.
     * @return a @see FontMetrics object with the physical characteristics of the font.
     *
     * @see FontMetrics
     * @see Graphics
     */
    public final FontMetrics getFontMetrics(Graphics gr) {}

    /**
     * Retrieves the Win32 font handle (HFONT) for this object's underlying
     * font.  This will use the screen
     * rendering dimensions.
     *
     * @return a Win32 handle to the font.
     */
    public int getHandle() {}

    /**
     * Retrieves the Win32 font handle (HFONT) for this object's underlying
     * font.
     *
     * @param graphics A Graphics object to render the font
     *                 against.  This is used to properly adapt
     *                 the font's size to the dimensions of the
     *                 graphics object.
     *
     * @return a Win32 handle to the font.
     *
     * @see Graphics
     */
    public int getHandle(Graphics graphics) {}

    /**
     * Retrieves a boolean value that indicates whether the font is
     * italicized.
     *
     * @return <b>true</b> if the font is italic, <b>false</b> if it is not.
     */
    public final boolean getItalic() {}

    /**
     * Retrieves the face name of the font and returns the name in a String
     * object. 
     *
     * @return the font's face name.
     */
    public final String getName() {}

    /**
     * Retrieves the orientation of the font, in tenths of a degree, from the x-axis of the
     * device. 
     *
     * @return the orientation of the font.
     */
    public final int getOrientation() {}

    /**
     * Retrieves the pitch of the font on which this object is based.DEFAULT if no font
     * pitch was specified.
     *
     * @return one of the FontPitch enum values.
     * @see FontPitch
     */
    public final int getPitch() {}

    /**
     * Retrieves the size of the font in the units with which the font was created.   The size will be in whatever units the
     * font object was created with.  You can obtain the units for this size
     * by calling getUnits.
     *
     * @return the font's size.
     *
     * @see #getUnits
     */
    public final float getSize() {}

    /**
     * Retrieves the size of the font in the units with which the font was created.   The size will be in the requested
     * dimensions and will use the screen resolution to determine conversion
     * factors.
     *
     * @param units One of the FontSize enun values.
     * @return the font's size in the requested units.
     *
     * @see FontSize
     */
    public final float getSize(int units) {}

    /**
     * Retrieves the size of the font in the units with which the font was created.   The size will be in the requested
     * dimensions and will use the given Graphics object to perform
     * the conversion.
     *
     * @param gr    A graphics object that will be used to perform
     *              the conversion.
     * @param units One of the FontSize enun values.
     * @return the font's size in the requested units.
     *
     * @see FontSize
     * @see Graphics
     */
    public final float getSize(Graphics gr, int units) {}

    /**
     * Retrieves the units in which the font's size is measured.   This will be
     * one of the FontSize enum values.
     *
     * @return the units the font's size is referenced in.
     *
     * @see FontSize
     */
    public final int getUnits() {}

    /**
     * Retrieves a stock font, based on a specified index.
     *
     * @param index The stock font index as defined in com.ms.wfc.win32.Windows
     * @return a stock font.
     *
     * @see com.ms.wfc.win32.Windows
     */
    public final static Font getStock(int index) {}

    /**
     * Retrieves a boolean value that indicates whether the current font is a
     * strikeout font. 
     *
     * @return <b>true</b> if the font is stike out, <b>false</b> if it isn't.
     */
    public final boolean getStrikeout() {}

    /**
     * Retrieves a boolean value that indicates whether the font is
     * underlined.
     *
     * @return <b>true</b> if the font is underlined, <b>false</b> if it isn't.
     */
    public final boolean getUnderline() {}

    /**
     * Retrieves the font's weight.
     *
     * @return one of the FontWeight enum values.
     * @see FontWeight
     */
    public final int getWeight() {}

    /**
     * Retrieves a hash code value for this font.
     *
     * @return a hash code value for this font.
     */
    public int hashCode() {}

    /**
     * Persists this font to the specified data stream. 
     *
     * @param stream The stream to persist the font information to.
     * @see IPersistable
     */
    public void save(IDataStream stream) {}

    /**
     * Retrieves a human-readable string
     * representation of this object.
     *
     * @return a String representation of this object
     * @internalonly
     * @hidden
     */
    public String toString() {}

    /**
     * Encapsulates a Win32 font, which is used to draw text on video displays and other  output devices.
     * This class implements IValueEditor by extending the default implementation
     * ValueEditor.
     *
     * @see com.ms.wfc.core.IValueEditor
     * @see com.ms.wfc.core.ValueEditor
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends ValueEditor {

        FontDialog fontDialog = null;
        IValueAccess valueAccess = null;
        UnitName unitNames[] = {
            new UnitName("char", FontSize.CHARACTERHEIGHT),
            new UnitName("cell", FontSize.CELLHEIGHT),
            new UnitName("cm", FontSize.CENTIMETERS),
            new UnitName("em", FontSize.EM),
            new UnitName("ex", FontSize.EX),
            new UnitName("in", FontSize.INCHES),
            new UnitName("mm", FontSize.MILLIMETERS),
            new UnitName("px", FontSize.PIXELS),
            new UnitName("pt", FontSize.POINTS)
        };

        /**
         * Displays a modal font dialog to choose the font's properties.
         *
         * @param valueAccess An IValueAccess interface to access
         *                    the font's current value.
         *
         * @see com.ms.wfc.core.IValueAccess
         * @see com.ms.wfc.core.IValueEditor
         */
        public void editValue(IValueAccess valueAccess) {}

        /**
         * Retrieves a list of sub-properties for a font object.
         *
         * @param value Object to get the sub-properties for.  This object must
         *                     be a Font instance.
         *
         * @return an array of sub-properties for the given object.
         * @see com.ms.wfc.core.IValueEditor
         */
        public SubProperty[] getSubProperties(Object value) {}

        /**
         * Determines if there is a constant name that can be used in place of the
         * given object.
         *
         * @param value Object to get the constant name for.  This object must
         *              be a Font instance.
         * @return a string representing the constant for the object's value, or
         *         <b>null</b> if no such constant exists.
         * @see com.ms.wfc.core.IValueEditor
         * @see Font
         */
        public String getConstantName(Object value) {}

        
        private String getFontSizeText(Font font) {}

        /**
         * Retrieves the style flags for this value editor.
         *
         * @return a combination of style flags from IValueEditor.
         * @see com.ms.wfc.core.IValueEditor
         */
        public int getStyle() {}

        /**
         * Retrieves a human readable string representing the properties for the
         * given font.
         *
         * @param value Object to get the text representation of.  This object
         *              must be a Font instance.
         *
         * @return a human-readable string representing the properties of the font.
         * @see com.ms.wfc.core.IValueEditor
         * @see Font
         */
        public String getTextFromValue(Object value) {}

        /**
         * Parses a string and tries to set font properties for it.
         *
         * @param text The text of the string to parse.
         * @return a Font object with it's properties set as sepcified in the string.
         * @see com.ms.wfc.core.IValueEditor
         * @see Font
         */
        public Object getValueFromText(String text) {}

        
        private Object getValue(String name, float size, int units, int weight,
            boolean italic, boolean underline,
            boolean strikeOut) {}

        /**
         * Converts the given array of values to an Object. The object values will
         * be determined by the current value of all the subProperty editors.
         *
         * @see com.ms.wfc.core.IValueEditor
         */
        public Object getValueFromSubPropertyValues(Object[] args) {}

        
        private void onApply(Object sender, Event e) {}

        
        private float parseFontSize(String text) {}

        
        private int parseFontUnits(String text) {}

        
        private static class UnitName {
            String name;
            int unit;

            public UnitName(String name, int unit) {}
        }
    }

    /**
     * Encapsulates a Win32 font, which is used to draw text on video displays and other  output devices.
     *
     * @see com.ms.wfc.core.IValueEditor
     *
     * @security(checkClassLinking=on)
     */
    public static class FontNameEditor extends ValueEditor {

        /**
         * Returns the value editor style.
         *
         * @return indication that we are a dropdown that paints its own values.
         * @see IValueEditor
         */
        public int getStyle() {}

        /**
         * Converts the given value into a font name.
         *
         * @param value The value of the font's name property.
         * @return a string representing the value.  Since the name property
         *         is already a string, this merely casts <i>value</i> to
         *         a string.
         */
        public String getTextFromValue(Object value) {}

        /**
         * Converts the given text string to a value.
         *
         * @param text The text to convert to a value.
         * @return a string representing the value.  Since the name property
         *         is a string, this merely casts <i>value</i> to an object.
         */
        public Object getValueFromText(String text) {}

        /**
         * Returns an array of values for the dropdown.
         *
         * @return an array of strings describing the fonts.
         * @see IValueEditor
         */
        public Object [] getValues() {}

        /**
         * Paints a representation of the given value in the given Rectangle of the
         * given Graphics.
         *
         * @param value The font name to paint.
         * @param g     The graphics object to paint the font on.
         * @param rect  The rectangle we are confined to paint in.
         * @see IValueEditor
         */
        public void paintValue(Object value, Graphics g, Rectangle rect) {}
    }
}


final class FontEntry {

    
    private static final int signature = 0x4A9F;
    private static final int version = 0x02;

    private static FontEntry cache;

    private FontEntry next;
    private int refCount;
    private int hashCode;
    private boolean noDerivation;
    private HandleEntry handles;
    private HandleEntry lastHandle;

    String name;
    int stockIndex;
    float size;
    int units;
    int weight;
    boolean italic;
    boolean underline;
    boolean strikeOut;
    int charSet;
    int orientation;
    int pitch;
    int family;

    /**
     * Clones the Font object, creating a duplicate font.  It may return the same entry if possible, or it may
     * create an entirely new entry.
     */
    public Object clone() {}

    
    private static int computeHash(String name, float size, int weight, boolean italic,
        boolean underline, boolean strikeOut, int charSet, int orientation) {}

    
    static synchronized FontEntry create(int handle) {}

    
    static synchronized FontEntry create(String name, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut, int charSet, int orientation, int pitch, int family) {}

    
    static synchronized FontEntry create(Font font, float size, int units, int weight, boolean italic,
        boolean underline, boolean strikeOut) {}

    
    static synchronized FontEntry create(FontMetrics fm) {}

    
    static synchronized FontEntry createStock(int index) {}

    
    static synchronized void free(Font font, FontEntry entry) {}

    /**
     * Retrieves the Win32 font handle (HFONT) for this object's underlying
     * font.
     *
     * @param gr A @see Graphics object to render the font to.
     * @return A Win32 HFONT handle.
     */
    public int getHandle(Graphics gr) {}

    /**
     * Retrieves a hash code value for this font.hashCode()
     *
     * @return An integer hash code value.
     *
     * @see java.lang.Object;
     */
    public int hashCode() {}

    /**
     * Creates a FontEntry given a persisted data stream
     *
     * @param stream    The stream to read from.
     */
    public static FontEntry load(IDataStream stream) {}

    /**
     * Persists this font to the specified data stream. 
     *
     * @param stream    The data stream to write to.
     */
    public void save(IDataStream stream) {}

    
    private void setLogicalUnits(int height) {}

    
    private static void validateArgs(float size, int units, int weight, int charSet, int pitch, int family) {}

    
    private static final class HandleEntry {
        int handle;
        int height;
        boolean ownHandle;
        HandleEntry nextHandle;
    }
}