//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.dll.*;
import com.ms.wfc.core.*;
import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Represents a common dialog box that displays a list of fonts that are currently  installed on the system. 
 *
 * Common usage:
 *
 * <pre>
 * FontDialog fd = new FontDialog();
 * // set any options, default fonts, etc. here...
 * int didUserHitOK = fd.showDialog();
 * if (didUserHitOK == DialogResult.OK)
 *      Font f = fd.getFont();
 * else
 *      userCancelledFontSelection();
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public class FontDialog extends CommonDialog
{
    private static final Object EVENT_APPLY = new Object();

    private int options;
    private Font font;
    private Color color;
    private int minSize;
    private int maxSize;
    private int printerDC;
    private boolean showColor = false;

    /**
     * Creates a new instance of a FontDialog.  Use the showDialog() method
     * to show the dialog.
     */
    public FontDialog() {}

    /**
     * Assigns a delegate to the apply event.   This
     * event is sent whenever the user clicks the "Apply" button in the
     * dialog.
     * Duplicates are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnApply(EventHandler value) {}

    /**
     * Retrieves a boolean value indicating whether the dialog box allows graphics
     * device interface (GDI) font simulations. 
     *
     * @return <b>true</b> if simulations are to be allowed.
     */
    public final boolean getAllowSimulations() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box allows vector font
     * selections. 
     *
     * @return <b>true</b> if vector fonts will be allowed.
     */
    public final boolean getAllowVectorFonts() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box displays both
     * vertically oriented and horizontally oriented fonts or only horizontally oriented fonts. 
     *
     * @return <b>true</b> if vertical fonts will be displayed.
     */
    public final boolean getAllowVerticalFonts() {}

    /**
     * Retrieves a boolean value indicating whether the user can change the character
     * set specified in the Script combo box to display a character set other than the
     * current one.  The user will not be allowed to change the character set
     * specified in the Scripts combo box.
     *
     * @return <b>true</b> if script changes are allowed.
     */
    public final boolean getAllowScriptChange() {}

    /**
     * Retrieves the selected font color. 
     *
     * @return Color    the color of the selected font.
     */
    public final Color getColor() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box should allow only
     * the selection of fixed-pitch fonts. 
     *
     * @return <b>true</b> if only fixed pitch fonts will be allowed for
     *          selection.
     */
    public final boolean getFixedPitchOnly() {}

    /**
     * Retrieves a value indicating the font the user selected in the dialog box. 
     *
     * @return Font     the font that was selected.
     */
    public final Font getFont() {}

    /**
     * Retrieves a value indicating whether the dialog box will show screen fonts, printer
     * fonts, or both. 
     *
     * @return int      a value from the com.ms.wfc.ui.FontDevice enumeration.
     *
     * @see com.ms.wfc.ui.FontDevice
     */
    public final int getFontDevice() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box should indicate an
     * error condition if the user attempts to select a font or style that does not exist. 
     *
     * @return  <b>true</b> if the dialog will not let the user select non-
     *          existant fonts.
     */
    public final boolean getFontMustExist() {}

    /**
     * Retrieves a value indicating the maximum point size a user can select. 
     *
     * @return       the max font size, or zero if there isn't one.
     */
    public final int getMaxSize() {}

    /**
     * Retrieves a value indicating the minimum point size a user can select. 
     *
     * @return      the minimum font size, or zero if there isn't one.
     */
    public final int getMinSize() {}

    
    final boolean getOption(int option) {}

    /**
     * @internalonly
     */
    protected int getOptions() {}

    /**
     * Retrieves a value identifying the device context of the printer whose fonts will be
     * listed in the dialog box. 
     *
     * @return int      a Win32 Graphics Device Context handle [DC]
     */
    public final int getPrinterDC() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box allows only the
     * selection of scalable fonts.  (Scalable fonts include vector fonts, scalable printer fonts,
     * TrueType fonts, and fonts scaled by other technologies.)
     *
     * @return  <b>true</b> if only scalable fonts will be allowed.
     */
    public final boolean getScalableOnly() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box allows selection of
     * fonts for all non-OEM and Symbol character sets, as well as the American National
     * Standards Institute (ANSI) character set. 
     */
    public final boolean getScriptsOnly() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box contains an Apply
     * button. 
     *
     * @return <b>true</b> if an apply button will be shown.
     */
    public final boolean getShowApply() {}

    /**
     * Retrieves a boolean value indicating whether or not the color choice is shown. 
     *
     * @return <b>true</b> if the color choice will be shown.
     */
    public final boolean getShowColor() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box displays the
     * controls that allow the user to specify strikeout, underline, and text color options. 
     *
     * @return  <b>true</b> if effects will be shown.
     */
    public final boolean getShowEffects() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box contains a Help
     * button. 
     *
     * @return  <b>true</b> if a "Help" button will be shown.
     */
    public final boolean getShowHelp() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box displays only
     * TrueType fonts. 
     *
     * @return <b>true</b> if only TrueType fonts will be allowed.
     */
    public final boolean getTrueTypeOnly() {}

    /**
     * Retrieves a boolean value indicating whether the dialog box allows only the
     * selection of fonts available on both the printer and the display. 
     *
     * @return <b>true</b> if only this type of font will be allowed.
     */
    public final boolean getWysiwyg() {}

    /**
     * This is the hook procedure that the dialog uses to make some of
     * it's extra functionality work.  Users inheriting from this class
     * who override this method should call super.hookProc() from theirs
     * to ensure that everything works fine.
     *
     * @param hWnd      Generic Win32 HookProc parameters.
     * @param msg
     * @param wParam
     * @param lParam
     *
     * @return int  a Win32 LRESULT
     */
    protected int hookProc(int hWnd, int msg, int wParam, int lParam) {}

    /**
     * Triggers the apply event.   Inheriting classes should override
     * this method instead of listening to the "OnApply" event.  Don't forget
     * to call super.onApply() to make sure that other listeners still do get
     * the event.
     *
     * @param e         The event to be fired.
     */
    protected void onApply(Event e) {}

    /**
     * Removes the delegate that is assigned to the apply event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnApply(EventHandler value) {}

    /**
     * Resets all dialog box options to their default values.   The options are reset to show only
     * screen fonts and the effects portion of the dialog.
     */
    public final void reset() {}

    /**
     * Implements running the dialog box.   Inheriting classes
     * should override this if they want to add more functionality, and call
     * super.runDialog() if necessary
     *
     * @param hookProcPtr   A pointer to the hook proc that we have to set up
     *                      for the ChooseFont call
     *
     * @return boolean      a value indicating whether the user hit OK [true]
     *                      or Cancel [false]
     */
    protected boolean runDialog(int hwndOwner, int hookProcPtr) {}

    /**
     * Sets a boolean value indicating whether the dialog box allows graphics device
     * interface (GDI) font simulations. 
     */
    public final void setAllowSimulations(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box allows vector font
     * selections. 
     */
    public final void setAllowVectorFonts(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box displays both vertical
     * and horizontal fonts or only horizontal fonts. 
     */
    public final void setAllowVerticalFonts(boolean value) {}

    /**
     * Sets a boolean value indicating whether the user can change the character set
     * specified in the Script combo box to display a character set other than the current
     * one. 
     */
    public final void setAllowScriptChange(boolean value) {}

    /**
     * Sets a value that indicates which color is selected by default when the dialog box is
     * opened. 
     *
     * @param Color     The color of the font when the dialog is first shown.
     */
    public final void setColor(Color value) {}

    /**
     * Sets a boolean value indicating whether the dialog box should allow only the
     * selection of fixed-pitch fonts. 
     */
    public final void setFixedPitchOnly(boolean value) {}

    /**
     * Sets a value that indicates which font is selected by default when the dialog box is
     * opened.  Values
     * such as face name, color, and style are taken from this for initial
     * values to display.
     *
     * @param value     The font to display when first shown.
     */
    public final void setFont(Font value) {}

    /**
     * Sets a value indicating whether the dialog box will show screen fonts, printer fonts,
     * or both. 
     */
    public final void setFontDevice(int value) {}

    /**
     * Sets a boolean value indicating whether the dialog box should indicate an error
     * condition if the user attempts to select a font or style that does not exist. 
     */
    public final void setFontMustExist(boolean value) {}

    /**
     * Sets a value indicating the maximum point size a user can select. 
     * @param value     The max font size.
     */
    public final void setMaxSize(int value) {}

    /**
     * Sets a value indicating the minimum point size a user can select. 
     *
     * @param value     The min font size.
     */
    public final void setMinSize(int value) {}

    
    final void setOption(int option, boolean value) {}

    /**
     * Sets a value identifying the device context of the printer whose fonts will be listed
     * in the dialog box. 
     *
     * @param   value       This is a Win32 Graphics Device Context [DC] handle.
     */
    public final void setPrinterDC(int value) {}

    /**
     * Sets a boolean value indicating whether the dialog box allows only the selection
     * of scalable fonts.  (Scalable fonts include vector fonts, scalable
     * printer fonts, TrueType fonts, and fonts scaled by other technologies.)
     */
    public final void setScalableOnly(boolean value) {}

    public final void setScriptsOnly(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box contains an Apply
     * button.   The "OnApply" even will be fired in this case.
     */
    public final void setShowApply(boolean value) {}

    /**
     * Sets a boolean value indicating whether or not the color choice is shown. 
     */
    public final void setShowColor(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box displays the controls
     * that allow the user to specify strikeout, underline, and text color options. , should be shown.
     */
    public final void setShowEffects(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box contains a Help
     * button. 
     */
    public final void setShowHelp(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box displays only TrueType
     * fonts. 
     */
    public final void setTrueTypeOnly(boolean value) {}

    /**
     * Sets a boolean value indicating whether the dialog box allows only the selection
     * of fonts available on both the printer and the display. 
     */
    public final void setWysiwyg(boolean value) {}

    /**
     * Retrieves a string that includes the name of the current font selected in the dialog
     * box. 
     *
     * @return  a String with some information about this dialog control.
     */
    public String toString() {}

    
    private void updateColor(int rgb) {}

    
    private void updateFont(LOGFONT lf) {}

    /**
     * Represents a common dialog box that displays a list of fonts that are currently  installed on the system. 
     * @see com.ms.wfc.core.ClassInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends CommonDialog.ClassInfo
    {
        public static final PropertyInfo allowScriptChange = new PropertyInfo(
            FontDialog.class, "allowScriptChange", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FnDallowScriptChangeDescr")));

        public static final PropertyInfo allowSimulations = new PropertyInfo(
            FontDialog.class, "allowSimulations", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FnDallowSimulationsDescr")));

        public static final PropertyInfo allowVectorFonts = new PropertyInfo(
            FontDialog.class, "allowVectorFonts", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FnDallowVectorFontsDescr")));

        public static final PropertyInfo allowVerticalFonts = new PropertyInfo(
            FontDialog.class, "allowVerticalFonts", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FnDallowVerticalFontsDescr")));

        public static final PropertyInfo color = new PropertyInfo(
            FontDialog.class, "color", Color.class,
            new DefaultValueAttribute(Color.BLACK),
            new DescriptionAttribute(Sys.getString("FnDcolorDescr")));

        public static final PropertyInfo fixedPitchOnly = new PropertyInfo(
            FontDialog.class, "fixedPitchOnly", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDfixedPitchOnlyDescr")));

        public static final PropertyInfo font = new PropertyInfo(
            FontDialog.class, "font", Font.class,
            new DefaultValueAttribute(Font.DEFAULT_GUI),
            new DescriptionAttribute(Sys.getString("FnDfontDescr")));

        public static final PropertyInfo fontDevice = new PropertyInfo(
            FontDialog.class, "fontDevice", FontDevice.class,
            new DefaultValueAttribute(new Integer(FontDevice.SCREEN)),
            new DescriptionAttribute(Sys.getString("FnDfontDeviceDescr")));

        public static final PropertyInfo fontMustExist = new PropertyInfo(
            FontDialog.class, "fontMustExist", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDfontMustExistDescr")));

        public static final PropertyInfo maxSize = new PropertyInfo(
            FontDialog.class, "maxSize", Integer.TYPE,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("FnDmaxSizeDescr")));

        public static final PropertyInfo minSize = new PropertyInfo(
            FontDialog.class, "minSize", Integer.TYPE,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("FnDminSizeDescr")));

        public static final PropertyInfo scalableOnly = new PropertyInfo(
            FontDialog.class, "scalableOnly", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDscalableOnlyDescr")));

        public static final PropertyInfo scriptsOnly = new PropertyInfo(
            FontDialog.class, "scriptsOnly", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDscriptsOnlyDescr")));

        public static final PropertyInfo showApply = new PropertyInfo(
            FontDialog.class, "showApply", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDshowApplyDescr")));

        public static final PropertyInfo showColor = new PropertyInfo(
            FontDialog.class, "showColor", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDshowColorDescr")));

        public static final PropertyInfo showEffects = new PropertyInfo(
            FontDialog.class, "showEffects", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("FnDshowEffectsDescr")));

        public static final PropertyInfo showHelp = new PropertyInfo(
            FontDialog.class, "showHelp", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDshowHelpDescr")));

        public static final PropertyInfo trueTypeOnly = new PropertyInfo(
            FontDialog.class, "trueTypeOnly", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDtrueTypeOnlyDescr")));

        public static final PropertyInfo wysiwyg = new PropertyInfo(
            FontDialog.class, "wysiwyg", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("FnDwysiwygDescr")));

        public static final EventInfo apply = new EventInfo(
            FontDialog.class, "apply", EventHandler.class,
            new DescriptionAttribute(Sys.getString("FnDapplyDescr")));

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}