//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Defines a group of constants that represent the families to which a font may belong.  Windows provides several families
 * that a font can belong to, which are enumerated here.
 * 
 * @see Font
 *
 * @security(checkClassLinking=on)
 */
public final class FontFamily extends Enum {

    /**
     * Represents the Default font family. When you create a Font object without specifying a font family,
     * this value is used to create the object.  If you specify this when creating a font,
     * Windows may use any family to render the font.
     */
    public static final int DEFAULT = win.FF_DONTCARE;

    /**
     * Represents the default font family (identical to DEFAULT).  If you specify this when creating a font,
     * Windows may use any family to render the font.  This is a
     * synonym of DEFAULT.
     */
    public static final int DONTCARE = win.FF_DONTCARE;
    
    /**
     * Represents the Roman font family, which consists of fonts that are of variable pitch
     * and that have serifs.   Times New Roman is an example of such
     * a typeface.
     */
    public static final int ROMAN = win.FF_ROMAN;
    
    /**
     * Represents the Swiss font family, which consists of fonts that are of variable pitch
     * and that are without serifs.   Arial is an example of such a typeface.
     */
    public static final int SWISS = win.FF_SWISS;
    
    /**
     * Represents the Modern font family, which consist of fonts that have fixed pitch and
     * that may or may not have serifs.   
     * Modern fonts may be with or without serifs.  Examples of modern 
     * fonts are Courier New and Lucidia Console.
     */
    public static final int MODERN = Windows.FF_MODERN;
    
    /**
     * Represents the Script font family, which consists of fonts that are designed to look
     * like handwriting.   Script and Cursive are examples of such
     * typefaces.
     */
    public static final int SCRIPT = win.FF_SCRIPT;
    
    /**
     * Represents the Decorative font family, which consists of novelty typefaces of both
     * variable and fixed pitch.   They can
     * be of both variable and fixed pitch, and may or may not have serifs.
     * Comic Sans and Old English are examples of decorative fonts.
     */
    public static final int DECORATIVE = win.FF_DECORATIVE;

    private static final int MIN = DEFAULT;
    private static final int MAX = DECORATIVE;
    
    /**
     * Retrieves a boolean value that indicates whether the specified value
     * is a valid FontFamily constant.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}