//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Defines a group of constants that represent the units in which font sizes can be  specified. 
 * 
 * @see Font
 *
 * @security(checkClassLinking=on)
 */
public final class FontSize extends Enum {
    
    /**
     * Represents the size of the font in logical units. The size is
     * the entire height of the font cell, including external and 
     * internal leading.  Logical units will scale with different 
     * coordinate systems.
     */
    public static final int CELLHEIGHT = 0;

    /**
     * Represents the size of the font in centimeters.  This unit
     * remains constant with different coordinate systems.
     */
    public static final int CENTIMETERS = 1;
    
    /**
     * Represents the size of the font in logical units.  The size
     * is the height of a character only, excluding the internal
     * leading.  Logical  units will scale with different coordinate
     * systems.
     */
    public static final int CHARACTERHEIGHT = 2;

    /**
     * Represents the size of the font as a percentage of the system default font's character
     * height.  This size will scale with different 
     * coordinate systems.
     */
    public static final int EM = 3;
    
    /**
     * Represents the size of the font as a percentage of the system default font's cell
     * height.  This size will scale with different 
     * coordinate systems.
     */
    public static final int EX = 4;
    
    /**
     * Represents the size of the font in inches.  This unit
     * remains constant with different coordinate systems.
     */
    public static final int INCHES = 5;
    
    /**
     * Represents the size of the font in millimeters.  This unit
     * remains constant with different coordinate systems.
     */
    public static final int MILLIMETERS = 6;

    /**
     * Represents the size of the font in pixels.  This is identical
     * to specifying it in CELLHEIGHT.
     */
    public static final int PIXELS = 7;
    
    /**
     * Represents the size of the font specified in points or 1/72nds of an inch.
     * The size is the height of the character only, excluding the internal
     * leading.  Points remain constant with different coordinate systems
     * because they are based on physical inches rather than logical units.
     */
    public static final int POINTS = 8;

    private static final int MIN = 0;
    private static final int MAX = 8;

    /**
     * Retrieves a boolean value that indicates whether the specified value
     * is a valid FontSize constant.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}