//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Encapsulates a font type.  A font type is determined by what 
 * technology renders the font.  A font may consist of one or more FontType
 * values combined together.
 * 
 * @see Font
 *
 * @security(checkClassLinking=on)
 */
public class FontType {
    
    /**
     * Specifies a raster font type.  A
     * raster font typically has several different sizes.  If a raster font
     * does not have a requested font size, the font mapper will scale the
     * bitmap of the font as appropriate.  This can make raster fonts look
     * blocky at larger sizes.
     */
    public static final int RASTER     = 0x0001;
    
    /**
     * Specifies that the font will be rendered entirely by the device.  In Windows, there are
     * no device fonts associated with a screen.  Printers, however, may offer
     * a wide variety of device fonts.
     */
    public static final int DEVICE     = 0x0002;
    
    /**
     * Specifies a TrueType font type.  They can
     * be scaled and rotated smoothly.
     */
    public static final int TRUETYPE   = 0x0004;

    private static final int ALL = RASTER | DEVICE | TRUETYPE;
    
    /**
     * Retrieves a boolean value that indicates whether the specified value
     * is a valid member of this class.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}