//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Defines constants that represent the different weights that you can associate with a  font.   Windows does not actually
 * restrict you to use these values; a font weight can be any weight from 0 to 1000.
 * However, it does define a set of predefined weights that are typically used.  Note
 * that a font may not support a given weight, so the nearest available weight will
 * be used.
 * 
 * @see Font
 *
 * @security(checkClassLinking=on)
 */
public final class FontWeight extends Enum {

    /**
     * Represents a thin font.
     */
    public static final int THIN             =100;
    
    /**
     * Represents an extra light font.  Not so light that it would float away, however.
     */
    public static final int EXTRALIGHT       =200;
    
    /**
     * Represents a light font.  
     */
    public static final int LIGHT            =300;
    
    /**
     * Represents a normal font weight.  All fonts implement this weight.
     */
    public static final int NORMAL           =400;
    
    /**
     * Represents a medium font weight.
     */
    public static final int MEDIUM           =500;
    
    /**
     * Represents a weight between medium and bold.
     */
    public static final int SEMIBOLD         =600;
    
    /**
     * Represents a bold font.
     */
    public static final int BOLD             =700;
    
    /**
     * Represents an extra bold font.
     */
    public static final int EXTRABOLD        =800;
    
    /**
     * Represents a heavy font.
     */
    public static final int HEAVY            =900;
    
    private static final int MIN = 0;
    private static final int MAX = 1000;
    
    /**
     * Retrieves a boolean value that indicates whether a specified value is
     * a valid member of this class.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}