//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.win32.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;

/**
 * Encapsulates a Win32 device context (DC) and the drawing operations that are typically  performed on a DC.   All painting of the client area of a window or
 * control is done through a Graphics object.<p>
 * 
 * Graphics objects, like other Java objects, are automatically garbage collected
 * when they are no longer in use.  Win32, however, has strict limitations on the
 * number of outstanding device contexts a program uses.  For this reason a Graphics object
 * may dispose itself much faster than the garbage collector does.  In WFC, a Graphics
 * object is disposed when the thread that obtained it re-enters the thread's message
 * loop.  Also, a graphics object that is obtained through a paint event is disposed 
 * when you are finished processing the event.  This means that you cannot store a graphics
 * object in a class variable to keep it around.
 *
 * @security(checkClassLinking=on)
 */
public class Graphics {
    private int    dc;
    private int    hWnd;
    private Brush  brush;
    private Pen    pen;
    private Font   font;
    private boolean realizeFont = false;
    private boolean ownDC = false;
    private Region defaultClipRegion = null;
    private Bitmap checkMask = null;
    
    private static final int stockPen    = Windows.GetStockObject(win.BLACK_PEN);
    private static final int stockBrush  = Windows.GetStockObject(win.WHITE_BRUSH);
    private static final int stockFont   = Windows.GetStockObject(win.SYSTEM_FONT);
    private static final int hollowBrush = Windows.GetStockObject(win.HOLLOW_BRUSH);

    #if DEBUG
    #endif 

    /**
     * Simple constructor that wraps an existing HDC.  The graphics object will assume
     * all properties of the given DC.  Note that the graphics object will not
     * claim ownership of this DC.  It is the caller's responsibility to free the DC
     * at the appropriate time.  Graphics objects that wrap an existing DC in this
     * way are disposed at garbage collection and not when the thread reenters the
     * message loop.
     *
     * @param dc The Win32 HDC.
     */
    public Graphics(int dc) {}

    /**
     * This constructor is called to associate a DC with a control.  If a zero DC
     * is given, this will create a DC for the given control.  If the graphics object
     * creates the DC, it will dispose itself when the thread reenters the message loop.
     *
     * @param control  The control to associate with the DC, or null for no association.
     * @param dc       The Win32 HDC, or zero to create one.
     * @param flags    Flags to be passed to the GetDCEx call.
     */
    protected Graphics(Control control, int dc, int flags) {}

    /**
     * Clears the object's clipping rectangle. 
     */
    public final void clearClip() {}

    /**
     * Clears the specified rectangle by filling with the background color for the Graphics
     * object. 
     *
     * @param rect The rectangle to clear.
     */
    public final void clearRect(Rectangle rect) {}

    /**
     * Clears the specified rectangle by filling with the background color for the Graphics
     * object. 
     *
     * @param x X coordinate of top left of rectangle.
     * @param y Y coordinate of top left of rectangle.
     * @param width Width of rectangle.
     * @param height Height of rectangle.
     */
    public final void clearRect(int x, int y, int width, int height) {}
    
    
    private static int createPOINTArray(Point [] points) {}

    /**
     * Creates a Graphics object that can draw anywhere on the display.
     * 
     * @return a Graphics object that can draw anywhere on the screen.
     */
    public static final Graphics createScreenGraphics() {}

    /**
     * Called when the Graphics object needs to destroy the underlying device
     * context handle (HDC).  It is called even if this Graphics object does not claim
     * ownership of the DC.  The default implementation of this method calls
     * ReleaseDC if the Graphics object owns the handle, and does nothing if the
     * Graphics object does not own the handle.
     * <p>
     * Extending classes can override this method to implement their own handle
     * creation/destruction semantics.
     */
    protected void destroyHandle() {}
    
    /**
     * Frees all resources allocated by this object.  Normally you do not need 
     * to call this as the garbage collector will cleanup graphics objects 
     * for you.  However, there may be times when you may want to expedite
     * the garbage collectors cleanup.
     */
    public void dispose() {}

    /** 
     * Draws a line segment and an arc.  The arc is drawn along
     * the perimeter of a circle with the given radius and center. The 
     * length of the arc is defined by the given start and sweep angles. The
     * arc is drawn by constructing an imaginary circle around the specified 
     * center point with the specified radius. The starting point of the arc 
     * is determined by measuring counterclockwise from the x-axis of the 
     * circle by the number of degrees in the start angle. The ending point 
     * is similarly located by measuring counterclockwise from the starting 
     * point by the number of degrees in the sweep angle. 
     *
     * @param center     The center of the arc circle.
     * @param radius     The radius of the circle.
     * @param startAngle Specifies the start angle, in degrees, relative to the x-axis. 
     * @param endAngle   Specifies the sweep angle, in degrees, relative to the starting angle. 
     */
    public final void drawAngleArc(Point center, int radius, float startAngle, float endAngle) {}

    /** 
     * Draws a line segment and an arc.  The arc is drawn along
     * the perimeter of a circle with the given radius and center. The 
     * length of the arc is defined by the given start and sweep angles. The
     * arc is drawn by constructing an imaginary circle around the specified 
     * center point with the specified radius. The starting point of the arc 
     * is determined by measuring counterclockwise from the x-axis of the 
     * circle by the number of degrees in the start angle. The ending point 
     * is similarly located by measuring counterclockwise from the starting 
     * point by the number of degrees in the sweep angle. 
     *
     * @param centerX    The X coordinate of the center of the arc circle.
     * @param centerY    The Y coordinate of the center of the arc circle.
     * @param radius     The radius of the circle.
     * @param startAngle Specifies the start angle, in degrees, relative to the x-axis. 
     * @param endAngle   Specifies the sweep angle, in degrees, relative to the starting angle. 
     */
    public final void drawAngleArc(int centerX, int centerY, int radius, float startAngle, float endAngle) {}

    /** 
     * Draws a line segment and an arc.  The arc is drawn along
     * the perimeter of a circle with the given radius and center. The 
     * length of the arc is defined by the given start and sweep angles. The
     * arc is drawn by constructing an imaginary circle around the specified 
     * center point with the specified radius. The starting point of the arc 
     * is determined by measuring counterclockwise from the x-axis of the 
     * circle by the number of degrees in the start angle. The ending point 
     * is similarly located by measuring counterclockwise from the starting 
     * point by the number of degrees in the sweep angle. 
     *
     * @param center     The center of the arc circle.
     * @param radius     The radius of the circle.
     * @param startAngle Specifies the start angle, in degrees, relative to the x-axis. 
     * @param endAngle   Specifies the sweep angle, in degrees, relative to the starting angle. 
     * @param op         A RasterOp to apply to the line.
     * 
     * @see RasterOp
     */
    public final void drawAngleArc(Point center, int radius, float startAngle, float endAngle, RasterOp op) {}

    /** 
     * Draws a line segment and an arc.  The arc is drawn along
     * the perimeter of a circle with the given radius and center. The 
     * length of the arc is defined by the given start and sweep angles. The
     * arc is drawn by constructing an imaginary circle around the specified 
     * center point with the specified radius. The starting point of the arc 
     * is determined by measuring counterclockwise from the x-axis of the 
     * circle by the number of degrees in the start angle. The ending point 
     * is similarly located by measuring counterclockwise from the starting 
     * point by the number of degrees in the sweep angle. 
     *
     * @param centerX    The X coorinate of the center of the arc circle.
     * @param centerY    The Y coorinate of the center of the arc circle.
     * @param radius     The radius of the circle.
     * @param startAngle Specifies the start angle, in degrees, relative to the x-axis. 
     * @param endAngle   Specifies the sweep angle, in degrees, relative to the starting angle. 
     * @param op         A RasterOp to apply to the line.
     * 
     * @see RasterOp
     */
    public final void drawAngleArc(int centerX, int centerY, int radius, float startAngle, float endAngle, RasterOp op) {}

    /**
     * Draws an elliptical arc in the specified bounding rectangle. An ellipse formed by the specified bounding
     * rectangle defines the curve of the arc. The arc extends in the current
     * drawing direction from the point where it intersects the radial from
     * the center of the bounding rectangle to the point "start". The arc 
     * ends where it intersects the radial from the center of the bounding
     * rectangle to the point "end". If the starting point and ending point
     * are the same, a complete ellipse is drawn.  The arc is always drawn
     * counter-clockwise.
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the arc.
     * @param end   Ending point for the arc.
     */
    public final void drawArc(Rectangle rect, Point start, Point end) {}

    /**
     * Draws an elliptical arc in the specified bounding rectangle. An ellipse formed by the specified bounding
     * rectangle defines the curve of the arc. The arc extends in the current
     * drawing direction from the point where it intersects the radial from
     * the center of the bounding rectangle to the point "start". The arc 
     * ends where it intersects the radial from the center of the bounding
     * rectangle to the point "end". If the starting point and ending point
     * are the same, a complete ellipse is drawn.  The arc is always drawn
     * counter-clockwise.
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the arc.
     * @param end   Ending point for the arc.
     * @param op    A RasterOp to apply to the drawing.
     * 
     * @see RasterOp
     */
    public final void drawArc(Rectangle rect, Point start, Point end, RasterOp op) {}

    /**
     * Draws an elliptical arc in the specified bounding rectangle. An ellipse formed by the specified bounding
     * rectangle defines the curve of the arc. The arc extends in the current
     * drawing direction from the point where it intersects the radial from
     * the center of the bounding rectangle to the point "start". The arc 
     * ends where it intersects the radial from the center of the bounding
     * rectangle to the point "end". If the starting point and ending point
     * are the same, a complete ellipse is drawn.  The arc is always drawn
     * counter-clockwise.
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the arc.
     * @param startY Y coordinate of the starting point for the arc.
     * @param endX   X coordinate of the ending point for the arc.
     * @param endY   Y coordinate of the ending point for the arc.
     */
    public final void drawArc(int x, int y, int width, int height, int startX, int startY, int endX, int endY) {}

    /**
     * Draws an elliptical arc in the specified bounding rectangle. An ellipse formed by the specified bounding
     * rectangle defines the curve of the arc. The arc extends in the current
     * drawing direction from the point where it intersects the radial from
     * the center of the bounding rectangle to the point "start". The arc 
     * ends where it intersects the radial from the center of the bounding
     * rectangle to the point "end". If the starting point and ending point
     * are the same, a complete ellipse is drawn.  The arc is always drawn
     * counter-clockwise.
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the arc.
     * @param startY Y coordinate of the starting point for the arc.
     * @param endX   X coordinate of the ending point for the arc.
     * @param endY   Y coordinate of the ending point for the arc.
     * @param op     A RasterOp to apply to the drawing.
     * 
     * @see RasterOp
     */
    public final void drawArc(int x, int y, int width, int height, int startX, int startY, int endX, int endY, RasterOp op) {}

    /** 
     * Draws one or more cubic Bezier curves by using the endpoints and control points
     * specified by the array of Point objects. The first curve 
     * is drawn from the first point to the fourth point by using the 
     * second and third points as control points. Each subsequent curve 
     * in the sequence needs exactly three more points: the ending point 
     * of the previous curve is used as the starting point, the next two 
     * points in the sequence are control points, and the third is the 
     * ending point. 
     *
     * @param points An array of points used to draw the curves.
     */
    public final void drawBezier(Point [] points) {}

    /** 
     * Draws one or more cubic Bezier curves by using the endpoints and control points
     * specified by the array of Point objects. The first curve 
     * is drawn from the first point to the fourth point by using the 
     * second and third points as control points. Each subsequent curve 
     * in the sequence needs exactly three more points: the ending point 
     * of the previous curve is used as the starting point, the next two 
     * points in the sequence are control points, and the third is the 
     * ending point. 
     *
     * @param points An array of points used to draw the curves.
     * @param op     A RasterOp to apply to the lines being drawn.
     * 
     * @see RasterOp
     */
    public final void drawBezier(Point [] points, RasterOp op) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  The default 3D style of
     * ETCHED is used.
     *
     * @param rect The Rectangle in which to draw the border.
     * 
     * @see Rectangle
     */
    public final void drawBorder3D(Rectangle rect) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  You may specify the style
     * of the 3D appearance. 
     *
     * @param rect  The Rectangle in which to draw the border.
     * @param style The 3D style to use when drawing the border.  Must be one of the
     *              Border3DStyle enumeration values.
     * 
     * @see Rectangle
     * @see Border3DStyle
     */
    public final void drawBorder3D(Rectangle rect, int style) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  You may specify the style
     * of the 3D appearance, and which sides of the 3D rectangle you wish to 
     * draw.
     *
     * @param rect  The rectangle in which to draw the border.
     * @param style The 3D style to use when drawing the border.  Must be one of the
     *              Border3DStyle enumeration values.
     * @param sides The sides of the rectangle you want to draw.  Must be one or more
     *              of the Border3DSide enumeration values.
     * 
     * @see Border3DStyle
     * @see Border3DSide
     */
    public final void drawBorder3D(Rectangle rect, int style, int sides) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  The default 3D style of
     * ETCHED is used.
     *
     * @param x      The X coordinate of the top left of the border rectangle.
     * @param y      The Y coordinate of the top left of the border rectangle.
     * @param width  The width of the border rectangle.
     * @param height The height of the border rectangle.
     */
    public final void drawBorder3D(int x, int y, int width, int height) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  You may specify the style
     * of the 3D appearance.
     *
     * @param x      The X coordinate of the top left of the border rectangle.
     * @param y      The Y coordinate of the top left of the border rectangle.
     * @param width  The width of the border rectangle.
     * @param height The height of the border rectangle.
     * @param style  The 3D style to use when drawing the border.  Must be one of the
     *               Border3DStyle enumeration values.
     * 
     * @see Border3DStyle
     */
    public final void drawBorder3D(int x, int y, int width, int height, int style) {}

    /**
     * Draws a three-dimensional style border around the specified rectangle.  You may specify the style
     * of the 3D appearance, and which sides of the 3D rectangle you wish to 
     * draw.
     *
     * @param x      The X coordinate of the top left of the border rectangle.
     * @param y      The Y coordinate of the top left of the border rectangle.
     * @param width  The width of the border rectangle.
     * @param height The height of the border rectangle.
     * @param style  The 3D style to use when drawing the border.  Must be one of the
     *               Border3DStyle enumeration values.
     * @param sides  The sides of the rectangle you want to draw.  Must be one or more
     *               of the Border3DSide enumeration values.
     * 
     * @see Border3DStyle
     * @see Border3DSide
     */
    public final void drawBorder3D(int x, int y, int width, int height, int style, int sides) {}
    
    /**
     * Draws a button control in the specified rectangle.
     *
     * @param rect  The coordiniates of the button to draw.
     * @param state One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawButton(Rectangle rect, int state) {}

    /**
     * Draws a button control in the specified rectangle.
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawButton(int x, int y, int width, int height, int state) {}
    
    /**
     * Draws a Win32 window caption button in the specified rectangle.
     *
     * @param rect   The coordiniates of the button to draw.
     * @param button A CaptionButton enum value that determines the caption button to draw.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see CaptionButton
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawCaptionButton(Rectangle rect, int button, int state) {}

    /**
     * Draws a Win32 window caption button in the specified rectangle.
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param button A CaptionButton enum value that determines the caption button to draw.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see CaptionButton
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawCaptionButton(int x, int y, int width, int height, int button, int state) {}

    /**
     * Draws a Win32 CheckBox control in the specified rectangle.
     *
     * @param rect  The coordiniates of the button to draw.
     * @param state One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawCheckBox(Rectangle rect, int state) {}

    /**
     * Draws a Win32 CheckBox control in the specified rectangle.
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawCheckBox(int x, int y, int width, int height, int state) {}

    /**
     * Draws a chord. The chord is outlined by 
     * using the current pen and filled by using the current brush. 
     * The curve of the chord is defined by an ellipse that fits the 
     * specified bounding rectangle. The curve begins at the point where
     * the ellipse intersects the first radial and extends counterclockwise
     * to the point where the ellipse intersects the second radial. (A 
     * radial is a line segment drawn from the center of the ellipse to a 
     * specified endpoint on the ellipse.) The chord is closed by drawing
     * a line from the intersection of the first radial and the curve to 
     * the intersection of the second radial and the curve. 
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the chord.
     * @param end   Ending point for the chord.
     */
    public final void drawChord(Rectangle rect, Point start, Point end) {}

    /**
     * Draws a chord. The chord is outlined by 
     * using the current pen and filled by using the current brush. 
     * The curve of the chord is defined by an ellipse that fits the 
     * specified bounding rectangle. The curve begins at the point where
     * the ellipse intersects the first radial and extends counterclockwise
     * to the point where the ellipse intersects the second radial. (A 
     * radial is a line segment drawn from the center of the ellipse to a 
     * specified endpoint on the ellipse.) The chord is closed by drawing
     * a line from the intersection of the first radial and the curve to 
     * the intersection of the second radial and the curve. 
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the chord.
     * @param end   Ending point for the chord.
     * @param op    A RasterOp to apply to the drawing.
     * 
     * @see RasterOp
     */
    public final void drawChord(Rectangle rect, Point start, Point end, RasterOp op) {}

    /**
     * Draws a chord. The chord is outlined by 
     * using the current pen and filled by using the current brush. 
     * The curve of the chord is defined by an ellipse that fits the 
     * specified bounding rectangle. The curve begins at the point where
     * the ellipse intersects the first radial and extends counterclockwise
     * to the point where the ellipse intersects the second radial. (A 
     * radial is a line segment drawn from the center of the ellipse to a 
     * specified endpoint on the ellipse.) The chord is closed by drawing
     * a line from the intersection of the first radial and the curve to 
     * the intersection of the second radial and the curve. 
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the chord.
     * @param startY Y coordinate of the starting point for the chord.
     * @param endX   X coordinate of the ending point for the chord.
     * @param endY   Y coordinate of the ending point for the chord.
     */
    public final void drawChord(int x, int y, int width, int height, int startX, int startY, int endX, int endY) {}

    /**
     * Draws a chord. The chord is outlined by 
     * using the current pen and filled by using the current brush. 
     * The curve of the chord is defined by an ellipse that fits the 
     * specified bounding rectangle. The curve begins at the point where
     * the ellipse intersects the first radial and extends counterclockwise
     * to the point where the ellipse intersects the second radial. (A 
     * radial is a line segment drawn from the center of the ellipse to a 
     * specified endpoint on the ellipse.) The chord is closed by drawing
     * a line from the intersection of the first radial and the curve to 
     * the intersection of the second radial and the curve. 
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the chord.
     * @param startY Y coordinate of the starting point for the chord.
     * @param endX   X coordinate of the ending point for the chord.
     * @param endY   Y coordinate of the ending point for the chord.
     * @param op     A RasterOp to apply to the drawing.
     * 
     * @see RasterOp
     */
    public final void drawChord(int x, int y, int width, int height, int startX, int startY, int endX, int endY, RasterOp op) {}

    /**
     * Draws the drop-down button of a Win32 combo box in the specified rectangle. 
     *
     * @param rect  The coordiniates of the button to draw.
     * @param state One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawComboButton(Rectangle rect, int state) {}

    /**
     * Draws the drop-down button of a Win32 combo box in the specified rectangle. 
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawComboButton(int x, int y, int width, int height, int state) {}

    /**
     * Draws an ellipse inside the given bounding box.
     *
     * @param rect The bounding rectangle to draw the elipse in.
     */
    public final void drawEllipse(Rectangle rect) {}

    /**
     * Draws an ellipse inside the given bounding box.
     *
     * @param x the  X coordinate of the top left corner of the bounding box.
     * @param y the  Y coordinate of the top left corner of the bounding box.
     * @param width  The width of the bounding box.
     * @param height The height of the bounding box.
     */
    public final void drawEllipse(int x, int y, int width, int height) {}

    /**
     * Draws an ellipse inside the given bounding box using the given @ see RasterOp.
     *
     * @param rect The bounding rectangle to draw the elipse in.
     * @param op   The RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawEllipse(Rectangle rect, RasterOp op) {}

    /**
     * Draws an ellipse inside the given bounding box using the given @ see RasterOp.
     *
     * @param x the  X coordinate of the top left corner of the bounding box.
     * @param y the  Y coordinate of the top left corner of the bounding box.
     * @param width  The width of the bounding box.
     * @param height The height of the bounding box.
     * @param op     The RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawEllipse(int x, int y, int width, int height, RasterOp op) {}
    
    
    private final void drawFlatCheckBox(int x, int y, int width, int height, int state) {}

    /**
     * Draws a Windows focus rectangle,
     * a dotted rectangle that Windows uses to indicate that a specified control has the input
     * focus.
     *
     * @param r The rectangle to draw.
     */
    public final void drawFocusRect(Rectangle r) {}

    /**
     * Draws a Windows focus rectangle,
     * a dotted rectangle that Windows uses to indicate that a specified control has the input
     * focus.
     *
     * @param x      X coordinate of upper left corner of rectangle to draw.
     * @param y      Y coordinate of upper left corner of rectangle to draw.
     * @param width  Width of rectangle to draw.
     * @param height Height of rectangle to draw.
     *
     */
    public final void drawFocusRect(int x, int y, int width, int height) {}

    /**
     * Draws an image at the specified location. 
     *
     * @param i  The image to draw.
     * @param pt The point to draw the image at.
     */
    public final void drawImage(Image i, Point pt) {}
    
    /**
     * Draws an image at the specified location. 
     *
     * @param i  The image to draw.
     * @param x  X coordinate of top left of image.
     * @param y  Y coordinate of top left of image.
     */
    public final void drawImage(Image i, int x, int y) {}
    
    /**
     * Draws an image at the specified location.
     *
     * @param i           The image to draw.
     * @param pt          The point to draw the image at.
     * @param op          The RasterOp to use while drawing.
     * 
     * @see RasterOp
     */
    public final void drawImage(Image i, Point pt, RasterOp op) {}
    
    /**
     * Draws an image at the specified location.
     *
     * @param i           The image to draw.
     * @param x           X coordinate of top left of image.
     * @param y           Y coordinate of top left of image.
     * @param op          The RasterOp to use while drawing.
     * 
     * @see RasterOp
     */
    public final void drawImage(Image i, int x, int y, RasterOp op) {}

    /**
     * Draws an image at the specified location.  If scale is true, this will stretch or
     * shrink the image to fit the rectangle.  Otherwise it will crop the image.
     *
     * @param i     The image to draw.
     * @param r     The rectangle to stretch or crop to.
     * @param scale <b>true</b> to scale the image, <b>false</b> to crop it.
     */
    public final void drawImage(Image i, Rectangle r, boolean scale) {}

    /**
     * Draws an image at the specified location.  If scale is true, this will stretch or
     * shrink the image to fit the rectangle.  Otherwise it will crop the image.
     *
     * @param i      The image to draw.
     * @param x      X coordinate of top left of bounding rectangle.
     * @param y      Y coordiniate of top left of bounding rectangle.
     * @param width  Width of bounding rectangle.
     * @param height Height of bounding rectangle.
     * @param scale  <b>true</b> to scale the image, <b>false</b> to crop it.
     */
    public final void drawImage(Image i, int x, int y, int width, int height, boolean scale) {}

    /**
     * Draws an image at the specified location.  If scale is true, this will stretch or
     * shrink the image to fit the rectangle.  Otherwise it will crop the image.
     *
     * @param i           The image to draw.
     * @param r           The rectangle to stretch or crop to.
     * @param scale       <b>true</b> to scale the image, <b>false</b> to crop it.
     * @param op          The RasterOp to use during the draw.
     * 
     * @see RasterOp
     */
    public final void drawImage(Image i, Rectangle r, boolean scale, RasterOp op) {}

    /**
     * Draws an image at the specified location.  If scale is true, this will stretch or
     * shrink the image to fit the rectangle.  Otherwise it will crop the image.
     *
     * @param i           The image to draw.
     * @param x           X coordinate of top left of bounding rectangle.
     * @param y           Y coordiniate of top left of bounding rectangle.
     * @param width       Width of bounding rectangle.
     * @param height      Height of bounding rectangle.
     * @param scale       <b>true</b> to scale the image, <b>false</b> to crop it.
     * @param op          The RasterOp to use during the draw.
     * 
     * @see RasterOp
     */
    public final void drawImage(Image i, int x, int y, int width, int height, boolean scale, RasterOp op) {}

    /**
     * Draws an image at the specified location.  If scale 
     * is <b>true</b>, this will stretch or shrink the image to the target rectangle.
     * Otherwise, it will crop the image.
     * 
     * @param i          The image to draw.
     * @param imageRect  The section of the image to draw.
     * @param targetRect The rectangle to draw the image into.
     * @param scale      <b>true</b> to scale the image, <b>false</b> to crop it.
     */
    public final void drawImage(Image i, Rectangle imageRect, Rectangle targetRect, boolean scale) {}
    
    /**
     * Draws an image at the specified location.  If scale 
     * is <b>true</b>, this will stretch or shrink the image to the target rectangle.
     * Otherwise, it will crop the image.  You may specify a RasterOp that will
     * determine how to draw the image.
     * 
     * @param i           The image to draw.
     * @param imageRect   The section of the image to draw.
     * @param targetRect  The rectangle to draw the image into.
     * @param scale       <b>true</b> to scale the image, <b>false</b> to crop it.
     * @param op          The RasterOp with which to render the image.
     * 
     * @see RasterOp
     */
    public final void drawImage(Image i, Rectangle imageRect, Rectangle targetRect, boolean scale, RasterOp op) {}

    /**
     * Draws a line from one point to another using the current pen.
     *
     * @param p1 The line starting point.
     * @param p2 The line ending point.
     */
    public final void drawLine(Point p1, Point p2) {}

    /**
     * Draws a line from one point to another using the current pen.
     *
     * @param x1 X coordinate of line starting point.
     * @param y1 Y coordinate of line starting point.
     * @param x2 X coordinate of line ending point.
     * @param y2 Y coordinate of line ending point.
     */
    public final void drawLine(int x1, int y1, int x2, int y2) {}

    /**
     * Draws a line from one point to another using the current pen.
     *
     * @param p1 The line starting point.
     * @param p2 The line ending point.
     * @param op A RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawLine(Point p1, Point p2, RasterOp op) {}

    /**
     * Draws a line from one point to another using the current pen.
     *
     * @param x1 X coordinate of line starting point.
     * @param y1 Y coordinate of line starting point.
     * @param x2 X coordinate of line ending point.
     * @param y2 Y coordinate of line ending point.
     * @param op A RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawLine(int x1, int y1, int x2, int y2, RasterOp op) {}

    /**
     * Draws a series of connected lines based on an array of points, and applies a raster
     * operation to the drawing. 
     *
     * @param points An array of points to draw.
     */
    public final void drawLines(Point [] points) {}

    /**
     * Draws a series of connected lines based on an array of points, and applies a raster
     * operation to the drawing.   The provided raster operation can be used to modify
     * the behavior of the pen.
     *
     * @param points An array of points to draw.
     * @param op     The RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawLines(Point [] points, RasterOp op) {}

    /**
     * Draws a menu glyph for a Win32 menu in the specified rectangle.
     *
     * @param rect  The coordiniates of the glyph.
     * @param glyph A MenuGlyph constant to determine what menu glyph to draw.
     *
     * @see MenuGlyph
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawMenuGlyph(Rectangle rect, int glyph) {}

    /**
     * Draws a menu glyph for a Win32 menu in the specified rectangle.
     *
     * @param x      X coordinate of the upper left corner of the glyph.
     * @param y      Y coordinate of the upper left corner of the glyph.
     * @param width  Width of the glyph.
     * @param height Height of the glyph.
     * @param glyph  A MenuGlyph constant to determine what menu glyph to draw.
     *
     * @see MenuGlyph
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawMenuGlyph(int x, int y, int width, int height, int glyph) {}

    /**
     * Draws a pie-shaped wedge bounded by the intersection of an ellipse and two radials. The pie is outlined by using the current pen and
     * filled by using the current brush. The curve of the pie is defined
     * by an ellipse that fits the specified bounding rectangle. The 
     * curve begins at the point where the ellipse intersects the first
     * radial and extends counterclockwise to the point where the ellipse
     * intersects the second radial. (A radial is a line drawn from the
     * center of the ellipse to the specified endpoint on the ellipse.) 
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the pie.
     * @param end   Ending point for the pie.
     */
    public final void drawPie(Rectangle rect, Point start, Point end) {}

    /**
     * Draws a pie-shaped wedge bounded by the intersection of an ellipse and two radials. The pie is outlined by using the current pen and
     * filled by using the current brush. The curve of the pie is defined
     * by an ellipse that fits the specified bounding rectangle. The 
     * curve begins at the point where the ellipse intersects the first
     * radial and extends counterclockwise to the point where the ellipse
     * intersects the second radial. (A radial is a line drawn from the
     * center of the ellipse to the specified endpoint on the ellipse.) 
     *
     * @param rect  Bounding rect for the ellipse.
     * @param start Starting point for the pie.
     * @param end   Ending point for the pie.
     * @param op    A RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawPie(Rectangle rect, Point start, Point end, RasterOp op) {}

    /**
     * Draws a pie-shaped wedge bounded by the intersection of an ellipse and two radials. The pie is outlined by using the current pen and
     * filled by using the current brush. The curve of the pie is defined
     * by an ellipse that fits the specified bounding rectangle. The 
     * curve begins at the point where the ellipse intersects the first
     * radial and extends counterclockwise to the point where the ellipse
     * intersects the second radial. (A radial is a line drawn from the
     * center of the ellipse to the specified endpoint on the ellipse.) 
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the pie.
     * @param startY Y coordinate of the starting point for the pie.
     * @param endX   X coordinate of the ending point for the pie.
     * @param endY   Y coordinate of the ending point for the pie.
     */
    public final void drawPie(int x, int y, int width, int height, int startX, int startY, int endX, int endY) {}

    /**
     * Draws a pie-shaped wedge bounded by the intersection of an ellipse and two radials. The pie is outlined by using the current pen and
     * filled by using the current brush. The curve of the pie is defined
     * by an ellipse that fits the specified bounding rectangle. The 
     * curve begins at the point where the ellipse intersects the first
     * radial and extends counterclockwise to the point where the ellipse
     * intersects the second radial. (A radial is a line drawn from the
     * center of the ellipse to the specified endpoint on the ellipse.) 
     *
     * @param x      X coordinate of the top left of the bounding rect for the ellipse.
     * @param y      Y coordinate of the top left of the bounding rect for the ellipse.
     * @param width  Width of the bounding rect for the ellipse.
     * @param height Height of the bounding rect for the ellipse.
     * @param startX X coordinate of the starting point for the pie.
     * @param startY Y coordinate of the starting point for the pie.
     * @param endX   X coordinate of the ending point for the pie.
     * @param endY   Y coordinate of the ending point for the pie.
     * @param op     A RasterOp to apply to the pen.
     * 
     * @see RasterOp
     */
    public final void drawPie(int x, int y, int width, int height, int startX, int startY, int endX, int endY, RasterOp op) {}

    /**
     * Draws a polygon based on a specified array of vertices.  The point array must have at least
     * two elements.  The polygon will be drawn using the current pen and brush properties
     * and will be automatically closed.
     *
     * @param vertices  Array of points that define the vertices of the polygon.  The
     *                         array must consist of at least two points.
     */
    public final void drawPolygon(Point [] vertices) {}

    /**
     * Draws a polygon based on a specified array of vertices.  The point array must have at least
     * two elements.  The polygon will be drawn using the current pen and brush properties
     * and will be automatically closed.  The RasterOp can be used to modify the pen that
     * is used to draw the polygon vertices.
     *
     * @param vertices  Array of points that define the vertices of the polygon.  The
     *                  array must consist of at least two points.
     * @param op        A RasterOp that determines how to draw the polygon lines.
     * 
     * @see RasterOp
     */
    public final void drawPolygon(Point [] vertices, RasterOp op) {}

    /**
     * Draws a polygon based on a specified array of vertices.  The point array must have at least
     * two elements.  The polygon will be automatically closed.
     *
     * @param vertices  Array of points that define the vertices of the polygon.  The
     *                  array must consist of at least two points.
     * @param op        A RasterOp that determines how to draw the polygon lines.
     * @param fillMode  One of the values from the PolyFillMode enum, which decides
     *                  how the polygon will be filled.
     * 
     * @see RasterOp
     */
    public final void drawPolygon(Point [] vertices, RasterOp op, int fillMode) {}

    /**
     * Draws a Win32 radio button in the specified rectangle.
     *
     * @param rect  The coordiniates of the button to draw.
     * @param state One or more ButtonState flags that determine 
     *              how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawRadioButton(Rectangle rect, int state) {}

    /**
     * Draws a Win32 radio button in the specified rectangle.
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param state  One or more ButtonState flags that determine 
     *               how to draw the button.
     *
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawRadioButton(int x, int y, int width, int height, int state) {}
    
    /** 
     * Draws a rectangle using the specified coordinates.  The rectangle is drawn using
     * the current brush as the background and the current pen as the edge.
     *
     * @param rect The coordinates of the rectangle.
     */
    public final void drawRect(Rectangle rect) {}

    /** 
     * Draws a rectangle using the specified coordinates.  The rectangle is drawn using
     * the current brush as the background and the current pen as the edge.
     *
     * @param x      X coordinate of top left corner of rectangle.
     * @param y      Y coordinate of top left corner of rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     */
    public final void drawRect(int x, int y, int width, int height) {}

    /** 
     * Draws a rectangle using the specified coordinates.  The rectangle is drawn using
     * the current brush as the background and the current pen as the edge.
     *
     * @param rect The coordinates of the rectangle.
     * @param op   The RasterOp to apply to the rectangle's pen and brush.
     * 
     * @see RasterOp
     */
    public final void drawRect(Rectangle rect, RasterOp op) {}

    /** 
     * Draws a rectangle using the specified coordinates.  The rectangle is drawn using
     * the current brush as the background and the current pen as the edge.
     *
     * @param x      X coordinate of top left corner of rectangle.
     * @param y      Y coordinate of top left corner of rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     * @param op     The RasterOp to apply to the rectangle's pen and brush.
     * 
     * @see RasterOp
     */
    public final void drawRect(int x, int y, int width, int height, RasterOp op) {}

    /**
     * Draws a rectangle with rounded corners using the current pen and fill brush.  The rectangle is drawn using the current
     * pen and filled using the current brush.
     *
     * @param rect   The rectangle to draw.
     * @param radius The radius of each of the corners.
     */
    public final void drawRoundedRect(Rectangle rect, int radius) {}

    /**
     * Draws a rectangle with rounded corners using the current pen and fill brush.  The rectangle is drawn using the current
     * pen and filled using the current brush.
     *
     * @param rect   The rectangle to draw.
     * @param radius The radius of each of the corners.
     * @param op     The RasterOp to apply to the drawing border pen.
     * 
     * @see RasterOp
     */
    public final void drawRoundedRect(Rectangle rect, int radius, RasterOp op) {}

    /**
     * Draws a rectangle with rounded corners using the current pen and fill brush.  The rectangle is drawn using the current
     * pen and filled using the current brush.
     *
     * @param x      X coordinate of the rectangle's upper left corner.
     * @param y      Y coordinate of the rectangle's upper left corner.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     * @param radius The radius of each of the corners.
     */
    public final void drawRoundedRect(int x, int y, int width, int height, int radius) {}

    /**
     * Draws a rectangle with rounded corners using the current pen and fill brush.  The rectangle is drawn using the current
     * pen and filled using the current brush.
     *
     * @param x      X coordinate of the rectangle's upper left corner.
     * @param y      Y coordinate of the rectangle's upper left corner.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     * @param radius The radius of each of the corners.
     * @param op     The RasterOp to apply to the drawing border pen.
     * 
     * @see RasterOp
     */
    public final void drawRoundedRect(int x, int y, int width, int height, int radius, RasterOp op) {}

    /**
     * Draws a button for a Win32 scroll bar.
     *
     * @param rect   The coordiniates of the button to draw.
     * @param button A ScrollButton enum value to determine the scroll bar button to draw.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see ScrollButton
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawScrollButton(Rectangle rect, int button, int state) {}

    /**
     * Draws a button for a Win32 scroll bar.
     *
     * @param x      X coordinate of the upper left corner of the drawing rectangle.
     * @param y      Y coordinate of the upper left corner of the drawing rectangle.
     * @param width  Width of the button.
     * @param height Height of the button.
     * @param button A ScrollButton enum value to determine the scroll bar button to draw.
     * @param state  One or more ButtonState flags that determine how to draw the button.
     *
     * @see ScrollButton
     * @see ButtonState
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawScrollButton(int x, int y, int width, int height, int button, int state) {}

    /**
     * Draws a sizing grip at the specified location.  A sizing grip is usually located at
     * the lower right corner of a window.
     *
     * @param rect The coordiniates of the grip.
     *
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawSizeGrip(Rectangle rect) {}

    /**
     * Draws a sizing grip at the specified location.  A sizing grip is usually located at
     * the lower right corner of a window.
     *
     * @param x      X coordinate of the upper left corner of the grip.
     * @param y      Y coordinate of the upper left corner of the grip.
     * @param width  Width of the grip.
     * @param height Height of the grip.
     *
     * @see #drawButton
     * @see #drawCaptionButton
     * @see #drawCheckBox
     * @see #drawComboButton
     * @see #drawMenuGlyph
     * @see #drawRadioButton
     * @see #drawScrollButton
     * @see #drawSizeGrip
     */
    public final void drawSizeGrip(int x, int y, int width, int height) {}
    
    
    private String validateDrawString(String s) {}
    
    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s The string to draw.
     * @param p The point to draw it at.
     */
    public final void drawString(String s, Point p) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s      The string to draw.
     * @param p      The point to draw it at.
     * @param format One or more TextFormat flags that specify 
     *               how to draw the string.
     * 
     * @see TextFormat
     */
    public final void drawString(String s, Point p, int format) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s The string to draw.
     * @param x X coordinate to draw at.
     * @param y Y coordinate to draw at.
     */
    public final void drawString(String s, int x, int y) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s      The string to draw.
     * @param x      X coordinate to draw at.
     * @param y      Y coordinate to draw at.
     * @param format One or more TextFormat flags that specify 
     *               how to draw the string.
     * 
     * @see TextFormat
     */
    public final void drawString(String s, int x, int y, int format) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s      The string to draw.
     * @param rect   A rectangle to draw the string in.
     * @param format One or more TextFormat flags that specify 
     *               how to draw the string.
     * 
     * @see TextFormat
     */
    public final void drawString(String s, Rectangle rect, int format) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s      The string to draw.
     * @param x      X coordinate of the top left of the text bounding rectangle.
     * @param y      Y coordinate of the top left of the text bounding rectangle.
     * @param width  Width of text bounding rectangle.
     * @param height Height of text bounding rectangle.
     * @param format One or more TextFormat flags that specify 
     *               how to draw the string.
     * 
     * @see TextFormat
     */
    public final void drawString(String s, int x, int y, int width, int height, int format) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s        The string to draw.
     * @param p        The point to draw it at.
     * @param tabStops An array of tab positions.  If there is a single value 
     *                 in the array, that value will be used for all tab stops.
     *                 If tabStops is <b>null</b>, a default of 8 will be used for the
     *                 tab width.
     */
    public final void drawString(String s, Point p, int [] tabStops) {}

    /**
     * Draws a string at the specified point or within the specified area.
     *
     * @param s        The string to draw.
     * @param x        X coordinate to draw at.
     * @param y        Y coordinate to draw at.
     * @param tabStops An array of tab positions.  If there is a single value 
     *                 in the array, that value will be used for all tab stops.
     *                 If tabStops is <b>null</b>, a default of 8 will be used for the
     *                 tab width.
     */
    public final void drawString(String s, int x, int y, int [] tabStops) {}

    /**
     * Removes the specified rectangle from the current clipping region.
     * 
     * @param rect   The rectangle to excluding from the clipping region.
     */
    public final void excludeFromClip(Rectangle rect) {}
    
    /**
     * Removes the specified rectangle from the current clipping region.
     * 
     * @param x       The X coordinate of the top left of the rectangle.
     * @param y       The Y coordinate of the top left of the rectangle.
     * @param width   The width of the rectangle.
     * @param height  The height of the rectangle.
     */
    public final void excludeFromClip(int x, int y, int width, int height) {}
    
    /**
     * Removes the specified rectangle from the current clipping region.
     * 
     * @param region   The region to excluding from the clipping region.
     */
    public final void excludeFromClip(Region region) {}

    /** 
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param rc The rectangle to fill.
     */
    public final void fill(Rectangle rc) {}
    
    /** 
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param x      X coordinate of top left corner of rectangle.
     * @param y      Y coordinate of top left corner of rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     */
    public final void fill(int x, int y, int width, int height) {}
    
    /** 
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param rc The rectangle to fill.
     * @param br The brush to fill it with.
     */
    public final void fill(Rectangle rc, Brush br) {}
    
    /** 
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param x      X coordinate of top left corner of rectangle.
     * @param y      Y coordinate of top left corner of rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     * @param br     The brush to fill it with.
     */
    public final void fill(int x, int y, int width, int height, Brush br) {}
    
    /** 
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param rc The rectangle to fill.
     * @param br The brush to fill it with.
     * @param op The raster operation to apply to the fill.
     */
    public final void fill(Rectangle rc, Brush br, RasterOp op) {}
    
    /** 
     * Fills a specified area of the display with the current  or specified brush.
     *
     * @param x      X coordinate of top left corner of rectangle.
     * @param y      Y coordinate of top left corner of rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     * @param brush  The brush to use.
     * @param op     The raster operation to apply to the filled area.
     */
    public final void fill(int x, int y, int width, int height, Brush brush, RasterOp op) {}
    
    /**
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param region The region to fill.
     */
    public final void fill(Region region) {}
    
    /**
     * Fills a specified area of the display with the current  or specified brush.
     * 
     * @param region The region to fill.
     * @param brush  The brush to fill it with.
     */
    public final void fill(Region region, Brush brush) {}

    /**
     * Fills a specified area with the current brush. There are
     * two types of flood fills:  border and surface.  A border flood fill 
     * assumes that the area to be filled is completely bounded by the color
     * specified by <i>color</i>. A border flood fill begins filling
     * at the point specified and continues in all directions until it 
     * reaches the boundary color.   A surface fill, on the other hand,
     * assumes that the area to be filled is of a single color. It
     * begins to fill the area at the point specified and continues in all
     * directions, filling all adjacent regions containing the given color.
     * The starting point must already be of color <i>color</i>.
     *
     * @param start Starting point for the fill.
     * @param color The color the flood fill will use as a boundary.
     * @param type  The type of the fill.  This must be one of the
     *              FloodFillType enum values.
     */
    public final void floodFill(Point start, Color color, int type) {}

    /**
     * Fills a specified area with the current brush. There are
     * two types of flood fills:  border and surface.  A border flood fill 
     * assumes that the area to be filled is completely bounded by the color
     * specified by <i>color</i>. A border flood fill begins filling
     * at the point specified and continues in all directions until it 
     * reaches the boundary color.   A surface fill, on the other hand,
     * assumes that the area to be filled is of a single color. It
     * begins to fill the area at the point specified and continues in all
     * directions, filling all adjacent regions containing the given color.
     * The starting point must already be of color <i>color</i>.
     *
     * @param x     X coordinate of the starting point for the fill.
     * @param y     Y coordinate of the starting point for the fill.
     * @param color The color the flood fill will use as a boundary.
     * @param type  The type of the fill.  This must be one of the
     *              FloodFillType enum values.
     */
    public final void floodFill(int x, int y, Color color, int type) {}

    /**
     * Disposes of the resources allocated by this object.  Here we just ensure that we've disposed of our Win32 resources
     */
    protected void finalize() {}

    /**
     * Retrieves the current background color.
     * 
     * @return the current background color.
     * @see #setBackColor
     * @see Color
     */
    public final Color getBackColor() {}

    /**
     * Retrieves the current brush.
     * 
     * @return the current Brush.
     * @see #setBrush
     * @see Brush
     */
    public final Brush getBrush() {}

    /**
     * Retrieves the current brush origin.  You may modify this origin to align
     * brush patterns.  This is only meaningful if you are drawing with a brush
     * that has a pattern.
     *
     * @return the current brush origin.
     * @see #setBrushOrigin
     */
    public final Point getBrushOrigin() {}

    /**
     * Retrieves the current clipping region for this object.
     * 
     * @return a Region object that contains the current clipping region,
     *         or null if there is no current clipping region.
     * 
     * @see Region
     * @see #setClip
     */
    public final Region getClip() {}
    
    /**
     * Retrieves the coordinate system that this
     * object is currently using.
     * This will be one of the values in the CoordinateSystem enum.
     * 
     * @return a value representing the current coordinate system the 
     *         graphics object is using.
     * 
     * @see CoordinateSystem
     * @see #setCoordinateSystem
     */
    public final int getCoordinateSystem() {}
    
    /**
     * Retrieves the device origin for a user-defined coordinate system.
     * 
     * @return a point representing the current device origin.
     * 
     * @see #setDeviceOrigin
     */
    public final Point getDeviceOrigin() {}
    
    /**
     * Converts the specified coordinates to device coordinates.
     * 
     * @param pt A point in logical units.
     * @return a point object in device coordinates.
     */
    public final Point getDevicePoint(Point pt) {}
    
    /**
     * Converts the specified coordinates to device coordinates.
     * 
     * @param x X logical coordinate to convert.
     * @param y Y logical coordniate to convert.
     * @return a point object in device coordinates.
     */
    public final Point getDevicePoint(int x, int y) {}
    
    /**
     * Retrieves the current device scale for a
     * user-defined coordinate system.
     * 
     * @return a point representing the current device scaling units.
     * 
     * @see #setCoordinateScale
     */
    public final Point getDeviceScale() {}

    /**
     * Converts the specified point to logical coordinates.
     * 
     * @param pt A point in device units.
     * @return a point object in logical coordinates.
     */
    public final Point getLogicalPoint(Point pt) {}
    
    /**
     * Converts the specified point to logical coordinates.
     * 
     * @param x X device coordinate to convert.
     * @param y Y device coordniate to convert.
     * @return a point object in logical coordinates.
     */
    public final Point getLogicalPoint(int x, int y) {}
    
    /**
     * Retrieves the page origin for a user-defined coordinate system.
     * 
     * @return a point representing the current page origin.
     * 
     * @see #setCoordniateOrigin
     */
    public final Point getPageOrigin() {}

    /**
     * Retrieves the current page scale for a user-defined coordinate system.
     * 
     * @return a point representing the current page scaling units.
     * 
     * @see #setCoordinateScale
     */
    public final Point getPageScale() {}
    
    /**
     * Retrieves the current font for this object.
     * 
     * @return the current font.
     * 
     * @see Font
     * @see #setFont
     */
    public final Font getFont() {}
    
    /**
     * Retrieves an array of FontDescriptor objects, which contains an entry
     * for each font that matches the specified face name.
     * @see FontDescriptor objects for all fonts this graphics
     * can render.
     * 
     * @return an array of FontDescriptor values.
     */
    public final FontDescriptor[] getFontDescriptors() {}
    
    /**
     * Retrieves an array of FontDescriptor objects, which contains an entry
     * for each font that matches the specified face name.
     * 
     * @param charSet The character set to search for.
     * @return an array of FontDescriptor values.
     * 
     * @see FontDescriptor
     */
    public final FontDescriptor[] getFontDescriptors(int charSet) {}

    /**
     * Retrieves an array of FontDescriptor objects, which contains an entry
     * for each font that matches the specified face name.
     * 
     * @param name The font's face name.
     * @return an array of FontDescriptor values.
     * 
     * @see FontDescriptor
     */
    public final FontDescriptor[] getFontDescriptors(String name) {}

    /**
     * Retrieves an array of FontDescriptor objects, which contains an entry
     * for each font that matches the specified face name.
     * 
     * @param charSet The character set to search for.
     * @param name    The font's face name.
     * @return an array of FontDescriptor values.
     * 
     * @see FontDescriptor
     */
    public final FontDescriptor[] getFontDescriptors(int charSet, String name) {}

    /**
     * Retrieves the Win32 device context handle (HDC) for this Graphics
     * object.
     * 
     * @return a Win32 HDC handle.
     */
    public int getHandle() {}

    /**
     * Retrieves the number of logical units that make up the specified number of inches.  These units
     * may be scaled or translated by the Graphics object.  This utility
     * function allows you to get the number of logical units required
     * for the given number of inches.
     *
     * @param inches The number of inches.
     * @return the number of logical units that make up the given number of inches.
     */
    public final int getLogicalSizeX(float inches) {}
    
    /**
     * Retrieves the number of logical units that make up the specified number of inches.  These units
     * may be scaled or translated by the Graphics object.  This utility
     * function allows you to get the number of logical units required
     * for the given number of inches.
     *
     * @param inches The number of inches.
     * @return the number of logical units that make up the given number of inches.
     */
    public final int getLogicalSizeY(float inches) {}
    
    /**
     * Retrieves the current fill mode on the Graphics object.
     * 
     * @return <b>true</b> if the current background color will be
     *         used to fill the background before drawing, or <b>false</b> if
     *         no such fill should occur.
     * @see #setOpaque
     */
    public final boolean getOpaque() {}

    /**
     * Retrieves the pen associated with the Graphics object.
     * 
     * @return the current pen.
     * 
     * @see Pen
     * @see #setPen
     */
    public final Pen getPen() {}

    /**
     * Retrieves, in inches, the physical size for a specified number of horizontal logical
     * coordinates.  These units
     * may be scaled or translated by the Graphics object.  This utility
     * function allows you to get the physical size for a given number
     * of logical units.  The physical size will be returned in inches.
     *
     * @param units The number of logical units to get the size for.
     * @return the number of inches the given logical units represent.
     */
    public final float getPhysicalSizeX(int units) {}
    
    /**
     * Retrieves, in inches, the physical size for a specified number of vertical logical
     * coordinates.  These units
     * may be scaled or translated by the Graphics object.  This utility
     * function allows you to get the physical size for a given number
     * of logical units.  The physical size will be returned in inches.
     *
     * @param units The number of logical units to get the size for.
     * @return the number of inches the given logical units represent.
     */
    public final float getPhysicalSizeY(int units) {}
    
    /**
     * Retrieves the color of the specified pixel.
     * 
     * @param pt The point in question.
     * @return the color of the pixel at the given point.
     * 
     * @see Color
     * @see #setPixel
     */
    public final Color getPixel(Point pt) {}
    
    /**
     * Retrieves the color of the specified pixel.
     * 
     * @param x The x coordinate of the pixel to get.
     * @param y The y coordinate of the pixel to get.
     * @return the color of the pixel at the given point.
     * 
     * @see Color
     * @see #setPixel
     */
    public final Color getPixel(int x, int y) {}

    /**
     * Retrieves the closest solid color that the hardware will use for the specified color.
     *
     * @param color The color you would like to draw with.
     * @return the nearest color the hardware can reproduce.
     * 
     * @see Color
     */
    public final Color getNearestColor(Color color) {}

    /** 
     * Retrieves the color used to display text in the Graphics object's
     * bounding rectangle.
     * 
     * @return the color in which text will be drawn.
     * 
     * @see Color
     * @see #getTextColor
     */
    public final Color getTextColor() {}

    /**
     * Retrieves the amount of extra space that will be used between characters when drawing
     * text.  You
     * can set this to create special effects.
     * 
     * @return the amount of extra space that will be used between characters when drawing
     *         text.
     * @see #setTextSpace
     */
    public final int getTextSpace() {}

    /**
     * Retrieves the area required to display the specified text string using the current font
     * settings. 
     *
     * @param text  The text to get the size of.
     * @return a point with the width and height of the text.
     */
    public final Point getTextSize(String text) {}

    /**
     * Retrieves the area required to display the specified text string using the current font
     * settings. 
     *
     * @param text      The text to get the size of.
     * @param tabStops  An array of tabstops to use to format this text.
     * @return a point with the width and height of the text.
     */
    public Point getTextSize(String text, int [] tabStops) {}

    /**
     * Retrieves the area required to display the specified text string using the current font
     * settings. 
     *
     * @param text      The text to get the size of.
     * @param width     The margin width where text wrapping, if specified, will be applied.
     * @param format    One or more @see TextFormat options to specify how the text should be drawn.
     * @return a point with the width and height of the text.
     */
    public Point getTextSize(String text, int width, int format) {}

    /**
     * Sets the clipping region for this object to include the area of this object's clipping
     * region that intersects with a specified rectangle or region.
     * 
     * @param rect   The rectangle to intersect.
     */
    public final void intersectWithClip(Rectangle rect) {}
    
    /**
     * Sets the clipping region for this object to include the area of this object's clipping
     * region that intersects with a specified rectangle or region.
     * 
     * @param x       The X coordinate of the top left of the rectangle.
     * @param y       The Y coordinate of the top left of the rectangle.
     * @param width   The width of the rectangle.
     * @param height  The height of the rectangle.
     */
    public final void intersectWithClip(int x, int y, int width, int height) {}
    
    /**
     * Sets the clipping region for this object to include the area of this object's clipping
     * region that intersects with a specified rectangle or region.
     * 
     * @param region   The region to intersect.
     */
    public final void intersectWithClip(Region region) {}
    
    /**
     * Inverts the pixels in the specified rectangle.
     *
     * @param rect The rectangle to invert.
     */
    public final void invert(Rectangle rect) {}

    /**
     * Inverts the pixels in the specified rectangle.
     *
     * @param x      X coordinate of top left of the rectangle.
     * @param y      Y coordinate of top left of the rectangle.
     * @param width  Width of the rectangle.
     * @param height Height of the rectangle.
     */
    public final void invert(int x, int y, int width, int height) {}
    
    /**
     * Inverts the pixels in the specified rectangle.
     * 
     * @param region The region to invert.
     * @see Region
     */
    public final void invert(Region region) {}

    
    static final void onEnterMessageLoop(int hWnd) {}

    
    private final void realizeBrush() {}
    
    
    private final void realizeFont() {}
    
    /**
     * Renders the specified palette to this Graphics object.  Palettes are used to control
     * the colors that are available for drawing when using display devices that only
     * support 256 colors.  By using the palette to determine which 256 colors the display
     * will use, bitmaps can be drawn with near true color quality.
     *
     * @param palette         The new Palette to render.
     * @param forceBackground <b>true</b> if the caller wants to force a background repaint.
     * @return the previous palette.
     *
     * @see Bitmap
     * @see Palette
     */
    public Palette renderPalette(Palette palette, boolean forceBackground) {}

    /**
     * Scrolls an area of the Graphics object.  This is designed to be very fast
     * and is typically used with scrollbars to quickly scroll a region of the client area.
     *
     * @param scrollX    The amount to scroll in the X direction.  Negative values will scroll to the left.
     * @param scrollY    The amount to scroll in the Y direction.  Netative values will scroll up.
     * @param scrollArea The rectangular area to scroll.
     * @param clipArea   The scrolling is confined to this rectangle.
     */
    public final void scroll(int scrollX, int scrollY, Rectangle scrollArea, Rectangle clipArea) {}

    /** 
     * Sets the background color for the Graphics object. After you set the
     * background color for the Graphics object, that color is used to fill
     * empty regions in the object's bounding rectangle.
     *
     * @param color  The color to use.
     * 
     * @see Color
     * @see #getBackColor
     */
    public final void setBackColor(Color color) {}

    /**
     * Associates a brush with this Graphics object.   Brushes are used to paint or fill areas with
     * color and patterns.
     *
     * @param brush The brush to use.
     * 
     * @see Brush
     * @see #getBrush
     */
    public final void setBrush(Brush brush) {}

    /**
     * Sets the brush origin for this Graphics object. The default
     * coordinates for the brush origin are 0,0.  You may modify this origin to align
     * brush patterns.  This function modifies the current brush origin.
     *
     * @param pt The point to set the brush origin to.
     * 
     * @see #getBrushOrigin
     */
    public final void setBrushOrigin(Point pt) {}

    /**
     * Sets the brush origin for this Graphics object. The default
     * coordinates for the brush origin are 0,0.  You may modify this origin to align
     * brush patterns.  This function modifies the current brush origin.
     *
     * @param x X coordinate of the brush origin.
     * @param y Y coordinate of the brush origin.
     *
     * @see #getBrushOrigin
     */
    public final void setBrushOrigin(int x, int y) {}

    /**
     * Sets the clipping region for this Graphics object to the specified
     * rectangle.  Note that this actually performs the intersection
     * between the default clipping region of the graphics object and 
     * the given rectangle, so system-defined clipping regions will 
     * be properly preserved.
     * 
     * @param rect   The rectangle to set the clipping region to.
     *               This may be null to remove all user-defined
     *               clipping.
     * @see #getClip
     */
    public final void setClip(Rectangle rect) {}
    
    /**
     * Sets the clipping region for this Graphics object to the specified
     * rectangle.  Note that this actually performs the intersection
     * between the default clipping region of the graphics object and 
     * the given rectangle, so system-defined clipping regions will 
     * be properly preserved.
     * 
     * @param x       The X coordinate of the top left of the rectangle.
     * @param y       The Y coordinate of the top left of the rectangle.
     * @param width   The width of the rectangle.
     * @param height  The height of the rectangle.
     * 
     * @see #getClip
     */
    public final void setClip(int x, int y, int width, int height) {}
    
    /**
     * Sets the clipping region for this Graphics object to the specified
     * rectangle.  Note that this actually performs the intersection
     * between the default clipping region of the graphics object and 
     * the given region, so system-defined clipping regions will 
     * be properly preserved.
     * 
     * @param region   The region to set the clipping region to.
     *                 This may be null to remove all user-defined
     *                 clipping.
     * @see #getClip
     */
    public final void setClip(Region region) {}
    
    /**
     * Sets up the origin for a user-defined coordinate system.  This method can only
     * be used if the current coordinate system is CoordinateSystem.ISOTROPIC or
     * CoordinateSystem.ANISOTROPIC.<p>
     * 
     * Win32 defines all coordinates with <b>page space</b> or <b>device space</b>.
     * <b>Page space</b> is the logical coordinate system that all graphics calls
     * use.  <b>Device space</b> is the physical coordinate system that represents
     * a window or printer page.  All page space coordinates are in logical units
     * for the page's coordinate system.  All device space coordinates are in pixels.<p>
     * 
     * You can set both the scaling and origin of the transformation Graphics uses
     * to go from page space to device space.  The originis set here.  The scaling
     * factor can be set through setCoordinateScale.<p>
     * 
     * The following formula shows the math involved in converting a point from 
     * page space to device space:<p>
     *
     * Dx = ((Px - POx) * DSx / PSx) + DOx<p>
     *
     * The following variables are involved:<p>
     *
     * Dx  x value in device units<p>
     * Px  x value in page space units<p>
     * POx page x origin<p>
     * DOx device x origin<p>
     * PSx page scaling factor<p>
     * DEx device scaling factor<p>
     *
     * @param page   The page space coordinate origin.  This is always in the
     *               coordinates for the page.  This value can be null to leave
     *               the current page origin as-is.
     * @param device The device space coordinate origin.  This is always in
     *               physical device coordinates (pixels).  This value
     *               can be null to leave the current device origin as-is.
     * 
     * @see #getCoordinateOrigin
     * @see #setCoordniateScale
     */
    public final void setCoordinateOrigin(Point page, Point device) {}
    
    /**
     * Sets up the coordinate scale for a user-defined coordinate system.  This method can only
     * be used if the current coordinate system is CoordinateSystem.ISOTROPIC or
     * CoordinateSystem.ANISOTROPIC.<p>
     * 
     * Win32 defines all coordinates with <b>page space</b> or <b>device space</b>.
     * <b>Page space</b> is the logical coordinate system that all graphics calls
     * use.  <b>Device space</b> is the physical coordinate system that represents
     * a window or printer page.  All page space coordinates are in logical units
     * for the page's coordinate system.  All device space coordinates are in pixels.<p>
     * 
     * You can set both the scaling and origin of the transformation Graphics uses
     * to go from page space to device space.  The scaling factor is set here.  The
     * origin can be set through setCoordinateOrigin.<p>
     * 
     * The following formula shows the math involved in converting a point from 
     * page space to device space:<p>
     *
     * Dx = ((Px - POx) * DSx / PSx) + DOx<p>
     *
     * The following variables are involved:<p>
     *
     * Dx  x value in device units<p>
     * Px  x value in page space units<p>
     * POx page x origin<p>
     * DOx device x origin<p>
     * PSx page scaling factor<p>
     * DEx device scaling factor<p>
     *
     * @param page   The page space coordinate scaling factor.  This is always
     *                      in the logical coordinates for the page.  This value can 
     *                      be null to leave the current page scaling as-is.
     * @param device The device space coordinate scaling factor.  This is 
     *                      always in physical device coordinates (pixels).  This value
     *                      can be null to leave the current device scaling as-is.
     * 
     * @see #getCoordinateScale
     * @see #setCoordniateOrigin
     */
    public final void setCoordinateScale(Point page, Point device) {}
    
    /**
     * Sets the coordinate system for this Graphics object.
     * 
     * @param system One of the values of the CoordinateSystem enum.
     * 
     * @see CoordinateSystem
     * @see #getCoordinateSystem
     */
    public final void setCoordinateSystem(int system) {}
    
    /**
     * Associates a font with the Graphics object. 
     *
     * @param font The font to use.
     * 
     * @see Font
     * @see #getFont
     */
    public final void setFont(Font font) {}

    /**
     * This method is called when the Graphics object initializes a handle to
     * device context (HDC) at object startup.  The
     * default implementation ensures that the graphics object and DC's
     * GDI objects are in sync.  You may override this if you are extending
     * graphics and you need your own functionality here.  You should always
     * call super.setHandle, however.
     * 
     * @param dc The Windows HDC to setup.  This should never be <b>null</b>
     *           (use dispose() to clear the existing handle).
     */
    protected void setHandle(int dc) {}

    /**
     * Sets the background fill mode for the Graphics object.
     *
     * @param opaque  If <b>true</b>, the background will be filled 
     *                       with the current background color before drawing.  
     *                       Otherwise, no fill will occur.
     * @see #getOpaque
     */
    public final void setOpaque(boolean opaque) {}

    /**
     * Associates a Pen object with the Graphics
     * object.
     *
     * @param pen The pen to draw with.
     * 
     * @see Pen
     * @see #getPen
     */
    public final void setPen(Pen pen) {}

    /**
     * Sets a pixel to the specified color.
     *
     * @param pt The pixel point to set.
     * @see #getPixel
     */
    public final void setPixel(Point pt) {}

    /**
     * Sets a pixel to the specified color.
     *
     * @param x X coordinate of the pixel to set.
     * @param y Y coordinate of the pixel to set.
     * 
     * @see #getPixel
     */
    public final void setPixel(int x, int y) {}

    /**
     * Sets a pixel to the specified color.
     *
     * @param pt    The pixel point to set.
     * @param color The color to set it to.
     * 
     * @see Color
     * @see #getPixel
     */
    public final void setPixel(Point pt, Color color) {}

    /**
     * Sets a pixel to the specified color.
     *
     * @param x     X coordinate of the pixel to set.
     * @param y     Y coordinate of the pixel to set.
     * @param color The color to set it to.
     * 
     * @see Color
     * @see #getPixel
     */
    public final void setPixel(int x, int y, Color color) {}

    /**
     * Sets a pixel to the specified color.  The provided RasterOp
     * can be used to modify how the color is drawn.
     *
     * @param pt    The pixel point to set.
     * @param color The color to set it to.
     * @param op    The @see RasterOp to use when drawing the pixel.
     * 
     * @see Color
     * @see RasterOp
     * @see #getPixel
     */
    public final void setPixel(Point pt, Color color, RasterOp op) {}

    /**
     * Sets a pixel to the specified color.  The provided RasterOp
     * can be used to modify how the color is drawn.
     *
     * @param x     The X coordinate of the pixel to set.
     * @param y     The Y coordinate of the pixel to set.
     * @param color The color to set it to.
     * @param op    The RasterOp to use when drawing the pixel.
     * 
     * @see Color
     * @see RasterOp
     * @see #getPixel
     */
    public final void setPixel(int x, int y, Color color, RasterOp op) {}

    /** 
     * Specifies the color that will be used to draw text.
     *
     * @param color The color to use.
     * 
     * @see Color
     * @see #getTextColor
     */
    public final void setTextColor(Color color) {}

    /**
     * Sets the amount of extra space to be used between characters when drawing text.
     *
     * @param space The amount of extra space to set.
     * 
     * @see #getTextSpace
     */
    public final void setTextSpace(int space) {}

    
    private final void throwInvalidDC() {}

    
    private static final class DCTracking {
        private static List grAllocs;

        /**
         * This is called when a new Graphics object is created.  This will save off the 
         * object and it's associated hWnd for later.  We save this data for two reasons:
         * 1) so we can throw a RuntimeException on Win 95 of too many DC's are allocated at
         * once, and 2) so we can automatically free DC's associated with a given window when
         * the window returns to it's message loop.
         *
         * @param hWnd The hwnd of the window owning this graphics.
         * @param gr   The graphics that has just been allocated.
         */
        public static synchronized void add(Graphics gr) {}

        /**
         * Frees all graphics objects associated with the given window.  This gets called by
         * Graphics.onEnterMessageLoop(hwnd).  This will call dispose on the graphics object.
         *
         * @param hWnd The hWnd that's about to re-enter it's message loop.
         *
         */
        public static synchronized void free(int hWnd) {}

        /**
         * Removes the given graphics from our list.
         *
         * @param gr Graphics object to remove.
         */
        public static synchronized void remove(Graphics gr) {}

        /**
         * Validates that it's OK to create a new graphics object.  Throws an exception
         * if it isn't.
         *
         * @param hWnd The hwnd to create the new object on.
         * @throws RuntimeException if a new object should not be created.
         */
        public static synchronized void validateNewDC(int hWnd) {}
}