//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;


/**
 * Defines methods that provide online help support for WFC controls. The HelpProvider offers both popup help 
 * and full help. If no helpFile has been set for the HelpProvider, then
 * only popup help can be used. The helpString property for a specific
 * control defines the popup help string that will be displayed for a control.
 * This is typically display by the user using "What's this Help" by clicking
 * on the "?" in the caption bar of a dialog. The helpTopic property for
 * a specific control determines the topic in the helpFile that will be
 * displayed. This help is typically invoked by the user pressing F1 while 
 * the control has focus.
 * 
 * @security(checkClassLinking=on)
 */
public class HelpProvider extends Component implements IExtenderProvider {

    private String helpFile = null;
    private HashTable helpStrings = new HashTable();
    private HashTable showHelp = new HashTable();
    private HashTable boundControls = new HashTable();
    private HashTable topics = new HashTable();

    /**
     * Creates a new HelpProvider.
     */
    public HelpProvider() {}

    /**
     * Determins if the help provider can offer it's extender properties
     * to the specified target object.
     * 
     * @hidden
     * @internalonly
     */
    public boolean canExtend(Object target) {}

    /**
     * Retrieves the name of the help file that is associated with this HelpProvider
     * object.  This can either be
     * a HTMLHelp file or a Win32Help file.
     * 
     * @return current helpFile.
     */
    public String getHelpFile() {}

    /**
     * Retrieves the help topic associated with a specified control.
     * 
     * @param ctl Control to retrieve the helpTopic for
     * 
     * @return helpTopic for <i>ctl</i>, or <b>null</b> if the contents should
     *         be displayed.
     */
    public String getHelpTopic(Control ctl) {}

    /**
     * Retrieves the contents of the pop-up help window for the specified control.
     * 
     * @param ctl Control to retrieve the helpString for.
     * 
     * @return current helpString for <i>ctl</i>.
     */
    public String getHelpString(Control ctl) {}
    
    /**
     * Retrieves a boolean value that indicates whether help should be
     * displayed for the specified control. If you set any other property (helpTopic,
     * or helpString) for a given control, then showHelp will automatically
     * be set to <b>true</b>. You can override this by specifically setting 
     * showHelp to <b>false</b>.
     * 
     * @param ctl Control to retrieve showHelp for.
     * 
     * @return <b>true</b> if help will be displayed for <i>ctl</i>
     */
    public boolean getShowHelp(Control ctl) {}

    
    private void onControlHelp(Object sender, HelpEvent event) {}

    /**
     * Associates a help string with a control.
     * 
     * @param ctl Control to set the helpString for.
     * @param helpString new helpString for <i>ctl</i>.
     */
    public void setHelpString(Control ctl, String helpString) {}

    /**
     * Sets the help file to be displayed for any controls for which this HelpProvider
     * object is providing support. This can either be
     * a HTMLHelp file or a Win32Help file.
     * 
     * @param helpFile new helpFile.
     */
    public void setHelpFile(String helpFile) {}

    /**
     * Sets the help topic to be displayed when the user invokes help for the specified
     * control.
     * 
     * @param ctl Control to set the helpTopic for
     * @param topic new helpTopic for <i>ctl</i>, or <b>null</b> if the 
     *        contents should be displayed.
     */
    public void setHelpTopic(Control ctl, String topic) {}

    /**
     * Sets a boolean value that determines whether help should be displayed
     * for a specified control. If you set any other property (helpTopic,
     * or helpString) for a given control, then showHelp will automatically
     * be set to <b>true</b>. You can override this by specifically setting 
     * showHelp to <b>false</b>.
     * 
     * @param ctl Control to set showHelp for.
     * @param value <b>true</b> if help should be displayed for <i>ctl</i>
     */
    public void setShowHelp(Control ctl, boolean value) {}

    /**
     * Used by the designer
     * 
     * @hidden
     * @internalonly
     */
    public boolean shouldPersistShowHelp(Control ctl) {}
    
    /**
     * Used by the designer
     * 
     * @hidden
     * @internalonly
     */
    public void resetShowHelp(Control ctl) {}

    
    private void updateEventBinding(Control ctl) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * Defines methods that provide online help support for WFC controls.
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends com.ms.wfc.core.Component.ClassInfo {

        public static final PropertyInfo helpFile = new PropertyInfo(HelpProvider.class,
            "helpFile", String.class,
            LocalizableAttribute.YES,
            DefaultValueAttribute.NULL,
            new ValueEditorAttribute(HelpFileFileNameEditor.class),
            new DescriptionAttribute(Sys.getString("HelpProviderHelpFileDescr")));

        public static final ExtenderInfo helpTopic = new ExtenderInfo(HelpProvider.class,
            "helpTopic", Control.class,
            String.class,
            DefaultValueAttribute.NULL,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("HelpProviderHelpTopicDescr")));

        public static final ExtenderInfo helpString = new ExtenderInfo(HelpProvider.class,
            "helpString", Control.class,
            String.class,
            DefaultValueAttribute.NULL,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("HelpProviderHelpStringDescr")));

        public static final ExtenderInfo showHelp = new ExtenderInfo(HelpProvider.class,
            "showHelp", Control.class,
            boolean.class,
            LocalizableAttribute.YES,
            new DescriptionAttribute(Sys.getString("HelpProviderShowHelpDescr")));

        public void getAttributes(IAttributes attrs) {}

        public void getProperties(IProperties props) {}

        public void getExtenders(IExtenders iexts) {}
    }

}