//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;

/**
 * Defines constants that represent areas in a MonthCalendar  control. 
 * The hitArea member of com.ms.wfc.ui.HitTestInfo will be one of these enumerated values, and
 * indicates which portion of a month calendar is under a specific point.
 * 
 * @see com.ms.wfc.ui.HitTestInfo
 * @see com.ms.wfc.ui.MonthCalendar
 *
 * @security(checkClassLinking=on)
 */
public class HitArea extends Enum {
    /**
     * Specifies an area that is not part of the month calendar control or an inactive area of
     * the month calendar control.
     */
    public static final int NOWHERE = 0;
    /**
     * Specifies the background of a month's title. */ 
    public static final int TITLE_BACKGROUND = 1;
    /**
     * Specifies a month's title bar, over a month name. */ 
    public static final int TITLE_MONTH = 2;
    /**
     * Specifies a month's title bar, over the year value. */ 
    public static final int TITLE_YEAR = 3;
    /**
     * Specifies the button at the top right corner of the control. 
     * If the user clicks here, the month calendar will scroll its display to the next 
     * month or set of months
     */ 
    public static final int NEXT_MONTH_BUTTON = 4;
    /**
     * Specifies the button at the top left corner of the control. If the 
     * user clicks here, the month calendar will scroll its display to the previous month 
     * or set of months
     */ 
    public static final int PREV_MONTH_BUTTON = 5;
    /**
     * Specifies the calendar's background. */ 
    public static final int CALENDAR_BACKGROUND = 6;
    /**
     * Specifies a particular date within the calendar.
     */ 
    public static final int DATE = 7;
    /**
     * Specifies a date from the next month (partially displayed at the end of the currently
     * displayed month). If the user clicks here, the month calendar will scroll 
     * its display to the next month or set of months. 
     */ 
    public static final int NEXT_MONTH_DATE = 8;
    /**
     * Specifies a date from the previous month (partially displayed at the beginning of the
     * currently displayed month). If the user clicks here, the month calendar will scroll 
     * its display to the previous month or set of months.  
     */ 
    public static final int PREV_MONTH_DATE = 9;
    /**
     * Specifies a day abbreviation ("Fri", for example). The <i>time</i> member
     * of HitTestInfo will be set to the corresponding date on the top row.
     */ 
    public static final int DAY_OF_WEEK = 10;
    /**
     * Specifies a week number.  This will only occur if the <i>showWeekNumbers<i> 
     * property of MonthCalendar is enabled.  The <i>time</i> member of HitTestInfo will be set to 
     * the corresponding date in the leftmost column. 
     */ 
    public static final int WEEK_NUMBERS = 11;
    /**
     * Specifies the "Today" link at the bottom of the month calendar control. */ 
    public static final int TODAY_LINK = 12;

    /**
     * Determines whether the specified value is one of the constants defined in this class. 
     */
    public static boolean valid(int value) {}
}