//STRIPPEDSOURCE//

package com.ms.wfc.ui;

/**
 * A site can provide this service if it is interested in knowing when it's components create and
 * destroy their handles.  Form packages typically need to know this if they're doing extra subclassing
 * work.
 *
 * @security(checkClassLinking=on)
 */
public interface IHandleHook { 
    
    /**
     * Indicates that the specified window handle has just been created. 
     * 
     * @param handle The Win32 handle of the control.
     */
    public void onCreateHandle(int handle);
    
    /**
     * Indicates that the specified window handle is about to be destroyed. 
     * 
     * @param handle The Win32 handle of the control.
     */
    public void onDestroyHandle(int handle);
    
    /**
     * Indicates that the control is about to create its handle. 
     * This allows a form designer or other siting object to agument the
     * control's creation information before the control is actually
     * created.
     * 
     * @param control The control that is about to be created.
     * @param cp      The control's creation information.
     */
    public void augmentCreateParams(Control control, CreateParams cp);
}