//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.com.*;

/**
 * Encapsulates a Windows icon, which is a small, transparent bitmap used to  visually represent an object, such as a Windows application.  Icons can be thought of as transparent bitmaps, although
 * their size is determined by the system.
 *
 * @security(checkClassLinking=on)
 */
public class Icon extends Image implements IPersistable {
    private Point iconSize = null;
    private int handle = 0;       
    private boolean ownHandle = true;
    
    /**
     * Creates an icon object from a given Win32 icon handle.  The Icon object
     * does not claim ownership of the icon handle; you must free it when you are
     * done.
     * 
     * @param handle The Win32 icon handle.
     */
    public Icon(int handle) {}

    /**
     * Loads an icon object from the given filename.
     * 
     * @param fileName The file to load the icon from.
     */
    public Icon(String fileName) {}
    
    /**
     * Duplicates the given icon, attempting to find a version of the icon
     * that matches the requested size.  If a version cannot be found that
     * exactally matches the size, the closest match will be used.  Note
     * that if <i>original</i> is an icon with a single size, this will
     * merely create a dupicate icon.  You can use the stretching modes
     * of drawImage to force the icon to the size you want.
     * 
     * @param original  The icon to load the different size from.
     * @param width     The width of the new icon.
     * @param height    The height of the new icon.
     */
    public Icon(Icon original, int width, int height) {}

    /**
     * Loads an icon object from the given resource.
     * 
     * @param type      The type of the resource class.
     * @param resource  The resource name to load.
     * 
     */
    public Icon(Class type, String resource) {}

    /**
     * Loads an icon object from the given data stream.
     * 
     * @param stream The data stream to load the icon from.
     * 
     * @see com.ms.wfc.io.IDataStream
     */
    public Icon(IDataStream stream) {}

    public Icon(IDataStream stream, int width, int height) {}
    
    /**
     * Loads an icon object from the given COM stream.
     * 
     * @param stream The COM stream to load the icon from.
     * 
     * @see com.ms.wfc.ole32.IStream
     */
    public Icon(IStream stream) {}

    public Icon(IStream stream, int width, int height) {}
    
    /**
     * Creates an icon object from the given OLE IPicture object.
     * 
     * @param picture An OLE IPicture object containing an icon.
     * 
     * @see com.ms.wfc.ole32.IPicture
     */
    public Icon(IPicture picture) {}

    /**
     * Clones the Icon object and returns a duplicate.  
     * 
     * @return an object that can be casted to an Icon.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of the Win32 handle for this icon.  You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 icon handle.
     */
    public final int copyHandle() {}
    
    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Frees the resources allocated by this object.  Once called, the cursor
     * object is no longer useful.
     */
    public void dispose() {}

    
    private void drawImageCore(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop, boolean stretch) {}
    
    /**
     * Renders the icon image (or part of it) to a Graphics object, cropping
     * the image to fit the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version crops the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to crop to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}
    
    /**
     * Renders the icon image to a Graphics object, stretching the image to
     * fill the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version stretches the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to stretch the image to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}

    /**
     * Frees the resources allocated by the Icon object.
     */
    protected void finalize() {}

    /**
     * Retrieves the recommended file extension for files that persist this object.
     * 
     * @return the recommended file extension, without a prefixing period.
     * @see IPersistable
     */
    public String getExtension() {}

    /**
     * Retrieves the Win32 handle to this icon.   This is not a copy of the handle; do
     * not free it.
     * 
     * @return the handle to this icon.
     */
    public int getHandle() {}

    
    /**
     * Retrieves a PICTDESC (Picture Descriptor) for this icon.   PICTDESCs are
     * used by OLE.
     * 
     * @return a PICDESC object.
     */
    public final PICTDESC getPICTDESC() {}

    /**
     * Retrieves the size of this Icon object's image.
     * 
     * @return the size of the object, in pixels.
     */
    public final Point getSize() {}

    /**
     * Initializes this image for the first time.  This should only be called once.
     * 
     * @param picture The IPicture object to initialize the bitmap with.
     *
     */
    protected void initialize(IPicture picture) {}

    /**
     * Loads a picture from the requested stream.
     *
     * @param stream The stream to load from
     * @return an OLE IPicture object
     *
     * @see com.ms.wfc.ole32.IPicture
     * @see com.ms.wfc.ole32.IStream
     */
    protected static IPicture loadPicture(IStream stream) {}

    /**
     * Retrieves a human-readable string representation of this object.
     * 
     * @return a string describing the cursor.
     */
    public String toString() {}

    /**
     * Encapsulates a Windows icon, which is a small, transparent bitmap used to  visually represent an object, such as a Windows application.ico)
     * files.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends Image.Editor {

        public String getFileDialogDescription() {}

        public String[] getExtensions() {}

        public Image loadFromStream(IDataStream stream) {}
    }
}