//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.com.*;
import com.ms.dll.*;

/**
 * The Image class is a base class for all WFC images:  icons, bitmaps, cursors, and metafiles.  It
 * is based on OLE's IPicture object, which allows it to handle a wider variety of file formats
 * than Win32 supports.  All of the OLE grunt work is located within this class, while all
 * descending classes make use of the IPicture object this class provides to perform useful
 * work.
 *
 * @security(checkClassLinking=on)
 */
public abstract class Image implements IPersistable {
    
    
    private static final int LP_DEFAULT    = 0;
    private static final int LP_MONOCHROME = 1;
    private static final int LP_VGACOLOR   = 2;
    private static final int LP_COLOR      = 4;

    
    
    
    

    
    private static Class [] imageExtenders = new Class[] { Bitmap.class, Cursor.class, Icon.class, Metafile.class };
    private static PictureList pictureList = null;
    private static int bitDepth = LP_DEFAULT;

    private IPicture picture;
    protected boolean dirty;

    /**
     * Empty constructor.
     */
    protected Image() {}

    /**
     * Creates an image based on the given IPicture.
     *
     * @param picture The IPicture to load
     *
     * @see com.ms.wfc.ole32.IPicture
     */
    protected Image(IPicture picture) {}

    /**
     * Descendants of this class all support some way to duplicate
     * their handle.
     *
     * @return the duplicated Win32 handle.
     */
    public abstract int copyHandle();

    /**
     * Cleans up this object.
     */
    public void dispose() {}

    /**
     * Draws this image to a graphics object.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So,
     * it passes the call to the actual image.  This version crops the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * Either rectangle can be null, in which case the dimensions of 0, 0,
     * (imagesize) will be used.
     * <p>
     * Developers should use the wide array of Graphics.drawImage() functions rather than
     * call this directly.
     *
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to crop to.
     * @param rop         A numerical rop code to blit with.
     *
     * @see Graphics#drawImage
     */
    protected abstract void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop);

    /**
     * Draws this image to a graphics object.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So,
     * it passes the call to the actual image.  This version stretches the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * Either rectangle can be null, in which case the dimensions of 0, 0,
     * (imagesize) will be used.
     * <p>
     * Developers should use the wide array of Graphics.drawImage() functions rather than
     * call this directly.
     *
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to stretch the image to.
     * @param rop         A numerical rop code to blit with.
     *
     * @see Graphics#drawImage
     */
    protected abstract void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop);

    /**
     * Finalizer for this object.
     */
    protected void finalize() {}

    /**
     * Retrieves the Win32 handle for this object.  This is not a copy of the handle; do
     * not free it.
     *
     * @return the handle to this bitmap.
     */
    public abstract int getHandle();

    /**
     * Retrieves the OLE PICTDESC for the image.  A PICTDESC describes an image
     * to OLE.  Typically you don't need to use this unless you are communicating
     * directly with OLE.
     *
     * @return a PICTDESC object describing the image.
     */
    public abstract PICTDESC getPICTDESC();

    /**
     * Retrieves the OLE IPicture object associated with this image.
     *
     * @return the OLE IPicture object associated with this image,
     *         or <b>null</b> if there is none.
     */
    protected IPicture getPicture() {}

    /**
     * Retrieves the size of the image.
     *
     * @return the size of the image.
     */
    public abstract Point getSize();

    /**
     * Initializes this Image object.  This is identical to calling the image's
     * constructor with <i>picture</i>, but this allows non-constructor initialization,
     * which may be necessary in some instances.
     * 
     * @param picture The IPicture object to initialize this image with.
     *
     */
    protected void initialize(IPicture picture) {}

    /**
     * Loads an image from a datastream.  This will return a bitmap, icon,
     * cursor or metafile object depending on the type of data in the stream.
     *
     * @param stream The data stream to load from.
     *
     * @see IDataStream
     */
    public static Image loadImage(IDataStream stream) {}

    /**
     * Loads an image from a COM stream.  This will return a bitmap, icon,
     * cursor or metafile object depending on the type of data in the stream.
     *
     * @param stream The COM stream to load from.
     * @return an Image object that may be of Bitmap, Icon, Metafile or
     *         Cursor type.
     *
     * @see com.ms.wfc.ole32.IStream
     * @see Bitmap
     * @see Cursor
     * @see Icon
     * @see Metafile
     */
    public static Image loadImage(IStream stream) {}

    /**
     * Loads a picture from the requested stream.
     *
     * @param stream The stream to load from
     * @return an OLE IPicture object
     *
     * @see com.ms.wfc.ole32.IPicture
     * @see com.ms.wfc.ole32.IStream
     */
    protected static IPicture loadPicture(IStream stream) {}

    /**
     * Loads a picture from the requested stream with the given size.
     *
     * @param stream The stream to load from
     * @param width requested width
     * @param height requested height
     * @return an OLE IPicture object
     *
     * @see com.ms.wfc.ole32.IPicture
     * @see com.ms.wfc.ole32.IStream
     */
    protected static IPicture loadPicture(IStream stream, int width, int height) {}

    /**
     * Indicates this image has changed and save should save the changed format.
     * If this is not called, the image will be saved in its original format.
     * @internalonly
     */
    protected void markDirty() {}

    /**
     * Saves this image to the given output stream.
     *
     * @param outputStream The stream to save to.  This can be a file, data object, or other
     *                     DataStream.
     */
    public void save(IDataStream outputStream) {}

    /**
     * Generates a string representation of this image.
     *
     * @return a String representing the image.
     */
    public String toString() {}

    /**
     * Editor for generic Image classes.  An image editor consists of a common file dialog
     * that shows a list of compatible image files.
     *
     * @security(checkClassLinking=on)
     */
    public static class ArrayEditor extends com.ms.wfc.core.ArrayEditor {

        public ArrayEditor(Class type) {}

        public int getStyle() {}

        public Object createNewInstance(int index) {}


        
        private static class ValueStore implements IValueAccess {
            Object value = null;

            public Object getValue() {}

            public void setValue(Object value) {}

            public Object getService(Class serviceClass) {}
        }
    }


    /**
     * @security(checkClassLinking=on)
     */
    public static class Editor extends FieldsEditor {

        public Editor() {}

        public Editor(Class fieldClass, Class valueClass, String prefix) {}

        public String getFileDialogDescription() {}

        public String[] getExtensions() {}

        public Image loadFromStream(IDataStream stream) {}

        FileDialog fileDialog = null;

        public static String createExtensionsString(String[] extensions,String sep) {}

        public static String createFilterEntry(Editor e) {}

        public void editValue(IValueAccess valueAccess) {}

        public int getStyle() {}

        public String getTextFromValue(Object value) {}

        public void paintValue(Object value, Graphics g, Rectangle rect) {}
    }

    /**
     * We keep a list of our IPicture objects here.  We need to do this because it's
     * very very bad if we don't release these, so we release them on application
     * shutdown.
     *
     * @security(checkClassLinking=on)
     */
    public static class PictureList {

        private List list = new List();

        public PictureList() {}

        public void addPicture(IPicture picture) {}

        public boolean removePicture(IPicture picture) {}

        private void onApplicationExit(Object sender, Event e) {}
    }
}