//STRIPPEDSOURCE//


package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.dll.*;

/**
 * Contains a collection of images that can be used by other controls, such as the ListView, TreeView,  Toolbar, TabStrip,  and TabControl controls.   You can add either bitmaps or Icons to the ImageList, and the
 * other controls will be able to use the Images as they desire.
 *
 * @security(checkClassLinking=on)
 */
public class ImageList extends Component {

    private Color backColor = Color.CONTROL;
    private boolean useMask = true;
    private boolean ownHandle = true;
    private int handle;
    private int himlTemp;
    private Bitmap temp = null;

    
    
    
    private Color maskColor = Color.LIGHTGRAY;
    private Point imageSize;

    private static final int INITIAL_CAPACITY = 4;
    private static final int GROWBY = 4;

    /** 
     * Creates a new ImageList Control with a default image size of 16x16 
     * pixels
     */
    public ImageList() {}

    /**
     * Creates a new ImageList control with the specified image size
     *
     * @param size      @see com.ms.wfc.ui.Point object with the size of Images
     */
    public ImageList(Point size) {}

    /**
     * Creates a new ImageList control with the given bitmap, image size,
     * and mask color
     *
     * @param image     @see com.ms.wfc.ui.Bitmap object with one or more images to
     *                  add.
     * @param size      @see com.ms.wfc.ui.Point object with the size of images in
     *                  the ImageList
     * @param maskColor @see com.ms.wfc.ui.Color object with the mask color for each
     *                  Image.
     */
    public ImageList(Point size, Color maskColor) {}

    /**
     * Adds one or more images derived from the specified bitmap or icon to the image list.  The number of images to add is
     * inferred from the width of the given image and the Image size set
     * in the ImageList.
     *
     * @param value     Image object with the image(s) to add.
     *
     * @return int The zero-based index of the first new image added.
     */
    public int addImage(Image value) {}


    /**
     * Adds one or more images derived from the specified bitmap or icon to the image list.  The number of images to add is inferred from
     * the width of the given image. If UseMask is false, the mask
     * parameter will be ignored.
     *
     * @param image     @see com.ms.wfc.ui.Bitmap object with the image(s) to add.
     * @param maskColor Use this color to mask this image.  If the "useMask"
     *                  property is false for this ImageList, this is ignored.
     *
     * @return int The zero-based index of the first new image added.
     */
    public int addImage(Bitmap image, Color maskColor) {}

    /**
     * Removes all images and masks from the image list. 
     */
    public void removeAll() {}

    /**
     * Creates the underlying HIMAGELIST handle, and sets up all the
     * appropriate values with it.  Inheriting classes overriding this method
     * should not forget to call super.createHandle();
     */
    protected void createHandle() {}

    /**
     * Dispose of all resources held by the ImageList control. Inheriting 
     * classes overriding this method should not forget to call
     * "super.destroyHandle()"
     */
    protected void destroyHandle() {}

    /**
     * Draws the specified image. 
     *
     * @param g         Graphics object to draw into.
     * @param pt        Location to draw the image at
     * @param index     image in the ImageList to draw
     */
    public void draw(Graphics g, Point pt, int index) {}

    /**
     * Draws the specified image. 
     *
     * @param g         Graphics object to draw into.
     * @param x         x portion of where to draw the image.
     * @param y         y portion of where to draw the image.
     * @param index     image in the ImageList to draw
     */
    public void draw(Graphics g, int x, int y, int index) {}

    /**
     * Draws the specified image.   The image is stretched or compressed as
     * necessary to fit the bounds provided.
     *
     * @param g         Graphics object to draw into.
     * @param x         x portion of where to draw the image.
     * @param y         y portion of where to draw the image.
     * @param width     width of destination image
     * @param height    height of destination image
     * @param rop       numerical raster op code
     * @param index     image in the ImageList to draw
     */
    public void drawImage(Graphics g, int x, int y, int width, int height, int rop, int index) {}

    /**
     * Make sure we clean up our handle
     */
    protected void finalize() throws Throwable {}

    /**
     * Retrieve the ImageList background color.
     *
     * @return  Color   the current background color of the ImageList
     */
    public Color getBackColor() {}

    /**
     * Retrieves the specified image as a bitmap.   The bitmap returned is a
     * copy of the original image.
     *
     * @param index     Image we wish to get as a Bitmap
     *
     * @return Bitmap   a Bitmap object with the specified image in it.
     */
    public Bitmap getBitmap(int index) {}

    /**
     * Retrieves the specified image.   The Image returned is a
     * reference to the original image, not a copy of it.  Therefore, if the images in
     * the ImageList are modified, the changes may affect the image referenced by
     * the Image object.
     *
     * @param index     Image we wish to get a reference to.
     *
     * @return Image   an Image object that references the specified image..
     */
    public Image getImage(int index) {}

    /**
     * Returns the handle of the ImageList object.  This corresponds to a win32
     * HIMAGELIST Handle.
     *
     * @return int      the underlying win32 handle
     */
    public int getHandle() {}

    /**
     * Creates and retrieves an icon based on the image and mask at the specified index. 
     * The Icon is created using the current drawing mode.
     *
     * @param index     Image we wish to get an Icon for.
     *
     * @return Icon     an Icon object representing the specified Image.
     */
    public Icon getIcon(int index) {}

    /**
     * Retrieves all the images in the image list. 
     *
     * @return Bitmap []    an array containing each Image in the ImageList
     *                      individually packaged in a Bitmap object.
     */
    public Image[] getImages() {}

    /**
     * Retrieves the number of images in the image list. 
     *
     * @return  int     the number of images currently in the ImageList.
     */
    public int getImageCount() {}

    
    IMAGEINFO getImageInfo(int index) {}

    /** 
     * Retrieves the size of images in the image list.  */
    public Point getImageSize() {}

    /**
     * Retrieves the color used to generate masks for images in the image list. 
     *
     * @return Color    the current mask color.
     */
    public Color getMaskColor() {}

    /**
     * Retrieves a boolean value indicating whether the image list uses a mask.  */
    public boolean getUseMask() {}

    public boolean getHandleCreated() {}

    public ImageListStreamer getImageStream() {}

#if DEBUG
    public Bitmap getMasterImage() {}

    public Bitmap getMasterMask() {}
#endif 

    
    private void putImageInTempBitmap(int index, boolean useSnapshot) {}

    protected void recreateHandle() {}

    /**
     * Removes the specified image from the image list. 
     */
    public void removeImage(int index) {}

    /**
     * Replaces the specified image with another image. 
     */
    public void replaceImage(int index, Image value) {}

    /**
     * Set the ImageLists background color.
     */
    public void setBackColor(Color value) {}

    /**
     * Wrap a pre-existing image list
     */
    protected void setHandle(int hImageList) {}

    public void setImages(Image[] image) {}
    
    public void setImageSize(Point value) {}

    public void setImageStream(ImageListStreamer ils) {}

    public void setMaskColor(Color value) {}

    public void setUseMask(boolean value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private static class OwnedBitmap extends Bitmap {
        public OwnedBitmap(int handle) {}
        
        protected void destroyHandle() {}
    }


    
    private static class ImageListGlyph extends Image {
    
        ImageList iml;
        int index;

        private ImageListGlyph(ImageList iml, int index) {}

        protected Bitmap getBitmap() {}

        public String getExtension() {}

        /**
         * Descendants of this class all support some way to duplicate
         * their handle.
         * 
         * @return the duplicated Win32 handle.
         */
        public int copyHandle() {}
    
        /**
         * Draws this image to a graphics object.  The drawing command originates on the graphics
         * object, but a graphics object generally has no idea how to render a given image.  So, 
         * it passes the call to the actual image.  This version crops the image to the given
         * dimensions and allows the user to specify a rectangle within the image to draw. 
         * Either rectangle can be null, in which case the dimensions of 0, 0, 
         * (imagesize) will be used.
         * <p>
         * Developers should use the wide array of Graphics.drawImage() functions rather than
         * call this directly.
         * 
         * @param g           The graphics object to render to.
         * @param imageRect   The rectanglular area of the image to draw.
         * @param targetRect  The rectangle to crop to.
         * @param rop         A numerical rop code to blit with.
         * 
         * @see Graphics#drawImage
         */
        protected void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}
    
        /**
         * Draws this image to a graphics object.  The drawing command originates on the graphics
         * object, but a graphics object generally has no idea how to render a given image.  So, 
         * it passes the call to the actual image.  This version stretches the image to the given
         * dimensions and allows the user to specify a rectangle within the image to draw.
         * Either rectangle can be null, in which case the dimensions of 0, 0, 
         * (imagesize) will be used.
         * <p>
         * Developers should use the wide array of Graphics.drawImage() functions rather than
         * call this directly.
         * 
         * @param g           The graphics object to render to.
         * @param imageRect   The rectanglular area of the image to draw.
         * @param targetRect  The rectangle to stretch the image to.
         * @param rop         A numerical rop code to blit with.
         * 
         * @see Graphics#drawImage
         */
        protected void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}
        
    
        /**
         * Retrieves the Win32 handle for this object.  This is not a copy of the handle; do
         * not free it.
         * 
         * @return the handle to this bitmap.
         */
        public int getHandle() {}
        
        /**
         * Retrieves the OLE PICTDESC for the image.  A PICTDESC describes an image 
         * to OLE.  Typically you don't need to use this unless you are communicating
         * directly with OLE.
         * 
         * @return a PICTDESC object describing the image.
         */
        public PICTDESC getPICTDESC() {}
    
        /**
         * Retrieves the size of the image.
         * 
         * @return the size of the image.
         */
        public Point getSize() {}
    }




    /**
     * Contains a collection of images that can be used by other controls, such as the ListView, TreeView,  Toolbar, TabStrip,  and TabControl controls. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Component.ClassInfo {
        public static final PropertyInfo backColor = new PropertyInfo(
            ImageList.class, "backColor", com.ms.wfc.ui.Color.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.COLOR_CONTROL,
            new DescriptionAttribute(Sys.getString("ImageListBackColorDescr")));

        public static final PropertyInfo images = new PropertyInfo(
            ImageList.class, "images", Image[].class,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.NULL,
            PersistableAttribute.NO,
            new DescriptionAttribute(Sys.getString("ImageListImagesDescr")));
        
        public static final PropertyInfo imageStream = new PropertyInfo(
            ImageList.class, "imageStream", ImageListStreamer.class,
            DefaultValueAttribute.NULL,
            BrowsableAttribute.NO);

        public static final PropertyInfo maskColor = new PropertyInfo(
            ImageList.class, "maskColor", com.ms.wfc.ui.Color.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(Color.LIGHTGRAY),
            new DescriptionAttribute(Sys.getString("ImageListMaskColorDescr")));

        public static final PropertyInfo imageSize = new PropertyInfo(
            ImageList.class, "imageSize", com.ms.wfc.ui.Point.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Point(16, 16)),
            new DescriptionAttribute(Sys.getString("ImageListSizeDescr")));

        public static final PropertyInfo useMask = new PropertyInfo(
            ImageList.class, "useMask", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("ImageListUseMaskDescr")));

        public void getAttributes(IAttributes attrs) {}

        public void getProperties(IProperties props) {}
    }
}