//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;

/**
 * Defines constants to use for processing keyboard input.  Keys
 * are identified by key values, which consist of a key code and a set of
 * modifiers combined into a single integer value. The low order word of a
 * key value contains the key code (which is the same as a Windows virtual
 * key code). The high order word of a key value contains modifier bits for
 * the SHIFT, CONTROL, and ALT keys.
 *
 * @security(checkClassLinking=on)
 */
public class Key { 
    /**
     * Specifies the bit mask to extract the key code for the key that was pressed from a key
     * value.
     */
    public static final int KEYCODE = 0x0000FFFF;

    /**
     * Specifies the bit mask to extract information about which modifier keys were pressed
     * from a key value.
     */
    public static final int MODIFIERS = 0xFFFF0000;

    /**
     * Specifies the left mouse button.
     */
    public static final int LBUTTON        = 0x01;
    public static final int RBUTTON        = 0x02;
    public static final int CANCEL         = 0x03;
    public static final int MBUTTON        = 0x04;
    public static final int BACK           = 0x08;
    public static final int TAB            = 0x09;
    public static final int CLEAR          = 0x0C;
    public static final int RETURN         = 0x0D;
    public static final int SHIFT_KEY      = 0x10;
    public static final int CONTROL_KEY    = 0x11;
    public static final int MENU           = 0x12;
    public static final int PAUSE          = 0x13;
    public static final int CAPITAL        = 0x14;
    public static final int CAPSLOCK       = 0x14;
    public static final int ESCAPE         = 0x1B;
    public static final int SPACE          = 0x20;
    public static final int PRIOR          = 0x21;
    public static final int NEXT           = 0x22;
    public static final int END            = 0x23;
    public static final int HOME           = 0x24;
    public static final int LEFT           = 0x25;
    public static final int UP             = 0x26;
    public static final int RIGHT          = 0x27;
    public static final int DOWN           = 0x28;
    public static final int SELECT         = 0x29;
    public static final int PRINT          = 0x2A;
    public static final int EXECUTE        = 0x2B;
    public static final int SNAPSHOT       = 0x2C;
    public static final int INSERT         = 0x2D;
    public static final int DELETE         = 0x2E;
    public static final int HELP           = 0x2F;
    
    public static final int D0             = 0x30; 
    public static final int D1             = 0x31; 
    public static final int D2             = 0x32; 
    public static final int D3             = 0x33; 
    public static final int D4             = 0x34; 
    public static final int D5             = 0x35; 
    public static final int D6             = 0x36; 
    public static final int D7             = 0x37; 
    public static final int D8             = 0x38; 
    public static final int D9             = 0x39; 
    
    public static final int A              = 0x41;
    public static final int B              = 0x42;
    public static final int C              = 0x43;
    public static final int D              = 0x44;
    public static final int E              = 0x45;
    public static final int F              = 0x46;
    public static final int G              = 0x47;
    public static final int H              = 0x48;
    public static final int I              = 0x49;
    public static final int J              = 0x4A;
    public static final int K              = 0x4B;
    public static final int L              = 0x4C;
    public static final int M              = 0x4D;
    public static final int N              = 0x4E;
    public static final int O              = 0x4F;
    public static final int P              = 0x50;
    public static final int Q              = 0x51;
    public static final int R              = 0x52;
    public static final int S              = 0x53;
    public static final int T              = 0x54;
    public static final int U              = 0x55;
    public static final int V              = 0x56;
    public static final int W              = 0x57;
    public static final int X              = 0x58;
    public static final int Y              = 0x59;
    public static final int Z              = 0x5A;
    
    private static final int FIRST_DIGIT = D0;
    private static final int LAST_DIGIT = D9;
    private static final int FIRST_ASCII = A;
    private static final int LAST_ASCII = Z;
    
    public static final int LWIN           = 0x5B;
    public static final int RWIN           = 0x5C;
    public static final int APPS           = 0x5D;
    
    public static final int NUMPAD0        = 0x60;
    public static final int NUMPAD1        = 0x61;
    public static final int NUMPAD2        = 0x62;
    public static final int NUMPAD3        = 0x63;
    public static final int NUMPAD4        = 0x64;
    public static final int NUMPAD5        = 0x65;
    public static final int NUMPAD6        = 0x66;
    public static final int NUMPAD7        = 0x67;
    public static final int NUMPAD8        = 0x68;
    public static final int NUMPAD9        = 0x69;
    
    public static final int MULTIPLY       = 0x6A;
    public static final int ADD            = 0x6B;
    public static final int SEPARATOR      = 0x6C;
    public static final int SUBTRACT       = 0x6D;
    public static final int DECIMAL        = 0x6E;
    public static final int DIVIDE         = 0x6F;
    
    public static final int F1             = 0x70;
    public static final int F2             = 0x71;
    public static final int F3             = 0x72;
    public static final int F4             = 0x73;
    public static final int F5             = 0x74;
    public static final int F6             = 0x75;
    public static final int F7             = 0x76;
    public static final int F8             = 0x77;
    public static final int F9             = 0x78;
    public static final int F10            = 0x79;
    public static final int F11            = 0x7A;
    public static final int F12            = 0x7B;
    public static final int F13            = 0x7C;
    public static final int F14            = 0x7D;
    public static final int F15            = 0x7E;
    public static final int F16            = 0x7F;
    public static final int F17            = 0x80;
    public static final int F18            = 0x81;
    public static final int F19            = 0x82;
    public static final int F20            = 0x83;
    public static final int F21            = 0x84;
    public static final int F22            = 0x85;
    public static final int F23            = 0x86;
    public static final int F24            = 0x87;
    
    public static final int NUMLOCK        = 0x90;
    public static final int SCROLL         = 0x91;
    public static final int LSHIFT_KEY     = 0xA0;
    public static final int RSHIFT_KEY     = 0xA1;
    public static final int LCONTROL_KEY   = 0xA2;
    public static final int RCONTROL_KEY   = 0xA3;
    public static final int LMENU          = 0xA4;
    public static final int RMENU          = 0xA5;
    public static final int PROCESSKEY     = 0xE5;
    public static final int ATTN           = 0xF6;
    public static final int CRSEL          = 0xF7;
    public static final int EXSEL          = 0xF8;
    public static final int EREOF          = 0xF9;
    public static final int PLAY           = 0xFA;
    public static final int ZOOM           = 0xFB;
    public static final int NONAME         = 0xFC;
    public static final int PA1            = 0xFD;
    public static final int OEM_CLEAR      = 0xFE;

    /**
     * Specifies the SHIFT modifier key.
     */
    public static final int SHIFT   = 0x00010000;
    public static final int CONTROL = 0x00020000;
    public static final int ALT     = 0x00040000;
    

    private static HashTable keys = null;

    private static HashTable getKeys() {}

    public static int getKeyFromString(String caption) {}

    private static int parseString(String sz) {}

    private static boolean shouldIgnore(char ch) {}


    public static String getStringFromKey(int key) {}

}