//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Provides data for the keyDown or keyUp event of a Control object.   When a key is pressed
 * in Windows, three events may be generated:  KeyDown, KeyPress, and KeyUp.
 * <p>
 * A KeyDown event is generated when any key on the keyboard is depressed.  Duplicate
 * events will be generated each time the key repeats.
 * <p>
 * A KeyPress event is generated when a key on the keyboard is depressed.
 * KeyPress events are generated each time the key repeats and contain a Unicode
 * character code corresponding to the character the user has depressed.  For these
 * events, a KeyPressEvent object is sent with the event instead of a KeyEvent object.
 * <p>
 * A KeyUp event is generated when the user releases a key on the keyboard.  There
 * will always be a single KeyUp event at the end of a sequence of KeyDown/KeyPress 
 * events.
 *
 * @security(checkClassLinking=on)
 */
public class KeyEvent extends Event {

    /**
     * Contains key data for KeyDown and KeyUp events.  This is a combination
     * of keycode and modifer flags.
     */
    public final int keyData;

    /**
     * Determines if this event has been handled by a handler.  If handled, the
     * key event will not be sent along to Windows.  If not handled, the event
     * will be sent to Windows for default processing.
     */
    public boolean handled;

    /**
     * Creates a new KeyEvent object.
     *
     * @param keyData The Win32 keycode information that comes from a Windows
     *                WM_KEYDOWN or WM_KEYUP message.  This data is only available
     *                for KeyDown and KeyUp events.
     */
    public KeyEvent(int keyData) {}
                    
    /**
     * Creates a new KeyEvent object.
     *
     * @param extendedInfo  Additional information used for HTML events.
     * 
     * @param keyData The Win32 keycode information that comes from a Windows
     *                WM_KEYDOWN or WM_KEYUP message.  This data is only available
     *                for KeyDown and KeyUp events.
     */
    public KeyEvent(Object extendedInfo, int keyData) {}

    /**
     * Retrieves the key code for the key the user pressed.   This will be 
     * one of the values in the Key enum class.
     *
     * @return the keycode for the event, which will be a value from the Key class
     *
     * @see Key
     */
    public int getKeyCode() {}

    /**
     * Retrieves a value indicating which, if any, of the CTRL, SHIFT, and ALT keys were
     * pressed when the event occurred.   This will
     * consist of one or more modifier flags from the Key class.
     *
     * @return a combination of modifier flags from the Key class.
     *
     * @see Key
     */
    public int getModifiers() {}

    public boolean getAlt() {}

    public boolean getControl() {}

    public boolean getShift() {}
}