//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * The KeyPressEvent class encapsulates a processed keyboard event.  When a key is pressed
 * in Windows, three events may be generated:  KeyDown, KeyPress, and KeyUp.
 * <p>
 * A KeyDown event is generated when any key on the keyboard is depressed.  Duplicate
 * events will be generated each time the key repeats.
 * <p>
 * A KeyPress event is generated when a key on the keyboard is depressed.
 * KeyPress events are generated each time the key repeats and contain a Unicode
 * character code corresponding to the character the user has depressed.  For these
 * events, a KeyPressEvent object is sent with the event instead of a KeyEvent object.
 * <p>
 * A KeyUp event is generated when the user releases a key on the keyboard.  There
 * will always be a single KeyUp event at the end of a sequence of KeyDown/KeyPress 
 * events.
 *
 * @security(checkClassLinking=on)
 */
public class KeyPressEvent extends Event {

    /**
     * Contains the character of the current KeyPress event.
     */
    public final char keyChar;

    /**
     * Determines if this event has been handled by a handler.  If handled, the
     * key event will not be sent along to Windows.  If not handled, the event
     * will be sent to Windows for default processing.
     */
    public boolean handled;

    /**
     * Creates a new KeyPressEvent object.
     *
     * @param keyChar The ASCII character of the key being pressed.
     */
    public KeyPressEvent(char keyChar) {}

    /**
     * Creates a new KeyPressEvent object.
     *
     * @param extendedInfo  Additional information used for HTML events.
     * 
     * @param keyChar The ASCII character of the key being pressed.
     */
    public KeyPressEvent(Object extendedInfo, char keyChar) {}

    /**
     * Returns the character for the last key press.
     *
     * @return a char with the key triggering this event.
     */
    public final char getKeyChar() {}
}