//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * This class implements a simple static label control.  Label controls are
 * typically used for either displaying status text to the user or for
 * identifying the purpose of other controls that don't have a textual labe
 * associated with them.  When a Label control gets focus, it passes that
 * focus to the next control in the tab order.  This allows you to specify a
 * mnemonic key for the label and have this key jump to other controls.
 *
 * @security(checkClassLinking=on)
 */
public class Label extends Control { 
    
    private int textAlign = HorizontalAlignment.LEFT;

    
    private int borderStyle = BorderStyle.NONE;

    
    private boolean useMnemonic = true;

    
    private boolean autoSize = false;

    
    private int requestedHeight;

    /**
     * Default constructor.
     */
    public Label() {}

    
    private void adjustHeight() {}

    /**
     * Indicates if the control is being auto-sized.  If so, then it will
     * adjust it's height to always be just big enough to hold characters
     * of the current font.
     *
     * @return boolean      <b>true</b> if this control autosizes itself.
     */
    public final boolean getAutoSize() {}

    /**
     * Overrides Control.  A Label is a Win32 STATIC control, which we setup here.
     *
     * @see #Control.getCreateParams
     */
    protected CreateParams getCreateParams() {}

    /**
     * Indicates that type of border this label control will draw with.
     * Valid values are taken from the com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @return  the current border style for this label control.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final int getBorderStyle() {}

    /**
     * Returns the preferred height of the label control assuming a single line
     * of text is to be displayed.
     *
     * @return      the preferred height of this control
     */
    public final int getPreferredHeight() {}

    /**
     * Indicates how the Label control will align text horizontally within its
     * client area.  It supports left, right, and center aligning of the text.
     * Valid values are taken from the com.ms.wfc.ui.HorizontalAlignment enumeration.
     *
     * @return      the current text alignment for the control.
     *
     * @see HorizontalAlignment
     */
    public final int getTextAlign() {}

    /**
     * Returns true if the label will consider the first ampersand (&) character a
     * hotkey mnemonic.
     *
     * @return True if the label will use mnemonics defined in its text.
     */
    public final boolean getUseMnemonic() {}

    /**
     * Overrides Control.  This is called when the user has pressed an Alt-CHAR
     * key combination and determines if that combination is an interesting
     * mnemonic for this control.
     *
     * @see #Control.processMnemonic
     */
    protected boolean processMnemonic(char charCode) {}

    /**
     * Overridden to adjust the height of the label control when the font
     * changes.
     */
    protected void propertyChanged(int property) {}

    /**
     * Controls whether the height of the label is
     * automatically adjusted when the control's font changes.
     *
     * @param value     <b>true</b> if the control should size itself.
     */
    public final void setAutoSize(boolean value) {}

    /**
     * Controls the type of border that this label control will draw with.
     * Valid values are taken from the com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @param value     The new border style for this control.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final void setBorderStyle(int value) {}

    /**
     * Overrides Control.setBoundsCore to enforce autoSize.
     * @internalonly
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}

    /**
     * Sets the textAlign mode for the label.  This controls how the text is
     * positioned in the label control.  This only control the horizontal
     * alignment of the text.
     *
     * @param value     A value from the HorizontalAlignmnent enum.
     *
     * @see HorizontalAlignment
     */
    public void setTextAlign(int value) {}

    /**
     * Determines if this control will use the first ampersand (&) in it's text as
     * a hotkey mnemonic.
     *
     * @param useMnemonic   <b>true</b> if the control is to treat it's text as a mnemonic.
     */
    public final void setUseMnemonic(boolean useMnemonic) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * Overrides Control.  This processes certain messages that the Win32 STATIC
     * class would normally override.
     *
     * @param m     The message to process.
     *
     * @see Control#wndProc
     */
    protected void wndProc(Message m) {}

    /**
     * ClassInfo for this control.  This defines the control's properties, methods and
     * events.
     *
     * @see com.ms.wfc.core.ClassInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo { 
        public static final PropertyInfo autoSize = new PropertyInfo(
            Label.class, "autoSize", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("LabelAutoSizeDescr")));

        public static final PropertyInfo borderStyle = new PropertyInfo(
            Label.class, "borderStyle", BorderStyle.class,
            new DefaultValueAttribute(new Integer(BorderStyle.NONE)),
            new DescriptionAttribute(Sys.getString("LabelBorderDescr")));

        public static final PropertyInfo textAlign = new PropertyInfo(
            Label.class, "textAlign", HorizontalAlignment.class,
            new DescriptionAttribute(Sys.getString("LabelTextAlignDescr")),
            new DefaultValueAttribute(new Integer(HorizontalAlignment.LEFT)));

        public static final PropertyInfo useMnemonic = new PropertyInfo(
            Label.class, "useMnemonic", Boolean.TYPE,
            new DescriptionAttribute(Sys.getString("LabelUseMnemonicDescr")),
            DefaultValueAttribute.TRUE);

        /**
         * Retrieves the default property name of the control.
         */
        public String getDefaultPropertyName() {}

        /**
         * Fills an event list with the events for this control.
         *
         * @param events    An IEvents interface that will be filled with events.
         *
         * @see com.ms.wfc.core.IClassInfo
         * @see com.ms.wfc.core.IEvents
         */
        public void getEvents(IEvents events) {}

        /**
         * Fills a property list with the properties for this control.
         *
         * @param props     An IProperties interface that will be filled with properties.
         *
         * @see com.ms.wfc.core.IClassInfo
         * @see com.ms.wfc.core.IProperties
         */
        public void getProperties(IProperties props) {}
    }
}