//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates the Windows list box control, which displays a list from which the user  can select one or more items.   They may be
 * navigated using the keyboard, or the scrollbar on the right side of the
 * control.  One or more items may be selected as well.
 * </p>
 *
 * <p>
 * The preferred way to add items is to set them all via an array at once,
 * which is definitely the most efficient way.  The following is an example
 * of this:
 * </p>
 *
 * <pre>
 * ListBox lb = new ListBox();
 * // set up properties on the listbox here.
 * lb.setItems(new String [] {
 *      "A",
 *      "B",
 *      "C",
 *      "D"});
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public class ListBox extends Control { 
    /**
     * Specifies that no matches are found during a search. */
    public static final int NOMATCHES = win.LB_ERR;

    private static final Object EVENT_SELECTEDINDEXCHANGED = new Object();

    
    
    
    protected Object[] items;
    protected int itemCount;
    protected int selectionMode = SelectionMode.ONE;

    private int updateCount;
    private int itemHeight = 15;
    private Object newItem;
    private boolean inserting = false;
    private int columnWidth;
    private boolean mousePressed = false;

    private boolean sorted = false;
    private boolean scrollAlwaysVisible = false;
    private boolean integralHeight = true;
    private int drawMode = DrawMode.NORMAL;
    private boolean multiColumn = false;
    private boolean useTabStops = true;
    private int borderStyle = BorderStyle.FIXED_3D;

    boolean haveItems = false;


    private DrawItemEventHandler onDrawItem;
    private MeasureItemEventHandler onMeasureItem;

    /**
     * Creates a basic win32 list box with default values for everything.
     */
    public ListBox() {}

    /**
     * Adds an item to the list box, and returns the index of the new item. 
     * For an unsorted list box, the item is added to the end of the existing
     * list of items. For a sorted list box, the item is inserted into the
     * list according to its sorted position. The item's toString() method is
     * called to obtain the string that is displayed in the list box.
     * A RuntimeException occurs if there is insufficient space available to
     * store the new item.
     *
     * @param item The item to insert.
     * @return Index at which the item was inserted.
     */
    public final int addItem(Object item) {}

    /**
     * Assigns a delegate to the drawItem event.  This
     * event is called for list boxes whose drawMode property is set to
     * DrawMode.OWNERDRAWFIXED or DrawMode.OWNERDRAWVARIABLE, and contains
     * a Graphics object in which people should paint the item.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Assigns a delegate to the measureItem event.  This
     * event is called for list boxes whose drawMode property is set to
     * DrawMode.OWNERDRAWVARIABLE, and asks the programmer for the size of the
     * given item in the listbox.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnMeasureItem(MeasureItemEventHandler value) {}

    /**
     * Assigns a delegate to the selectedIndexChanged event.   This
     * event is sent whenever the selection changes.
     * Duplicates are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnSelectedIndexChanged(EventHandler value) {}

    /**
     * Maintains performance while items are added to the list box one at a time by preventing
     * the ListBox control from painting until the endUpdate
     * method is called.   To help with the performance of this,
     * it is desirable to prevent the ListBox from painting during these
     * operations.  This method, along with @see endUpdate, is the preferred
     * way of doing this.  Don't forget to call endUpdate when you're done,
     * or else the ListBox won't paint properly afterwards.
     */
    public final void beginUpdate() {}

    /**
     * Resumes painting the ListBox control after painting is suspended by the beginUpdate method.   To help with the performance of this,
     * it is desirable to prevent the ListBox from painting during these
     * operations.  This method, along with @see beginUpdate, is the preferred
     * way of doing this.  beginUpdate should be called first, and this method
     * should be called when you want the control to start painting again.
     */
    public final void endUpdate() {}

    /**
     * Finds the first item in the list box that starts with the specified string. 
     * The search is not case sensitive.
     *
     * @param s The string to search for.
     * @return The index of the first item that starts with the given string,
     * or -1 if no match was found.
     */
    public final int findString(String s) {}

    /**
     * Finds the first item in the list box that starts with the specified string.  The search is not case sensitive.
     *
     * @param s The string to search for.
     * @param startIndex The index of the item to start after.
     * @return The index of the first item that starts with the given string,
     * or -1 if no match was found.
     */
    public final int findString(String s, int startIndex) {}

    /**
     * Finds the first item in the list that exactly matches the string specified in the s
     * parameter. 
     * The strings must match exactly, except for differences in casing.
     *
     * @param s The string to search for.
     * @return The index of the first item that matches the given string,
     * or -1 if no match was found.
     */
    public final int findStringExact(String s) {}

    /**
     * Finds the first item in the list that exactly matches the string specified in the s
     * parameter.  The strings must match excatly, except for differences in
     * casing.
     *
     * @param s The string to search for.
     * @param startIndex The index of the item to start after.
     * @return The index of the first item that matches the given string,
     * or -1 if no match was found.
     */
    public final int findStringExact(String s, int startIndex) {}

    /**
     * Retrieves a value indicating if the list box has a three-dimensional border, a flat
     * single-line border, or no border.   Values for this are taken from
     * The com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @return the current border style.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final int getBorderStyle() {}

    /**
     * Retrieves a value indicating the current width of each column in a multicolumn list
     * box.  A value of zero [0] means that windows will
     * choose a default width for each column.
     *
     * @return  the width, in pixels, of each column in the listbox.
     */
    public final int getColumnWidth() {}

    /**
     * Retrieves the parameters needed to create the handle.  Inheriting classes
     * can override this to provide extra functionality.  They should not,
     * however, forget to call super.getCreateParams() first to get the struct
     * filled up with the basic info.
     *
     * @return a CreateParams object with all the info needed to create
     *         the control.
     *
     * @see com.ms.wfc.ui.CreateParams
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a value indicating whether the system draws the list box, whether the list
     * box owner draws the list box with all items of equal height, or whether the list box owner
     * draws the list box with items of variable height.   This will indicate if the system
     * draws it, or if the user paints each item manually.  It also indicates
     * whether or not items have to be of the same height.
     *
     * @return an Integer with the style.
     *
     * @see com.ms.wfc.ui.DrawMode
     */
    public final int getDrawMode() {}

    /**
     * Retrieves a boolean value indicating whether the list box should resize to avoid
     * showing partial items.   If so,
     * then only full items will be displayed, and the listbox will be resized
     * to prevent partial items from being shown.  Otherwise, they will be
     * shown
     *
     * @return  a boolean indicating if only full items will be shown
     */
    public final boolean getIntegralHeight() {}

    /**
     * Retrieves the item at the specified zero-based index.   All Index are zero-based.
     *
     * @param index Integer value with the index of the item to retrieve
     *
     * @return an Object handle with the item at that index in the listbox.
     */
    public final Object getItem(int index) {}

    /**
     * Retrieves the number of items in the list box. 
     *
     * @return int
     */
    public final int getItemCount() {}

    /**
     * Retrieves the height, in pixels, of an item in the list box.  When drawMode
     * is OWNERDRAWFIXED, all items have the same height. When drawMode is
     * OWNERDRAWVARIABLE, this method returns the height that will be given
     * to new items added to the list box. To determine the actual height of
     * an item, use the getItemHeight() method with an integer parameter.
     *
     * @return The height, in pixels, of an item in the list box.
     * @see #getItemHeight(int)
     */
    public final int getItemHeight() {}

    /**
     * Retrieves the height, in pixels, of an item in the list box.  The index parameter
     * is ignored if drawMode is not OWNERDRAWVARIABLE.
     *
     * @param index Item to return the height of.
     * @return The height, in pixels, of the specified item.
     */
    public final int getItemHeight(int index) {}

    /**
     * Retrieves the bounding rectangle for an item in the list. 
     * @param   index   index of item to return bounding rect for
     *
     * @return  a Rectangle object with the given item's bounds.
     */
    public final Rectangle getItemRect(int index) {}

    /**
     * Retrieves an Object array containing all the items in the list box. 
     *
     * @return an array of objects with the first item as the 0th element,
     *         and the last item in the list is last in the array.
     */
    public final Object[] getItems() {}

    /**
     * Retrieves a boolean value indicating whether the list box supports multiple
     * columns.   If it's multi-column,
     * then the listbox uses the columnWidth property to determine how wide to
     * make each column, and displays the data horizontally in columns instead
     * of vertically.
     *
     * @return  a boolean indicating if the listbox is multi-column or not.
     */
    public final boolean getMultiColumn() {}

    /**
     * Retrieves the combined height, in pixels, of all the items in the list box. 
     *
     * @return      the height, in pixels, of all items in the list box.
     */
    public final int getPreferredHeight() {}

    /**
     * For single-column list boxes, retrieves a boolean value indicating whether the
     * scroll bar always appears on the right side of the list, even when all items are visible
     * in the list box without scrolling.   By Default, windows will
     * only show a scrollbar when there are enough items to warrant it.
     *
     * For multi-column listboxes, Windows does not show a horizontal scroll
     * bar at all.  Setting this value indicates that a horizontal scroll
     * bar should be added.  There is never a vertical scroll bar.
     *
     * @return a boolean indicating whether or not the scrollbar should always
     *         be visible
     */
    public final boolean getScrollAlwaysVisible() {}

    /**
     * Retrieves a boolean value indicating whether the specified item is selected. 
     *
     * @param index We want to know if this item is selected or not.
     *
     * @return a boolean indicating whether it is [true] or not [false].
     */
    public final boolean getSelected(int index) {}

    /**
     * Retrieves the zero-based index of the currently selected item in a single-selection
     * list box.   If the value is -1, there is currently no selection.  If the
     * value is 0 or greater, than the value is the index of the currently
     * selected item.  If the MultiSelect property on the ListBox is true,
     * then a non-zero value for this property is the index of the first
     * selection
     *
     * @return the index of the currently selected item.
     */
    public final int getSelectedIndex() {}

    /**
     * Retrieves an array that contains the zero-based indices of all currently selected
     * items.  If there are no selected items in the list box, the result is
     * an empty array.
     *
     * @return Array of indices of the selected items
     */
    public final int[] getSelectedIndices() {}

    /**
     * Retrieves the currently selected item in the list.   If the value is null, there is currently no selection.  If the
     * value is non-null, then the value is that of the currently selected
     * item. If the MultiSelect property on the ListBox is true, then a
     * non-null return value for this method is the value of the first item
     * selected
     *
     * @return an Object with either <b>null</b> or the current selection.
     */
    public final Object getSelectedItem() {}

    /**
     * Retrieves an array containing all selected items in a list box.  If there are no
     * selected items in the list box, the result is an empty array.
     *
     * @return Array of selected items.
     */
    public final Object[] getSelectedItems() {}

    /**
     * Retrieves a value indicating how many items in the list box a user can select at one
     * time and how the user can make multiple selections.  Valid
     * values are from the com.ms.wfc.ui.SelectionMode enumeration.
     *
     * @return int  an integer value with the current selection style.
     *
     * @see com.ms.wfc.ui.SelectionMode
     */
    public final int getSelectionMode() {}

    /**
     * Retrieves a boolean value indicating whether the items in the list box are
     * sorted alphabetically.   'true' means that strings in
     * the list will be sorted alphabetically
     */
    public final boolean getSorted() {}

    /**
     * Retrieves the zero-based index of the first visible item in a list box.  Initially
     * the item with index 0 is at the top of the list box, but if the list
     * box contents have been scrolled another item may be at the top.
     *
     * @return index of the topmost visible item.
     */
    public final int getTopIndex() {}

    /**
     * Retrieves a boolean value indicating whether a list box can recognize and expand
     * tab characters when drawing its strings. 
     *
     * @return  indicating whether or not the listbox will honour TABs
     */
    public final boolean getUseTabStops() {}

    /**
     * Retrieves the zero-based index of the item at the specified coordinates. 
     *
     * @param point Point object with the coordinates to test.
     *
     * @return  the index of item that is under said point, or
     *          <b>ListBox.NOMATCHES</b> if there is no item under this
     *          location.
     */
    public final int indexFromPoint(Point p) {}

    /**
     * Retrieves the zero-based index of the item at the specified coordinates. 
     *
     * @param x  x coordinate of point to test.
     * @param y  y coordinate of point to test.
     *
     * @return the index of item that is under said point, or
     *         <b>ListBox.NOMATCHES</b> if there is no item under this
     *         location.
     */
    public final int indexFromPoint(int x, int y) {}

    /**
     * @internalonly
     */
    protected void insert(int index, Object item) {}

    /**
     * Adds an item to the list box at the specified position.   Note that if the sorted
     * property is set to "true", values inserted via this method are not
     * property sorted.  the @see addItem method should be used instead.
     *
     * @param index Where in the list [zero-based] it should be inserted.
     * @param item  The value of the item you want inserted
     *
     * @return  the index at which it was inserted [this can be different
     *          from the requested index in sorted listboxes, etc.]
     */
    public final void insertItem(int index, Object item) {}

    /**
     * We need to know when the window handle has been created so we can
     * set up a few things, like column width, etc!  Inheriting classes should
     * not forget to call <i>super.onCreateHandle()</i>.
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Overridden to make sure that we set up and clear out items
     * correctly.  Inheriting controls should not forget to call
     * <i>super.onDestroyHandle()</i>
     */
    protected void onDestroyHandle(Event e) {}

    /**
     * Triggers the drawItem event.   Inheriting controls
     * should use this to know when the event is fired [this is preferable to
     * adding an event handler yourself for this event].  They should,
     * however, remember to call super.onDrawItem(e); to ensure the event is
     * still fired to external listeners
     *
     * @param e     DrawItemEvent object with the details
     */
    protected void onDrawItem(DrawItemEvent e) {}

    protected void onMeasureItem(MeasureItemEvent e) {}

    /**
     * Triggers the selectedIndexChanged event.   Inheriting controls
     * should use this to know when the event is fired [this is preferable to
     * adding an event handler on yourself for this event].  They should,
     * however, remember to call super.onSelectedIndexChanged(e); to ensure the event is
     * still fired to external listeners
     *
     * @param e     Event object with the details
     */
    protected void onSelectedIndexChanged(Event e) {}

    /**
     * @internalonly
     */
    protected void remove(int index) {}

    /**
     * Removes all items from the list box.   All values and item data are
     * lost.
     */
    public void removeAll() {}

    /**
     * Removes the specified item from the list box. 
     * The item and it's values are discarded.
     *
     * @param index Index of item to removed
     */
    public final void removeItem(int index) {}

    /**
     * Removes the specified item from the list box. 
     *
     * @param value     Object to remove from the ListBox.
     *
     * @return   the integer [zero-based] index of the item removed,
     *           or -1 if it did not exist
     */
    public final int removeItem(Object value) {}

    /**
     * Removes the delegate that is assigned to the drawItem event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the measureItem event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnMeasureItem(MeasureItemEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the selectedIndexChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnSelectedIndexChanged(EventHandler value) {}

    
    private int sendInsertMessage(int message, int index, Object item) {}

    /**
     * Sets a value indicating if the list box has three-dimensional border, a flat
     * single-line border, or no border.   Values for this are taken from the
     * BorderStyle enumeration.
     *
     * @param value         New border style.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public final void setBorderStyle(int value) {}

    /**
     * Sets a value indicating the current width of each column in a multicolumn list box.   A value of zero [0] means that windows will pick a width for
     * us.
     *
     * @param int   new width of each column, in pixels.
     */
    public final void setColumnWidth(int value) {}

    /**
     * Sets a value indicating whether the system draws the list box, whether the list box
     * owner draws the list box with all items of equal height, or whether the list box owner
     * draws the list box with items of variable height.   This lets the user control whether
     * or not they paint the items themselves [default is not] and whether
     * or not the items are all the same height [default yes]
     *
     * @param value New Value of the listbox style
     */
    public final void setDrawMode(int value) {}

    /**
     * Sets a boolean value indicating whether the list box should resize to avoid
     * showing partial items.   If so,
     * then only full items will be displayed, and the listbox will be resized
     * to prevent partial items from being shown.  Otherwise, they will be
     * shown
     *
     * @param value new value for this property
     */
    public final void setIntegralHeight(boolean value) {}

    /**
     * Allows you to replace the item at the specified position in the list box.   If
     * there is no value at the supplied index, an exception is thrown.
     * Otherwise, the value becomes the newly supplied one
     *
     * @param index   Index of item to change the value for
     * @param item    New value for said index
     */
    public final void setItem(int index, Object item) {}

    /**
     * Sets the height, in pixels, of an item in the list box.  If drawMode is
     * OWNERDRAWFIXED, this method changes the height of all the items in the
     * list box. If drawMode is OWNERDRAWVARIABLE, this method sets the default
     * height that is given to new items added to the list box.
     *
     * @param value The item height in pixels.
     */
    public final void setItemHeight(int value) {}

    /**
     * Adds a set of items to the list box.   All old values in the ListBox are
     * discarded and lost
     *
     * @param value     Array of Objects that will be inserted into the ListBox
     */
    public final void setItems(Object[] value) {}

    /**
     * Sets a boolean value indicating whether the list box supports multiple columns.   If it's multi-column,
     * then the listbox uses the columnWidth property to determine how wide to
     * make each column, and displays the data horizontally in columns instead
     * of vertically.
     *
     * @param value  New value indicating if we should be multi-column or not.
     */
    public final void setMultiColumn(boolean value) {}

    /**
     * For single-column list boxes, sets a boolean value indicating whether the scroll
     * bar always appears on right side of the list, even when all items are visible in the list
     * box without scrolling.   By Default, windows will
     * only show a scrollbar when there are enough items to warrant it.
     * </p>
     *
     * <p>
     * For multi-column listboxes, Windows does not show a horizontal scroll
     * bar at all.  Setting this value indicates that a horizontal scroll
     * bar should be added.  There is never a vertical scroll bar.
     * </>
     *
     * @param value  new value indicating if this should be set
     */
    public final void setScrollAlwaysVisible(boolean value) {}

    /**
     * Selects or clears the selection for the specified item in a multiple selection list
     * box.   This should
     * only be used with ListBoxes that allow some sort of multi-selection.
     *
     * @param index Index of the item to mark as selected
     * @param value boolean indicating whether the item should be selected or
     *              not
     */
    public final void setSelected(int index, boolean value) {}

    /**
     * Selects an item in a single-selection list box.   If the <i>selectionMode</i> property is set to allow multi-
     * selection, then this deselects all other selections.  Note that if the
     * value of <i>index</i> is -1, the ListBox is set to have no selection.
     *
     * @param index  Index of item to select
     */
    public final void setSelectedIndex(int index) {}

    /**
     * Selects the first occurrence of the specified item in a single-selection list box, and
     * returns the zero-based index of the item. 
     *
     * @param value     The object to make selected.
     *
     * @return    the integer [zero-based] index of the selected
     *            item, or -1 if it did not exist.
     */
    public final int setSelectedItem(Object value) {}

    /**
     * Sets a value indicating how many items in the list box a user can select at one time
     * and how the user can make multiple selections.  Valid
     * values are from the com.ms.wfc.ui.SelectionMode enumeration.
     *
     * @param value     The new selection style for this ListBox
     *
     * @see com.ms.wfc.ui.SelectionMode
     */
    public void setSelectionMode(int value) {}

    /**
     * Sets a boolean value indicating whether the items in the list box are sorted
     * alphabetically. 
     *
     * @param sorted    boolean indicating whether or not sorting should be on
     */
    public final void setSorted(boolean value) {}

    /**
     * Sets a boolean value indicating whether a list box can recognize and expand tab
     * characters when drawing its strings. 
     *
     * @param value New value indciating whether or not the listbox should
     *        honour tab characters
     */
    public final void setUseTabStops(boolean value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * @internalonly
     */
    protected void wmReflectCommand(Message m) {}

    
    private void wmReflectDrawItem(Message m) {}

    
    private void wmReflectMeasureItem(Message m) {}

    /**
     * The list's window procedure.  Inheriting classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the list continues to function properly.
     *
     * @param m     A Windows Message Object.
     */
    protected void wndProc(Message m) {}

    /**
     * Encapsulates the Windows list box control, which displays a list from which the user  can select one or more items. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        public static final PropertyInfo backColor = new PropertyInfo(
            ListBox.class, "backColor", Color.class,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.COLOR_WINDOW,
            new DescriptionAttribute(Sys.getString("ListBoxBackColorDescr")));

        public static final PropertyInfo borderStyle = new PropertyInfo(
            ListBox.class, "borderStyle", BorderStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(BorderStyle.FIXED_3D)),
            new DescriptionAttribute(Sys.getString("ListBoxBorderDescr")));

        public static final PropertyInfo columnWidth = new PropertyInfo(
            ListBox.class, "columnWidth", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("ListBoxColumnWidthDescr")));

        public static final PropertyInfo drawMode = new PropertyInfo(
            ListBox.class, "drawMode", com.ms.wfc.ui.DrawMode.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.DrawMode.NORMAL)),
            new DescriptionAttribute(Sys.getString("ListBoxDrawModeDescr")));

        public static final PropertyInfo integralHeight = new PropertyInfo(
            ListBox.class, "integralHeight", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("ListBoxIntegralHeightDescr")));

        public static final PropertyInfo items = new PropertyInfo(
            ListBox.class, "items", Object[].class,
            new MemberAttribute[] {
            CategoryAttribute.Behavior,
            LocalizableAttribute.YES,
            DefaultValueAttribute.EMPTY_ARRAY,
            new DescriptionAttribute(Sys.getString("ListBoxItemsDescr")),
            new ValueEditorAttribute(com.ms.wfc.core.StringListEditor.class)
            });

        public static final PropertyInfo itemHeight = new PropertyInfo(
            ListBox.class, "itemHeight", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(15)),
            new DescriptionAttribute(Sys.getString("ListBoxItemHeightDescr")));

        public static final PropertyInfo multiColumn = new PropertyInfo(
            ListBox.class, "multiColumn", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("ListBoxMultiColumnDescr")));

        public static final PropertyInfo selectedItem = new PropertyInfo(
            ListBox.class, "selectedItem", Object.class,
            BrowsableAttribute.NO,
            BindableAttribute.YES,
            PersistableAttribute.NO,
            DefaultValueAttribute.FALSE);

        public static final PropertyInfo selectionMode = new PropertyInfo(
            ListBox.class, "selectionMode", com.ms.wfc.ui.SelectionMode.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.SelectionMode.ONE)),
            new DescriptionAttribute(Sys.getString("ListBoxSelectionModeDescr")));

        public static final PropertyInfo sorted = new PropertyInfo(
            ListBox.class, "sorted", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("ListBoxSortedDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final PropertyInfo useTabStops = new PropertyInfo(
            ListBox.class, "useTabStops", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("ListBoxUseTabStopsDescr")));

        public static final EventInfo drawItem = new EventInfo(
            ListBox.class, "drawItem", DrawItemEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("drawItemEventDescr")));

        public static final EventInfo measureItem = new EventInfo(
            ListBox.class, "measureItem", MeasureItemEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("measureItemEventDescr")));

        public static final EventInfo selectedIndexChanged = new EventInfo(
            ListBox.class, "selectedIndexChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("selectedIndexChangedEventDescr")));

        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public static final EventInfo mouseWheel = new EventInfo(
            Control.ClassInfo.mouseWheel, BrowsableAttribute.NO);

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}