//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.DllLib;
import com.ms.lang.Delegate;

import com.ms.wfc.win32.NMHEADER;

/**
 * Encapsulates the Windows list view control, which displays a collection of items, each  consisting of an icon (from an image list) and a label.   Images can be associated with each item.
 * </p>
 * 
 * <p>
 * Items can be added using either the addItem, insertItem, or setItems method.
 * </p>
 * 
 *
 * @security(checkClassLinking=on)
 */
public class ListView extends Control {

    
    int activation = ItemActivation.STANDARD;
    int alignStyle = ListViewAlignment.TOP;
    int borderStyle = BorderStyle.FIXED_3D;
    int headerStyle = ColumnHeaderStyle.CLICKABLE;
    int sorting = SortOrder.NONE;
    int viewStyle = ViewEnum.LARGEICON;
    boolean allowColumnReorder = false;
    boolean autoArrange = false;
    boolean checkBoxes = false;
    boolean fullRowSelect = false;
    boolean gridLines = false;
    boolean hideSelection = true;
    boolean labelEdit = false;
    boolean labelWrap = true;
    boolean multiSelect = true;
    boolean scrollable = true;
    boolean hoverSelection = false;
    boolean nonclickHdr = false;

    ImageList imageListLarge;
    ImageList imageListSmall;
    ImageList imageListState;

    private int updateCount;
    private int downButton;
    private boolean clickSeen;
    int itemCount;
    ListItem[] listItems;
    ColumnHeader[] columnHeaders;

    LabelEditEventHandler onAfterLabelEdit;
    LabelEditEventHandler onBeforeLabelEdit;
    ColumnClickEventHandler onColumnClick;
    EventHandler onItemActivate;
    ItemDragEventHandler onItemDrag;
    ItemCheckEventHandler onItemCheck;
    
    /**
     * Creates an empty ListView with default styles.
     */
    public ListView() {}

    /**
     * Adds a column to the list view control and returns the column header that appears at
     * the top of the column. 
     * @param str           Text for new column
     * @param width         Width of new column in pixels
     * @param textAlign     The alignment of the text in this column.  Must be
     *                      a value from HorizontalAlignment class
     * 
     * @return a ColumnHeader object representing the new column.
     * @see ColumnHeader
     * @see HorizontalAlignment
     */
    public ColumnHeader addColumn(String str, int width, int textAlign) {}

    /**
     * Adds an item to the list view control and returns the new item.   The item will be inserted either in
     * the correct sorted position, or, if no sorting is set, at the end
     * of the list.
     *
     * @param listItem      ListItem object containing the item data
     *
     * @return the ListItem object passed in
     */
    public ListItem addItem(ListItem listItem) {}

    /**
     * Adds an item to the list view control and returns the new item.   The item will be inserted either in
     * the correct sorted position, or, if no sorting is set, at the end
     * of the list.  The item is created with no associated image or subItems.
     *
     * @param text          string to display in list
     *
     * @return a ListItem object representing the added item
     */
    public ListItem addItem(String text) {}

    /**
     * Adds an item to the list view control and returns the new item.   The item will be inserted either in
     * the correct sorted position, or, if no sorting is set, at the end
     * of the list.  The item is created with no subItems.
     *
     * @param text          string to display in list
     * @param imageIndex    index of image in associated ImageList object
     *
     * @return a ListItem object representing the added item
     */
    public ListItem addItem(String text, int imageIndex) {}

    /**
     * Adds an item to the list view control and returns the new item.   The item will be inserted either in
     * the correct sorted position, or, if no sorting is set, at the end
     * of the list.
     *
     * @param text          string to display in list
     * @param imageIndex    index of image in associated ImageList object
     * @param subItems  an array of strings corresponding to subitems of the item
     *
     * @return a ListItem object representing the added item
     */
    public ListItem addItem(String text, int imageIndex, String[] subItems) {}

    /**
     * Assigns a delegate to the afterLabelEdit event. 
     * The afterLabelEdit event is fired when the user finishes editing the text of
     * an item in the ListView.  The labelEdit property of the ListView must be <b>true</b>
     * to enable the user to do this.  The string to which the user changed the text is
     * passed to the event, and the event handler is given the opportunity to reject
     * the change, in which case the text will revert back to what it was before the
     * user started the change.
     *
     * @param value     LabelEditEventHandler to install for this event.
     */
    public final void addOnAfterLabelEdit(LabelEditEventHandler value) {}

    /**
     * Assigns a delegate to the beforeLabelEdit event. 
     * The beforeLabelEdit event is fired when the user attempts to begin changing
     * the text of an item in the ListView.  The event handler can cancel this event,
     * in which case the user won't be allowed to edit the text.  This event can be
     * used to prevent the user from editing specific items in the ListView.  If the
     * labelEdit property of the ListView is <b>false</b>, this event will not be fired,
     * and all user attempts to edit item labels will be automatically rejected.
     *
     * @param value     LabelEditEventHandler to install for this event.
     */
    public final void addOnBeforeLabelEdit(LabelEditEventHandler value) {}

    /**
     * Assigns a delegate to the columnClick event. 
     * The columnClick event is fired only in Report view, when the user clicks
     * on one of the report column headers.  Typical response to such a click
     * would be to sort the ListView items using the clicked column as the key.
     *
     * @param value     ColumnClickEvent handler to install for this event.
     */
    public final void addOnColumnClick(ColumnClickEventHandler value) {}

    /**
     * Assigns a delegate to the itemActivate event. 
     * Activation may be accomplished by either a single or double click, depending
     * on the value of the <b>activation</b> property, or with the keyboard.
     * The event handler should call <b>getSelectedItems</b> to determine which items
     * are being activated.
     *
     * @param value     Event handler to install for this event.
     */
    public final void addOnItemActivate(EventHandler value) {}

    /**
     * Assigns a delegate to the itemCheck event.  This
     * event is called whenever the check state of an item changes.
     * NOTE: The value is not updated until after the event.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnItemCheck(ItemCheckEventHandler value) {}

    /**
     * Assigns a delegate to the itemDrag event.   A typical response to this
     * event would be to call <b>doDragDrop</b>.
     *
     * @param value     Event handler to install for this event.
     */
    public final void addOnItemDrag(ItemDragEventHandler value) {}

    /**
     * Arranges items in Large Icon or Small Icon view. 
     * @param  Icon Arrangement behavior. May be:
     *     LVA_DEFAULT    Aligns items according to the ListView's current <b>alignment</b> style
     *     LVA_ALIGNLEFT  Aligns items along the left edge of the window
     *     LVA_ALIGNTOP   Aligns items along the top edge of the window
     *     LVA_SNAPTOGRID Snaps all icons to the nearest grid position
     *
     * @exception IllegalArgumentException thrown if flag 
     *            is not one of the supported Icon Arrangement styles.
     */
    public void arrangeIcons(int value) {}

    /**
     * Arranges items in Large Icon or Small Icon view. 
     */
    public void arrangeIcons() {}

    /**
     * Maintains performance while items are added to the list view control one at a time by
     * preventing the ListView control from painting until the endUpdate
     * method is called. 
     * Calling this method before individually adding or removing a large number of ListItems
     * will improve performance and reduce flicker on the ListView as items are
     * being updated.  Always call endUpdate immediately after the last item is updated.
     *
     * @see endUpdate
     */
    public final void beginUpdate() {}

    /**
     * Resumes painting the ListView control after painting is suspended by the beginUpdate method. 
     *
     * @see beginUpdate
     */
    public final void endUpdate() {}

    /**
     * Removes all items and columns from the list view control. 
     */
    public void clear() {}

    
    private void detachImageList(Object sender, Event e) {}

    /**
     * Disposes of the component.  Call dispose when the component is no longer needed. 
     * This method removes the component from its container (if the component has a site) 
     * and triggers the dispose event. 
     */
    public synchronized void dispose() {}

    /** 
     * Ensures that the specified list item is visible, scrolling the list view control if
     * necessary. 
     *
     * @index  Index of item to scroll into view
     */
    public void ensureVisible(int index) {}

    /**
     * Retrieves a value indicating what kind of action the user must take to activate an item
     * and what sort of feedback is given to the user to show which item the mouse pointer is
     * over.  
     *
     * @return int  value of the current activation style from com.ms.wfc.ui.ItemActivation.
     * 
     * @see com.ms.wfc.ui.ItemActivation
     */
    public final int getActivation() {}

    /**
     * Retrieves a value indicating whether items are aligned to the top or to the left of the
     * list view control by default. 
     * @return int  value of the current alignment style from com.ms.wfc.ui.ListViewAlignment
     *
     * @see com.ms.wfc.ui.ListViewAlignment
     */
    public final int getAlignment() {}

    /**
     * Retrieves a boolean value indicating whether the user can drag and drop column
     * headers to reorder columns in the list view control. 
     * This property is only meaningful in Report view.
     *
     * @return boolean whether Column reordering is allowed
     */
    public final boolean getAllowColumnReorder() {}

    /**
     * Retrieves a boolean value indicating whether icons are automatically kept
     * arranged.   Items are also kept snapped to grid.
     * This property is only meaningful in Large Icon or Small Icon views.
     *
     * @return boolean whether AutoArrange is set
     */
    public final boolean getAutoArrange() {}

    /**
     * Retrieves a value indicating the kind of border the list view control has. 
     *
     * @return int representing BorderStyle from com.ms.wfc.ui.BorderStyle
     */
    public int getBorderStyle() {}

    /**
     * Retrieves a boolean value indicating whether a check box appears next to each
     * item in the list view control.   The user can change the state of the item by clicking the checkbox.
     *
     * @return boolean whether CheckBoxes will appear by items
     */
    public final boolean getCheckBoxes() {}

    /**
     * Retrieves a value indicating the number of columns that appear in the list view control
     * in Report view. 
     *
     * @return int     number of columns in ListView
     */
    public final int getColumnCount() {}

    
    final int getColumnIndex(ColumnHeader ch) {}

    /**
     * Retrieves the column header for the specified column. 
     * @param index     Zero based index of specific column
     *
     * @return          ColumnHeader object
     *
     * @exception       WFCIllegalArgumenException Thrown if index is out of bounds
     */
    public final ColumnHeader getColumn(int index) {}

    /**
     * Retrieves an array of all the column headers that appear in the list view control in
     * Report view. 
     * @return         Array of ColumnHeader objects
     */
    public final ColumnHeader[] getColumns() {}

    /**
     * Computes the handle creation parameters for the ListView control.
     *
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the item in the list view control that currently has the focus.   This is the
     * item that's drawn with the dotted focus rectangle around it.
     *
     * @return     Currently focused ListItem
     *
     * @exception  Throws WFCException if no item has the focus
     */
    public ListItem getFocusedItem() {}

    /**
     * Retrieves a boolean value indicating whether clicking an item selects the item
     * and all its subitems rather than just the item itself. 
     * This property is only meaningful in Report view
     *
     * @return  boolean whether FullRowSelect is set
     *
     */
    public final boolean getFullRowSelect() {}

    /**
     * Retrieves a boolean value indicating whether gridlines appear between the rows
     * and columns containing the items and subitems in a list view control. 
     * This property is only meaningful in Report view
     *
     * @return  boolean whether GridLInes is set.
     *
     */
    public final boolean getGridLines() {}

    /**
     * Retrieves a value indicating whether column headers are visible in Report view and, if
     * they are visible, whether they act like buttons, allowing users to click them to carry out
     * actions. 
     * This property is only meaningful in Report view
     *
     * @return  int from com.ms.wfc.ui.HeaderStyle class
     *
     * @see com.ms.wfc.ui.HeaderStyle
     */
    public final int getHeaderStyle() {}

    /**
     * Retrieves a boolean value indicating whether the selected item in the list view
     * control remains highlighted when the control loses the focus. 
     *
     * @return  boolean  whether HideSelection is set
     */
    public final boolean getHideSelection() {}

    /**
     * Retrieves the specified item in the list view control. 
     *
     * @param index     Zero based index into ListView's list of items
     *
     * @return          ListItem representing item at specified index
     *
     * @exception WFCInvalidArgumentException Thrown if Index is out of bounds.
     */
    public final ListItem getItem(int index) {}

    /**
     * Retrieves the item at the specified location. 
     *
     * @param x x position to check against
     * @param y y position to check against
     *
     * @return ListItem ListItem at position, or null if no 
     * Item exists there.
     */
    public ListItem getItemAt(int x, int y) {}

    /**
      * Retrieves the number of items contained in the list view control. 
      *
      * @return Integer count of items.
      *
      */
    public final int getItemCount() {}

    
    final int getItemIndex(ListItem li) {}

    /**
      * Retrieves an array containing all the items in the list view control. 
      *
      * @return items Array containing ListItems
      */
    public final ListItem[] getItems() {}

    final int getItemState(int index) {}

    final int getItemState(int index, int mask) {}

    /**
     * Retrieves the specified portion of the bounding rectangle for a list view item. 
     *
     * @param index     Zero based index into ListView's list of items
     *
     * @return Rectangle associated with the ListItem
     */
    public final Rectangle getItemRect(int index) {}

    /**
     * Retrieves the specified portion of the bounding rectangle for a list view item. 
     *
     * @param index     Zero based index into ListView's list of items
     * @param portion   The portion of the item's rectange desired.
     *                  This must be one of the values from the ItemBoundsPortion enum.
     *
     * @return Rectangle associated with the ListItem
     *
     * @see ItemBoundsPortion
     */
    public final Rectangle getItemRect(int index, int portion) {}

    /**
     * Retrieves the text for the specified list view item. 
     *
     * @param index     Zero based index into ListView's list of items
     *
     * @return          String representing the label of the item
     *
     * @exception WFCInvalidArgumentException Thrown if Index is out of bounds.
     */
    public final String getItemText(int index) {}

    /**
      * Retrieves a boolean value indicating whether the user can edit the labels of
     * list view items. 
      *
      * @return Boolean whether LabelEdit is set.
      */
    public boolean getLabelEdit() {}

    /**
      * Retrieves a boolean value indicating whether item labels wrap in icon view. 
      *
      * @return Boolean whether LabelWrap is set.
      */
    public boolean getLabelWrap() {}

    /**
     * Retrieves the image list control associated with Large Icon view in the list view
     * control. 
     *
     * @return  ImageList or null if none set.
     */
    public final ImageList getLargeImageList() {}

    /**
      * Retrieves a boolean value indicating whether multiple items in the list view
     * control can be selected at one time. 
      *
      * @return Boolean whether MultiSelect is set.
      */
    public boolean getMultiSelect() {}

    /**
      * Retrieves a boolean value indicating whether a scroll bar is added to the list
     * view control when there is not enough room to display all the list view items in the
     * control client area. 
      *
      * @return Boolean whether ScrollBars are visible.
      */
    public boolean getScrollable() {}

    /**
      * Retrieves an array containing all selected items in a list view control. 
      *
      * @return ListItem[] array of currently selected list items.
      *
      * @exception RuntimeException Thrown if the number of selected 
      * items < the number of actual items selected
      */
    public ListItem[] getSelectedItems() {}

    /**
      * Retrieves the image list control associated with all views other than Large Icon view
     * in the list view control. 
      *
      * @return ImageList representing SmallIcon mage list, or null
      * if not set.
      */
    public ImageList getSmallImageList() {}

    /**
      * Retrieves a value indicating whether list items are sorted based on item text in
     * ascending or descending order or whether items are not sorted. 
      * @return Integer Current sorting style. Possibilites are:
      *     Ascending
      *     Descending
      *     None
      */
    public int getSorting() {}

    public final ImageList getStateImageList() {}

    public final ListItem getTopItem() {}

    /**
      * Retrieves a boolean value indicating whether a list control item is
     * automatically selected when the mouse pointer remains over the item for a few seconds.  
      *
      * @return Boolean whether HoverSelection is set.
      */
    public boolean getHoverSelection() {}

    /**
      * Retrieves a value that indicates how data is displayed in the list view control. 
      * @return Integer Current view style. Possibilites are:
      *     Icon
      *     SmallIcon
      *     List
      *     Report
      */
    public int getView() {}

    /**
     * Inserts a column into the list view control at the specified position and returns the
     * column header that appears at the top of the new column. 
     * @param index Index of new column
     *
     * @param ch    ColumnHeader object describing new column
     *
     * @return      ColumnHeader object representing the new column
     *
     * @exception WFCInvalidArgumentException Thrown if ch is null
     *            or if its textAlign is not valid.
     * @exception WFCException Thrown if the column already exists
     *            in another control or there is a problem creating 
     *            the new column in the Windows control.
     */
    public ColumnHeader insertColumn(int index, ColumnHeader ch) {}

    
    private ColumnHeader insertColumn(int index, ColumnHeader ch, boolean refreshSubItems) {}

    /**
     * Inserts a column into the list view control at the specified position and returns the
     * column header that appears at the top of the new column. 
     * @param index         Index for new Column
     * @param str           Text for new Column
     * @param width         Width of new column
     * @param textAlign     The alignment of the text in this column.  Must be
     *                      a value from HorizontalAlignment class
     * 
     * @return a ColumnHeader object representing the new column.
     * @see ColumnHeader
     * @see HorizontalAlignment
     */
    public ColumnHeader insertColumn(int index, String str, int width, int textAlign) {}

    /**
     * Inserts an item into the list view control.   The item will be inserted
     * either in the correct sorted position, or, if no sorting is set, at the
     * positiion indicated by the index parameter.
     * 
     * @param index     Index for new Item
     * @param li        ListItem object describing new item
     *
     * @return the ListItem object passed in.
     *
     * @exception runtimeException Thrown if there is a problem creating 
     * the new item.
     */
    public ListItem insertItem(int index, ListItem li) {}

    /**
     * Inserts an item into the list view control.   The item will be inserted
     * either in the correct sorted position, or, if no sorting is set, at the
     * position indicated by the index parameter.    The item is created with
     * no associated image or subItems.
     * 
     * @param index     Index for new Item
     * @param text      string to display in list
     *
     * @return a ListItem object representing the added item
     */
    public ListItem insertItem(int index, String text) {}

    /**
     * Inserts an item into the list view control.   The item will be inserted
     * either in the correct sorted position, or, if no sorting is set, at the
     * position indicated by the index parameter.    The item is created with
     * no subItems.
     *
     * @param index         Index for new Item
     * @param text          string to display in list
     * @param imageIndex    index of image in associated ImageList object
     *
     * @return a ListItem object representing the added item
     */
    public ListItem insertItem(int index, String text, int imageIndex) {}

    /**
     * Inserts an item into the list view control.   The item will be inserted
     * either in the correct sorted position, or, if no sorting is set, at the
     * position indicated by the index parameter.
     *
     * @param index         Index for new Item
     * @param text          string to display in list
     * @param imageIndex    index of image in associated ImageList object
     * @param subItems      an array of strings corresponding to subitems of the item
     *
     * @return a ListItem object representing the added item
     */
    public ListItem insertItem(int index, String text, int imageIndex, String[] subItems) {}

    /**
      * @internalonly
      */
    protected void onCreateHandle(Event e) {}

    /**
      * Triggers the afterLabelEdit event. 
      *
      * @param e    LabelEditEvent object with the details
      */
    protected void onAfterLabelEdit(LabelEditEvent e) {}

    /**
      * Triggers the beforeLabelEdit event. 
      *
      * @param e    LabelEditEvent object with the details
      */
    protected void onBeforeLabelEdit(LabelEditEvent e) {}

    /**
      * Triggers the columnClick event. 
      *
      * @param e     ColumnClickEvent object with the details
      */
    protected void onColumnClick(ColumnClickEvent e) {}

    /**
      * Triggers the itemActivate event. 
      *
      * @param e     Event object
      */
    protected void onItemActivate(Event e) {}

    /**
     * This is the code that actually fires the KeyEvent.  Don't
     * forget to call <i>super.onItemCheck()</i> to ensure that itemCheck vents
     * are correctly fired for all other keys.
     *
     * @param e     The KeyPress event that was fired.
     * @internalonly
     */
    protected void onItemCheck(ItemCheckEvent ice) {}

    protected void onItemDrag(ItemDragEvent e) {}

    /**
      * @internalonly
      */
    protected void recreateHandle() {}

    /**
      * @internalonly
      */
    protected void realizeProperties() {}

    /**
     * Removes all columns from the list view control.  */
    public void removeAllColumns() {}

    /**
     * Removes all items from the list view control.  */
    public void removeAllItems() {}

    /**
     * Removes the specified column from the list view control. 
     * @param index Zero based index of the column that is to be removed
     *
     *
     * @exception WFCInvalidArgumentException Thrown is index is out of bounds.
     */
    public void removeColumn(int index) {}

    /**
     * Removes the specified item from the list view control. 
     * @param index Zero based index of the item that is to be removed
     *
     *
     * @exception WFCInvalidArgumentException Thrown is index is out of bounds.
     */
    public void removeItem(int index) {}

    /**
     * Removes the specified item from the list view control. 
     * @param item  ListItem to be removed
     *
     * @exception WFCInvalidArgumentException if item is null.
     */
    public void removeItem(ListItem item) {}

    /**
     * Removes the delegate that is assigned to the afterLabelEdit event. 
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnAfterLabelEdit(LabelEditEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the beforeLabelEdit event. 
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnBeforeLabelEdit(LabelEditEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the columnClick event. 
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnColumnClick(ColumnClickEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the itemActivate event. 
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnItemActivate(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the itemCheck event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnItemCheck(ItemCheckEventHandler value) {}

    public final void removeOnItemDrag(ItemDragEventHandler value) {}

    public void setActivation(int value) {}

    /**
      * Sets a value indicating whether items are aligned to the top or to the left of the list
     * view control by default. 
      * @param alignflag Specifies alignment style for ListView
      *
      * @exception WFCInvalidArgumentException Thrown if 
      * alignment style is unknown.
      */
    public void setAlignment(int value) {}

    /**
      * Sets a boolean value indicating whether the user can drag and drop column
     * headers to reorder columns in the list view control. 
      * @param flag Sets Column Reorder On/Off
      *
      * 
      */
    public void setAllowColumnReorder(boolean flag) {}

    /**
      * Sets a boolean value indicating whether icons are automatically kept arranged. 
      * @param flag Sets AutoArrange Reorder On/Off
      *
      * 
      */
    public void setAutoArrange(boolean flag) {}

    /**
      * Sets the background color for the list view control.  */
    public void setBackColor(Color value) {}

    /**
      * Sets a value indicating the kind of border the list view control has. 
      * @param value Sets Borderstyle to one of the following:
      *     NONE
      *     SUNKEN3D
      */
    public void setBorderStyle(int value) {}

    /**
      * Sets a boolean value indicating whether a check box appears next to each item in
     * the list view control. 
      * @param flag Sets CheckBoxes On/Off
      *
      * 
      */
    public void setCheckBoxes(boolean flag) {}

    
    final void setColumnInfo(int mask, ColumnHeader ch) {}

    
    final void setColumnWidth(int index, int width) {}

    /**
      * Adds a set of columns to the list view control. 
      *
      * @param columns Array containing ColumnHeaders
      *
      */
    public void setColumns(ColumnHeader[] columns) {}

    /**
      * Sets a boolean value indicating whether this control is enabled. SetEnabled
      */
    public void setEnabled(boolean enabled) {}

    /**
     * Overrides Control.setFont.
     */
    public void setFont(Font value) {}

    /**
      * Sets the current foreground color for this control, which is the color the control uses
     * to draw its text. SetForeColor
      */
    public void setForeColor(Color value) {}

    /**
      * Sets a boolean value indicating whether clicking an item selects the item and
     * all its subitems instead of selecting just the item itself. 
      * @param flag Sets Full Row Select On/Off
      *
      * 
      */
    public void setFullRowSelect(boolean flag) {}

    /**
      * Sets a boolean value indicating whether gridlines appear around items and
     * subitems. 
      * @param flag Sets GridLines On/Off
      *
      * 
      */
    public void setGridLines(boolean flag) {}

    /**
      * Sets a boolean value indicating whether the selected item in the list view
     * control remains highlighted when the control loses the focus. 
      * @param flag Sets Selection Always Visible On/Off
      *
      * 
      */
    public void setHideSelection (boolean flag) {}

    /**
      * Sets the image list control associated with Large Icon view in the list view control. 
      *
      * @param v ImageList containing Large Icons
      *
      * 
      */
    public void setLargeImageList(ImageList value) {}

    /**
      * Adds a set of items to the list view control. 
      *
      * @param items Array containing ListItems
      *
      */
    public void setItems(ListItem[] items) {}

    final void setItemImage(int index, int image) {}

    final void setItemState(int index, int state, int mask) {}

    final void setItemText(int index, String text) {}

    /**
      * Sets a boolean value indicating whether the user can edit the labels of list
     * view items. 
      * @param flag Sets LabelEdit On/Off
      *
      * 
      */
    public void setLabelEdit (boolean flag) {}

    /**
      * Sets a boolean value indicating whether item labels wrap in icon view. 
      * @param flag Sets Label Wrap On/Off
      *
      * 
      */
    public void setLabelWrap(boolean flag) {}

    /**
      * Sets a boolean value indicating whether multiple items can be selected at one
     * time in the list view control. 
      * @param flag Sets MultiSelection On/Off
      *
      * 
      */
    public void setMultiSelect(boolean flag) {}

    /**
      * Sets a boolean value indicating whether a scroll bar is added to the list view
     * control when there is not enough room to display all of the list view items in the control
     * client area. 
      * @param flag Sets Scroll Bar visible On/Off
      *
      * 
      */
    public void setScrollable(boolean flag) {}

    /**
      * Sets the image list control associated with all views other than Large Icon view in the
     * list view control. 
      *
      * @param v ImageList containing Small Icons
      *
      * 
      */
    public void setSmallImageList(ImageList value) {}

    /**
      * Sets a value indicating whether column headers are visible in Report view and, if they
     * are visible, whether they act like buttons, allowing users to click them to carry out
     * actions. 
      * @param flag Sets Column Sort On/Off
      *
      * 
      */
    public void setHeaderStyle(int value) {}

    /**
      * Sets a value indicating whether list items are sorted based on item text in ascending
     * or descending order or whether items are not sorted. 
      * @param sortflag Sets Sort style on the ListView.
      * Style may be one of the following:
      *     None
      *     Ascending
      *     Descending
      *
      * 
      */
    public void setSorting(int value) {}

    public void setStateImageList(ImageList value) {}

    
    void setSubItem(int itemIndex, int subItemIndex, String text) {}

    
    private void realizeAllSubItems() {}

    /**
      * Sets a boolean value indicating whether a list control item is automatically
     * selected when the mouse pointer remains over the item for a few seconds. 
      * @param flag Sets Track Select On/Off
      *
      * 
      */
    public void setHoverSelection(boolean flag) {}

    /**
      * Sets a value that indicates how data is displayed in the list view control. 
      * @param viewflag Sets View style on the ListView.
      * Style may be one of the following:
      *     Icon
      *     SmallIcon
      *     List
      *     Report
      * 
      */
    public void setView(int value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    protected void updateExtendedStyles() {}

    
    void wmNotify(Message m) {}

    private void wmMouseDown(Message m, int button, int clicks) {}

    /**
      * @internalonly
      */
    protected void wndProc(Message m) {}


    /**
      * Encapsulates the Windows list view control, which displays a collection of items, each  consisting of an icon (from an image list) and a label. 
      * @internalonly
      *
      * @security(checkClassLinking=on)
      */
    public static class ClassInfo extends Control.ClassInfo {

        

        public static final EventInfo afterLabelEdit = 
            new EventInfo(ListView.class, 
                         "afterLabelEdit", 
                         LabelEditEventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewAfterLabelEditDescr")));
                         

        public static final EventInfo beforeLabelEdit = 
            new EventInfo(ListView.class, 
                         "beforeLabelEdit", 
                         LabelEditEventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewBeforeLabelEditDescr")));

        public static final EventInfo columnClick = 
            new EventInfo(ListView.class, 
                         "columnClick", 
                         ColumnClickEventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewColumnClickDescr")));

        public static final EventInfo itemActivate = 
            new EventInfo(ListView.class, 
                         "itemActivate", 
                         EventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewItemClickDescr")));

        public static final EventInfo itemCheck =
            new EventInfo(ListView.class,
                          "itemCheck",
                          ItemCheckEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("CheckedListBoxItemCheckDescr")));

        public static final EventInfo itemDrag = 
            new EventInfo(ListView.class, 
                         "itemDrag", 
                         ItemDragEventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewItemDragDescr")));

        
        public static final PropertyInfo activation = 
            new PropertyInfo(ListView.class, 
                         "activation", 
                         ItemActivation.class,
                         CategoryAttribute.Behavior,
                         new DefaultValueAttribute(new Integer(ItemActivation.STANDARD)),
                         new DescriptionAttribute(Sys.getString("ListViewActivationDescr")));

        public static final PropertyInfo alignment = 
            new PropertyInfo(ListView.class, 
                         "alignment", 
                         ListViewAlignment.class,
                         CategoryAttribute.Behavior,
                         new DefaultValueAttribute(new Integer(ListViewAlignment.TOP)),
                         new DescriptionAttribute(Sys.getString("ListViewAlignmentDescr")));

        public static final PropertyInfo allowColumnReorder = 
            new PropertyInfo(ListView.class, 
                         "allowColumnReorder", 
                         Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewAllowColumnReorderDescr")));

        public static final PropertyInfo autoArrange = 
            new PropertyInfo(ListView.class, 
                         "autoArrange",
                         Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewAutoArrangeDescr")));

        public static final PropertyInfo backColor =
            new PropertyInfo(Control.ClassInfo.backColor, DefaultValueAttribute.COLOR_WINDOW);
            
        public static final PropertyInfo borderStyle = 
            new PropertyInfo(ListView.class, 
                         "borderStyle",
                         com.ms.wfc.ui.BorderStyle.class,
                         CategoryAttribute.Appearance,
                         new DefaultValueAttribute(new Integer(com.ms.wfc.ui.BorderStyle.FIXED_3D)),
                         new DescriptionAttribute(Sys.getString("borderStyleDescr")));

        public static final PropertyInfo checkBoxes = 
            new PropertyInfo(ListView.class, 
                         "checkBoxes",Boolean.TYPE,
                         CategoryAttribute.Appearance,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewCheckBoxesDescr")));

        public static final PropertyInfo columns =
            new PropertyInfo(ListView.class, "columns", ColumnHeader[].class,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.EMPTY_ARRAY,
                             LocalizableAttribute.YES,
                             new DescriptionAttribute(Sys.getString("ListViewColumnsDescr")));

        public static final PropertyInfo fullRowSelect = 
            new PropertyInfo(ListView.class, 
                         "fullRowSelect",Boolean.TYPE,
                         CategoryAttribute.Appearance,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewFullRowSelectDescr")));

        public static final PropertyInfo gridLines = 
            new PropertyInfo(ListView.class, 
                         "gridLines",Boolean.TYPE,
                         CategoryAttribute.Appearance,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewGridLinesDescr")));

        public static final PropertyInfo headerStyle = 
            new PropertyInfo(ListView.class, 
                         "headerStyle",
                         ColumnHeaderStyle.class,
                         CategoryAttribute.Behavior,
                         new DefaultValueAttribute(new Integer(ColumnHeaderStyle.CLICKABLE)),
                         new DescriptionAttribute(Sys.getString("ListViewHeaderStyleDescr")));

        public static final PropertyInfo hideSelection = 
            new PropertyInfo(ListView.class, 
                         "hideSelection",Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.TRUE,
                         new DescriptionAttribute(Sys.getString("ListViewHideSelectionDescr")));

        public static final PropertyInfo hoverSelection = 
            new PropertyInfo(ListView.class, 
                         "hoverSelection",Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewHoverSelectDescr")));        

        public static final PropertyInfo items =
            new PropertyInfo(ListView.class, "items", ListItem[].class,
                             CategoryAttribute.Behavior,                             
                             DefaultValueAttribute.EMPTY_ARRAY,
                             LocalizableAttribute.YES,
                             new DescriptionAttribute(Sys.getString("ListViewItemsDescr")));

        public static final PropertyInfo labelEdit = 
            new PropertyInfo(ListView.class, 
                         "labelEdit",Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.FALSE,
                         new DescriptionAttribute(Sys.getString("ListViewLabelEditDescr")));

        public static final PropertyInfo labelWrap = 
            new PropertyInfo(ListView.class, 
                         "labelWrap",Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.TRUE,
                         new DescriptionAttribute(Sys.getString("ListViewLabelWrapDescr")));        

        public static final PropertyInfo largeImageList = 
            new PropertyInfo(ListView.class, "largeImageList", com.ms.wfc.ui.ImageList.class,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.NULL,
                             new DescriptionAttribute(Sys.getString("ListViewLargeImageListDescr")));

        public static final PropertyInfo multiSelect = 
            new PropertyInfo(ListView.class, 
                         "multiSelect",Boolean.TYPE,
                         CategoryAttribute.Behavior,
                         DefaultValueAttribute.TRUE,
                         new DescriptionAttribute(Sys.getString("ListViewMultiSelectDescr")));

        public static final PropertyInfo scrollable = 
            new PropertyInfo(ListView.class, 
                         "scrollable",Boolean.TYPE,
                         CategoryAttribute.Appearance,
                         DefaultValueAttribute.TRUE,
                         new DescriptionAttribute(Sys.getString("ListViewScrollableDescr")));

        public static final PropertyInfo smallImageList = 
            new PropertyInfo(ListView.class, "smallImageList", com.ms.wfc.ui.ImageList.class,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.NULL,
                             new DescriptionAttribute(Sys.getString("ListViewSmallImageListDescr")));

        public static final PropertyInfo sorting = 
            new PropertyInfo(ListView.class, 
                         "sorting",SortOrder.class,
                         CategoryAttribute.Behavior,
                         new DefaultValueAttribute(new Integer(SortOrder.NONE)),
                         new DescriptionAttribute(Sys.getString("ListViewSortingDescr")));

        public static final PropertyInfo stateImageList = 
            new PropertyInfo(ListView.class, "stateImageList", com.ms.wfc.ui.ImageList.class,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.NULL,
                             new DescriptionAttribute(Sys.getString("ListViewStateImageListDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final PropertyInfo view = 
            new PropertyInfo(ListView.class, 
                         "view",ViewEnum.class,
                         CategoryAttribute.Appearance,
                         new DefaultValueAttribute(new Integer(ViewEnum.LARGEICON)),
                         new DescriptionAttribute(Sys.getString("ListViewViewDescr")));

        

        public void getEvents(IEvents events)
        {}

        public void getProperties(IProperties props) {}

        public ICustomizer getCustomizer(Object component) {}
    }


    /**
     * Encapsulates the Windows list view control, which displays a collection of items, each  consisting of an icon (from an image list) and a label. 
     * @security(checkClassLinking=on)
     */
    public static class Customizer extends com.ms.wfc.core.Customizer {
        private ListView listview = null;
        private HDHITTESTINFO hdrhit = new HDHITTESTINFO();

        public Customizer(ListView listview) {}

        public boolean getHitTest(Point point) {}
    }
}