//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;


/**
 * Encapsulates a WFC menu.
 *
 * @security(checkClassLinking=on)
 */
public abstract class Menu extends Component {
    static final int CHANGE_ITEMS     = 0; 
    static final int CHANGE_VISIBLE   = 1; 
    static final int CHANGE_MDI       = 2; 
    static final int CHANGE_MERGE     = 3; 

    /**
     * Used by findMenuItem
     * @internalonly
     */
    public static final int FIND_HANDLE   = 0;
    /**
     * Used by findMenuItem
     * @internalonly
     */
    public static final int FIND_SHORTCUT = 1;

    MenuItem[] items;
    int itemCount;
    int handle;
    boolean created;

    /**
     * This is an abstract class.  Instances cannot be created, so the constructor
     * is only called from derived classes.
     * 
     * @internalonly
     */
    protected Menu(MenuItem[] items) {}

    /**
     * Adds a menu item to the end of this menu.
     *
     * @param item  The MenuItem to add
     */
    public void add(MenuItem item) {}

    /**
     * Removes all existing items from this menu. */
    public void clear() {}

    
    void clearHandles() {}

    /**
     * Sets this menu to be an identical copy of another menu. 
     *
     * @param menuSrc   The menu to copy
     */
    protected void cloneMenu(Menu menuSrc) {}

    /**
     * @internalonly
     */
    protected int createMenuHandle() {}

    
    void createMenuItems() {}

    
    void destroyMenuItems() {}

    /**
     * Frees the resources allocated by this component.  Call dispose when the component is no longer needed. 
     * This method removes the component from its container (if the component has a site) 
     * and triggers the dispose event. 
     */
    public void dispose() {}

    /**
     * @internalonly
     */
    protected void finalize() throws Throwable {}

    /**
     * @internalonly
     */
    public MenuItem findMenuItem(int type, int value) {}

    /**
     * @internalonly
     */
    protected final int findMergePosition(int mergeOrder) {}

    /**
     * Returns the Win32 menu handle (HMENU) handle for this menu. 
     */
    public int getHandle() {}

    /**
     * Returns the MainMenu object that contains this menu.   The MainMenu
     * is at the top of this menu's parent chain.
     *
     * Returns <b>null</b> if this menu is not contained in a MainMenu.
     * This can occur if it's contained in a ContextMenu or if it isn't
     * currently contained in any menu at all.
     */
    public MainMenu getMainMenu() {}

    /**
     * Retrieves the the MDI list from this menu.
     */
    public MenuItem getMDIListItem() {}

    /**
     * Retrieves the menu item at the specified index. 
     *
     * @param index     The index of the MenuItem to retrieve
     * @exception       WFCInvalidArgumentException thrown if index is out of range
     */
    public MenuItem getMenuItem(int index) {}

    /**
     * Retrieves the number of items that this menu contains. 
     */
    public int getMenuItemCount() {}

    /**
     * Retrieves the items in this menu. 
     */
    public MenuItem[] getMenuItems() {}

    /**
     * Adds a menu item to this menu at the specified index.   The item currently at
     * that index, and all items after it, will be moved up one slot.
     * MenuItems can only be contained in one menu at a time, and may not be added
     * more than once to the same menu.
     *
     *
     * @param index     The position to add the new item at
     * @param item      The MenuItem to add
     * @exception       WFCException thrown if item is already in another menu
     */
    public void insert(int index, MenuItem item) {}

    /**
     * Retrieves a boolean value that indicates whether this menu contains
     * items.
     */
    public boolean getIsParent() {}

    
    void itemsChanged(int change) {}

    /**
     * Merges the specified menu with this one.  Menu items are merged according to their
     * mergeType and mergeOrder properties.  This function is typically used to
     * merge an MDI container's menu with that of its active MDI child.
     *
     * @param menuSrc  The menu whose items are to be merged with this menu's items.
     *
     * @see MenuItem.mergeType()
     * @see MenuItem.mergeOrder()
     */
    public void mergeMenu(Menu menuSrc) {}

    
    boolean processInitMenuPopup(int handle) {}

    /**
     * @internalonly
     */
    protected boolean processCmdKey(MSG msg, int keyData) {}

    /**
     * Removes the specified menu item.  All subsequent
     * items are moved up one slot.
     *
     * @param index     The index of the MenuItem to remove
     */
    public MenuItem remove(int index) {}

    /**
     * Removes the specified menu item.  All subsequent
     * items are moved down one slot.
     *
     * @param item     The MenuItem to remove
     */
    public void remove(MenuItem item) {}

    /**
     * Initializes this menu to contain the specified list of menu items.  Any existing
     * items contained in the menu are replaced.
     *
     * @param value   Array of MenuItems to set to this menu
     */
    public void setMenuItems(MenuItem[] value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * Encapsulates a WFC menu.
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Component.ClassInfo {
        public static final PropertyInfo menuItems = new PropertyInfo(
            Menu.class, "menuItems", MenuItem[].class,
            new DefaultValueAttribute(new MenuItem[] {}),
            BrowsableAttribute.NO,
            new DescriptionAttribute(Sys.getString("MenuMenuItemsDescr")));

        public void getAttributes(IAttributes attrs) {} 
        
        public void getProperties(IProperties props) {}
    }
}