//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;


/**
 * Encapsulates a menu item.  It derives from Menu
 * because a menu item can itself be a submenu.
 *
 * @security(checkClassLinking=on)
 */
public class MenuItem extends Menu {
    static final int STATE_BARBREAK   = 0x00000020;
    static final int STATE_BREAK      = 0x00000040;
    static final int STATE_CHECKED    = 0x00000008;
    static final int STATE_DEFAULT    = 0x00001000;
    static final int STATE_DISABLED   = 0x00000003;
    static final int STATE_RADIOCHECK = 0x00000200;
    static final int STATE_HIDDEN     = 0x00010000;
    static final int STATE_MDILIST    = 0x00020000;
    static final int STATE_CLONE_MASK = 0x0003126B;

    Menu menu;
    private boolean hasHandle;
    private MenuItemData data;
    private int dataVersion;
    private MenuItem nextLinkedItem; 

    /**
     * Creates a blank MenuItem
     */
    public MenuItem() {}

    /**
     * Creates a MenuItem with the specified caption
     *
     * @param text          The item's caption
     */
    public MenuItem(String text) {}

    /**
     * Creates a MenuItem with the specified caption and click handler
     *
     * @param text          The item's caption
     * @param onClick       The event handler to get called when the item is chosen. This
     *                      event only fires on items that aren't submenus.
     */
    public MenuItem(String text, EventHandler onClick) {}

    /**
     * Creates a submenu with the specified caption, click event handler, and items.
     *
     * @param text          The item's caption
     * @param onClick       The event handler to get called when the item is chosen. This
     *                      event only fires on items that aren't submenus.
     * @param items         Array of items this MenuItem will contain.  Unless this paramter is
     *                      empty or <b>null</b>, this MenuItem will be a submenu.
     */
    public MenuItem(String text, EventHandler onClick, MenuItem[] items) {}

    MenuItem(MenuItemData data) {}

    /**
     * Creates a MenuItem
     *
     * @param mergeType     A member of the MenuMerge class that describes how
     *                      this item will behave if the menu which contains it is merged
     *                      with another menu.
     * @param mergeOrder    The relative position this item will assume in a merged menu
     * @param shortcut      The shortcut key that triggers this MenuItem.  See the <b>Key</b> class
     * @param text          The item's caption
     * @param onClick       The event handler to get called when the item is chosen. This
     *                      event only fires on items that aren't submenus.
     * @param onPopup       The event handler to get called when the item is expanded. This
     *                      event only fires on items that are submenus.
     * @param onSelect      The event handler to get called when the mouse is moved over an item or
     *                      the keyboard is used to navigate to an item but it hasn't yet been chosen
     * param items          The array of MenuItems contained by this item.  This only applies to
     *                      items that are submenus
     */
    public MenuItem(int mergeType, int mergeOrder, int shortcut,
        String text, EventHandler onClick, EventHandler onPopup,
        EventHandler onSelect, MenuItem[] items) {}

    /**
     * Assigns a delegate to the click event.
     * The click event is fired whenever this menu item is chosen by the user.
     * This can be in the way of a mouse click, or through the keyboard using
     * either the mnemonic keys or the shortcut key for this item.
     * This event will only occur on items that are not submenus.
     * This is where the command processing for menu items should go.
     *
     * @param value     Event handler to install for this event.
     */
    public void addOnClick(EventHandler value) {}

    /**
     * Assigns a delegate to the popup event. 
     * The popup event is fired when this item is about to beexpanded to show
     * its contained menu items.  Thus it will only occur on items that are submenus.
     * The event handler can use this opportunity to add/remove/enable/disable
     * items contained in this menu as appropriate for the context.
     *
     * @param value     Event handler to install for this event.
     */
    public void addOnPopup(EventHandler value) {}

    /**
     * Assigns a delegate to the select event.
     * The select event is fired when the user is hoving over an item with the mouse or
     * has selected it with the keyboard but hasn't activated it yet.
     * This event is commonly used to display a brief help string pertaining to this item
     * in an application's status bar.
     *
     * @param value     Event handler to install for this event.
     */
    public void addOnSelect(EventHandler value) {}

    private void cleanListItems(MenuItem senderMenu) {}        

    /**
     * Creates a copy of this menu item.
     */
    public MenuItem cloneMenu() {}

    /**
     * Creates a copy of this menu item.
     *
     * @param menuSrc   The menu to copy
     */
    protected void cloneMenu(MenuItem itemSrc) {}

    void createMenuItem() {}

    private MENUITEMINFO_T createMenuItemInfo() {}

    /**
     * Frees all the resources allocated by this object.  Call dispose when the component is no longer needed. 
     * This method removes the component from its container (if the component has a site) 
     * and triggers the dispose event. 
     */
    public void dispose() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item has
     * been placed on a new line (if the item is part of a menu bar) or in a new column (if the
     * item is part of a drop-down menu, submenu, or shortcut menu). For a submenu or context menu, a vertical
     * line separates the new column from the old.
     */
    public boolean getBarBreak() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item has
     * been placed on a new line (if the item is part of a menu bar) or in a new column (if the
     * item is part of a drop-down menu, submenu, or shortcut menu). For a submenu or context menu, the columns
     * are not separated by a vertical line.
     */
    public boolean getBreak() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item is
     * checked.
     */
    public boolean getChecked() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item is the
     * default menu item. A menu can contain only one default
     * menu item, which is displayed in bold.
     */
    public boolean getDefault() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item is
     * enabled.  Disabled items appear grayed.
     */
    public boolean getEnabled() {}

    /**
     * Retrieves the zero-based index of this menu item.
     */
    public int getIndex() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item is
     * part of a Multiple Document Interface (MDI) list.
     */
    public boolean getMDIList() {}

    /**
     * Retrieves the menu in which this item appears.
     */
    public Menu getMenu() {}

    /**
     * Returns the Windows identifier for this item.
     */
    protected int getMenuID() {}

    /**
     * Retrieves a constant that indicates how this menu item behaves when the menu of which
     * it is a part is merged with another menu.
     *
     * @return  int value from the MenuMerge class
     *
     * @see MenuMerge class
     */
    public int getMergeType() {}

    /**
     * Retrieves the merge order for this menu item.
     */
    public int getMergeOrder() {}

    /**
     * Retrieves a boolean value that indicates whether a radio button is
     * used instead of a check mark to display checked menu items. 
     */
    public boolean getRadioCheck() {}

    /**
     * Retrieves the shortcut key that is associated with this menu item.
     *
     * @see Key class
     */
    public int getShortcut() {}

    /**
     * Retrieves a boolean value that indicates whether the shortcut
     * associated with this menu item should be displayed. 
     */
    public boolean getShowShortcut() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item
     * contains child items.
     */
    public boolean getIsParent() {}

    /**
     * Retrieves the text of this menu item.
     */
    public String getText() {}

    /**
     * Retrieves a boolean value that indicates whether this menu item is
     * visible.
     */
    public boolean getVisible() {}

    void itemsChanged(int change) {}

    private Form[] getMDIForms() {}        
    
    private void mdiPopup() {}

    /**
     * Merges this menu item with another menu item.  This is typically called by the parent Menu during
     * merging, which occurs when an MDI child is activated.
     */
    public MenuItem mergeMenu() {}

    /**
     * Merges this menu item with another menu item.  Menu items are merged according to their
     * mergeType and mergeOrder properties.  This function is typically used to
     * merge an MDI container's menu with that of its active MDI child.
     *
     * @param menuSrc  The MenuItem to be merged with this one.
     *
     * @see Menu.mergeMenu()
     */
    public void mergeMenu(MenuItem itemSrc) {}

    /**
     * Triggers the click event.
     * @param e     Event object
     */
    protected void onClick(Event e) {}

    /**
     * Triggers the popup event.
     * @param e     Event object
     */
    protected void onPopup(Event e) {}

    /**
     * Triggers the select event.
     * @param e     Event object
     */
    protected void onSelect(Event e) {}

    /**
     * @internalonly
     */
    protected void onInitMenuPopup(Event e) {}

    /**
     * Selects this menu item. 
     */
    public void performSelect() {}

    /**
     * Removes the delegate that is assigned to the click event.
     * @see addOnClick
     */
    public void removeOnClick(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the popup event.
     * @see addOnPopup
     */
    public void removeOnPopup(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the select event. 
     * @see addOnSelect
     */
    public void removeOnSelect(EventHandler value) {}

    /**
     * Sets a boolean value that determines whether this menu item should be
     * placed on a new line (if the item is part of a menu bar) or in a new column (if the item
     * is part of a drop-down menu, submenu, or shortcut menu). For a submenu or context menu, a vertical
     * line separates the new column from the old.
     */
    public void setBarBreak(boolean value) {}

    /**
     * Sets a boolean value that determines whether this menu item should be
     * placed on a new line (if the item is part of a menu bar) or in a new column (if the item
     * is part of a drop-down menu, submenu, or shortcut menu). For a submenu or context menu, the columns
     * are not separated by a vertical line.
     */
    public void setBreak(boolean value) {}

    /**
     * Sets a boolean value that determines whether this menu item is
     * checked.
     */
    public void setChecked(boolean value) {}

    /**
     * Sets a boolean value that determines whether this menu item is the
     * default item for the submenu in which it appears. A menu can contain only one default
     * menu item, which is displayed in bold.
     */
    public void setDefault(boolean value) {}

    /**
     * Sets a boolean value that indicates whether this item is enabled.  Disabled items appear grayed.
     */
    public void setEnabled(boolean value) {}

    /**
     * Sets this menu item's zero-based index.
     */
    public void setIndex(int value) {}

    /**
     * Sets a boolean value that indicates whether this menu item should be
     * populated with a list of the MDI children that appear on the form with which this menu is
     * associated.
     */
    public void setMDIList(boolean value) {}

    /**
     * Specifies the merge type of this menu item.
     *
     * @see MenuMerge class
     */
    public void setMergeType(int value) {}

    /**
     * Sets the merge order for this menu item.
     */
    public void setMergeOrder(int value) {}

    /**
     * Sets a boolean value that determines whether a radio button is used
     * instead of a check mark to display checked menu items.
     */
    public void setRadioCheck(boolean value) {}

    /**
     * Associates a shortcut key with this menu item. 
     *
     * @see Key class
     */
    public void setShortcut(int value) {}

    /**
     * Sets a boolean value that indicates whether the shortcut associated
     * with this menu item should be displayed.
     */
    public void setShowShortcut(boolean value) {}

    /**
     * Sets the text for this menu item.
     */
    public void setText(String value) {}

    /**
     * Sets a boolean value that determines whether this menu item is
     * visible.
     */
    public void setVisible(boolean value) {}

    boolean shortcutClick() {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    final void updateMenuItemIfDirty() {}

    final void updateMenuItem(boolean force) {}


    
    static class MenuItemData implements ICommandExecutor {
        MenuItem baseItem;
        MenuItem firstItem;
    
        private int state;
        int version;
        int mergeType;
        int mergeOrder;
        String caption;
        int shortcut;
        boolean showShortcut;
        EventHandler onClick;
        EventHandler onPopup;
        EventHandler onSelect;
        Command cmd;
    
        MenuItemData(MenuItem baseItem, int mergeType, int mergeOrder, int shortcut, boolean showShortcut,
            String caption, EventHandler onClick, EventHandler onPopup, EventHandler onSelect) {}
    
        void addItem(MenuItem item) {}
    
        public void execute() {}
    
        int getMenuID() {}
    
        int getState() {}
                
        
        void itemsChanged(int change) {}
    
        void removeItem(MenuItem item) {}
    
        void setCaption(String value) {}
    
        void setMDIList(boolean value) {}
    
        void setMergeType(int value) {}
    
        void setMergeOrder(int value) {}
    
        void setState(int flag, boolean value) {}
    
        void setVisible(boolean value) {}
    
        void updateMenuItems() {}
    }


    
    private static class MDIListItem extends MenuItem {
        public Form boundForm = null;
        
        public MDIListItem() {}

        public MDIListItem(com.ms.wfc.ui.MenuItem.MenuItemData data) {}
        
        protected void onClick(Event e) {}

        public MenuItem mergeMenu() {}
        
    }
    

    
    private static class MDIListSeparator extends MDIListItem {
        public MDIListSeparator() {}

        public MDIListSeparator(com.ms.wfc.ui.MenuItem.MenuItemData data) {}
        
        protected void onClick(Event e) {}
        
        public MenuItem mergeMenu() {}
    }
    

    
    private static class MDIListMoreWindows extends MDIListItem {
        public Form[] forms = null;
        public Form active = null;
        
        public MDIListMoreWindows() {}
    
        public MDIListMoreWindows(com.ms.wfc.ui.MenuItem.MenuItemData data) {}
        
        public MDIListMoreWindows(Form active, Form[] all) {}
        
        protected void onClick(Event e) {}
        
        public MenuItem mergeMenu() {}
    }
    

    /**
     * Encapsulates a menu item.
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Menu.ClassInfo
    {
        public static final PropertyInfo checked = new PropertyInfo(
            MenuItem.class, "checked", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("MenuItemCheckedDescr")));

        public static final PropertyInfo defaultProp = new PropertyInfo(
            MenuItem.class, "default", Boolean.TYPE,
            LocalizableAttribute.YES, 
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("MenuItemDefaultDescr")));

        public static final PropertyInfo enabled = new PropertyInfo(
            MenuItem.class, "enabled", Boolean.TYPE,
            LocalizableAttribute.YES, 
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("MenuItemEnabledDescr")));        

        public static final PropertyInfo mergeOrder = new PropertyInfo(
            MenuItem.class, "mergeOrder", Integer.TYPE,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("MenuItemMergeOrderDescr")));

        public static final PropertyInfo mergeType = new PropertyInfo(
            MenuItem.class, "mergeType", MenuMerge.class,
            new DefaultValueAttribute(new Integer(MenuMerge.ADD)),
            new DescriptionAttribute(Sys.getString("MenuItemMergeTypeDescr")));

        public static final PropertyInfo MDIList = new PropertyInfo(
            MenuItem.class, "MDIList", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("MenuItemMDIListDescr")));

        public static final PropertyInfo radioCheck = new PropertyInfo(
            MenuItem.class, "radioCheck", Boolean.TYPE,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("MenuItemCheckedDescr")));

        public static final PropertyInfo shortcut = new PropertyInfo(
            MenuItem.class, "shortcut", com.ms.wfc.ui.Shortcut.class,
            LocalizableAttribute.YES, 
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.Shortcut.NONE)),
            new DescriptionAttribute(Sys.getString("MenuItemShortCutDescr")));

        public static final PropertyInfo showShortcut = new PropertyInfo(
            MenuItem.class, "showShortcut", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("MenuItemShowShortCutDescr")));

        public static final EventInfo click = new EventInfo(
            MenuItem.class, "click", EventHandler.class,
            new DescriptionAttribute(Sys.getString("MenuItemOnClickDescr")));

        public static final EventInfo popup = new EventInfo(
            MenuItem.class, "popup", EventHandler.class,
            new DescriptionAttribute(Sys.getString("MenuItemOnInitDescr")));

        public static final EventInfo select = new EventInfo(
            MenuItem.class, "select", EventHandler.class,
            new DescriptionAttribute(Sys.getString("MenuItemOnSelectDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            MenuItem.class, "text", String.class,
            LocalizableAttribute.YES, 
            new DescriptionAttribute(Sys.getString("MenuItemTextDescr")));

        public static final PropertyInfo visible = new PropertyInfo(
            MenuItem.class, "visible", Boolean.TYPE,
            LocalizableAttribute.YES, 
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("MenuItemVisibleDescr")));

        public void getAttributes(IAttributes attrs) {}

        public String getDefaultEventName()
        {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events)
        {}

        public void getProperties(IProperties props)
        {}
    }
}