//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Allows the user to display a message box that can contain various buttons and icons.   A title and the displayed text can be controlled by
 * the user.
 * </p>
 * 
 * <p>
 * Correct usage of this class would be:
 * </p>
 * 
 * <pre>
 * MessageBox.show("This is my message", "Title!", MessageBox.OK);
 * </pre>
 *
 * @security(checkClassLinking=on)
 */
public class MessageBox { 

    /**
     * Indicates that the message box should display an OK button.
     * These can be bitwise OR'd together.
     */
    public static final int OK               = 0x00000000;

    /**
     * Indicates that the message box should display OK and Cancel
     * buttons.
     * These can be bitwise OR'd together.
     */
    public static final int OKCANCEL         = 0x00000001;

    /**
     * Indicates that the message box should display Abort, Retry,
     * and Ignore buttons.
     * These can be bitwise OR'd together.
     */
    public static final int ABORTRETRYIGNORE = 0x00000002;

    /**
     * Indicates that the message box should display Yes, No,
     * and Cancel buttons.
     * These can be bitwise OR'd together.
     */
    public static final int YESNOCANCEL      = 0x00000003;

    /**
     * Indicates that the message box should display Yes and No
     * buttons.
     * These can be bitwise OR'd together.
     */
    public static final int YESNO            = 0x00000004;

    /**
     * Indicates that the message box should display Retry and Cancel
     * buttons.
     * These can be bitwise OR'd together.
     */
    public static final int RETRYCANCEL      = 0x00000005;
    

    /**
     * Indicates that a hand icon should be displayed on the message box.
     * These can be bitwise OR'd together.
     */
    public static final int ICONHAND         = 0x00000010;

    /**
     * Indicates that the message box should display a question mark.
     * These can be bitwise OR'd together.
     */
    public static final int ICONQUESTION     = 0x00000020;

    /**
     * Indicates that the message box should display an exclamation icon.
     * These can be bitwise OR'd together.
     */
    public static final int ICONEXCLAMATION  = 0x00000030;

    /**
     * Indicates that the message box should display an asterisk icon.
     * These can be bitwise OR'd together.
     */
    public static final int ICONASTERISK     = 0x00000040;

    /**
     * Indicates that the message box should display a stop icon.
     * These can be bitwise OR'd together.
     */
    public static final int ICONSTOP         = ICONHAND;

    /**
     * Indicates that the message box should display an error icon.
     * These can be bitwise OR'd together.
     */
    public static final int ICONERROR        = ICONHAND;

    /**
     * Indicates that the message box should display a warning icon.
     * These can be bitwise OR'd together.
     */
    public static final int ICONWARNING      = ICONEXCLAMATION;

    /**
    * A value for the <i>style</i> parameter of the <i>show</i> method.
    * These can be bitwise OR'd together.
    */

    /**
     * A value for the <i>style</i> parameter of the <i>show</i> method.
     * These can be bitwise OR'd together.
     */
    public static final int ICONINFORMATION  = ICONASTERISK;
    
    public static final int DEFBUTTON1       = 0x00000000;
    public static final int DEFBUTTON2       = 0x00000100;
    public static final int DEFBUTTON3       = 0x00000200;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDOK             = 1;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDCANCEL         = 2;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDABORT          = 3;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDRETRY          = 4;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDIGNORE         = 5;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDYES            = 6;

    /**
     * @deprecated.  Use DialogResult instead!
     */
    public static final int IDNO             = 7;
    
    
    private MessageBox() {}
    
    /**
     * Displays a message box with the specified text, caption, and style.
     * @param text      The text to show in the body of the message box
     * @param caption   The title of the message box
     * @param style     Controls the appearance of the MessageBox.  can be 
     *                  ORing of the various values in the MessageBox class
     *
     * @return an integer with the value the dialog returns, typically coming
     *         from a button the user clicked.  These values all come from the
     *         com.ms.wfc.ui.DialogResult enumeration. 
     * 
     * @see com.ms.wfc.ui.DialogResult
     */
    public static int show(String text, String caption, int style) {}
    
    /**
     * Displays a message box with the specified text, caption, and style.  The style of
     * the message box is the default. [OK button only]
     *
     * @param text      The text to show in the body of the message box
     * @param caption   The title of the message box
     *
     * @return DialogResult.OK
     */
    public static int show(String text, String caption) {}
    
    /**
     * Displays a message box with the specified text, caption, and style.  The style of
     * the message box is the default. [OK button only].  There is no title.
     *
     * @param text      The text to show in the body of the message box
     *
     * @return DialogResult.OK
     */
    public static int show(String text) {}
    
    /**
     * Displays a message box with the specified text, caption, and style.
     * @param owner     The owner of the message box.
     * @param text      The text to show in the body of the message box
     * @param caption   The title of the message box
     * @param style     Controls the appearance of the MessageBox.  can be 
     *                  ORing of the various values in the MessageBox class
     *
     * @return an integer with the value the dialog returns, typically coming
     *         from a button the user clicked.  These values all come from the
     *         com.ms.wfc.ui.DialogResult enumeration. 
     * 
     * @see com.ms.wfc.ui.DialogResult
     */
    public static int show(ITopLevelWindow owner, String text, String caption, int style) {}
    
    /**
     * Displays a message box with the specified text, caption, and style.  The style of
     * the message box is the default. [OK button only]
     *
     * @param owner     The owner of the message box.
     * @param text      The text to show in the body of the message box
     * @param caption   The title of the message box
     *
     * @return DialogResult.OK
     */
    public static int show(ITopLevelWindow owner, String text, String caption) {}
    
    /**
     * Displays a message box with the specified text, caption, and style.  The style of
     * the message box is the default. [OK button only].  There is no title.
     *
     * @param owner     The owner of the message box.
     * @param text      The text to show in the body of the message box
     *
     * @return DialogResult.OK
     */
    public static int show(ITopLevelWindow owner, String text) {}
}