//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.ole32.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.DllLib;
import com.ms.com.*;

/**
 * Encapsulates a Windows metafile.  Metafiles can be thought of as
 * graphics macros.  They consist of a series of graphics calls that have been
 * stored in a file.  This allows you to reproduce the original graphics commands
 * that created the metafile image on any resolution with any scale, giving you
 * smoothly scaled images.
 *
 * @security(checkClassLinking=on)
 */
public class Metafile extends Image implements IPersistable { 
    
    private static final int EMR_HEADER	= 1;

    private Rectangle bounds = null;
    
    
    
    
    
    private int handle = 0; 
    
    
    
    
    
    private int dc = 0;

    
    
    private Graphics graphics = null;

    private boolean ownHandle = true;

    /**
     * Creates a new metafile of an empty size.  The size
     * of the metafile will be dynamically calculated.
     */
    public Metafile() {}
    
    /**
     * Creates a new metafile of the given size.
     * 
     * @param bounds The dimensions of the metafile, in .01 millimeter
     *               units.
     */
    public Metafile(Rectangle bounds) {}

    /**
     * Loads a metafile from a file
     * 
     * @param fileName The file to load the metafile from.
     */
    public Metafile(String fileName) {}

    /**
     * Wraps an existing metafile handle with a Metafile object.
     * The handle is not owned by this object; you are responsible
     * for freeing it when you are done.
     * 
     * @param handle The metafile handle.
     */
    public Metafile(int handle) {}

    /**
     * Loads a metafile from a resource.
     * 
     * @param type      The class used to resolve the resource.
     * @param resource  The name of the resource.
     */
    public Metafile(Class type, String resource) {}

    /**
     * Loads a metafile from a data stream.
     * 
     * @param stream    The data stream to load the metafile from.
     * 
     * @see com.ms.wfc.io.IDataStream
     */
    public Metafile(IDataStream stream) {}

    /**
     * Loads a metafile from a COM stream.
     * 
     * @param stream    The COM stream to load the metafile from.
     * 
     * @see com.ms.wfc.ole32.IStream
     */
    public Metafile(IStream stream) {}

    /**
     * Loads a metafile from an OLE IPicture object.
     * 
     * @param picture The IPicture object to load the metafile from.
     * 
     * @see com.ms.wfc.ole.IPicture
     */
    public Metafile(IPicture picture) {}

    /**
     * Clones the Metafile object and returns a duplicate.  
     * 
     * @return an object that can be casted to a Metafile.
     */
    public Object clone() {}

    
    private void convertDCToHandle() {}
    
    
    private void convertHandleToDC() {}

    
    private static int convertMetafile(int hmf) {}
    
    /**
     * Retrieves a copy of the Win32 handle for the metafile on which this object is based.   You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 metafile handle.
     */
    public final int copyHandle() {}

    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Frees all the resources allocated by this object.  Once called, the metafile
     * object is no longer useful.
     */
    public void dispose() {}

    /**
     * Renders the metafile image (or part of it) to a Graphics object,
     * cropping the image to fit the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version crops the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to crop to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}

    /**
     * Renders the metafile image to a Graphics object, stretching the image
     * to fill the specified dimensions.  The drawing command originates on the graphics
     * object, but a graphics object generally has no idea how to render a given image.  So, 
     * it passes the call to the actual image.  This version stretches the image to the given
     * dimensions and allows the user to specify a rectangle within the image to draw.
     * 
     * @param g           The graphics object to render to.
     * @param imageRect   The rectanglular area of the image to draw.
     * @param targetRect  The rectangle to stretch the image to.
     * @param rop         A numerical rop code to blit with.
     */
    protected void drawStretchTo(Graphics g, Rectangle imageRect, Rectangle targetRect, int rop) {}

    /**
     * Frees the resources allocated by the Metafile object.
     */
    protected void finalize() {}

    
    private static ENHMETAHEADER getEnhMetaFileHeader(int handle) {}

    /**
     * Retrieves the recommended file extension for files that persist this object.
     * 
     * @return the recommended file extension, without a prefixing period.
     * @see IPersistable
     */
    public String getExtension() {}

    /**
     * Retrieves a Graphics object that you can use to paint to this image.  This will create a graphics
     * object if none exists, or will return the existing one if it was created.
     *
     * @return Graphics
     */
    public final Graphics getGraphics() {}	

    /**
     * Retrieves the Win32 handle (HMETAFILE) to this metafile.   This is not a copy of the handle; do
     * not free it.
     * 
     * @return the handle to this metafile.
     */
    public int getHandle() {}

    /**
     * Retrieves a PICTDESC (Picture Descriptor) for this metafile.   PICTDESCs are
     * used by OLE.
     * 
     * @return a PICDESC object.
     */
    public final PICTDESC getPICTDESC() {}

    /**
     * Retrieves the size of the image, in logical units, for the specified Graphics
     * object.  Metafiles are always recorded in 
     * .01 mm units, but this size is not always convienent when
     * rendering.  
     * 
     * @param g     The graphics object to use when converting to
     *              logical units.
     * 
     * @return the size, in logical units, of the metafile.
     */
    public final Point getRenderedSize(Graphics g) {}

    /**
     * Retrieves the size of the metafile in .01 millimeter units.
     * 
     * @return the size of the object, in pixels.
     */
    public final Point getSize() {}

    /**
     * Initializes this image for the first time.  This should only be called once.
     * 
     * @param picture The IPicture object to initialize the metafile with.
     *
     */
    protected void initialize(IPicture picture) {}

    /**
     * Retrieves a human-readable string representation of this object.
     * 
     * @return a string describing the metafile.
     */
    public String toString() {}

    
    private class MetafileGraphics extends Graphics {
        public MetafileGraphics(int dc) {}

        /**
         * Frees all the resources allocated by this object.
         */
        public void dispose() {}
        
        /**
         * Retrieves the Win32 handle (HMETAFILE) to this metafile.   We want
         * to enable people to use this graphics object even if 
         * they've gotten the metafile's handle first, so we need
         * to check to see if the dc has been reset.
         * 
         * @return a Win32 HDC.
         */
        public int getHandle() {}
    }
    
    /**
     * Encapsulates a Windows metafile.emf)
     * files.
     *
     * @security(checkClassLinking=on)
     */
    public static class Editor extends Image.Editor {

        public String getFileDialogDescription() {}

        public String[] getExtensions() {}

        public Image loadFromStream(IDataStream stream) {}
    }
}