//STRIPPEDSOURCE//


package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a Windows month calendar control, which provides a simple calendar  interface from which the user can select a date. 
 * A month calendar control implements a calendar-like user interface, that
 * provides the user with a very intuitive and recognizable method of entering 
 * or selecting a date.    
 *
 * Users can also select which days bold.  The most efficient way to add the 
 * bolded dates is via an array all at once.  (The below descriptions can be applied
 * equally to annually and monthly bolded dates as well)
 *
 * The following is an example of this: 
 *
 * <pre>
 * MonthCalendar mc = new MonthCalendar();
 * // add specific dates to bold
 * Time time[] = new Time[3];
 * time[0] = new Time();
 * time[1] = time[0].addDays(2);
 * time[2] = time[1].addDays(2);
 * mc.setBoldedDates(time); 
 * </pre> 
 *
 * Removal of all bolded dates is accomplished with:
 *
 * <pre>
 * mc.removeAllBoldedDates();
 * </pre> 
 *
 * Although less efficient, the user may need to add or remove bolded dates one at 
 * a time.  To improve the performance of this, neither addBoldedDate nor
 * removeBoldedDate repaints the monthcalendar.  The user must call updateBoldedDates
 * to force the repaint of the bolded dates, otherwise the monthCalendar will not
 * paint properly.
 * 
 * The following is an example of this: 
 *
 * <pre>
 * Time time1 = new Time("3/5/98");
 * Time time2 = new Time("4/19/98");
 * mc.addBoldedDate(time1);
 * mc.addBoldedDate(time2);
 * mc.removeBoldedDate(time1); 
 * mc.updateBoldedDates();
 * </pre>  
 *
 * The same applies to addition and removal of annual and monthly bolded dates.
 *
 * @security(checkClassLinking=on)
 */
public class MonthCalendar extends Control {
    protected static final long DAYS_TO_1601 = 548229; 
    protected static final long DAYS_TO_10000 = 3615900; 
    protected static final Color DEFAULT_FORE_COLOR = Color.WINDOWTEXT;
    protected static final Color DEFAULT_TITLE_BACK_COLOR = Color.ACTIVECAPTION;
    protected static final Color DEFAULT_TITLE_FORE_COLOR = Color.ACTIVECAPTIONTEXT;
    protected static final Color DEFAULT_MONTH_BACK_COLOR = Color.WINDOW;
    protected static final Color DEFAULT_TRAILING_FORE_COLOR = Color.GRAYTEXT;    
    private static final int MINIMUM_ALLOC_SIZE = 12;  
    private static final int MONTHS_IN_YEAR = 12;
    
    private static final int   INSERT_WIDTH_SIZE = 6;
    
    private static final int   INSERT_HEIGHT_SIZE = 6;
    private static final int   DEFAULT_FIRST_DAY_OF_WEEK = Days.DEFAULT;
    private static final int   DEFAULT_MAX_SELECTION_COUNT = 7;
    private static final int   DEFAULT_SCROLL_CHANGE = 1;
    private static final int   UNIQUE_DATE = 0;
    private static final int   ANNUAL_DATE = 1;
    private static final int   MONTHLY_DATE = 2;
    
    private int         mdsBuffer = 0;    
    private int         mdsBufferSize = 0;    

    
    private Color       titleBackColor = DEFAULT_TITLE_BACK_COLOR;
    private Color       titleForeColor = DEFAULT_TITLE_FORE_COLOR;    
    private Color       trailingForeColor = DEFAULT_TRAILING_FORE_COLOR;    
    private boolean     showToday = true;
    private boolean     showTodayCircle = true;
    private boolean     showWeekNumbers = false;
    
    
    private Dimensions  dimensions = new Dimensions(1, 1);
    private int         maxSelectionCount = DEFAULT_MAX_SELECTION_COUNT;
    private Time        maxDate = null;
    private Time        minDate = null;
    private int         scrollChange = DEFAULT_SCROLL_CHANGE;
    private Time        todayDate = null;
    private Time        selectionStart = null;
    private Time        selectionEnd = null;
    private int         firstDayOfWeek = DEFAULT_FIRST_DAY_OF_WEEK;        
    
    private boolean     updateBoldedDates = true; 
    
    private int         monthsOfYear[] = new int[12]; 
    
    private int         datesToBoldMonthly = 0;   
    
    private List        arrayOfDates = new List();    
    private List        annualArrayOfDates = new List(); 
    private List        monthlyArrayOfDates = new List();

    
    private DateRangeEventHandler       onDateChanged;
    private DateRangeEventHandler       onDateSelected;    

    /**
     * Creates a new MonthCalendar object.  Styles are the default for a
     * regular month calendar control.
     */
    public MonthCalendar() {}   

    /**
     * Specifies that a date will be displayed in bold every year in the month calendar.   
     * Be sure to call updateBoldedDates() afterwards.
     *
     * @param date The date to add.     
     * @exception WFCException Thrown if <i>date</i> is null.
     */
    public void addAnnuallyBoldedDate(Time date) {}

    /**
     * Specifies that a date will be displayed in bold in the month calendar.   
     * Be sure to call updateBoldedDates() afterwards.
     *
     * @param date The date to add.     
     * @exception WFCException Thrown if <i>date</i> is null.
     */
    public void addBoldedDate(Time date) {}    

    /**
     * Specifies that a date will be displayed in bold every month in the month calendar.   
     * Be sure to call updateBoldedDates() afterwards.
     *
     * @param date The date to add.     
     * @exception WFCException Thrown if <i>date</i> is null.
     */
    public void addMonthlyBoldedDate(Time date) {}

    /**
     * Assigns a delegate to the dateRange event.  
     * This event is called when the currently selected date or range of dates changes.
     * This occurs, for example, when the user explicitly changes his or her selection 
     * within the current month or when the selection is implicitly changed in response 
     * to next/previous month navigation.  This event, however, is NOT called if the
     * selection range is changed by method alone (ie: through setSelectionRange).
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */    
    public void addOnDateChanged(DateRangeEventHandler value) {}

    /**
     * Assigns a delegate to the dateSelected event.  
     * This event is called when the user explicitly changes his or her selection.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */    
    public void addOnDateSelected(DateRangeEventHandler value) {}

    
    private void adjustSize() {}

        
    private void boldDates(DateBoldEvent e) {}

    
    private final void checkDate(Time date) {}

    
    private int compareTimes(Time t1, Time t2) {}

    
    private int compareMaxTimes(Time t1, Time t2) {}

    
    private int compareMinTimes(Time t1, Time t2) {}

    
    private boolean compareDayAndMonth(Time t1, Time t2) {}

    /**
     * Releases windowing system resources used by the month calendar control.   Normally you do not need 
     * to call this as the garbage collector will cleanup the buffer
     * for you.  However, there may be times when you may want to expedite
     * the garbage collectors cleanup.
     */
    public void dispose() {}

    /**
     * Here we just ensure that we've disposed of our Win32 resources.
     * @internalonly
     */
    protected void finalize() {}

    /**
     * Retrieves an array of Time objects that
     * represent dates that are displayed in bold every year in the month calendar. 
     *
     * @return The array.
     */
    public Time[] getAnnuallyBoldedDates() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a com.ms.wfc.ui.CreateParams object with the information for creating
     *                   this control.
     *
     * @see com.ms.wfc.ui.CreateParams
     */
    protected CreateParams getCreateParams() {}     

    /**
     * Retrieves an array of Time objects that
     * represent dates that are displayed in bold in the month calendar. 
     *
     * @return The array.
     */
    public Time[] getBoldedDates() {}

    /**
     * Retrieves the number of columns and rows of months that the control displays. 
     *
     * @return the current dimensions of the control
     *
     * @see #setDimensions
     */
    public Dimensions getDimensions() {}
    
    /**
     * Retrieves the starting and ending dates of the date range displayed in the control.   
     *
     * @param visible If <b>true</b>, then only the dates in those months that are 
     *                entirely displayed will be returned. 
     *                If <b>false</b>, then the partially displayed dates in the 
     *                preceding and trailing months of the visible range will be 
     *                included in the returned date range.
     *
     * @return the start and end dates of the display range.     
     * 
     * @see com.ms.wfc.app.Time
     * @see com.ms.wfc.ui.SelectionRange
     */
    public SelectionRange getDisplayRange(boolean visible) {}

    /**
     * Retrieves the first day of the week for the month calendar control. 
     *
     * @return   a value from the com.ms.wfc.ui.Days enumeration.
     *
     * @see com.ms.wfc.ui.Days 
     */    
    public int getFirstDayOfWeek() {}

    
    private int getHitArea(int hit) {}    
    
    /** 
     * Retrieves a value indicating the last date that the control allows the user to select.   
     *
     * @return the maximum allowable date.
     *
     * @see #getMinDate
     * @see #setMaxDate     
     * @see com.ms.wfc.app.Time
     */    
    public Time getMaxDate() {}    
    
    /**
     * Retrieves the maximum number of days that can be selected in a month calendar control. 
     *
     * @return the maximum number of dates that can be selected
     *
     * @see #setMaxSelectionCount
     */    
    public int getMaxSelectionCount() {}    
    
    /** 
     * Retrieves a value indicating the first date that the control allows the user to select.
     * 
     *
     * @return the minimum allowable date.
     *
     * @see #getMaxDate
     * @see #setMinDate
     * @see com.ms.wfc.app.Time
     */    
    public Time getMinDate() {}

    
    private Point getMinReqRect() {}
    
    
    private Point getMinReqRect(int height, boolean updateRows) {}

    /**
     * Retrieves an array of Time objects that
     * represent dates that are displayed in bold every month in the month calendar. 
     *
     * @return The array.
     */
    public Time[] getMonthlyBoldedDates() {}    

     
    private SelectionRange getMonthRange(int flag) {}

    /**
     * Retrieves the scroll rate for a month calendar control.  The scroll 
     * rate is the number of months that the control moves its display 
     * when the user clicks a scroll button. 
     *
     * @return the current scroll rate
     *
     * @see #setScrollChange
     */    
    public int getScrollChange() {}

    
    private int getPreferredHeight(int height, boolean updateRows) {}

    
    private int getPreferredWidth(int width, boolean updateCols) {}    

    
    private Time getNow() {}
    
    /**
     * Retrieves the end of the date range currently selected in the control.      
     *
     * @return the end date value of the selection range
     *
     * @see #getSelectionStart
     * @see #setSelectionEnd
     * @see #setSelectionStart
     */    
    public Time getSelectionEnd() {}

    /**
     * Retrieves the selected date range for a month calendar control. 
     *
     * @return The current selection range.
     *
     * @see #setSelectionRange(SelectionRange)
     * @see com.ms.wfc.ui.SelectionRange
     */
    public SelectionRange getSelectionRange() {}    
    
    /**
     * Retrieves the start of the date range currently selected in the control.      
     *
     * @return the beginning date value of the selection range
     *
     * @see #getSelectionEnd
     * @see #setSelectionEnd
     * @see #setSelectionStart
     */    
    public Time getSelectionStart() {}
    
    /**
     * Retrieves a boolean value indicating whether the month calendar control will
     * display the "today" date at the bottom of the control. 
     *
     * @return <b>true</b> if enabled; otherwise, returns <b>false</b>.
     *
     * @see #setShowToday
     */
    public boolean getShowToday() {}

    /**      
     * Retrieves the minimum dimensions required to display a full month in a month calendar
     * control.   The size 
     * information is presented in the form of a <i>Point</i>, with the <i>x</i>
     * and <i>y</i> members representing the minimum width and height required 
     * for the control.  The minimum required window size for a month calendar 
     * control depends on the currently selected font.
     *
     * @return the minimum size required to display a full month.
     * @exception WFCSystemException Thrown if the applicable bounding information 
     *                              cannot be returned
     *
     * @see com.ms.wfc.ui.Point
     */    
    public Point getSingleMonthSize() {}

    /**
     * Retrieves a boolean value indicating whether the month calendar control will
     * circle the "today" date. 
     *
     * @return <b>true</b> if enabled; otherwise, returns <b>false</b>.
     *
     * @see #setShowTodayCircle
     */
    public boolean getShowTodayCircle() {}    

    /**
     * Retrieves the background color displayed in the month calendar's title.      
     * 
     * @return the current background color of the title.
     * 
     * @see #setTitleBackColor
     */
    public Color getTitleBackColor() {}

    /**
     * Retrieves the color used to display text within the month calendar's title. 
     * 
     * @return the current foreground color of the title.
     * 
     * @see #setTitleForeColor
     */
    public Color getTitleForeColor() {}
    
    /**
     * Retrieves the date information for the date specified as "today" for a month
     * calendar control. 
     *
     * @return "today"'s date value
     *
     * @see #setTodayDate
     */
    public Time getTodayDate() {}    

    /**
     * Retrieves a boolean value indicating whether the month calendar control displays
     * week numbers (1 through 52) to the left of each row of days. 
     *
     * @return <b>true</b> if enabled; otherwise, returns <b>false</b>.
     * 
     * @see #setWeekNumbers
     */
    public boolean getShowWeekNumbers() {}
    
    /**
     * Retrieves the color used to display text for header and trailing-day days (days from
     * the previous and following month that appear on the current calendar).       
     * 
     * @return the current trailing foreground color.
     * 
     * @see #setTrailingForeColor
     */
    public Color getTrailingForeColor() {}
    
    /**
     * Determines which portion of a month calendar control is at at the specified point on
     * the screen.  
     *
     * @param x The x coordinate of the point to be hit-tested
     * @param y The y coordinate of the point to be hit-tested
     *     
     * @return a HitTestInfo object that carries information specific 
     *         to hit-testing points for a month calendar control
     *
     * @see com.ms.wfc.ui.HitTestInfo
     * @see com.ms.wfc.ui.HitArea
     */
    public HitTestInfo hitTest(int x, int y) {}    

    /**
     * Determines which portion of a month calendar control is at at the specified point on
     * the screen.  
     *
     * @param point The coordinate of the point to be hit-tested     
     *     
     * @return a HitTestInfo object that carries information specific 
     *         to hit-testing points for a month calendar control
     *
     * @see com.ms.wfc.ui.HitTestInfo
     */    
    public HitTestInfo hitTest(Point point) {}    

    /**
     * Overrides Control.onCreateHandle()
     * @internalonly
     */    
    protected void onCreateHandle(Event e) {}   

    /**    
     * Triggers the dateChanged event. 
     *
     * @param event Event data
     * 
     * @see #addOnDateChanged
     * @see #removeOnDateChanged
     * @see com.ms.wfc.core.Event
     */
    protected void onDateChanged(DateRangeEvent event) {}

    /**    
     * Triggers the dateSelected event.      
     *
     * @param event Event data
     * 
     * @see #addOnDateSelected
     * @see #removeOnDateSelected
     * @see com.ms.wfc.core.Event
     */
    protected void onDateSelected(DateRangeEvent event) {}

    /**
     * This method is called by the control when any property changes. Inheriting
     * controls can overide this method to get property change notification on 
     * basic properties. Inherting controls must call <i>super.propertyChanged</i>.
     * 
     * @param property Property that changed.
     */

    protected void propertyChanged(int property) {}
    
    /**
     * Specifies that no dates are displayed every year in bold in the month calendar.   Be sure to call updateBoldedDates() afterwards.
     */
    public void removeAllAnnuallyBoldedDates() {}
    

    /**
     * Specifies that no dates are displayed in bold in the month calendar.   Be sure to call updateBoldedDates() afterwards.
     */
    public void removeAllBoldedDates() {}    

    /**
     * Specifies that no dates are displayed every month in bold in the month calendar.   Be sure to call updateBoldedDates() afterwards.
     */
    public void removeAllMonthlyBoldedDates() {}

    /**
     * Specifies that a date will not be displayed in bold every year in the month calendar.   If the <i>date</i> is not found in the
     * bolded date list, then no action is taken.  If <i>date</i> occurs more than
     * once in the bolded date list, then only the first date is removed.  When
     * comparing dates, only the day and month are used. Be sure to call 
     * updateBoldedDates afterwards.
     *
     * @param date The date to remove.
     * @param removeAll <b>true</b> if all dates are to be removed     
     *
     * @see #updateBoldedDates
     */
    public void removeAnnuallyBoldedDate(Time date) {}    

    /**
     * Specifies that a date will not be displayed in bold in the month calendar.   If the <i>date</i> is not found in the
     * bolded date list, then no action is taken.  If <i>date</i> occurs more than
     * once in the bolded date list, then only the first date is removed.
     * Be sure to call updateBoldedDates() afterwards.
     *
     * @param date The date to remove.
     *
     * @see #updateBoldedDates
     */
    public void removeBoldedDate(Time date) {}       

    /**
     * Specifies that a date will not be displayed in bold every month in the month calendar.   If the <i>date</i> is not found in the
     * bolded date list, then no action is taken.  If <i>date</i> occurs more than
     * once in the bolded date list, then only the first date is removed.  When
     * comparing dates, only the day and month are used.  Be sure to call 
     * updateBoldedDates afterwards.
     *
     * @param date The date to remove.
     *
     * @see #updateBoldedDates
     */
    public void removeMonthlyBoldedDate(Time date) {}
    
    /**
     * Removes the delegate that is assigned to the dateChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnDateChanged(DateRangeEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the dateSelected event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnDateSelected(DateRangeEventHandler value) {}

    /**
     * Resets the calendar so that there is no upper limit to the selectable range of dates.   By default value, there is no
     * upper limit.
     */
    public void resetMaxDate() {}

    /**
     * Resets the calendar so that there is no lower limit to the selectable range of dates.   By default value, there is no
     * lower limit.
     */
    public void resetMinDate() {}

    /**
     * Resets the selected range of the control to the current date.   By default value, the upper
     * and lower limit is the current date.
     */
    public void resetSelectionRange() {}

    /**
     * Resets the "today" date to the current date.   By default value, "today" is the 
     * current date.
     */
    public void resetTodayDate() {}

    
    private int requestBuffer(int reqSize) {}

    /**
     * Sets an array of Time objects that represent
     * dates that are displayed in bold every year in the month calendar.   The previous dates will be removed.
     *
     * @param array The new dates.
     */
    public void setAnnuallyBoldedDates(Time[] dates) {}

    /**
     * Sets an array of Time objects that represent
     * dates that are displayed in bold in the month calendar.   The previous dates will be removed.
     *
     * @param array The new dates.
     */
    public void setBoldedDates(Time[] dates) {}    

    /**
     * Overrides Control.setBoundsCore to enforce auto-sizing.
     *
     * @param x new left of the control.
     * @param y new right of the control.
     * @param width new width of the control.
     * @param height new height of the control.
     * @internalonly     
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}

    
    private void setControlColor(int colorIndex, Color value) {}   
    
    /**
     * Sets the first day of the week for the month calendar control. 
     *
     * @param value A value from the com.ms.wfc.ui.Days enumeration
     *
     * @see com.ms.wfc.ui.Days
     * @see #setFirstDayOfWeek
     *
     * @exception WFCInvalidArgumentException Thrown if the value parameter is not 
     *                                        a valid com.ms.wfc.ui.Days enumeration
     */     
    public void setFirstDayOfWeek(int value) {}    
    
    /** 
     * Sets a value indicating the last date that the control allows the user to select.   By default, there
     * is no maximum date.  The maximum date is not set if <i>max</i> less than the 
     * current minimum date.
     *
     * @param max The new maximum selectable date value.
     *     
     * @see #getMaxDate
     * @see #setMinDate     
     * @see com.ms.wfc.app.Time
     * 
     * @exception WFCSystemException Thrown if method is unable to change the maximum allowable date.
     */ 
    public void setMaxDate(Time max) {}
    
    /** 
     * Sets the maximum number of days that can be selected in a month calendar control.   This method does not affect the current
     * selection range.
     *
     * @param max The new number of days that the user can select.
     *
     * @see #getMaxSelectionCount
     * @exception WFCSystemException Thrown if method is unable to change the maximum allowable date.
     */    
    public void setMaxSelectionCount(int max) {}
    
    /** 
     * Sets a value indicating the first date that the control allows the user to select.   By default, there
     * is no minimum date.  The minimum date is not set if <i>min</i> greater than the 
     * current maximum date.  MonthCalendar does not support dates prior to 1601.
     *
     * @param min The mininum selectable date value
     *     
     * @see #getMinDate
     * @see #setMaxDate     
     * @see com.ms.wfc.app.Time
     * 
     * @exception WFCSystemException Thrown if method is unable to change the minimum allowable date.
     */
    public void setMinDate(Time min) {}    

    
    private void setRange() {}

    /** 
     * Sets the scroll rate for a month calendar control.  The scroll 
     * rate is the number of months that the control moves its display
     * when the user clicks a scroll button.  If this value is zero, 
     * the month delta is reset to the default, which is the number of 
     * months displayed in the control. 
     *
     * @param rate The number of months to be set as the control's new
     *             scroll rate.
     *
     * @see #getScrollChange
     */    
    public void setScrollChange(int rate) {}
    
    /**
     * Sets the number of columns and rows of months that the control will display. 
     * 
     * @param dimensions The new dimensions to display.
     *
     * @see #getDimensions
     * @see #getDimensions(int, int)
     * @see com.ms.wfc.ui.Dimensions
     */
    public void setDimensions(Dimensions dimensions) {}

    /**
     * Sets the number of columns and rows of months that the control will display. 
     * 
     * @param rows The new number of rows.
     * @param columns The new number of columns.
     *
     * @see #getDimensions
     * @see #getDimensions(Dimensions)
     * @see com.ms.wfc.ui.Dimensions
     */
    public void setDimensions(int rows, int columns) {}

    /**
     * Selects the specified date in the calendar.   The start and begin of 
     * the selection range will both be equal to <i>date</i>.
     *
     * @param date The new date to be selected.
     */
    public void setDate(Time date) {}

    /**
     * Sets an array of Time objects that represent
     * dates that are displayed in bold every month in the month calendar.   The previous dates will be removed.
     *
     * @param array The new dates.
     */
    public void setMonthlyBoldedDates(Time[] dates) {}

    /** 
     * Sets the end of the date range currently selected in the control.   If this value is 
     * before the current start selection, or if selecting this date would
     * cause the selection range to exceed the maximum selection count, 
     * then the end date will not be set.
     *
     * @param date The new end date of the selection range.
     * 
     * @see #getSelectionStart
     * @see #getSelectionEnd
     * @see #setSelectionStart
     * @see #setSelectionRange(Time, Time)
     */
    public void setSelectionEnd(Time date) {}
    
    /**
     * Sets the selection for a month calendar control to a specified date range.      
     * The selection range will not be set if the selection range exceeds the 
     * maximum selection count.
     *
     * @param date1 The lower limit of the selection range
     * @param date2 The upper limit of the selection range
     *
     * @see #setSelectionStart
     * @see #setSelectionEnd
     */
    public void setSelectionRange(Time date1, Time date2) {}

    /**
     * Sets the selection for a month calendar control to a specified date range.      
     * The selection range will not be set if the selection range exceeds the 
     * maximum selection count, or if either element in the <i>range</i> array 
     * is less than 0.
     *
     * @param range The new selection range.
     *
     * @see #setSelectionStart
     * @see #setSelectionEnd
     * @see #getSelectionRange
     */
    public void setSelectionRange(SelectionRange range) {}

    
    private void setSelRange(Time lower, Time upper) {}

    /** 
     * Sets the start date of the selection range.   If this value is 
     * after the current end selection, or if selecting this date would
     * cause the selection range to exceed the maximum selection count, 
     * then the starting date will not be set.
     *
     * @param date The new start date of the selection range.
     * 
     * @see #getSelectionStart
     * @see #setSelectionEnd
     * @see #setSelectionStart
     * @see #setSelectionRange
     */     
    public void setSelectionStart(Time date) {}

    /**
     * Sets a boolean value indicating whether the month calendar control will display
     * the "today" date at the bottom of the control. 
     * @param value     <b>true</b> means show the "today" date, 
     *                  <b>false</b> means do not show the "today" date.
     *
     * @see #getShowToday
     */    
    public void setShowToday(boolean value) {}

    /**
     * Sets a boolean value indicating whether the month calendar control will circle
     * the "today" date. 
     * 
     * @param value     <b>true</b> means circle the "today" date, 
     *                  <b>false</b> means do not circle the "today" date.
     *
     * @see #getShowTodayCircle
     */
    public void setShowTodayCircle(boolean value) {}

    /**
     * Sets the background color displayed in the month calendar's title.  This color is used as the 
     * background for the calendar's title.
     * 
     * @param value Color to set the titleBackColor to.
     * @exception WFCInvalidArgumentException Thrown if <i>value</i> is null.
     * 
     * @see #getTitleBackColor
     */
    public void setTitleBackColor(Color value) {}

    /**
     * Sets the color used to display text within the month calendar's title.  This color is used to display
     * the text in the calendar's title.
     * 
     * @param value Color to set the titleForeColor to.
     * @exception WFCInvalidArgumentException Thrown if <i>value</i> is null.
     * 
     * @see #getTitleForeColor
     */
    public void setTitleForeColor(Color value) {}

    /**
     * Sets the "today" selection for a month calendar control. 
     * If the <i>todayDate</i> parameter is -1, then month calendar 
     * control will return to the default setting.
     *
     * @param date The new "today" date value
     *
     * @see #getTodayDate
     * 
     * @exception WFCSystemException Thrown if method is unable to change the date.
     */
    public void setTodayDate(Time date) {}    
    
    /**
     * Sets the color used to display text for header and trailing-day days (days from the
     * previous and following month that appear on the current calendar). 
     * 
     * @param value Color to set the trailingForeColor to.
     * @exception WFCInvalidArgumentException Thrown if <i>value</i> is null.     
     * 
     * @see #getTrailingForeColor
     */
    public void setTrailingForeColor(Color value) {}           

    /**
     * Sets a boolean value indicating whether the month calendar control displays week
     * numbers (1 through 52) to the left of each row of days. 
     * 
     * @param value     <b>true</b> means show the week numbers, 
     *                  <b>false</b> means do not show the week numbers.
     *
     * @see #getShowWeekNumbers
     */    
    public void setShowWeekNumbers(boolean value) {}

    /**
     * Retrieves a boolean value indicating whether the value of the maxDate
     * property has been explicitly set. 
     * 
     * @return <b>true</b> if the maxDate should be persisted.
     */
    public boolean shouldPersistMaxDate() {}

    /**
     * Retrieves a boolean value indicating whether the value of the minDate
     * property has been explicitly set. 
     * 
     * @return <b>true</b> if the minDate should be persisted.
     */
    public boolean shouldPersistMinDate() {}        

    /**
     * Retrieves a boolean value indicating whether the value of the selectionRange
     * property has been explicitly set. 
     * 
     * @return <b>true</b> if the selectionRange should be persisted.
     */
    public boolean shouldPersistSelectionRange() {}

    /**
     * Retrieves a boolean value indicating whether the value of the todayDate
     * property has been explicitly set. 
     * 
     * @return <b>true</b> if the todayDate should be persisted.
     */
    public boolean shouldPersistTodayDate() {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * Updates the list of dates that are displayed in bold in the month calendar and repaints
     * the calendar.  
     */
    public void updateBoldedDates() {}

        
    private void wmDateChanged(Message m) {}

    
    private void wmDateBold(Message m) {}

        
    private void wmDateSelected(Message m) {}

    
    private void wmReflectCommand(Message m) {}

    /**
     * Overrided wndProc
     * 
     * @internalonly 
     */    
    protected void wndProc(Message m) {}
    
    /**
     * Encapsulates a Windows month calendar control, which provides a simple calendar  interface from which the user can select a date.   This defines the control's properties, methods and
     * events.
     *
     * @security(checkClassLinking=on)
     */    
    public static class ClassInfo extends Control.ClassInfo {
        
        public static final PropertyInfo annuallyBoldedDates = new PropertyInfo(
            MonthCalendar.class, "annuallyBoldedDates", Time[].class,
            DefaultValueAttribute.EMPTY_ARRAY,
            new DescriptionAttribute(Sys.getString("MonthCalendarAnnuallyBoldedDatesDescr")));

        public static final PropertyInfo backColor = new PropertyInfo(
            Control.ClassInfo.backColor, new DefaultValueAttribute(DEFAULT_MONTH_BACK_COLOR),
            new DescriptionAttribute(Sys.getString("MonthCalendarMonthBackColorDescr")));

        public static final PropertyInfo boldedDates = new PropertyInfo(
            MonthCalendar.class, "boldedDates", Time[].class,
            DefaultValueAttribute.EMPTY_ARRAY,
            new DescriptionAttribute(Sys.getString("MonthCalendarBoldedDatesDescr")));
        
        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, new DefaultValueAttribute(DEFAULT_FORE_COLOR),
            new DescriptionAttribute(Sys.getString("MonthCalendarForeColorDescr")));

        public static final PropertyInfo monthlyBoldedDates = new PropertyInfo(
            MonthCalendar.class, "monthlyBoldedDates", Time[].class,
            DefaultValueAttribute.EMPTY_ARRAY,
            new DescriptionAttribute(Sys.getString("MonthCalendarMonthlyBoldedDatesDescr")));
        
        public static final PropertyInfo titleBackColor = new PropertyInfo(
            MonthCalendar.class, "titleBackColor", Color.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(DEFAULT_TITLE_BACK_COLOR),
            new DescriptionAttribute(Sys.getString("MonthCalendarTitleBackColorDescr")));
        
        public static final PropertyInfo titleForeColor = new PropertyInfo(
            MonthCalendar.class, "titleForeColor", Color.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(DEFAULT_TITLE_FORE_COLOR),
            new DescriptionAttribute(Sys.getString("MonthCalendarTitleForeColorDescr")));        
        
        public static final PropertyInfo trailingForeColor = new PropertyInfo(
            MonthCalendar.class, "trailingForeColor", Color.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(DEFAULT_TRAILING_FORE_COLOR),
            new DescriptionAttribute(Sys.getString("MonthCalendarTrailingForeColorDescr")));        

        public static final PropertyInfo firstDayOfWeek = new PropertyInfo( 
            MonthCalendar.class, "firstDayOfWeek", Days.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(DEFAULT_FIRST_DAY_OF_WEEK)),
            new DescriptionAttribute(Sys.getString("MonthCalendarFirstDayOfWeekDescr")));

        public static final PropertyInfo maxDate = new PropertyInfo(
            MonthCalendar.class, "maxDate", Time.class,
            new ValueEditorAttribute(Time.Editor.class),
            CategoryAttribute.Behavior,            
            new DescriptionAttribute(Sys.getString("MonthCalendarMaxDateDescr")));

        public static final PropertyInfo maxSelectionCount = new PropertyInfo(
            MonthCalendar.class, "maxSelectionCount", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(DEFAULT_MAX_SELECTION_COUNT)),
            new DescriptionAttribute(Sys.getString("MonthCalendarMaxSelectionCountDescr")));                    

        public static final PropertyInfo minDate = new PropertyInfo(
            MonthCalendar.class, "minDate", Time.class,
            new ValueEditorAttribute(Time.Editor.class),
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("MonthCalendarMinDateDescr")));                

        public static final PropertyInfo scrollChange = new PropertyInfo(
            MonthCalendar.class, "scrollChange", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(DEFAULT_SCROLL_CHANGE)),
            new DescriptionAttribute(Sys.getString("MonthCalendarScrollChangeDescr")));

        public static final PropertyInfo dimensions = new PropertyInfo(
            MonthCalendar.class,  "dimensions", Dimensions.class,
            
            new DefaultValueAttribute(new Dimensions(1,1)),
            CategoryAttribute.Appearance,
            new DescriptionAttribute(Sys.getString("MonthCalendarDimensionsDescr")));       
        
        public static final PropertyInfo selectionEnd = new PropertyInfo(
            MonthCalendar.class, "selectionEnd", Time.class,
            CategoryAttribute.Behavior,
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO,
            new DescriptionAttribute(Sys.getString("MonthCalendarSelectionEndDescr")));        

        public static final PropertyInfo selectionStart = new PropertyInfo(
            MonthCalendar.class, "selectionStart", Time.class,
            CategoryAttribute.Behavior,
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO,
            new DescriptionAttribute(Sys.getString("MonthCalendarSelectionStartDescr")));

        public static final PropertyInfo selectionRange = new PropertyInfo(
            MonthCalendar.class, "selectionRange", SelectionRange.class,
            new ValueEditorAttribute(SelectionRange.Editor.class),
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("MonthCalendarSelectionRangeDescr")));            

        public static final PropertyInfo showToday = new PropertyInfo(
            MonthCalendar.class, "showToday", Boolean.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(Boolean.TRUE),
            new DescriptionAttribute(Sys.getString("MonthCalendarShowTodayDescr")));        

        public static final PropertyInfo showTodayCircle = new PropertyInfo(
            MonthCalendar.class, "showTodayCircle", Boolean.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(Boolean.TRUE),
            new DescriptionAttribute(Sys.getString("MonthCalendarShowTodayCircleDescr")));        

        public static final PropertyInfo size = new PropertyInfo(
            Control.ClassInfo.size, 
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO);

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, DefaultValueAttribute.FALSE);

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, 
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO);        

        public static final PropertyInfo todayDate = new PropertyInfo(
            MonthCalendar.class, "todayDate", Time.class,
            new ValueEditorAttribute(Time.Editor.class),
            CategoryAttribute.Behavior,            
            new DescriptionAttribute(Sys.getString("MonthCalendarTodayDateDescr")));        

        public static final PropertyInfo showWeekNumbers = new PropertyInfo(
            MonthCalendar.class, "showWeekNumbers", Boolean.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(Boolean.FALSE),
            new DescriptionAttribute(Sys.getString("MonthCalendarShowWeekNumbersDescr")));

        
        public static final EventInfo dateChanged = new EventInfo(
            MonthCalendar.class, "dateChanged", DateRangeEventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("MonthCalendarOnDateChangedDescr")));

        public static final EventInfo dateSelected = new EventInfo(
            MonthCalendar.class, "dateSelected", DateRangeEventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("MonthCalendarOnDateSelectedDescr")));

        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public static final EventInfo doubleClick = new EventInfo(
            Control.ClassInfo.doubleClick, BrowsableAttribute.NO);
        
        public String getDefaultPropertyName() {}        

        public String getDefaultEventName() {}        
        
        public void getProperties(IProperties props) {}
        
        public void getEvents(IEvents ievents) {}
    }
    
    
        
    class SYSTEMTIMEARRAY {
        public short wYear1 = 0;
        public short wMonth1 = 0;
        public short wDayOfWeek1 = 0;
        public short wDay1 = 0;
        public short wHour1 = 0;
        public short wMinute1 = 0;
        public short wSecond1 = 0;
        public short wMilliseconds1 = 0;
        public short wYear2 = 0;
        public short wMonth2 = 0;
        public short wDayOfWeek2 = 0;
        public short wDay2 = 0;
        public short wHour2 = 0;
        public short wMinute2 = 0;
        public short wSecond2 = 0;
        public short wMilliseconds2 = 0;
    }
}