//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.win32.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;

/**
 * Encapsulates a Windows logical palette.  Windows may associate a palette with a bitmap
 * in order to define the set of colors the bitmap uses.  This helps to conserve
 * memory space because each pixel of the bitmap only needs to reference an 
 * entry in the palette, rather than completely specify its color.  When Windows
 * is running on a system that has a 256 color video driver, it will use this
 * palette information to control the display's hardware palette.  Windows can
 * display bitmaps using near true color quality this way, because it optimizes
 * all the colors of a display device to a bitmap.
 * <p>
 * Normally, WFC handles all palette interaction for you.  You can use this 
 * object, however, if you want finer control over palette operations.
 * 
 * @see Graphics
 * @see Bitmap
 *
 * @security(checkClassLinking=on)
 */
public class Palette {

    private static boolean paletteSupported;
    private static boolean paletteQueried;
    private static Palette halftonePalette;

    private boolean ownHandle;
    private int handle;

    /**
     * Creates a new palette object from a given handle.  Handles are not
     * owned, so the caller is responsible for freeing the handle when
     * finished.
     */
    public Palette(int handle) {}

    /**
     * Clones the Palette object and returns a duplicate.
     * 
     * @return an object that can be casted to a Palette.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of the Win32 handle (HPALETTE) for the palette.  You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 palette handle.
     */
    public final int copyHandle() {}
    
    /**
     * Called when this object is going to destroy its Win32 handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}
    
    /**
     * Frees all the resources allocated by this object.   Once disposed, a palette object
     * may not be used.
     */
    public void dispose() {}
    
    /**
     * Frees the resources allocated by this object. */
    protected void finalize() {}
    
    /**
     * Retrieves the Win32 handle to this palette. 
     * 
     * @return a handle to the palette.
     */
    public int getHandle() {}

    /**
     * Retrieves a stock Windows halftone palette.   A halftone palette 
     * consists of a broad variety of colors and is not tuned to any
     * specific bitmap.
     * 
     * @return a Palette object.
     */
    public static final Palette getHalftonePalette() {}
    
    /**
     * Retrieves a boolean value that indicates whether the display driver
     * supports palettes. 
     * 
     * @return <b>true</b> if palettes are supported, <b>false</b> if not.
     */
    public static final boolean getPaletteSupported() {}

    /**
     * Retrieves a boolean value that indicates whether the specified object
     * is equivalent to this Palette object.
     * 
     * @param pal The palette to check equality with.
     * 
     * @return <b>true</b> if the palettes are equivalent, <b>false</b> otherwise.
     */
    public boolean equals(Object pal) {}
}