//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Encapsulates a Windows pen that applications use to draw lines, curves, and shapes. Drawing applications use pens to draw freehand lines, straight lines,
 * and curves. Computer-aided design (CAD) applications use pens to draw visible
 * lines, hidden lines, section lines, center lines, and so on. Word processing
 * and desktop publishing applications use pens to draw borders and rules.
 * Spreadsheet applications use pens to designate trends in graphs and to outline
 * bar graphs and pie charts.
 *
 * @security(checkClassLinking=on)
 */
public class Pen {

    /**
     * Specifies a Pen object that is the color of the active window's
     * caption text.
     */
    public static final Pen ACTIVECAPTIONTEXT   = new Pen(Color.ACTIVECAPTIONTEXT);

    /**
     * Specifies a Pen object that is the color of the text on a button or
     * other control.
     */
    public static final Pen CONTROLTEXT         = new Pen(Color.CONTROLTEXT);

    /**
     * Specifies a Pen object that is the color of disabled text.
     */
    public static final Pen GRAYTEXT            = new Pen(Color.GRAYTEXT);

    /**
     * Specifies a Pen object that is the color of highlighted text.
     */
    public static final Pen HIGHLIGHTTEXT       = new Pen(Color.HIGHLIGHTTEXT);

    /**
     * Specifies a Pen object that is the color of an inactive window's
     * caption text.
     */
    public static final Pen INACTIVECAPTIONTEXT = new Pen(Color.INACTIVECAPTIONTEXT);

    /**
     * Specifies a Pen object that is the color of the information ToolTip's
     * text.
     */
    public static final Pen INFOTEXT            = new Pen(Color.INFOTEXT);

    /**
     * Specifies a Pen object that is the color of the menu text.
     */
    public static final Pen MENUTEXT            = new Pen(Color.MENUTEXT);

    /**
     * Specifies a Pen object that does nothing in Graphics
     * operations that require a pen.  Drawing with this pen is a no-op.
     */
    public static final Pen NULL                = new Pen(Color.BLACK, PenStyle.NULL);

    /**
     * Specifies a Pen object that is the color of the window frame.
     */
    public static final Pen WINDOWFRAME         = new Pen(Color.WINDOWFRAME);

    /**
     * Specifies a Pen object that is the color of a window's text.
     */
    public static final Pen WINDOWTEXT          = new Pen(Color.WINDOWTEXT);

    private PenEntry entry;

    
    private Pen() {}

    /**
     * Create a new pen with the given color. The style of the pen will be
     * PenStyle.SOLID.  The width of the pen is one pixel.
     *
     * @param color The color of the pen.
     *
     * @see Color
     */
    public Pen(Color color) {}

    /**
     * Creates a new pen with the given color and style.  The style should be
     * one of the constants specified in the Pen class.  Width of the pen is
     * one pixel.
     *
     * @param color The color of the pen.
     * @param style The style of the pen to create.  This should be one of the
     *              values from the PenStyle enum.
     *
     * @see Color
     * @see PenStyle
     */
    public Pen(Color color, int style) {}

    /**
     * Creates a pen with the given style, color, and width.  The style should
     * be one of the constants specified in the PenStyle enum, and the width
     * should be be greater than zero.
     *
     * @param color The color of the pen.
     * @param style The style of the pen to create.  This should be one of the
     *              values from the PenStyle enum.
     * @param width The width of the pen, in logical units.
     *
     * @see Color
     * @see PenStyle
     * @throws WFCInvalidArgumentException
     */
    public Pen(Color color, int style, int width) {}

    /**
     * Creates a pen based on an existing Win32 HPEN handle.  The pen object does not
     * assume ownership of the handle (you are responsible for freeing it later).
     *
     * @param handle The Win32 HPEN to create the Pen object from.
     */
    public Pen(int handle) {}

    /**
     * Creates a duplicate of this Pen object.
     *
     * @return an object that can be casted to a Pen.
     */
    public Object clone() {}

    /**
     * Retrieves a copy of this pen's handle (HPEN).  You are responsible for
     * freeing the returned handle when you are done with it.
     *
     * @return a Win32 pen handle.
     */
    public final int copyHandle() {}

    /**
     * Called when this object is about to destroy its handle.  You
     * may override this if there is something special you need to do to
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Frees all resources allocated by this object.  You do not have to call dispose; the
     * garbage collector will do it for you.  However, you may expedite
     * the process by calling dispose manually.
     */
    public void dispose() {}

    /**
     * Retrieves a boolean value that indicates whether the specified object is equivalent to
     * this Pen object.
     *
     * @param obj Object to compare equality to.
     * @return <b>true</b> if the given object is equalivalent to this object.
     */
    public boolean equals(Object obj) {}

    /**
     * Frees the resources allocated by this object.
     */
    protected void finalize() throws Throwable {}

    /**
     * Retrieves the color of this pen.
     *
     * @return the pen color.
     */
    public final Color getColor() {}

    /**
     * Retrieves the Win32 handle for this pen.
     *
     * @return a Win32 HPEN.
     */
    public int getHandle() {}

    /**
     * Retrieves the style of this pen.
     *
     * @return a value from the PenStyle enum.
     */
    public final int getStyle() {}

    /**
     * Retrieves the width of this pen in logical units.
     *
     * @return the width of the pen.
     */
    public final int getWidth() {}

    /**
     * Computes the hash code for this object. 
     *
     * @return an integer hash code value.
     */
    public int hashCode() {}

    
    private static String stringFromPenStyle(int penStyle) {}

    /**
     * Returns a String representation of this object.
     * @internalonly
     */
    public String toString() {}
}


final class PenEntry {

    private static PenEntry   cache;
    private static boolean    fSysEvent;

    private PenEntry next;
    private int refCount;
    private int handle;
    private int hashCode;
    private boolean ownHandle;

    Color color;
    int style;
    int width;

    /**
     * Creates a duplicate of this Pen object.
     */
    public Object clone() {}

    
    private static int computeHash(Color color, int style, int width) {}

    
    static PenEntry create(int handle) {}

    
    static synchronized PenEntry create(Color color, int style, int width) {}

    /**
     * Called when this object is about to destroy its handle.
     */
    public void destroyHandle() {}

    
    static void fillHandle(PenEntry e) {}

    
    static synchronized void free(Pen pen, PenEntry entry) {}

    /**
     * Retrieves the Win32 handle for this pen.
     *
     * @return a Win32 HPEN object handle.
     */
    public int getHandle() {}

    /**
     * This event gets fired when a system color change happens and we have pens
     * that consist of system colors.  Here we recreate all the pen handles that
     * consist of system colors.
     */
    public static void onSettingChange() {}
}


class PenSettingChangeProxy {
    void onSettingChange(Object sender, Event evt) {}
}