//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Defines constants for the seven built-in pen styles supported by the Windows operating  system.
 * 
 * @see Pen
 *
 * @security(checkClassLinking=on)
 */
public class PenStyle extends Enum {
    
    /** 
     * Represents a pen style that consists of a series of dashed lines. */
    public static final int DASH        = win.PS_DASH;

    /**
     * Represents a pen style that consists of a dash, followed by a dot. _ . _ .
     */
    public static final int DASHDOT     = win.PS_DASHDOT;

    /** 
     * Represents a pen style that consists of a dash, followed by two dots. . _ . . _ . .
     */
    public static final int DASHDOTDOT  = win.PS_DASHDOTDOT;

    /**
     * Represents a pen style that consists of a dotted line...........
     */
    public static final int DOT         = win.PS_DOT;

    /**
     * Represents a pen style that consists of a solid pen that is drawn from within any given
     * bounding rectangle.  Using this style allows you to have a wide pen that
     * automatically conforms to the interior of a rectangle.
     */
    public static final int INSIDEFRAME = win.PS_INSIDEFRAME;
    
    /**
     * Represents a null pen. A null pen is one that results
     * in no drawing.  This is useful when
     * you have a function that always draws a border, but you don't want
     * the border.
     */
    public static final int NULL        = win.PS_NULL;

    /**
     * Represents a pen style that consists of a solid line. */
    public static final int SOLID       = win.PS_SOLID;

    private static final int MIN = 0;
    private static final int MAX = 6;
    
    /**
     * Retrieves a boolean
     * value that indicates whether a specified value designates a valid PenStyle
     * constant.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}