//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Encapsulates the ProgressBar control.  This control lets you display the progress
 * of any particular event.  It does so by dividing it's client area up in
 * discrete regions, defined by the <i>minimum</i> and <i>maximum</i> properties.  
 * Then, by looking at the current position [obtained from the <i>value</i>
 * property], it paints the appropriate portion of the client area.  
 *
 * People doing long operations can periodically come back and increase the 
 * position of the ProgressBar, and it will 'show' the progress of whatever
 * the operation is.
 *
 * @security(checkClassLinking=on)
 */
public final class ProgressBar extends Control { 

    private static final Object EVENT_VALUECHANGED = new Object();

    
    
    
    private int minimum = 0;
    private int maximum = 100;
    private int step = 10;
    private int value = 0;

    /**
     * Creates a new ProgressBar control.  By default, the range is set to
     * be 0..100.  The default step is 10.
     */
    public ProgressBar() {}

    /**
     * Adds an event handler for the "valueChanged" event notification. This
     * event is called whenever the progressbar's current position changes,
     * whether it be because of mouse, keyboard, or programmatic input.
     *
     * @param value New Event Handler to install for this event.
     */
    public void addOnValueChanged(EventHandler eh) {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a CreateParams object with the information for creating
     *             this Control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the upper limit of the ProgressBar control's range.
     *
     * @return  an integer with the upper bound of the ProgressBars range.
     */
    public final int getMaximum() {}

    /**
     * Retrieves the lower limit of the ProgressBar control's range.
     *
     * @return  an integer with the lower bound of the controls range.
     */
    public final int getMinimum() {}

    /**
     * Retrieves the step increment for the ProgressBar control.   This should be used in conjunction
     * with the <i>step()</i> method.
     *
     * @return      the current stepping size
     *
     * @see step
     */
    public final int getStep() {}

    /**
     * Retrieves the current position for the ProgressBar control.  The control 'fills in' the portion of the 
     * ProgressBar from the <i>minimum</i> value up to this position.
     *
     * @return      the current position.
     */
    public final int getValue() {}

    /**
     * Advances the current position for the ProgressBar control by the
     * specified step increment and redraws the control to reflect the new position.   If the
     * new value overflows the maximum, it is reset to the minimum.
     *
     * @param value     how much to increment by.
     */
    public final void increment(int value) {}

    /**
     * Overridden to set up our properties.
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Actually fires the "valueChanged" event.  
     * @hidden
     * @internalonly
     */
    protected void onValueChanged(Event e) {}

    /**
     * Removes the given handler for the "valueChanged" event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnValueChanged(EventHandler eh) {}
    
    /**
     * Sets the upper bound of the range the ProgressBar will operate
     * within.
     *
     * @param value     The new upper bound for this control.
     */
    public final void setMaximum(int value) {}
    
    /**
     * Sets the lower limit of the ProgressBar control's range and redraws
     * the control to reflect the new value.
     *
     * @param value     The new lower bound for this control.
     */
    public final void setMinimum(int value) {}
    
    public final void setStep(int stepNew) {}
    
    /**
     * Sets the ProgressBar control's current position and redraws the
     * control to reflect the new position.  The control 'fills in' the portion of the 
     * ProgressBar from the <i>minimum</i> value up to this position.
     *
     * @param   value       The new value for the ProgressBar
     */
    public final void setValue(int value) {}

    /**
     * Advances the current position for a progress bar by the step increment and redraws the
     * control to reflect the new position. 
     */
    public final void step() {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}
    
    
    private final void updatePos() {}

    /**
     * Encapsulates the ProgressBar control.
     * @security(checkClassLinking=on)
     */
    public final static class ClassInfo extends Control.ClassInfo {
        public static PropertyInfo backColor = new PropertyInfo (
            Control.ClassInfo.backColor, BrowsableAttribute.NO);

        public static final PropertyInfo minimum = new PropertyInfo(
            ProgressBar.class, "minimum", Integer.TYPE, 
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("ProgressBarMinimumDescr")));

        public static final PropertyInfo maximum = new PropertyInfo(
            ProgressBar.class, "maximum", Integer.TYPE,
            new DefaultValueAttribute(new Integer(100)),
            new DescriptionAttribute(Sys.getString("ProgressBarMaximumDescr")));

        public static final PropertyInfo step = new PropertyInfo(
            ProgressBar.class, "step", Integer.TYPE,
            new DefaultValueAttribute(new Integer(10)),
            new DescriptionAttribute(Sys.getString("ProgressBarStepDescr")));

        public static final PropertyInfo value = new PropertyInfo(
            ProgressBar.class, "value", Integer.TYPE,
            DefaultValueAttribute.ZERO,
            BindableAttribute.YES,
            new DescriptionAttribute(Sys.getString("ProgressBarValueDescr")));

        public static final EventInfo valueChanged = new EventInfo(
            ProgressBar.class, "valueChanged", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("valueChangedEventDescr")));        

        public String getDefaultPropertyName() {}

        public final void getEvents(IEvents events) {}

        public final void getProperties(IProperties props) {}
    }
}