//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a radio button (or option button) control, which displays an option that  can be turned on or off. 
 * @security(checkClassLinking=on)
 */
public class RadioButton extends Control {

    private static final Object EVENT_CHECKEDCHANGED = new Object();

    private boolean checked = false;
    private boolean autoCheck = true;
    private int appearance = Appearance.NORMAL;
    private int textAlign = LeftRightAlignment.RIGHT;

    /**
     * Creates a RadioButton with a default alignment of the text to the
     * right of the button and the <i>autoCheck</i> property set to true.
     */
    public RadioButton() {}

    /**
     * Assigns a delegate to the checkedChanged event. 
     * This event is fired whenever the value for the RadioButton control
     * changes.  Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnCheckedChanged(EventHandler handler) {}

    /**
     * Retrieves a boolean value that indicates whether the user can change the value
     * of the radio button by clicking it or whether the value can only be changed
     * programmatically.   If not, then this has to be
     * done manually in the <i>click</i> event.  In additon, if the RadioButton
     * is part of a group of RadioButtons, this property ensures that only one
     * of them is checked at a given time.
     * 
     * @return      the current value of the autoCheck property.
     */
    public final boolean getAutoCheck() {}

    /**
     * Retrieves a value that indicates whether the radio button will have the appearance of a
     * command button rather than the usual appearance of a radio button.  The
     * radio button can either take on the default look with a little circular
     * 'button' to the left or the right of some text, or it can look like a
     * regular windows push button.  Valid values for this property come from 
     * the com.ms.wfc.ui.Appearance enumeration.
     *
     * @return      the current appearance for this control.
     *
     * @see com.ms.wfc.ui.Appearance
     */
    public final int getAppearance() {}

    /**
     * Retrieves a boolean value that indicates whether the radio button is turned on
     * or off. 
     * 
     * @return  <b>true</b> if the control is checked, or <b>false</b>
     *          otherwise.
     */
    public final boolean getChecked() {}

    /**
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a value that indicates where the text for the RadioButton control is
     * positioned relative to the circle that shows whether the option is turned on or off.   By default, it is aligned to the right of
     * the button.  Valid values are taken from the com.ms.wfc.ui.LeftRightAlignment
     * enumeration.
     * 
     * @return   current value of this property.  
     * 
     * @see com.ms.wfc.ui.LeftRightAlignment
     */
    public final int getTextAlign() {}

    /**
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Triggers the checkedChanged event. 
     * 
     * @param e Event data.
     */
    protected void onCheckedChanged(Event e) {}

    /**
     * Triggers the click event. 
     * @internalonly
     */
    protected void onClick(Event e) {}

    
    private void performAutoUpdates() {}

    /**
     * Generates a click event for the button, simulating a click by a user. 
     */
    public final void performClick() {}

    /**
     * @internalonly
     */
    protected boolean processMnemonic(char charCode) {}

    /**
     * Removes the delegate that is assigned to the checkedChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnCheckedChanged(EventHandler handler) {}

    /**
     * Sets a value that indicates whether the radio button will have the appearance of a
     * command button rather than the usual appearance of a radio button.  The
     * radio button can either take on the default look with a little circular
     * 'button' to the left or the right of some text, or it can look like a
     * regular windows push button.  Valid values for this property come from 
     * the com.ms.wfc.ui.Appearance enumeration.
     *
     * @param   value       The new appearance for this RadioButton.
     *
     * @see com.ms.wfc.ui.Appearance
     */
    public final void setAppearance(int value) {}

    /**
     * Sets a boolean value that indicates whether the user can change the value of the
     * check box by clicking it or whether the value can only be changed programmatically.   If not, then this has to be
     * done manually in the <i>click</i> event.  In additon, if the RadioButton
     * is part of a group of RadioButtons, this property ensures that only one
     * of them is checked at a given time.
     * 
     * @param value     The new value for the <i>autoCheck</i> property.
     */
    public final void setAutoCheck(boolean value) {}

    /**
     * Sets a boolean value that indicates whether the radio button is turned on. 
     * 
     * @param   value   <b>true</b> means this control should be checked.
     */
    public final void setChecked(boolean value) {}

    /**
     * Sets a value that indicates where the text for the RadioButton control is
     * positioned relative to the circle that shows whether the option is turned on or off.   By default, it is aligned to the right of
     * the button.  Valid values are taken from the com.ms.wfc.ui.LeftRightAlignment
     * enumeration.
     * 
     * @param   value   New value for this property
     * 
     * @see com.ms.wfc.ui.LeftRightAlignment
     */
    public final void setTextAlign(int value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * @internalonly
     */
    protected void wndProc(Message m) {}

    /**
     * Encapsulates a radio button (or option button) control, which displays an option that  can be turned on or off. 
     *
     * @security(checkClassLinking=on)
     */
    public  static class ClassInfo extends Control.ClassInfo { 
        public static final PropertyInfo appearance = new PropertyInfo(
            RadioButton.class, "appearance", Appearance.class,
            new DefaultValueAttribute(new Integer(Appearance.NORMAL)),
            new DescriptionAttribute(Sys.getString("RadioButtonAppearanceDescr")));

        public static final PropertyInfo autoCheck = new PropertyInfo(
            RadioButton.class, "autoCheck", Boolean.TYPE,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("RadioButtonAutoCheckDescr")));

        public static final PropertyInfo checked = new PropertyInfo(
            RadioButton.class, "checked", Boolean.TYPE,
            LocalizableAttribute.YES,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("RadioButtonCheckedDescr")));

        public static PropertyInfo textAlign = new PropertyInfo(
            RadioButton.class, "textAlign", LeftRightAlignment.class,
            LocalizableAttribute.YES,
            new DefaultValueAttribute(new Integer(LeftRightAlignment.RIGHT)),
            new DescriptionAttribute(Sys.getString("RadioButtonTextAlignDescr")));

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, DefaultValueAttribute.FALSE);

        public static EventInfo checkedChanged = new EventInfo(
            RadioButton.class, "checkedChanged", EventHandler.class,
            new DescriptionAttribute(Sys.getString("RadioButtonOnCheckedChangedDescr")));

        public String getDefaultPropertyName() {}

        public String getDefaultEventName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}