//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a rebar control, which contains other controls within moveable, resizable  bands. 
 * 
 * A Rebar is a control that hosts multiple other controls inside of moveable
 * bands. The rebar allows the bands to be resized, repositioned, and hidden.
 *
 * @security(checkClassLinking=on)
 */
public class Rebar extends Control {
    private static final Object EVENT_AUTOSIZE      = new Object();
    private static final Object EVENT_HEIGHTCHANGE  = new Object();
    private static final Object EVENT_LAYOUTCHANGE  = new Object();

    private List bands = new List();
    private int orientation = Orientation.HORIZONTAL;
    private boolean autoSize = true;
    private int borderStyle = BorderStyle.FIXED_SINGLE;
    private boolean bandBorders = true;
    private boolean doubleClickToggle = true;
    private boolean fixedOrder = false;
    private ImageList imageList = null;
    private boolean reverseInsert = false;

    /**
     * Creates a Rebar.
     */
    public Rebar() {}

    /**
     * Adds a control, along with a rebar band to contain it, to the rebar control. 
     * 
     * @param control Control to add.
     * 
     * @see com.ms.wfc.ui.Control#add(com.ms.wfc.ui.Control)
     */
    public void add(Control control) {}

    
    void add(Control control, RebarBand band) {}

    /**
     * Adds a rebar band to the rebar control. 
     * 
     * @param band Band to add.
     */
    public void addBand(RebarBand band) {}

    /**
     * Assigns a delegate to the autoSize event. 
     * @param handler Delegate to add to the event.
     * 
     * @see #removeOnAutoSize
     * @see #onAutoSize
     */
    public void addOnAutoSize(AutoSizeEventHandler handler) {}

    /**
     * Assigns a delegate to the heightChange event. 
     * @param handler Delegate to add to the event.
     * 
     * @see #removeOnHeightChange
     * @see #onHeightChange
     */
    public void addOnHeightChange(EventHandler handler) {}

    /**
     * Assigns a delegate to the layoutChange event. 
     * @param handler Delegate to add to the event.
     * 
     * @see #removeOnLayoutChange
     * @see #onLayoutChange
     */
    public void addOnLayoutChange(EventHandler handler) {}

    /**
     * Forces the rebar to update the size and location of child
     * bands.
     * 
     * @internalonly
     */
    protected void applyAutoSize() {}

    
    private void applyBarInfo() {}


    /**
     * @internalonly 
     */
    protected void createHandle() {}

    
    private void createAllRealBands() {}

    
    private void createRealBand(RebarBand band) {}

    public void dispose() {}

    
    private void fireAutoSize() {}

    
    private void fireHeightChange() {}

    
    private void fireLayoutChange() {}


    /**
     * Retrieves a boolean value indicating whether the rebar will automatically adjust
     * its size when the bands it contains are moved or resized. 
     * 
     * @return current AutoSize value.
     * 
     * @see #setAutoSize
     */
    public boolean getAutoSize() {}

    /**
     * Retrieves the all the bands in the rebar. 
     * 
     * @return current Bands.
     * 
     * @see #setBands
     */
    public RebarBand[] getBands() {}

    /**
     * Retrieves a boolean value indicating whether narrow lines separate adjacent
     * bands in the rebar control. 
     * 
     * @return current BandBorders value.
     * 
     * @see #setBandBorders
     */
    public boolean getBandBorders() {}

    /**
     * Retrieves a value indicating the kind of border the rebar control has.   Valid values are taken from the com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @return      the current border style for this control.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public int getBorderStyle() {}

    /**
     * @internalonly 
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a boolean value indicating whether the user double-clicks or
     * single-clicks to toggle the size of the rebar band. 
     * 
     * @return current DoubleClickToggle value.
     * 
     * @see #setDoubleClickToggle
     */
    public boolean getDoubleClickToggle() {}

    /**
     * Retrieves a boolean value indicating whether the user can change the order of
     * the bands in the rebar control. 
     * 
     * @return current FixedOrder value.
     * 
     * @see #setFixedOrder
     */
    public boolean getFixedOrder() {}

    /**
     * Retrieves the image list control associated with the rebar control. 
     * 
     * @return current ImageList.
     * 
     * @see #setImageList
     */
    public ImageList getImageList() {}

    /**
     * Retrieves a value indicating whether the rebar control is oriented horizontally or
     * vertically. 
     * 
     * @return current Orientation value.
     * 
     * @see #setOrientation
     */
    public int getOrientation() {}

    private void invalidateBands() {}

    /**
     * @internalonly 
     */
    protected void onLayout(LayoutEvent event) {}

    /**
     * Triggers the resize event. 
     * 
     * @param event Event data.
     * 
     * @see com.ms.wfc.ui.Control#onResize(Event)
     */
    protected void onResize(Event event) {}

    /**
     * Triggers the autoSize event. 
     * 
     * @param event event data.
     */
    protected void onAutoSize(AutoSizeEvent event) {}

    /**
     * Triggers the heightChange event. 
     * 
     * @param event Event data.
     */
    protected void onHeightChange(Event event) {}

    /**
     * Triggers the layoutChange event. 
     * 
     * @param event Event data.
     */
    protected void onLayoutChange(Event event) {}

    /**
     * Removes a control, along with the band that contains it, from the rebar control. 
     * 
     * @param ctl Control to remove.
     * 
     * @see com.ms.wfc.ui.Control#remove(com.ms.wfc.ui.Control)
     */
    public void remove(Control ctl) {}

    /**
     * Removes all bands from the rebar control. 
     */
    public void removeAllBands() {}

    /**
     * Removes the specified band from the rebar control. 
     * 
     * @param band Band to remove.
     */
    public void removeBand(RebarBand band) {}

    /**
     * Removes the delegate that is assigned to the autoSize event. 
     * 
     * @param handler Delegate to remove from the event.
     * 
     * @see #addOnAutoSize
     * @see #onAutoSize
     */
    public void removeOnAutoSize(AutoSizeEventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the heightChange event. 
     * 
     * @param handler Delegate to remove from the event.
     * 
     * @see #addOnHeightChange
     * @see #onHeightChange
     */
    public void removeOnHeightChange(EventHandler handler) {}

    /**
     * Removes the delegate that is assigned to the layoutChange event. 
     * 
     * @param handler Delegate to remove from the event.
     * 
     * @see #addOnLayoutChange
     * @see #onLayoutChange
     */
    public void removeOnLayoutChange(EventHandler handler) {}

    /**
     * Sets a boolean value indicating whether the rebar will automatically adjust its
     * size when the bands it contains are moved or resized.  When AutoSize is set to true the
     * Rebar will automatically size itself to fit the contained
     * bands.
     * 
     * @param value New value for the AutoSize property.
     * 
     * @see #getAutoSize
     */
    public void setAutoSize(boolean value) {}

    /**
     * Adds a set of bands to the rebar control.  Each band in the Rebar contains a child control.
     * 
     * @param bands List of bands that the Rebar will contain.
     * 
     * @see #getBands
     */
    public void setBands(RebarBand[] bands) {}

    /**
     * Sets a boolean value indicating whether narrow lines separate adjacent bands in
     * the rebar control.  When BandBordes is set to true a small border
     * is drawn around each band.
     * 
     * @param value New value for BandBorders.
     * 
     * @see #getBandBorders
     */
    public void setBandBorders(boolean value) {}

    protected void setBoundsCore(int x, int y, int width, int height) {}

    /**
     * Sets a value indicating the kind of border the rebar control has. 
     * Valid values are taken from the com.ms.wfc.ui.BorderStyle enumeration.
     *
     * @param value     The new border style for this Rebar control.
     *
     * @see com.ms.wfc.ui.BorderStyle
     */
    public void setBorderStyle(int value) {}

    /**
     * Sets a value indicating which edge of its container this control is docked to. 
     * 
     * @param dock New dock.
     * 
     * @see com.ms.wfc.ui.Control#setDock(int)
     */
    public void setDock(int dock) {}

    /**
     * Sets a boolean value indicating whether the user double-clicks or single-clicks
     * to toggle the size of the rebar band.  When DoubleClickToggle is
     * set to true users can enlarge and shrink bands by double clicking
     * on the band header.
     * 
     * @param value New DoubleClickToggle value.
     * 
     * @see #getDoubleClickToggle
     */
    public void setDoubleClickToggle(boolean value) {}

    /**
     * Sets a boolean value indicating whether the user can change the order of the
     * bands in the rebar control.  When FixedOrder is set to true
     * the contained bands can be sized, but the order of the bands
     * can not change.
     * 
     * @param value New value for the FixedOrder property
     * 
     * @see #getFixedOrder
     */
    public void setFixedOrder(boolean value) {}

    /**
     * Sets the image list control associated with the rebar control. 
     * 
     * @param value New ImageList.
     * 
     * @see #getImageList
     */
    public void setImageList(ImageList value) {}

    /**
     * Adds controls, along with bands to contain them, to the rebar control. 
     * 
     * @param ctls Controls to put in the Rebar.
     * 
     * @see com.ms.wfc.ui.Control#setNewControls
     */
    public void setNewControls(Control[] ctls) {}

    /**
     * Sets a value indicating whether the rebar control is oriented horizontally or
     * vertically.  This controls the direction in
     * which the bands are drawn.
     * 
     * @param value New Orientation value.
     * 
     * @see #getOrientation
     */
    public void setOrientation(int value) {}

    /**
     * Sets the Site for the Rebar.
     * 
     * @param site New Site.
     * 
     * @see com.ms.wfc.core.Component#setComponentSite
     */
    public void setComponentSite(IComponentSite site) {}

    
    private void sizeToRect() {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void updateBandsWithLayout() {}

    
    private void wmReflectCommand(Message m) {}

    private void paintBackground(Graphics g) {}

    private void wmEraseBackground(Message m) {}

    /**
     * @internalonly 
     */
    protected void wndProc(Message m) {}


    /**
     * Encapsulates a rebar control, which contains other controls within moveable, resizable  bands. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        public static final PropertyInfo autoSize = new PropertyInfo(
            Rebar.class, "autoSize", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("RebarAutoSizeDescr")));

        public static final PropertyInfo bandBorders = new PropertyInfo(
            Rebar.class, "bandBorders", Boolean.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("RebarBandBordersDescr")));

        public static final PropertyInfo bands = new PropertyInfo(
            Rebar.class, "bands", RebarBand[].class,
            CategoryAttribute.Behavior,
            new ValueEditorAttribute(RebarBand.ArrayEditor.class),
            new DescriptionAttribute(Sys.getString("RebarBandsDescr")));

        public static final PropertyInfo borderStyle = new PropertyInfo(
            Rebar.class, "borderStyle", BorderStyle.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(BorderStyle.FIXED_SINGLE)),
            new DescriptionAttribute(Sys.getString("RebarBorderStyleDescr")));

        public static final PropertyInfo dock = new PropertyInfo(
            Rebar.class, "dock", ControlDock.class,
            CategoryAttribute.Position,
            new ValueEditorAttribute(DockEditor.class),
            new DefaultValueAttribute(new Integer(ControlDock.TOP)),
            new DescriptionAttribute(Sys.getString("ControlDockDescr")));

        public static final PropertyInfo doubleClickToggle = new PropertyInfo(
            Rebar.class, "doubleClickToggle", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("RebarDoubleClickToggleDescr")));

        public static final PropertyInfo fixedOrder = new PropertyInfo(
            Rebar.class, "fixedOrder", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("RebarFixedOrderDescr")));

        public static final PropertyInfo orientation = new PropertyInfo(
            Rebar.class, "orientation", com.ms.wfc.ui.Orientation.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.Orientation.HORIZONTAL)),
            new DescriptionAttribute(Sys.getString("RebarOrientationDescr")));

        public static final PropertyInfo imageList = new PropertyInfo(
            Rebar.class, "imageList", ImageList.class,
            CategoryAttribute.Appearance,
            new DescriptionAttribute(Sys.getString("RebarImageListDescr")));

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, DefaultValueAttribute.FALSE);


        public static final EventInfo autoSizeEvent = new EventInfo(
            Rebar.class, "autoSize", AutoSizeEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("RebarOnAutoSizeDescr")));

        public static final EventInfo heightChange = new EventInfo(
            Rebar.class, "heightChange", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("RebarOnHeightChangeDescr")));

        public static final EventInfo layoutChange = new EventInfo(
            Rebar.class, "layoutChange", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("RebarOnLayoutChangeDescr")));

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}

        public ICustomizer getCustomizer(Object component) {}
    }


    /**
     * Encapsulates a rebar control, which contains other controls within moveable, resizable  bands. 
     * @security(checkClassLinking=on)
     */
    public static class Customizer extends com.ms.wfc.core.Customizer {

        private Rebar rebar = null;
        private RBHITTESTINFO hit = new RBHITTESTINFO();

        public Customizer(Rebar rebar) {}

        public boolean getHitTest(Point point) {}
    }
}