//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.io.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Encapsulates a rectangular area defined  by its top-left (x, y) coordinate and its width and height. Stores the location and size of a rectangular region. For more
 * advanced region functions use a <i>Region</i> object.
 *
 * @see com.ms.wfc.ui.Region
 *
 * @security(checkClassLinking=on)
 */
public final class Rectangle implements IPersistable, IConstructable {

    public int x = 0;
    public int y = 0;
    public int width = 0;
    public int height = 0;


    /**
     * Creates a new Rectangle. The size and location default to 0.
     */
    public Rectangle() {}

    /**
     * Creates a new Rectangle. The size and location are read from <i>stream</i>.
     *
     * @param stream Stream to read a persisted rectangle from.
     */
    public Rectangle(IDataStream stream) {}

    /**
     * Creates a new Rectangle. The size and location are copied from <i>r</i>.
     *
     * @param r Rectangle to copy.
     */
    public Rectangle(Rectangle r) {}

    /**
     * Creates a new Rectangle. The size and location are determined from the
     * parameters.
     *
     * @param x X location
     * @param y Y location
     * @param width width
     * @param height height
     */
    public Rectangle(int x, int y, int width, int height) {}

    /** 
     * Creates a new Rectangle. The size and location are copied from <i>rect</i>.
     *
     * @param rect Win32 RECT structure to copy.
     */
    public Rectangle(RECT rect) {}

    /**
     * Retrieves a boolean
     * value that indicates whether this rectangle contains the specified rectangle or points. 
     *
     * @param pt Point to test
     *
     * @return <b>true</b> if the point is contained within this rectangle.
     */
    public boolean contains(Point pt) {}

    /**
     * Retrieves a boolean
     * value that indicates whether this rectangle contains the specified rectangle or points. 
     *
     * @param x X location to test
     * @param y Y location to test
     *
     * @return <b>true</b> if the point is contained within this rectangle.
     */
    public boolean contains(int x, int y) {}

    /**
     * Retrieves a boolean
     * value that indicates whether this rectangle contains the specified rectangle or points. 
     * 
     * @param rect Rectangle to test
     *
     * @return <b>true</b> if the rectangle is contained.
     */
    public boolean contains(Rectangle rect) {}

    public boolean equals(Object obj) {}

    /**
     * Retrieves the rightmost point on the
     * rectangle's x-axis. 
     *
     * @return right value for this rectangle.
     */
    public final int getRight() {}

    /**
     * Retrieves the lowest point in the
     * rectangle's y-axis. 
     * 
     * @return bottom value for this rectangle.
     */
    public final int getBottom() {}

    public ConstructorArg[] getConstructorArgs() {}

    /**
     * Inflates this rectangle by the specified
     * amount. If a negative size
     * is specified the rectangle will be deflated.
     *
     * @param size Amount to inflate this rectangle.
     */
    public void inflate(Point size) {}
    
    /**
     * Inflates this rectangle by the specified
     * amount. If a negative size
     * is specified the rectangle will be deflated.
     *
     * @param x Amount to inflate this rectangle horizontally.
     * @param y Amount to inflate this rectangle vertically.
     */
    public void inflate(int x, int y) {}

    /**
     * Inflates this rectangle by the specified
     * amount. If a 
     * negative size is specified the rectangle will be deflated.
     *
     * @param rect Rectangle to base the operation on. This rectangle will not
     *        be modified.
     * @param x Amount to inflate this rectangle horizontally.
     * @param y Amount to inflate this rectangle vertically.
     *
     * @return the resulting rectangle.
     */
    public static Rectangle inflate(Rectangle rect, int x, int y) {}

    /**
     * Retrieves a Rectangle
     * object that represents the intersecting area of two specified rectangles. If there is no intersection, <b>null</b> is returned.
     *
     * @param a Rectangle to intersect
     * @param b Rectangle to intersect
     *
     * @return the insected region
     */
    public static Rectangle intersect(Rectangle a, Rectangle b) {}

    /** 
     * Retrieves a Rectangle
     * object that represents the smallest rectangle that contains two specified rectangular
     * areas.
     * 
     * @param a Rectangle to union
     * @param b Rectangle to union
     *
     * @return the unioned region.
     */
    public static Rectangle union(Rectangle a, Rectangle b) {}

    /**
     * Retrieves a boolean
     * value that indicates whether the specified rectangle intersects with this one. 
     *
     * @param rect Rectangle to test
     *
     * @return <b>true</b> if there is any intersection
     */
    public boolean intersectsWith(Rectangle rect) {}
    
    /**
     * Adjusts the location of the rectangle by
     * the specified amount.
     * 
     * @param pos Amount to offset the location
     */
    public void offset(Point pos) {}
    
    /**
     * Adjusts the location of the rectangle by
     * the specified amount.
     * 
     * @param x Amount to offset the location horizontally
     * @param y Amount to offset the location vertically
     */
    public void offset(int x, int y) {}

    /**
     * Sets the size and location of this
     * object.
     *
     * @param x X location
     * @param y Y location
     * @param width width
     * @param height height
     */
    public void setBounds(int x, int y, int width, int height) {}

    /**
     * Sets the size and location of this
     * object.
     *
     * @param r Win32 RECT structure to read values from
     */
    public void setBounds(RECT r) {}

    /**
     * Sets the size and location of this
     * object.
     *
     * @param r Rectangle to read values from
     */
    public void setBounds(Rectangle r) {}

    /**
     * Retrieves a Win32 RECT
     * structure that contains the settings of a Rectangle object.
     *
     * @return Win32 RECT structure.
     */
    public final RECT toRECT() {}

    /**
     * Retrieves a Win32 RECT
     * structure that contains the settings of a Rectangle object.
     *
     * @param r Rectangle to convert.
     *
     * @return Win32 RECT structure.
     */
    public static final RECT toRECT(Rectangle r) {}

    public String toString() {}

    public void save(IDataStream stream) {}
    public String getExtension() {}


    /**
     * Encapsulates a rectangular area defined  by its top-left (x, y) coordinate and its width and height.
     * @security(checkClassLinking=on)
     */
    public static class Editor extends ValueEditor {

        public int getStyle() {}

        public String getTextFromValue(Object value) {}

        public Object getValueFromText(String text) {}
    }

}