//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.core.*;

/**
 * Encapsulates a Windows region and the logical operations that you can perform on  regions.  A region may
 * consist of rectangles, ellipses, polygons or any combination of the 
 * three.  Regions can be painted directly or may be used to clip 
 * other drawing operations.
 * 
 * @see Graphics
 *
 * @security(checkClassLinking=on)
 */
public class Region {
    private int handle;
    private boolean ownHandle;

    /**
     * Creates an empty region.
     */
    public Region() {}
    
    /**
     * Creates a region object from an existing Win32 region handle.  In
     * this case the region object does not own the handle and will not
     * destroy it when the region is garbage collected.
     * 
     * @param handle A Win32 region handle.
     */
    public Region(int handle) {}

    /**
     * Creates a Region object that contains the elements common to a
     * specified region and this one.
     * 
     * @param region The region to combine.
     * @return a new Region object that represents the combination.
     */
    public final Region andWith(Region region) {}
    
    /**
     * Creates a duplicate of this Region object.
     * 
     * @return an Object that is castable to a Region.
     */
    public Object clone() {}

    /**
     * Retrieves a boolean value that indicates whether a specified point or
     * rectangle exists in the region.
     * 
     * @param pt The point in question.
     * @returns <b>true</b> if the point lies within the region, or
     *          <b>false</b> if it doesn't.
     */
    public final boolean contains(Point pt) {}
    
    /**
     * Retrieves a boolean value that indicates whether a specified point or
     * rectangle exists in the region.
     * 
     * @param x The X coordinate of the point in question.
     * @param y The Y coordinate of the point in question.
     * @returns <b>true</b> if the point lies within the region, or
     *          <b>false</b> if it doesn't.
     */
    public final boolean contains(int x, int y) {}
    
    /**
     * Retrieves a boolean value that indicates whether a specified point or
     * rectangle exists in the region.
     * 
     * @param rect The rectangle in question.
     * @returns <b>true</b> if the rectangle lies within the region, or
     *          <b>false</b> if it doesn't.
     */
    public final boolean contains(Rectangle rect) {}
    
    /**
     * Retrieves a boolean value that indicates whether a specified point or
     * rectangle exists in the region.
     * 
     * @param x       The X coordinate of the top left of the rectangle.
     * @param y       The Y coordinate of the top left of the rectangle.
     * @param width   The width of the rectangle.
     * @param height  The height of the rectangle.
     * @returns <b>true</b> if the rectangle lies within the region, or
     *          <b>false</b> if it doesn't.
     */
    public final boolean contains(int x, int y, int width, int height) {}

    /**
     * Retrieves a copy of the Win32 handle for the region on which this object is based.   You are responsible for
     * freeing the returned handle when you are done with it.
     * 
     * @return a Win32 region handle.
     */
    public final int copyHandle() {}
    
    /**
     * Creates an elliptical region based on a specified bounding rectangle.
     * 
     * @param rect   The bounding rectangle to create the ellipse from.
     * @return a new Region object that contains the ellipse.
     */
    public static final Region createElliptical(Rectangle rect) {}
    
    /**
     * Creates an elliptical region based on a specified bounding rectangle.
     * 
     * @param x      The X coordinate of the upper left corner of the 
     *               boudning rectangle.
     * @param y      The Y coordinate of the upper left corner of the
     *               bounding rectangle.
     * @param width  The width of the bounding rectangle.
     * @param height The width of the bounding rectangle.
     * @return a new Region object that contains the ellipse.
     */
    public static final Region createElliptical(int x, int y, int width, int height) {}

    
    private static int createPOINTArray(Point [] points) {}

    /**
     * Creates a region based on an array of points.  In the case of points that cuase lines
     * to intersect and overlap, the order of the points becomes important.
     * This order determines how the region will be filled.  The filling
     * mode defaults to ALTERNATE.
     * 
     * @param points   An array of points that define the shape of
     *                 the polygon.
     * @return a new Region object that contains the polygon.
     * 
     * @see PolyFillMode
     */
    public static final Region createPolygonal(Point [] points) {}

    /**
     * Creates a region based on an array of points.  In the case of points that cuase lines
     * to intersect and overlap, the order of the points becomes important.
     * This order determines how the region will be filled.
     * 
     * @param points   An array of points that define the shape of
     *                 the polygon.
     * @param fillMode The polygon fill mode.  This can be one of
     *                 the values of the PolyFillMode enum.
     * @return a new Region object that contains the polygon.
     * 
     * @see PolyFillMode
     */
    public static final Region createPolygonal(Point [] points, int fillMode) {}

    /**
     * Creates a rectangular region based on a specified bounding rectangle.
     * 
     * @param rect   The rectangle to create the region from.
     * @return a new Region object that contains the rectangle.
     */
    public static final Region createRectangular(Rectangle rect) {}
    
    /**
     * Creates a rectangular region based on a specified bounding rectangle.
     * 
     * @param x      The X coordinate of the upper left corner of the rectangle.
     * @param y      The Y coordinate of the upper left corner of the rectangle.
     * @param width  The width of the rectangle.
     * @param height The width of the rectangle.
     * @return a new Region object that contains the rectangle.
     */
    public static final Region createRectangular(int x, int y, int width, int height) {}
    /**
     * Creates a rounded rectangular region based on a specified bounding rectangle.
     * 
     * @param rect   The rectangle to create the region from.
     * @param radius The radius of the ellipse.
     * @return a new Region object that contains a rectangle with rounded
     *         corners.
     */
    public static final Region createRoundedRectangular(Rectangle rect, int radius) {}
    
    /**
     * Creates a rounded rectangular region based on a specified bounding rectangle.
     * 
     * @param x      The X coordinate of the upper left corner of the rectangle.
     * @param y      The Y coordinate of the upper left corner of the rectangle.
     * @param width  The width of the rectangle.
     * @param height The width of the rectangle.
     * @param radius The radius of the ellipse.
     * @return a new Region object that contains the rectangle.
     */
    public static final Region createRoundedRectangular(int x, int y, int width, int height, int radius) {}

    /**
     * Called when this object is about to destroy its handle.  You
     * may override this if there is something special you need to do to 
     * destroy the handle.  This will be called even if the handle is not
     * owned by this object, which is handy if you want to create a
     * derived class that has it's own create/destroy semantics.
     * <p>
     * The default implementation will call the appropriate Win32
     * call to destroy the handle if this object currently owns the
     * handle.  It will do nothing if the object does not currently
     * own the handle.
     */
    protected void destroyHandle() {}

    /**
     * Creates a new region that consists of all areas of this region that are not included in
     * the specified one.
     * 
     * @param region The region to combine.
     * @return a new Region object that represents the combination.
     */
    public final Region diffWith(Region region) {}

    /**
     * Frees all resources allocated by this object.  You do not have to call dispose; the
     * garbage collector will do it for you.  However, you may expedite
     * the process by calling dispose manually.
     */
    public void dispose() {}
    
    /**
     * Retrieves a boolean value that indicates whether the specified object
     * is equivalent to this Region object.
     * 
     * @param object The object to compare equality with.
     * @return <b>true</b> if the objects are equal, <b>false</b>
     * if not.
     */
    public boolean equals(Object object) {}

    /**
     * Frees the resources allocated by this object.  Cleans up a Region object.
     */
    protected void finalize() {}
    
    /**
     * Retrieves the bounding rectangle for this region.  This will
     * be the smallest rectangle that fully encompasses the region.
     * 
     * @return a Rectangle containing the bounds for the region.
     */
    public final Rectangle getBounds() {}

    /**
     * Retrieves the Win32 handle (HREGION) for this region.
     */
    public int getHandle() {}
    
    /**
     * Retrieves a hash code for this object.
     * 
     * @return a hashcode for this region.
     */
    public int hashCode() {}
	
	/**
	 * Creates a new Region object which consists of this region, relocated
     * by the specified offset.
	 * 
	 * @param point The amount to offset the region.
	 * @return a new region that has been offset by <i>point</i>.
	 */
	public final Region offset(Point point) {}
	
	/**
	 * Creates a new Region object which consists of this region, relocated
     * by the specified offset.
	 * 
	 * @param x The amount to offset the region in the X direction.
	 * @param y The amount to offset the region in the Y direction.
	 * @return a new region that has been offset by <i>x</i> and <i>y</i>.
	 */
	public final Region offset(int x, int y) {}
    
    /**
     * Creates and returns a new region that represents a union between a specified region and
     * this one.
     * 
     * @param region The region to combine.
     * @return a new Region object that represents the combination.
     */
    public final Region orWith(Region region) {}
    
    /**
     * Creates a new Region
     * object that contains all non-duplicate elements of this region and a specified one.
     * 
     * @param region The region to combine.
     * @return a new Region object that represents the combination.
     */
    public final Region xorWith(Region region) {}
}