//STRIPPEDSOURCE//
package com.ms.wfc.ui;

import com.ms.dll.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.util.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;


/**
 * Represents the base class for scroll bar controls.  The control
 * is most commonly used to navigate over a range of values.
 * @security(checkClassLinking=on)
 */
public abstract class ScrollBar extends Control {
    
    private static final Object EVENT_SCROLL = new Object();
    private static final Object EVENT_VALUECHANGED = new Object();
    
    private int minimum = 0;
    private int maximum = 100;
    private int smallChange = 1;
    private int largeChange = 10;
    private int value = 0;

    /**
     * Creats a new ScrollBar object.  The range of operation, defined by
     * the "minimum" and "maximum" properties, is defaulted to 0..100. The
     * "value" starts out at zero.
     */
    public ScrollBar() {}
    
    /**
     * Assigns a delegate to the scroll event.  This
     * event is raised whenever the ScrollBar's thumb has been moved through
     * mouse or keyboard action, and proposes the new value that the ScrollBar
     * should take.
     *
     * @param value New Event Handler to install for this event.
     */
    public void addOnScroll(ScrollEventHandler seh) {}
    
    /**
     * Assigns a delegate to the valueChanged event.  This
     * event is called whenever the scrollbar's current position changes,
     * whether it be because of mouse, keyboard, or programmatic input.
     *
     * @param value New Event Handler to install for this event.
     */
    public void addOnValueChanged(EventHandler eh) {}

    /**
     * Retrieves the parameters needed to create the handle.  Inheriting classes
     * can override this to provide extra functionality.  They should not,
     * however, forget to call super.getCreateParams() first to get the struct
     * filled up with the basic info.
     *
     * @return a CreateParams object with all the info needed to create
     *         the control.
     *
     * @see com.ms.wfc.ui.CreateParams
     * @hidden
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the increment between each large change of the scroll thumb.   This
     * is typically caused by hitting either the PgUp or PgDn keys, or by
     * clicking in the client area of the scrollbar above or below the scroll
     * thumb.
     *
     * @return  the current number of units "value" will be changed by
     *              when a "large" change action is performed.
     */
    public int getLargeChange() {}

    /**
     * Retrieves the maximum value of the scroll bar. 
     *
     * @return   the highest value the "value" property can be set to.
     */
    public int getMaximum() {}
    
    /**
     * Retrieves the minimum value of the scroll bar. 
     *
     * @return   the lowest value the "value" property can be set to.
     */
    public int getMinimum() {}
    
    /**
     * Retrieves the increment between each small change of the scroll thumb.    This
     * is typically caused by using the arrow keys on the keyboard, or by 
     * clicking the perimeter buttons with the arrows on the scrollbar contorl.
     *
     * @return  the current number of unites "value" will be changed by when
     *          a "small" change action is performed.
     */
    public int getSmallChange() {}
    
    /**
     * Retrieves the current value of the scroll bar.   This value will be
     * between "minimum" and "maximum".
     *
     * @return  the current offset into the scrollable range.
     */
    public int getValue() {}
    
    /**
     * Creates the handle.  overridden to help set up scrollbar information.
     * @hidden
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Triggers the scroll event.   
     * @hidden
     * @internalonly
     */
    protected void onScroll(ScrollEvent se) {}

    /**
     * Triggers the valueChanged event.   
     * @hidden
     * @internalonly
     */
    protected void onValueChanged(Event e) {}
    
    /**
     * Indicates that a 'stock' property has changed.  We look for the enabled
     * property to help out.
     * @hidden
     * @internalonly
     */
    protected void propertyChanged(int prop) {}
    
    /**
     * Removes the delegate that is assigned to the scroll event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnScroll(ScrollEventHandler seh) {}
    
    /**
     * Removes the delegate that is assigned to the valueChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnValueChanged(EventHandler eh) {}

    /**
     * Sets the increment between each large change of the scroll thumb.   This
     * is typically caused by hitting either the PgUp or PgDn keys, or by
     * clicking in the client area of the scrollbar above or below the scroll
     * thumb. This is also the size of the thumb in proportion to the whole range.
     *
     * @param  value  the number of units "value" will be changed by
     *                when a "large" change action is performed.
     */
    public void setLargeChange(int value) {}
    
    /**
     * Sets the maximum value of the scroll bar. 
     *
     * @param value the highest value the "value" property can be set to.
     */
    public void setMaximum(int value) {}
    
    /**
     * Sets the minimum possible value of the scroll bar. 
     *
     * @param value the lowest value the "value" property can be set to.
     */
    public void setMinimum(int value) {}
    
    /**
     * Sets the increment between each small change of the scroll thumb.    This
     * is typically caused by using the arrow keys on the keyboard, or by 
     * clicking the perimeter buttons with the arrows on the scrollbar contorl.
     *
     * @param value  the number of unites "value" will be changed by when
     *               a "small" change action is performed.
     */
    public void setSmallChange(int value) {}
    
    /**
     * Sets the value of the scroll bar.   This value must be
     * between "minimum" and "maximum".  The scroll-thumb will move to reflect
     * this new value.
     *
     * @param value   the offset into the scrollable range.
     */
    public void setValue(int value) {}
    
    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @hidden
     * @internalonly
     */
    public String toString() {}

    /**
     * Internal helper method
     * @hidden
     * @internalonly
     */
    protected void updateScrollInfo() {}
    
    
    
    private void wmReflectScroll(Message m) {}
    
    /**
     * @internalonly
     * @hidden
     */
    protected void wndProc(Message m) {}
    

    /**
     * Represents the base class for scroll bar controls.
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        
        public final static PropertyInfo largeChange = new PropertyInfo(
            ScrollBar.class, "largeChange", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(10)),
            new DescriptionAttribute(Sys.getString("ScrollBarLargeChangeDescr")));
        
        public final static PropertyInfo minimum = new PropertyInfo(
            ScrollBar.class, "minimum", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("ScrollBarMinimumDescr")));
        
        public final static PropertyInfo maximum = new PropertyInfo(
            ScrollBar.class, "maximum", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(100)),
            new DescriptionAttribute(Sys.getString("ScrollBarMaximumDescr")));
        
        public final static PropertyInfo smallChange = new PropertyInfo(
            ScrollBar.class, "smallChange", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ONE,
            new DescriptionAttribute(Sys.getString("ScrollBarSmallChangeDescr")));

        public final static PropertyInfo value = new PropertyInfo(
            ScrollBar.class, "value", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            BindableAttribute.YES,
            new DescriptionAttribute(Sys.getString("ScrollBarValueDescr")));
        
        public final static EventInfo scroll = new EventInfo(
            ScrollBar.class, "scroll", ScrollEventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("ScrollBarOnScrollDescr")));
        
        public static final PropertyInfo backColor = new PropertyInfo(
            Control.ClassInfo.backColor, BrowsableAttribute.NO);

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO);

        public final static PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, DefaultValueAttribute.FALSE);

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final PropertyInfo font = new PropertyInfo(
            Control.ClassInfo.font, BrowsableAttribute.NO);

        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public static final EventInfo doubleClick = new EventInfo(
            Control.ClassInfo.doubleClick, BrowsableAttribute.NO);

        public static final EventInfo mouseDown = new EventInfo(
            Control.ClassInfo.mouseDown, BrowsableAttribute.NO);

        public static final EventInfo mouseUp = new EventInfo(
            Control.ClassInfo.mouseUp, BrowsableAttribute.NO);

        public static final EventInfo mouseMove = new EventInfo(
            Control.ClassInfo.mouseMove, BrowsableAttribute.NO);

        public static final EventInfo valueChanged = new EventInfo(
            ScrollBar.class, "valueChanged", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("valueChangedEventDescr")));        

        public void getProperties(IProperties props) {}
        
        public void getEvents(IEvents events) {}
        
        public String getDefaultPropertyName() {}
        
        public String getDefaultEventName() {}
    }
}