//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.win32.win;

/**
 * For objects that raise the "scroll" event, and send it a ScrollEvent
 * object, the event can be raised by a number of different occurrances.
 * This enumeration lists said occurrances.
 *
 * @security(checkClassLinking=on)
 */
public class ScrollEventType extends Enum {

    /**
     * Indicates that the event was fired because of a small change in the
     * scroll thumb, typically generated by clicking on an arrow at either
     * end of the ScrollBar control, or by using a single press of an arrow
     * key.
     */
    public static final int SMALL_DECREMENT = win.SB_LINELEFT;

    /**
     * Indicates that the event was fired because of a small change in the
     * scroll thumb, typically generated by clicking on an arrow at either
     * end of the ScrollBar control, or by using a single press of an arrow
     * key.
     */
    public static final int SMALL_INCREMENT = win.SB_LINERIGHT;
    
    /**
     * Indicates that the event was fired because of a large change in the
     * scroll thumb, typically generated by clicking on an arrow to either
     * side of the thumb, but not on an end arrow, or by using the PgUp/PgDn
     * keys on the keyboard.
     */
    public static final int LARGE_DECREMENT = win.SB_PAGELEFT;

    /**
     * Indicates that the event was fired because of a large change in the
     * scroll thumb, typically generated by clicking on an arrow to either
     * side of the thumb, but not on an end arrow, or by using the PgUp/PgDn
     * keys on the keyboard.
     */
    public static final int LARGE_INCREMENT = win.SB_PAGERIGHT;

    /**
     * Indicates that the user has dragged the thumb and let go.
     */
    public static final int THUMB_POSITION = win.SB_THUMBPOSITION;

    /**
     * Indicates that the user is dragging the thumb, and we are about to
     * receive it's current location.
     */
    public static final int THUMB_TRACK = win.SB_THUMBTRACK;

    /**
     * Indicates that the ScrollBar was told to go to the lowest/first possible
     * value.
     */
    public static final int FIRST = win.SB_LEFT;

    /**
     * Indicates that the ScrollBar was told to go to the highest/last possible
     * value.
     */
    public static final int LAST = win.SB_RIGHT;

    /**
     * Indicates that the control is done scrolling.
     */
    public static final int ENDSCROLL = win.SB_ENDSCROLL;

    /**
     * Ensures that the given value is valid within this enumeration.
     */
    public static boolean valid(int value) {}
}