//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;

/**
 * Defines constants that specify the borders a component can have when selected in the  Forms Designer.   When a compnent is selected,
 * the selection border for the component defaults to <b>SELECTED</b>.  While a WFC
 * component supports rich design-time editing support through the ICustomizer interface,
 * it is sometimes necessary to put a component into a special "editing" mode.  The 
 * user should be able to tell what mode a componet is in, which can be achieved through
 * the user of a different selection border.  
 * <p>
 * Note that while a component can configure different selection border styles, changing
 * a border style does not effect the behavior of the component in the designer.  
 * Developers must make use of the ICustomizer interface to modify the component's 
 * behavior when running in a design environment.
 * 
 * @see com.ms.wfc.core.ICustomizer
 * @see com.ms.wfc.ui.ISelectionService
 *
 * @security(checkClassLinking=on)
 */
public class SelectionStyle extends Enum {
    
    /**
     * Specifies the default selection border that typically indicates that a component is
     * selected and can be dragged.
     */
    public static final int SELECTED = 0x01;
    
    /**
     * Specifies an alternative selection border that typically indicates that a component is
     * in editing mode.
     */
    public static final int ACTIVE   = 0x02;
    
    /**
     * Determines whether the specified value is one of the constants defined in this class. 
     * 
     * @param value The value to check.
     * @return <b>true</b> if the value is valid, <b>false</b> if it is not.
     */
    public static boolean valid(int value) {}  
}