//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.wfc.util.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;


/**
 * Encapsulates the splitter control, which allows the user to resize docked controls at  run time.  To use a Splitter you can
 * dock any control to an edge of a container, and then dock the splitter to the same
 * edge. The splitter will then resize the control that is previous in the docking
 * order.
 * 
 * @security(checkClassLinking=on)
 */
public class Splitter extends Control implements IMessageFilter {
    private static final int DRAW_START = 1;
    private static final int DRAW_MOVE = 2;
    private static final int DRAW_END = 3;
    
    private int minSize = 25;
    private int minExtra = 25;
    private Point anchor;
    private Control splitTarget;
    private int splitSize;
    private int initTargetSize;
    private int lastDrawSplit = -1;
    private int maxSize;
    private static final Object EVENT_MOVING = new Object();
    private static final Object EVENT_MOVED = new Object();

    /**
     * Creates a new Splitter.
     */
    public Splitter() {}

    /**
     * Assigns a delegate to the splitterMoving event.  This event occurs while the 
     * splitter is being moved by the user.
     * 
     * @param handler Delegate to invoke when the event gets fired.
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     * @see removeOnSplitterMoving
     */
    public void addOnSplitterMoving(SplitterEventHandler handler) {}

    /**
     * Assigns a delegate to the splitterMoved event.  This event occurs when the user
     * finishes moving the splitter.
     * 
     * @param handler Delegate to invoke when the event gets fired.
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     * @see removeOnSplitterMoved
     */
    public void addOnSplitterMoved(SplitterEventHandler handler) {}

    
    private void drawSplitBar(int mode) {}

    
    private Rectangle calcSplitLine(int splitSize, int minWeight) {}
    
    
    private void drawSplitHelper(int splitSize) {}
    
    
    private void fireSplitterEvent(Object key, SplitterEvent event) {}

    
    private Control findTarget() {}
    
    /**
     * Retrieves the minimum distance that must remain between the splitter and the edge of
     * the opposite side of the container (or the closest control docked to that side).  This area is center of the container that
     * is not occupied by edge docked controls, this is the are that 
     * would be used for any fill docked control.
     * 
     * @return minimum size of the non-docked area of the container.
     */
    public int getMinExtra() {}

    /**
     * Retrieves the minimum distance that must remain between the splitter and the container
     * edge that the control is docked to.  The target of a splitter is always the control adjacent 
     * to the splitter, just prior in the dock order.
     * 
     * @return minimum size of the target of the splitter.
     */
    public int getMinSize() {}

    
    private int getSplitSize(int x, int y) {}

    
    private boolean getHorizontal() {}

    /**
     * @internalonly
     */
    protected void onKeyDown(KeyEvent e) {}

    /**
     * @internalonly
     */
    protected void onMouseDown(MouseEvent e) {}

    /**
     * @internalonly
     */
    protected void onMouseMove(MouseEvent e) {}

    /**
     * @internalonly
     */
    protected void onMouseUp(MouseEvent e) {}

    /**
     * Triggers the splitterMoving event.  This event occurs while the splitter is 
     * being moved by the user.
     * 
     * @param event Event data
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     */
    protected void onSplitterMoving(SplitterEvent event) {}

    /**
     * Triggers the splitterMoved event.  This event occurs when the user finishes 
     * moving the splitter.
     * 
     * @param event Event data
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     */
    protected void onSplitterMoved(SplitterEvent event) {}

    /**
     * @internalonly
     */
    public boolean preFilterMessage(Message m) {}

    /**
     * @internalonly
     */
    public void postFilterMessage(Message m) {}

    /**
     * Removes the delegate that is assigned to the splitterMoving event.  This event occurs while the 
     * splitter is being moved by the user.
     * 
     * @param handler Delegate to remove.
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     * @see addOnSplitterMoving
     */
    public void removeOnSplitterMoving(SplitterEventHandler handler) {}
    
    /**
     * Removes the delegate that is assigned to the splitterMoved event.  This event occurs when the user
     * finishes moving the splitter.
     * 
     * @param handler Delegate to remove.
     * 
     * @see com.ms.wfc.ui.SplitterEvent
     * @see addOnSplitterMoved
     */
    public void removeOnSplitterMoved(SplitterEventHandler handler) {}

    /**
     * @internalonly 
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}
    
    /**
     * @internalonly
     */
    public void setDock(int value) {}

    /**
     * Sets the minimum distance that must remain between the splitter and the edge of the
     * opposite side of the container (or the closest control docked to that side).  This area is center of the container that
     * is not occupied by edge docked controls, this is the are that 
     * would be used for any fill docked control.
     * 
     * @param value minimum size of the non-docked area of the container.
     */
    public void setMinExtra(int value) {}

    /**
     * Sets the minimum distance that must remain between the splitter and the container edge
     * that the control is docked to.  The target of a splitter is always the control adjacent 
     * to the splitter, just prior in the dock order.
     * 
     * @param value minimum size of the target of the splitter.
     */
    public void setMinSize(int value) {}
    
    
    private void splitBegin(int x, int y) {}

    
    private void splitEnd(boolean accept) {}

    /**
     * Sets the distance between the splitter and the container edge that the control is
     * docked to.  <i>split</i> is the splitSize 
     * where you want the splitter position. This controls the size of the 
     * target control of the splitter.
     * 
     * @param split Size of the target control of splitter.
     */
    public void setSplitPosition(int split) {}

    
    private void applySplitPosition() {}

    
    private void splitMove(int x, int y) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * Encapsulates the splitter control, which allows the user to resize docked controls at  run time. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo minExtra = new PropertyInfo(
            Splitter.class, "minExtra", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(25)),
            new DescriptionAttribute(Sys.getString("SplitterMinExtraDescr")));

        public static final PropertyInfo minSize = new PropertyInfo(
            Splitter.class, "minSize", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(25)),
            new DescriptionAttribute(Sys.getString("SplitterMinSizeDescr")));

        public static final PropertyInfo dock = new PropertyInfo(
            Control.ClassInfo.tabStop, new DefaultValueAttribute(new Integer(ControlDock.LEFT)));

        public static final PropertyInfo cursor = new PropertyInfo(
            Control.ClassInfo.cursor, new DefaultValueAttribute(Cursor.VSPLIT));

        public static final PropertyInfo tabStop = new PropertyInfo(
            Control.ClassInfo.tabStop, DefaultValueAttribute.FALSE);

        public static final EventInfo splitterMoving = new EventInfo(
            Splitter.class, "splitterMoving", SplitterEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("SplitterSplitterMovingDescr")));

        public static final EventInfo splitterMoved = new EventInfo(
            Splitter.class, "splitterMoved", SplitterEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("SplitterSplitterMovedDescr")));

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO);

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO, PersistableAttribute.NO);

        public static final PropertyInfo font = new PropertyInfo(
            Control.ClassInfo.font, BrowsableAttribute.NO);


        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}