//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Defines the base class that contains common functionality for the TabStrip and TabControl classes. 
 * It is abstract and can not be instantiated.
 *
 * @security(checkClassLinking=on)
 */
public abstract class TabBase extends Control {

    private static final Point DEFAULT_ITEMSIZE = new Point(100, 21);
    private static final Point DEFAULT_PADDING = new Point(6, 3);

    
    private int alignment        = TabAlignment.TOP;
    private int drawMode         = TabDrawMode.NORMAL;
    private boolean hotTrack     = false;
    private ImageList imageList  = null;
    private Point itemSize       = new Point(DEFAULT_ITEMSIZE);
    private Point saveItemSize   = new Point(DEFAULT_ITEMSIZE);
    private boolean multiline    = false;
    private Point padding        = new Point(DEFAULT_PADDING);
    private boolean showToolTips = false;
    private int sizeMode         = TabSizeMode.NORMAL;
    private int appearance       = TabAppearance.NORMAL;
    private Rectangle cachedDisplayRect = null;
    private boolean UISelection  = false;
    
    
    private EventHandler onSelectedIndexChanged;
    private DrawItemEventHandler onDrawItem;

    
    private static final int tabBaseReLayoutMessage = Windows.RegisterWindowMessage("WFCTabBaseReLayout");

    
    private Object[] items;
    private int itemCount;
    private int updateCount;

    /**
     * Constructs a TabBase object, usually as the base class for a TabStrip or TabControl.
     */
    public TabBase() {}

    /**
     * Assigns a delegate to the drawItem event.  This
     * event is called for list boxes whose listStyle property is set to
     * TabDrawMode.OWNERDRAWFIXED , and contains a Graphics object in which
     * people should paint the item.
     * Duplicates adds are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Assigns a delegate to the selectedIndexChanged event.   This
     * event is sent whenever a new tab is selected through UI or programmatically.
     * Duplicates are not filtered out.
     *
     * @param value New Event Handler to install for this event.
     */
    public final void addOnSelectedIndexChanged(EventHandler value) {}

    
    final int addItem(Object item, TCITEM_T tcitem) {}

    
    final void applySize() {}

    
    final void beginUpdate() {}

    
    final void endUpdate() {}

    
    final void endUpdate(boolean invalidate) {}

    
    final int findItem(Object item) {}

    
    final int findItemExact(Object item) {}
    /**
     * Retrieves a value indicating where the tabs are located in the container control. 
     * The possibilities are TOP (the default), BOTTOM, LEFT, and RIGHT.  When alignment
     * is left or right, the multiline property is ignored and multiline is implicitly on.
     * If the alignment is anything other than top, TabAppearance.FLAT_BUTTONS degenerates
     * to TabAppearance.BUTTONS.
     *
     * @return alignment    a TabAlignment value which indicates where in the control
     * the tabs are.
     */
    public final int getAlignment() {}

    /**
     * Retrieves a value indicating whether the tabs in this control have the appearance of
     * standard tabs, three-dimensional buttons, or flat buttons. 
     *
     * @return integer with one of the following values:
     *          TabAppearance.NORMAL  - indicates they are painted as normal tabs.
     *          TabAppearance.Buttons - indicates they are painted like taskbar btns
     */
    public final int getAppearance() {}

    /**
     * Retrieves the rectangle that represents the display area of the control (the area not
     * used to draw the tabs).   This
     * is typically the rectangle you want to use to place the individual
     * children of the tab strip.
     *
     * @return Rectangle    with the Display area inside the tab strip.
     */
    public final Rectangle getDisplayRect() {}

    /**
     * Returns the parameters needed to create the handle.  Inheriting classes
     * can override this to provide extra functionality.  They should not,
     * however, forget to call super.getCreateParams() first to get the struct
     * filled up with the basic info.
     *
     * @return CreateParams     an object with all the info needed to create
     *                          the control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves a value indicating whether the system draws the tabs or whether the parent
     * control draws the tabs.   This will indicate
     * if the system draws it, or if the user paints each item manually.  It also
     * indicates whether or not items have to be of the same height.
     *
     * @return drawMode A TabDrawMode value which indicates whether the control is owner drawn.
     */
    public final int getDrawMode() {}

    /**
     * Retrieves a boolean value indicating whether tabs are highlighted as the mouse
     * pointer passes over them. 
     *
     * @return hotTrack whether hot tracking is enabled.
     */
    public final boolean getHotTrack() {}

    /**
     * Retrieves the image list control associated with this control.   This is where tabs that have imageIndex
     * set will get there images from.
     *
     * @return imageList An image list control.
     */
    public final ImageList getImageList() {}

    
    final Object getItem(int index) {}

    /**
     * This has package scope so that TabStrip and TabControl can call it.
     * @internalonly
     */
    protected Object[] getItems() {}

    /**
     * This has package scope so that TabStrip and TabControl can call it.
     * @internalonly
     */
    protected Object[] getItems(Class baseType) {}

    /**
     * Retrieves the height of all tabs and retrieves the width of tabs in a fixed-width (sizeMode set to TabSizeMode.FIXED) or owner-drawn
     * (drawMode set to TabDrawMode.OWNERDRAWFIXED)
     * control. 
     *
     * @return itemSize the size of each tab when tab sizes are fixed.
     */
    public final Point getItemSize() {}

    /**
     * Retrieves a boolean value indicating whether multiple rows of tabs can be
     * displayed to allow all tabs to be visible at one time.   By default [when
     * this property is false], if there are more tabs than available display
     * space, arrows are shown to let the user navigate between the extra
     * tabs, but only one row is shown.  If this property is set to true, then
     * Windows spills extra tabs over on to second rows.
     *
     * @return boolean indicating whether or not multiple rows are allowed
     */
    public final boolean getMultiline() {}

    /**
     * Retrieves the amount of horizontal and vertical space (padding) around the text and
     * image displayed on the tabs in this control. 
     * You can specify both horizontal and vertical padding.
     *
     * @return Point  width contains the horizontal padding and height contains
     *               the vertical padding.
     */
    public final Point getPadding() {}

    /**
     * Retrieves the number of rows of tabs displayed in the control.   This is most commonly used when the Multline property
     * is 'true' and you want to know how many rows the tabs are currently
     * taking up.
     *
     * @return int  Count of rows currently being used.
     */
    public final int getRowCount() {}

    /**
     * Retrieves the index of the selected tab in this control.   If the value is -1, there is currently no selection.  If the
     * value is 0 or greater, than the value is the index of the currently
     * selected tab.
     *
     * @return int  The currently selected tab.
     */
    public final int getSelectedIndex() {}

    
    final Object getSelectedItem() {}

    /**
     * Retrieves a value indicating whether the size of each tab in this control is adjusted
     * to what is displayed on the tab, whether the sizes of the tabs are adjusted so that each
     * row of tabs fills the entire width of this control, or whether all tabs are assigned the
     * same fixed width.   However, you can also
     * set it such that the tabs are stretched to fill out the right extent
     * of the strip, if necessary, or you can set it such that all tabs
     * the same width.
     *
     * @return int with one of the following values:
     *          TabSizeMode.NORMAL     - tabs are wide as they need to be only.
     *          TabSizeMode.FILL_TO_RIGHT- makes sure that tabs at least make it
     *              to the right extent of the strip.
     *          TabSizeMode.FIXED      - all tabs are the same width
     */
    public final int getSizeMode() {}

    /**
     * Retrieves a boolean value indicating whether to display ToolTips for tabs that
     * have ToolTip text associated with them. 
     *
     * @return whether tooltips are being shown.
     */
    public final boolean getShowToolTips() {}

    /**
     * Retrieves the number of tabs contained in this control. 
     * @return int containing the number of valid tabs
     */
    public final int getTabCount() {}

    /**
     * Retrieves the bounding rectangle for the specified tab in this control. 
     *
     * @param index     Index to get the bouding rect for
     *
     * @return Rectangle with said bounding rect
     */
    public final Rectangle getTabRect(int index) {}

    /**
     * @internalonly
     */
    public abstract TCITEM_T getTCITEM(Object item);

    /**
     * This has package scope so TabStrip and TabControl can override and provide their
     * tooltip text.
     * @internalonly
     */
    protected String getToolTipText(Object item) {}

    
    final void insert(int index, Object item) {}

    
    final int insertItem(int index, Object item, TCITEM_T tcitem) {}

    /**
     * This is a notification that the handle has been created.
     * We do some work here to configure the handle.
     * Overriders should call super.onCreateHandle()
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Triggers the drawItem event.   Inheriting controls
     * should use this to know when the event is fired [this is preferable to
     * adding an event handler on yourself for this event].  They should,
     * however, remember to call super.onDrawItem(e); to ensure the event is
     * still fired to external listeners
     *
     * @param e     DrawItemEvent object with the details
     */
    protected void onDrawItem(DrawItemEvent e) {}

    /**
     * We override this to get tabbing functionality.
     * If overriding this, remember to call super.onKeyDown.
     * @internalonly
     */
    protected void onKeyDown(KeyEvent ke) {}

    /**
     * @internalonly
     */
    protected void onResize(Event e) {}

    /**
     * Triggers the selectedIndexChanged event.   Inheriting controls
     * should use this to know when the event is fired [this is preferable to
     * adding an event handler on yourself for this event].  They should,
     * however, remember to call super.onSelectedIndexChanged(e); to ensure the event is
     * still fired to external listeners
     *
     * @param e     Event object with the details
     */
    protected void onSelectedIndexChanged(Event e) {}

    /**
     * We override this to get the Ctrl and Ctrl-Shift Tab functionality.
     * @internalonly
     */
    protected boolean processKeyPreview(Message m) {}

    
    final void updateSize() {}

    /**
     * @internalonly
     */
    protected void updateStylesCore() {}

    protected void propertyChanged(int property) {}

    protected void recreateHandle() {}

    /**
     * Removes all tabs from this control.   All values and data are discarded.
     */
    public final void removeAll() {}

    
    final void removeItem(int index) {}

    /**
     * Removes the delegate that is assigned to the drawItem event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnDrawItem(DrawItemEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the selectedIndexChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnSelectedIndexChanged(EventHandler value) {}

    /**
     * Sets a value indicating where the tabs are located in the container control. 
     * The possibilities are TOP (the default), BOTTOM, LEFT, and RIGHT.  When alignment
     * is left or right, the multiline property is ignored and multiline is implicitly on.
     * If the alignment is anything other than top, TabAppearance.FLAT_BUTTONS degenerates
     * to TabAppearance.BUTTONS.
     *
     * @param alignment    a TabAlignment value which indicates where in the control
     * the tabs are.
     */
    public final void setAlignment(int alignment) {}

    /**
     * Sets a value indicating whether the tabs in this control have the appearance of
     * standard tabs, three-dimensional buttons, or flat buttons. 
     *
     * @param value with one of the following values:
     *          TabAppearance.NORMAL  - indicates they are painted as normal tabs.
     *          TabAppearance.Buttons - indicates they are painted like taskbar btns
     */
    public final void setAppearance(int value) {}

    /**
     * Sets the size the display rectangle for this control.   Note that this is only guaranteed to be valid until tabs
     * are added or removed.  After that, the display size can change when
     * the number of visible rows changes. [Note: zero tabs == zero rows]
     *
     * @param value     New Desired Display Size.  The size of the tabstrip
     *                  will be adjusted to reflect this.
     */
    public final void setDisplayRectSize(int width, int height) {}

    /**
     * Sets the size the display rectangle for this control.   Note that this is only guaranteed to be valid until tabs
     * are added or removed.  After that, the display size can change when
     * the number of visible rows changes. [Note: zero tabs == zero rows]
     *
     * @param value     New Desired Display Size.  The size of the tabstrip
     *                  will be adjusted to reflect this.
     */
    public final void setDisplayRectSize(Point p) {}

    /**
     * Sets a value indicating whether the system draws the tabs or whether the parent control
     * draws the tabs.   This lets the user control whether
     * or not they paint the items themselves [default is not] and whether
     * or not the items are all the same height [default yes]
     *
     * @param value New Value of the TabStrip drawing style
     * @see com.ms.wfc.ui.TabDrawMode
     */
    public final void setDrawMode(int value) {}

    /**
     * Sets a boolean value indicating whether tabs are highlighted as the mouse
     * pointer passes over them. 
     *
     * @param hotTrack whether hot tracking should be enabled.
     */
    public final void setHotTrack(boolean hotTrack) {}

    /**
     * Sets the image list control associated with this control.   This is where tabs that have imageIndex
     * set will get there images from.
     *
     * @param imageList An image list control.
     */
    public final void setImageList(ImageList imageList) {}

    
    final void setItem(int index, Object item, TCITEM_T tcitem) {}

    /**
     * Sets the height of tabs; sets the width of tabs in a fixed-width (sizeMode set to TabSizeMode.FIXED) or owner-drawn
     * (drawMode set to TabDrawMode.OWNERDRAWFIXED)
     * control.  Sets the height for the tabs in any mode.
     *
     * @param itemSize the size of each tab when tab sizes are fixed.
     */
    public final void setItemSize(Point size) {}

    /**
     * Sets a boolean value indicating whether multiple rows of tabs can be displayed
     * to allow all tabs to be visible at one time.   By default [when
     * this property is false], if there are more tabs than available display
     * space, arrows are shown to let the user navigate between the extra
     * tabs, but only one row is shown.  If this property is set to true, then
     * Windows spills extra tabs over on to second rows.
     *
     * @param value indicating whether or not more than one row should be
     *              allowed
     */
    public final void setMultiline(boolean value) {}

    /**
     * Sets the amount of horizontal and vertical space (padding) around the text and image
     * displayed on the tabs in this control. 
     * You can specify both horizontal and vertical padding.
     *
     * @return Point  width contains the horizontal padding and height contains
     *                the vertical padding.
     */
    public final void setPadding(Point value) {}

    /**
     * Selects the specified tab. 
     *
     * @param index  Index of tab to select
     */
    public void setSelectedIndex(int index) {}


    
    int setSelectedItem(Object item) {}

    /**
     * Sets a value indicating whether the size of each tab in this control is adjusted to
     * what is displayed on the tab, whether the sizes of the tabs are adjusted so that each row
     * of tabs fills the entire width of this control, or whether all tabs are assigned the same,
     * fixed width.   However, you can also
     * set it such that the tabs are stretched to fill out the right extent
     * of the strip, if necessary, or you can set it such that all tabs
     * the same width.
     *
     * @param value with one of the following values:
     *          TabSizeMode.NORMAL     - tabs are wide as they need to be only.
     *          TabSizeMode.FILL_TO_RIGHT- makes sure that tabs at least make it
     *              to the right extent of the strip.
     *          TabSizeMode.FIXED      - all tabs are the same width
     */
    public final void setSizeMode(int value) {}

    /**
     * Sets a boolean value indicating whether to display ToolTips for tabs that have
     * ToolTip text associated with them. 
     *
     * @param showToolTips whether tooltips should be shown.
     */
    public final void setShowToolTips(boolean showToolTips) {}
    
    /**
     * @internalonly
     */
    protected void updateTabSelection(boolean fUISelection) {}
    
    
    private void wmNeedText(Message m) {}

    
    private void wmReflectDrawItem(Message m) {}

    
    private void wmSelChange(Message m) {}

    
    private void wmTabBaseReLayout(Message m) {}

    /**
     * The tab's window procedure.  Inheritng classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the tab continues to function properly.
     *
     * @param m     A Windows Message Object.
     * @internalonly
     */
    protected void wndProc(Message m) {}

    /**
     * Defines the base class that contains common functionality for the TabStrip and TabControl classes. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {

        public static final PropertyInfo alignment = new PropertyInfo(
            TabBase.class, "alignment", com.ms.wfc.ui.TabAlignment.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.TabAlignment.TOP)),
            new DescriptionAttribute(Sys.getString("TabBaseAlignmentDescr")));

        public static final PropertyInfo drawMode = new PropertyInfo(
            TabBase.class, "drawMode", com.ms.wfc.ui.TabDrawMode.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.TabDrawMode.NORMAL)),
            new DescriptionAttribute(Sys.getString("TabBaseDrawModeDescr")));

        public static final PropertyInfo hotTrack = new PropertyInfo(
            TabBase.class, "hotTrack", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("TabBaseHotTrackDescr")));

        public static final PropertyInfo imageList = new PropertyInfo(
            TabBase.class, "imageList", ImageList.class,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.NULL,
            new DescriptionAttribute(Sys.getString("TabBaseImageListDescr")));

        public static final PropertyInfo itemSize = new PropertyInfo(
            TabBase.class, "itemSize", Point.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Point(TabBase.DEFAULT_ITEMSIZE)),
            new DescriptionAttribute(Sys.getString("TabBaseItemSizeDescr")));

        public static final PropertyInfo multiline = new PropertyInfo(
            TabBase.class, "multiline", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("TabBaseMultilineDescr")));

        public static final PropertyInfo padding = new PropertyInfo(
            TabBase.class, "padding", Point.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Point(TabBase.DEFAULT_PADDING)),
            new DescriptionAttribute(Sys.getString("TabBasePaddingDescr")));

        public static final PropertyInfo selectedIndex = new PropertyInfo(
            TabBase.class, "selectedIndex", int.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.NEGATIVE_ONE,
            new DescriptionAttribute(Sys.getString("selectedIndexDescr")));

        public static final PropertyInfo sizeMode = new PropertyInfo(
            TabBase.class, "sizeMode", TabSizeMode.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.TabSizeMode.NORMAL)),
            new DescriptionAttribute(Sys.getString("TabBaseSizeModeDescr")));

        public static final PropertyInfo showToolTips = new PropertyInfo(
            TabBase.class, "showToolTips", boolean.class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("TabBaseShowToolTipsDescr")));

        public static final PropertyInfo appearance = new PropertyInfo(
            TabBase.class, "appearance", TabAppearance.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.TabAppearance.NORMAL)),
            new DescriptionAttribute(Sys.getString("TabBaseAppearanceDescr")));

        public static final EventInfo drawItem = new EventInfo(
            TabBase.class, "drawItem", DrawItemEventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("drawItemEventDescr")));

        public static final EventInfo selectedIndexChanged = new EventInfo(
            TabBase.class, "selectedIndexChanged", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("selectedIndexChangedEventDescr")));

        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}