//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.dll.DllLib;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.wfc.util.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a tab strip control.   This control provides one or more rows of tabs that the
 * user can select one at a time.  After each selection, a notification
 * is provided that allows for changing of UI.
 *
 * Two basic UI modes supported are the traditional tabs seen in Property
 * Page type scenarios and a button-style tab, as in the taskbar found in
 * Windows 95 and Windows NT4.
 *
 * @security(checkClassLinking=on)
 */
public class TabStrip extends TabBase {

    /**
     * Adds a tab to the tab strip.   The TabItem encapsulates
     * the text, tooltiptext, and imagelist for a TabStrip.
     *
     * @param item  TabItem that encapsulates the info for each tab.
     *
     * @return index of where the item was inserted.
     */
    public final int addTab(TabItem item) {}

    /**
     * Adds a tab to the tab strip. 
     *
     * @param text The text for the tab
     *
     * @return index of where the item was inserted.
     */
    public final int addTab(String text) {}

    /**
     * Searches for the specified tab in the tab strip, returning the zero-based index of the
     * tab within the tab strip if it is found. equals)
     * and returns the index, or -1 if it doesn't exist.
     * 
     * @param item The TabItem to search for
     *
     * @return index of where the item was found, or -1.
     */
    public final int findTab(TabItem item) {}

    /**
     * Searches for the specified tab in the tab strip, returning the zero-based index of the
     * tab within the tab strip if it is found. equals)
     * and returns the index, or -1 if it doesn't exist.
     * 
     * @param text The text to search for
     *
     * @return index of where the item was found, or -1.
     */
    public final int findTab(String text) {}

    /**
     * Retrieves the tab that is selected in this tab strip. 
     *
     * @return Object   the tabItem that is currently selected.
     */
    public final TabItem getSelectedTab() {}


    /**
     * Retrieves the specified tab.  All indices are zero-based. An exception
     * is thrown if the index is out of range.
     *
     * @param index     Index of the item we wish to retrieve.
     *
     * @return TabItem  the tabItem at the given index.
     *
     * Throws IllegalArgument Exception if the index is out of range.
     */
    public final TabItem getTab(int index) {}

    /**
     * Retrieves all the tabs in this tab strip. 
     *
     * @return TabItem[].  The first item is the 0th element, and the last
     *         item in the TabStrip is last in the array.
     */
    public final TabItem[] getTabs() {}

    /**
     * Retrieves the text for the specified tab. 
     *
     * @param index     The index of the tab for which we want the text.

     * @return the text of the tab.
     */
    public final String getTabText(int index) {}

    /**
     * @internalonly
     */
    public TCITEM_T getTCITEM(Object item) {}

    /**
     * Adds a tab to the tab strip at the specified position.  An exception is thrown if
     * the index is out of range.
     *
     * @param index     Where in the tabstrip [zero-based] it should be 
     *                  inserted.
     * @param item      The value of the item you want inserted
     *
     * Throws IllegalArgument Exception if the index is out of range.
     */
    public final int insertTab(int index, TabItem item) {}

    /**
     * Adds a tab to the tab strip at the specified position.  An exception is thrown if
     * the index is out of range.
     *
     * @param index     Where in the tabstrip [zero-based] it should be 
     *                  inserted.
     * @param text      The string you want inserted
     *
     * Throws IllegalArgument Exception if the index is out of range.
     */
    public final int insertTab(int index, String text) {}

    /**
     * @internalonly
     */
    protected String getToolTipText(Object item) {}

    /**
     * Removes the specified tab from the tab strip.  The tab and it's
     * data are discarded.
     *
     * @param index     Index of the tab to remove.
     */
    public final void removeTab(int index) {}

    /**
     * @internalonly
     */
    public void setComponentSite(IComponentSite value) {}

    /**
     * Selects the specified tab in this tab strip. equals a tab in the
     * list.  The return value is the index of the tab that was selected,
     * or -1 if no tab was selected.
     *
     * @param tab      Tab to select.
     *
     * @return index    Index of selected tab.
     */
    public final int setSelectedTab(TabItem tab) {}

    /**
     * Selects the specified tab in this tab strip.  The return value 
     * is the index of the tab that is selected,
     * or -1 if no tab was selected.
     *
     * @param text      Name of tab to select.
     *
     * @return index    Index of selected tab.
     */
    public final int setSelectedTab(String text) {}

    /**
     * Replaces the specified tab.  If there is no value at the supplied index, an exception is
     * thrown. Otherwise, the value becomes the newly supplied one
     *
     * @param index   Index of tab to change the value for
     * @param item    New value for said index
     *
     * Throws IllegalArgument Exception if the index is not currently assigned
     * a value.
     */
    public final void setTab(int index, TabItem item) {}

    /**
     * Replaces the specified tab.  If there is no value at the supplied index, an exception is
     * thrown. Otherwise, the value becomes the newly supplied one
     *
     * @param index   Index of tab to change the value for
     * @param text    New text for said index
     *
     * Throws IllegalArgument Exception if the index is not currently assigned
     * a value.
     */
    public final void setTab(int index, String text) {}

    /**
     * Adds a set of tabs to the tab strip after removing all existing tabs.   All old values in the TabStrip are
     * discarded and lost
     *
     * @param value Array of TabItems that will be the new tabs in the strip.
     */
    public final void setTabs(TabItem[] value) {}

    /**
     * Adds a set of tabs to the tab strip after removing all existing tabs.   All old values in the TabStrip are
     * discarded and lost
     *
     * @param value Array of strings that will be the new tabs in the strip.
     */
    public final void setTabs(String[] value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    void updateTab(TabItem item) {}

    /**
     * Encapsulates a tab strip control. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends TabBase.ClassInfo {

        public static final PropertyInfo tabs = new PropertyInfo(
            TabStrip.class, "tabs", TabItem[].class,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.EMPTY_ARRAY,
            new DescriptionAttribute(Sys.getString("TabStripTabsDescr")));

        public String getDefaultPropertyName() {}

        public void getProperties(IProperties props) {}
    }
}