//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Defines a group of constants that indicate how text should be formatted.drawString calls to format
 * the text a certain way.
 * 
 * @see Graphics
 *
 * @security(checkClassLinking=on)
 */
public class TextFormat {

    /**
     * Specifies that the text should be formatted along the bottom of a rectangle.
     */
    public static final int BOTTOM = win.DT_BOTTOM | win.DT_SINGLELINE;

    /**
     * Specifies that the text should be centered horizontally.
     */
    public static final int HORIZONTALCENTER = win.DT_CENTER;

    /**
     * Specifies that the text should be formatted in the same manner in which the Edit
     * control formats text.  The
     * average character width is calculated in the same manner, and the last
     * line of multiline text is not drawn if it would only be partially visible.
     */
    public static final int EDITCONTROL = win.DT_EDITCONTROL;

    /**
     * Specifies that an ellipsis should be placed at the end of the text if the text is too
     * long to fit into the rectangle.
     */
    public static final int ENDELLIPSIS = win.DT_END_ELLIPSIS;

    /**
     * Specifies that the tabs in the text should be expanded.
     */
    public static final int EXPANDTABS = win.DT_EXPANDTABS;

    /**
     * Specifies that the text should be aligned to the left.
     */
    public static final int LEFT = win.DT_LEFT;

    /**
     * Specifies that an ellipsis should be placed in the middle of the text. If the text
     * contains backslashes (\), as much of the text that appears after the last backslash
     * character is preserved as is possible.
     */
    public static final int PATHELLIPSIS = win.DT_PATH_ELLIPSIS;

    /** 
     * Specifies that the text should be aligned to the right.
     */
    public static final int RIGHT = win.DT_RIGHT;

    /** 
     * The text is laid from right to left, as when using Hebrew or Arabic fonts.
     */
    public static final int RIGHTTOLEFT = win.DT_RTLREADING;

    /**
     * Specifies that the text should be aligned along the top of the rectangle.
     */
    public static final int TOP = win.DT_TOP | win.DT_SINGLELINE;

    /**
     * Specifies that the text should be aligned vertically.
     */
    public static final int VERTICALCENTER = win.DT_VCENTER | win.DT_SINGLELINE;

    /**
     * Specifies that words should automatically be broken at the end of a line.
     */
    public static final int WORDBREAK = win.DT_WORDBREAK;

    /**
     * Specifies that carriage returns and line feed characters do not cause line breaks.  Carriage returns do not break the line.
     */
    public static final int SINGLELINE = win.DT_SINGLELINE;

    /**
     * Specifies that prefixes should be turned off.  Prefix characters are menumonic
     * characters that begin with a "&".  Normall, Windows ommits the "&" and draws
     * the next character with an underscore.
     */
    public static final int NOPREFIX = win.DT_NOPREFIX;

    private static final int ALL = BOTTOM | HORIZONTALCENTER | EDITCONTROL |ENDELLIPSIS |
        EXPANDTABS | LEFT | PATHELLIPSIS | RIGHT | RIGHTTOLEFT | TOP |
        VERTICALCENTER | WORDBREAK | SINGLELINE | NOPREFIX;
                    
    /**
     * Retrieves a boolean value that indicates whether a specified value is
     * a valid member of the TextFormat class.
     * 
     * @param value The value to check
     * @return <b>true</b> if the value is valid, <b>false</b> if not.
     */
    public static boolean valid(int value) {}
}