//STRIPPEDSOURCE//

package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;

/**
 * Encapsulates a trackbar control (also known as a slider control), which contains a  slider for selecting a value in a range.   You can configure ranges through which it should
 * scroll, and also define increments for off-button clicks.  It can be
 * aligned horizontally or vertically.  You can also configure how many
 * 'ticks' are shown for the total range of values
 *
 * @security(checkClassLinking=on)
 */
public class TrackBar extends Control {

    private static final Object EVENT_SCROLL = new Object();
    private static final Object EVENT_VALUECHANGED = new Object();

    private boolean autoSize = true;
    private int largeChange = 5;
    private int maximum = 10;
    private int minimum = 0;
    private int orientation = Orientation.HORIZONTAL;
    private int value = 0;
    private int smallChange = 1;
    private int tickFrequency = 1;
    private int tickStyle = TickStyle.BOTTOMRIGHT;

    private int requestedDim;

    /**
     * Creates a new TrackBar control with a default range of 0..10 and
     * ticks shown every value.
     */
    public TrackBar() {}

    /**
     * Assigns a delegate to the scroll event.  This
     * event is called whenever the user moves the thumb in any way, shape,
     * or form.
     *
     * @param value     New Event Handler to install for this event.
     */
    public void addOnScroll(EventHandler value) {}

    /**
     * Assigns a delegate to the valueChanged event.  This
     * event is called whenever the scrollbar's current position changes,
     * whether it be because of mouse, keyboard, or programmatic input.
     *
     * @param value New Event Handler to install for this event.
     */
    public void addOnValueChanged(EventHandler eh) {}

    
    private void adjustSize() {}

    /**
     * Retrieves a boolean value indicating whether the trackbar automatically adjusts
     * its size to fit the size of the slider.   If <b>true</b>, the
     * TrackBar will adjust either it's height or width [depending on
     * <i>orientation</i> to make sure that only the required amount of
     * space is used.
     *
     * @return boolean  <b>true</b> if it is, <b>false</b> if not.
     */
    public boolean getAutoSize() {}

    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return     a CreateParams object with the information for creating
     *             this Control.
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Returns the current foreground color of the TrackBar.  Note that users
     * are unable to change this.  It is always Color.WINDOWTEXT
     *
     * @return the current foreground color [Color.WINDOWTEXT]
     */
    public Color getForeColor() {}

    /**
     * Retrieves the number of units the slider moves when the user presses the PAGE UP or
     * PAGE DOWN key or clicks in the control on either side of the slider.   These include, Clicking the
     * mouse to the side of the button, or using the PgUp/PgDn keys on the
     * keyboard.
     *
     * @return          the number of ticks to move the thumb by when a
     *                  "large change" action occurs.
     */
    public int getLargeChange() {}

    /**
     * Retrieves the maximum value of the trackbar. 
     *
     * @return     the upper limit for the range of values currently in
     *             use by this TrackBar
     */
    public int getMaximum() {}

    /**
     * Retrieves the minimum value of the trackbar. 
     *
     * @return    The lower limit for the range of values currently in
     *            use by this TrackBar
     */
    public int getMinimum() {}

    /**
     * Retrieves a value indicating whether the trackbar is oriented horizontally or
     * vertically.  Valid values are from
     * the Orientation enumeration.  The control currently supports being
     * oriented horizontally and vertically.
     *
     * @return     A value from the Orientation enumeration controlling
     *             the TrackBars orientation.
     *
     * @see com.ms.wfc.ui.Orientation
     */
    public int getOrientation() {}

    
    private int getPreferredDimension() {}

    /**
     * Retrieves the number of units the slider moves when the user presses the LEFT ARROW,
     * RIGHT ARROW, UP ARROW, or DOWN ARROW key.   These are most commonly
     * seen by using the arrow keys to move the TrackBar thumb around.
     *
     * @return      The number of ticks to move the thumb by when a
     *              "small change" action occurs.
     */
    public int getSmallChange() {}

    /**
     * Retrieves a value indicating where tick marks appear in a trackbar.   This affects
     * both where the ticks will be drawn in relation to the moveable thumb,
     * and how the thumb itself will be drawn.  values are taken from the
     * TickStyle enumeration.
     *
     * @return      The new style with which this TrackBar will draw
     *
     * @see com.ms.wfc.ui.TickStyle
     */
    public int getTickStyle() {}

    /**
     * Retrieves the number of units between tick marks.   For a TrackBar with a
     * range of 0..100, it might be impractical to draw all 100 ticks for a
     * very small control.  Passing in a value of 5 here would only draw
     * 20 ticks -- i.e. Each tick would represent 5 units in the TrackBars
     * range of values.
     *
     * @return      The number of units in the TrackBars range that each
     *              tick represents.
     */
    public int getTickFrequency() {}

    /**
     * Retrieves the value of the trackbar (the position of the trackbar slider).   This value must
     * be between the lower and upper limits of the TrackBar range, of course.
     *
     * @return     The new location for the TrackBar thumb.
     */
    public int getValue() {}

    /**
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Triggers the scroll event.   Inheriting classes should override
     * this method in favor of actually adding an EventHandler for this
     * event.  Inheriting classes should not forget to call
     * <i>super.onScroll(e)</i>
     *
     * @param e     Event object with the information for the Event.
     */
    protected void onScroll(Event e) {}

    /**
     * Actually fires the "valueChanged" event.  
     * @hidden
     * @internalonly
     */
    protected void onValueChanged(Event e) {}

    /**
     * Triggers the propertyChanged event.  Inheriting
     * controls can overide this method to get property change notification on
     * basic properties. Inherting controls must call <i>super.propertyChanged</i>.
     *
     * @param property Property that changed.
     */
    protected void propertyChanged(int property) {}

    /**
     * Removes the delegate that is assigned to the scroll event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnScroll(EventHandler value) {}

    /**
     * Removes the delegate that is assigned to the valueChanged event. 
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnValueChanged(EventHandler eh) {}

    /**
     * Sets a boolean value indicating whether the trackbar automatically adjusts its
     * size to fit the size of the slider. 
     *
     * @param value     Boolean controlling whether this is turned on or
     *                  off.
     */
    public void setAutoSize(boolean value) {}

    /**
     * Overrides Control.setBoundsCore to enforce autoSize.
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}

    /**
     * You are unable to change the foreground color of a TrackBar control.
     *
     * @param value This parameter is ignored.
     */
    public void setForeColor(Color value) {}

    /**
     * Sets the number of units the slider moves when the user presses the PAGE UP or PAGE
     * DOWN key or clicks in the control on either side of the slider.   These include, Clicking the
     * mouse to the side of the button, or using the PgUp/PgDn keys on the
     * keyboard.
     *
     * @param value     The number of ticks to move the thumb by when a
     *                  "large change" action occurs.
     */
    public void setLargeChange(int value) {}

    /**
     * Sets the maximum value of the trackbar. 
     *
     * @param value     The upper limit for the range of values currently in
     *                  use by this TrackBar
     */
    public void setMaximum(int value) {}

    /**
     * Sets the minimum value of the trackbar. 
     *
     * @param value     The lower limit for the range of values currently in
     *                  use by this TrackBar
     */
    public void setMinimum(int value) {}

    /**
     * Sets a value indicating whether the trackbar is oriented horizontally or vertically.  Valid values are from
     * the Orientation enumeration.  The control currently supports being
     * oriented horizontally and vertically.
     *
     * @param value     A value from the Orientation enumeration controlling
     *                  the TrackBars orientation.
     *
     * @see com.ms.wfc.ui.Orientation
     */
    public void setOrientation(int value) {}

    /**
     * Sets the minimum and maximum values for the trackbar. 
     * The values passed are both the lower and upper limits to the range
     * with which the control will work.
     *
     * @param minValue      The lower limit of the TrackBars range.
     * @param maxValue      The upper limit of the TrackBars range.
     */
    public void setRange(int minValue, int maxValue) {}

    /**
     * Sets the number of units the slider moves when the user presses the LEFT ARROW, RIGHT
     * ARROW, UP ARROW, or DOWN ARROW key.   These are most commonly
     * seen by using the arrow keys to move the TrackBar thumb around.
     *
     * @param value     The number of ticks to move the thumb by when a
     *                  "small change" action occurs.
     */
    public void setSmallChange(int value) {}

    /**
     * Sets a value indicating where tick marks appear in a trackbar.   This affects
     * both where the ticks will be drawn in relation to the moveable thumb,
     * and how the thumb itself will be drawn.  values are taken from the
     * TickStyle enumeration.
     *
     * @param value     The new style with which this TrackBar will draw
     *
     * @see com.ms.wfc.ui.TickStyle
     */
    public void setTickStyle(int value) {}

    /**
     * Sets the number of units between tick marks.   For a TrackBar with a
     * range of 0..100, it might be impractical to draw all 100 ticks for a
     * very small control.  Passing in a value of 5 here would only draw
     * 20 ticks -- i.e. Each tick would represent 5 units in the TrackBars
     * range of values.
     *
     * @param value     The number of units in the TrackBars range that each
     *                  tick represents.
     */
    public void setTickFrequency(int value) {}

    /**
     * Sets the value of the trackbar (the position of the trackbar slider).   This value must
     * be between the lower and upper limits of the TrackBar range, of course.
     *
     * @param value     The new location for the TrackBar thumb.
     */
    public void setValue(int value) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    /**
     * The button's window procedure.  Inheriting classes can override this
     * to add extra functionality, but should not forget to call
     * super.wndProc(m); to ensure the button continues to function properly.
     *
     * @param m     A Windows Message Object.
     * @internalonly
     */
    protected void wndProc(Message m) {}

    /**
     * Encapsulates a trackbar control (also known as a slider control), which contains a  slider for selecting a value in a range.   This is used by design environments to determine
     * properties of the Control
     *
     * @see com.ms.wfc.core.ClassInfo
     *
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo autoSize = new PropertyInfo(
            TrackBar.class, "autoSize", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("EditAutoSizeDescr")));

        public static final PropertyInfo largeChange = new PropertyInfo(
            TrackBar.class, "largeChange", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(5)),
            new DescriptionAttribute(Sys.getString("TrackBarLargeChangeDescr")));

        public static final PropertyInfo maximum = new PropertyInfo(
            TrackBar.class, "maximum", Integer.TYPE,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(10)),
            new DescriptionAttribute(Sys.getString("TrackBarMaximumDescr")));

        public static final PropertyInfo minimum = new PropertyInfo(
            TrackBar.class, "minimum", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            new DescriptionAttribute(Sys.getString("TrackBarMinimumDescr")));

        public static final PropertyInfo orientation = new PropertyInfo(
            TrackBar.class, "orientation", Orientation.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.Orientation.HORIZONTAL)),
            new DescriptionAttribute(Sys.getString("TrackBarOrientationDescr")));

        public static final PropertyInfo smallChange = new PropertyInfo(
            TrackBar.class, "smallChange", Integer.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.ONE,
            new DescriptionAttribute(Sys.getString("TrackBarSmallChangeDescr")));


        public static final PropertyInfo tickStyle = new PropertyInfo(
            TrackBar.class, "tickStyle", TickStyle.class,
            CategoryAttribute.Appearance,
            new DefaultValueAttribute(new Integer(com.ms.wfc.ui.TickStyle.BOTTOMRIGHT)),
            new DescriptionAttribute(Sys.getString("TrackBarTickStyleDescr")));

        public static final PropertyInfo tickFrequency = new PropertyInfo(
            TrackBar.class, "tickFrequency", Integer.TYPE,
            CategoryAttribute.Appearance,
            DefaultValueAttribute.ONE,
            new DescriptionAttribute(Sys.getString("TrackBarTickFrequencyDescr")));

        public static final PropertyInfo value = new PropertyInfo(
            TrackBar.class, "value", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            BindableAttribute.YES,
            new DescriptionAttribute(Sys.getString("TrackBarValueDescr")));


        public static final EventInfo scroll = new EventInfo(
            TrackBar.class, "scroll", EventHandler.class,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("TrackBarOnScrollDescr")));

        public static final EventInfo valueChanged = new EventInfo(
            TrackBar.class, "valueChanged", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("valueChangedEventDescr")));        

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO);

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public String getDefaultEventName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}
    }
}