//STRIPPEDSOURCE//


package com.ms.wfc.ui;

import com.ms.dll.*;
import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.lang.Delegate;

/**
 * Encapsulates a Windows tree view control. 
 * @security(checkClassLinking=on)
 */
public class TreeView extends Control {

    private static final String backSlash = "\\";

    private NodeLabelEditEventHandler onBeforeLabelEdit;
    private NodeLabelEditEventHandler onAfterLabelEdit;
    private TreeViewCancelEventHandler onBeforeCheck;
    private TreeViewEventHandler onAfterCheck;
    private TreeViewCancelEventHandler onBeforeCollapse;
    private TreeViewEventHandler onAfterCollapse;
    private TreeViewCancelEventHandler onBeforeExpand;
    private TreeViewEventHandler onAfterExpand;
    private TreeViewCancelEventHandler onBeforeSelect;
    private TreeViewEventHandler onAfterSelect;
    private ItemDragEventHandler onItemDrag;

    int selectedImageIndex = 0;
    private boolean hideSelection = true;
    int imageIndex = 0;
    private ImageList imageList;
    private int indent = -1;
    private String pathSeparator = backSlash;
    private boolean labelEdit = false;
    private boolean scrollable = true;
    private int borderStyle = BorderStyle.FIXED_3D;
    private boolean checkBoxes = false;
    private boolean showLines = true;
    private boolean showPlusMinus = true;
    private boolean showRootLines = true;
    private boolean sorted = false;
    private boolean hotTracking = false;

    TreeNode editNode;
    TreeNode root = new TreeNode(this);
    HashTable nodeTable = new HashTable();
    private int updateCount;
    private int downButton;
    private boolean clickSeen;

    /**
     * Creates a TreeView control
     */
    public TreeView() {}

    /**
     * Adds a root node to the tree view control. 
     *
     * @param text  Label for new node
     *
     * @return a TreeNode object representing the new node
     */
    public TreeNode addNode(String text) {}

    /**
     * Adds a root node to the tree view control. 
     *
     * @param node The node to add.
     */
    public void addNode(TreeNode node) {}

    /**
     * Assigns a delegate to the beforeLabelEdit event. 
     * The beforeLabelEdit event is fired when the user attempts to begin changing
     * the text of a node in the TreeView.  The event handler can cancel this event,
     * in which case the user won't be allowed to edit the text.  This event can be
     * used to prevent the user from editing specific nodes in the TreeView.  If the
     * labelEdit property of the TreeView is <b>false</b>, this event will not be fired,
     * and all user attempts to edit node labels will be automatically rejected.
     *
     * @param value     NodeLabelEditEventHandler to install.
     */
    public void addOnBeforeLabelEdit(NodeLabelEditEventHandler value) {}

    /**
     * Assigns a delegate to the afterLabelEdit event. 
     * The afterLabelEdit event is fired when the user finishes editing the text of
     * a node in the TreeView.  The labelEdit property of the TreeView must be <b>true</b>
     * to enable the user to do this.  The string to which the user changed the text is
     * passed to the event, and the event handler is given the opportunity to reject
     * the change, in which case the text will revert back to what it was before the
     * user started the change.
     *
     * @param value     NodeLabelEditEventHandler to install.
     */
    public void addOnAfterLabelEdit(NodeLabelEditEventHandler value) {}

    /**
     * Assigns a delegate to the beforeCheck event. 
     *
     * @param value     The event handler to install.
     */
    public void addOnBeforeCheck(TreeViewCancelEventHandler value) {}

    /**
     * Assigns a delegate to the afterCheck event. 
     *
     * @param value     The event handler to install.
     */
    public void addOnAfterCheck(TreeViewEventHandler value) {}

    /**
     * Assigns a delegate to the beforeCollapse event. 
     * The beforeCollapse event is fired when the user attempts to collapse a node.
     * Collapsing a node hides all child nodes of that node from view.
     * The event can be cancelled by the handler, in which case the node won't collapse.
     *
     * @param value     The event handler to install.
     */
    public void addOnBeforeCollapse(TreeViewCancelEventHandler value) {}

    /**
     * Assigns a delegate to the afterCollapse event. 
     * The afterCollapse event is fired after the user has successfully collapsed a node.
     * Collapsing a node hides all child nodes of that node from view.
     *
     * @param value     The event handler to install.
     */
    public void addOnAfterCollapse(TreeViewEventHandler value) {}

    /**
     * Assigns a delegate to the beforeExpand event. 
     * The beforeExpand event is fired when the user attempts to expand a node.
     * Expanding a node causes its child nodes to be displayed.
     * The event can be cancelled by the handler, in which case the node won't expand.
     *
     * @param value     The event handler to install.
     */
    public void addOnBeforeExpand(TreeViewCancelEventHandler value) {}

    /**
     * Assigns a delegate to the afterExpand event. 
     * The afterExpand event is fired after the user has successfully expanded a node.
     * Expanding a node causes its child nodes to be displayed.
     *
     * @param value     The event handler to install.
     */
    public void addOnAfterExpand(TreeViewEventHandler value) {}

    /**
     * Assigns a delegate to the itemDrag event.   A typical response to this
     * event would be to call <b>doDragDrop</b>.
     *
     * @param value     The event handler to install.
     */
    public final void addOnItemDrag(ItemDragEventHandler value) {}

    /**
     * Assigns a delegate to the beforeSelect event. 
     * The onBeforeSelect event is fired when the user attempts to select a node.
     * The event can be cancelled by the handler, in which case the node won't be selected.
     *
     * @param value     The event handler to install.
     */
    public void addOnBeforeSelect(TreeViewCancelEventHandler value) {}

    /**
     * Assigns a delegate to the afterSelect event. 
     * The onAfterSelect event is fired after the user has selected a node.
     *
     * @param value The event handler to install.
     */
    public void addOnAfterSelect(TreeViewEventHandler value) {}

    /**
     * Maintains performance while items are added to the tree view control one at a time by
     * preventing the TreeView control from painting until the endUpdate
     * method is called.  A call to beginUpdate() must be
     * balanced by a following call to endUpdate(). Following a call to
     * beginUpdate(), any redrawing caused by operations performed on the
     * tree view is deferred until the call to endUpdate().
     */
    public void beginUpdate() {}

    /**
     * Collapses all root nodes in the tree view control. 
     */
    public void collapseAll() {}

    /**
     * @internalonly
     */
    protected void createHandle() {}

    
    private void detachImageList(Object sender, Event e) {}

    /**
     * @internalonly
     */
    public synchronized void dispose() {}

    /**
     * Resumes painting the TreeView control after painting is suspended by the beginUpdate method.  A call to beginUpdate() must be
     * balanced by a following call to endUpdate(). Following a call to
     * beginUpdate(), any redrawing caused by operations performed on the
     * combo box is deferred until the call to endUpdate().
     */
    public void endUpdate() {}

    /**
     * Expands all root nodes in the tree view control. 
     */
    public void expandAll() {}

    
    final void forceScrollbarUpdate(boolean delayed) {}

    
    TreeNode nodeFromHandle(int handle) {}

    /**
     * Retrieves a value indicating the kind of border the tree view control has. 
     *
     * @return int representing BorderStyle from wfc.ui.BorderStyle
     * @see wfc.ui.BorderStyle
     */
    public int getBorderStyle() {}

    /**
     * @internalonly
     */
    protected CreateParams getCreateParams() {}

    /**
     * Retrieves the number of root nodes contained in the tree view control. 
     *
     * @return int  Count of nodes at the root of the tree.
     */
    public int getNodeCount() {}

    /**
     * Retrieves the number of root nodes contained in the tree view control. 
     *
     * @param includeSubTrees   Whether to include nodes in subtrees in the count.
     *
     * @return int  Count of nodes.  If includeSubTrees is <b>true</b>, the result is
     *              the count of all the nodes in the entire tree.
     */
    public int getNodeCount(boolean includeSubTrees) {}

    /**
     * Retrieves the index of the image that appears next to the node that is currently
     * selected in the tree view control. 
     * The index applies to the ImageList referred to by the <b>imageList</b> property,
     *
     * @return int  Image index for selected nodes.
     */
    public int getSelectedImageIndex() {}

    /**
     * Retrieves a boolean value indicating whether the selected node in the tree view
     * control remains highlighted when the control loses the focus. 
     *
     * @return boolean  Whether hideSelection is set
     */
    public boolean getHideSelection() {}

    /**
     * Retrieves the index of the image that appears by default next to nodes in the tree view
     * control. 
     * The index applies to the ImageList referred to by the <b>imageList</b> property,
     *
     * @return int  Image index for unselected nodes.
     */
    public int getImageIndex() {}

    /**
     * Retrieves the image list control associated with the tree view control. 
     *
     * @return ImageList The tree view's image list.
     */
    public ImageList getImageList() {}

    /**
     * Retrieves the distance, in pixels, that nodes are indented relative to their parent
     * nodes. 
     *
     * @return int The indentation level.
     */
    public int getIndent() {}

    /**
     * Retrieves the node at the specified zero-based index. 
     *
     * @return TreeNode The root node at the requested index.
     */
    public TreeNode getNode(int index) {}

    /**
     * Retrieves the node at the specified location. 
     *
     * @param pt     point to check against
     *
     * @return TreeNode The tree node at the given location.
     */
    public TreeNode getNodeAt(Point pt) {}

    /**
     * Retrieves the node at the specified location. 
     *
     * @param x x position to check against
     * @param y y position to check against
     *
     * @return TreeNode The tree node at the given location.
     */
    public TreeNode getNodeAt(int x, int y) {}

    /**
     * Retrieves an array containing all the root nodes in the tree view control. 
     *
     * @return TreeNode[] All nodes at the root.
     */
    public TreeNode[] getNodes() {}

    /**
     * Retrieves the delimiter character used in the path returned by the TreeNode.getFullPath method. getFullPath().
     *
     * @return String The FullPath delimeter string.
     */
    public String getPathSeparator() {}

    /**
     * Retrieves a boolean value indicating whether a plus (+) or minus (-) button,
     * which allows the user to expand or collapse a node by clicking, appears next to tree nodes
     * that have children.  The ShowPlusMinus
     * property determines if the "plus/minus" expand button is shown next
     * to tree nodes that have children.
     *
     * @return boolean The value of the ShowPlusMinus property.
     */
    public boolean getShowPlusMinus() {}

    /**
     * Retrieves a boolean value indicating whether a check box appears next to each
     * node in the tree view control.  The CheckBoxes
     * property determines if check boxes are shown next to node in the
     * tree view.
     *
     * @return boolean The value of the CheckBoxes property.
     */
    public boolean getCheckBoxes() {}

    /**
     * Retrieves a boolean value indicating whether a line is drawn to connect each
     * child node to its parent node in the tree view control.  The ShowLines property
     * determines if lines are drawn between nodes in the tree view.
     *
     * @return boolean The value of the ShowLines property.
     */
    public boolean getShowLines() {}

    /**
     * Retrieves a boolean value indicating whether a line is drawn to connect all the
     * root nodes of the tree view control.  The ShowRootLines
     * property determines if lines are draw between nodes at the root of
     * the tree view.
     *
     * @return boolean The value of the ShowRootLines property.
     */
    public boolean getShowRootLines() {}

    /**
     * Retrieves a boolean value indicating whether the nodes in the tree view control
     * are sorted alphabetically.  The Sorted property determines
     * if nodes in the tree view are sorted.
     *
     * @return boolean The value of the Sorted property.
     */
    public boolean getSorted() {}

    /**
     * Retrieves a boolean value indicating whether the user can edit the labels of
     * tree view nodes.  The LabelEdit property 
     * determines if the label text of nodes in the tree view is editable.
     *
     * @return boolean The value of the LabelEdit property.
     */
    public boolean getLabelEdit() {}

    /**
     * Retrieves a boolean value indicating whether a scroll bar is added to the tree
     * view control when there is not enough room to display all the tree view nodes in the
     * control's client area. 
     *
     * @return int The value of the ScrollBar property.
     */
    public boolean getScrollable() {}

    /**
     * Retrieves the currently selected node in the tree view control. 
     *
     * @return TreeNode The currently selected tree node, null if no node
     *                  is selected.
     */
    public TreeNode getSelectedNode() {}

    /**
     * Retrieves first visible node in a tree view control.  Initially
     * the first root node is at the top of the TreeView, but if the
     * contents have been scrolled another node may be at the top.
     *
     * @return the topmost visible TreeNode.
     */
    public TreeNode getTopNode() {}

    /**
     * Retrieves a boolean value indicating whether nodes in the tree view control are
     * highlighted as the mouse pointer passes over them.  The HotTracking
     * property determines if nodes are highlighted as the mousepointer
     * passes over them.
     *
     * @return boolean The value of the HotTracking property.
     */
    public boolean getHotTracking() {}

    /**
     * Retrieves the number of nodes that can be fully visible in the tree view control.   This number
     * may be greater than the number of nodes in the control.
     * The control calculates this value by dividing the height of the
     * client window by the height of an item
     *
     * @return int The count of visible nodes.
     */
    public int getVisibleCount() {}

    /**
     * Inserts the specified node into the tree view control as a root node at the specified
     * position. 
     */
    public void insertNode(int index, TreeNode node) {}

    /**
     * Triggers the createHandle event. 
     * @internalonly
     */
    protected void onCreateHandle(Event e) {}

    /**
     * Triggers the beforeLabelEdit event. 
     */
    protected void onBeforeLabelEdit(NodeLabelEditEvent e) {}

    /**
     * Triggers the afterLabelEdit event. 
     */
    protected void onAfterLabelEdit(NodeLabelEditEvent e) {}

    /**
     * Triggers the beforeCheck event. 
     */
    protected void onBeforeCheck(TreeViewCancelEvent e) {}

    /**
     * Triggers the afterCheck event. 
     */
    protected void onAfterCheck(TreeViewEvent e) {}

    /**
     * Triggers the beforeCollapse event. 
     */
    protected void onBeforeCollapse(TreeViewCancelEvent e) {}

    /**
     * Triggers the afterCollapse event. 
     */
    protected void onAfterCollapse(TreeViewEvent e) {}

    /**
     * Triggers the beforeExpand event. 
     */
    protected void onBeforeExpand(TreeViewCancelEvent e) {}

    /**
     * Triggers the afterExpand event. 
     */
    protected void onAfterExpand(TreeViewEvent e) {}

    /**
     * Triggers the itemDrag event. 
     */
    protected void onItemDrag(ItemDragEvent e) {}

    /**
     * Triggers the beforeSelect event. 
     */
    protected void onBeforeSelect(TreeViewCancelEvent e) {}

    /**
     * Triggers the afterSelect event. 
     */
    protected void onAfterSelect(TreeViewEvent e) {}

    /**
     * Remove all nodes from the tree view control. 
     */
    public void removeAll() {}

    /**
     * Removes the delegate that is assigned to the beforeLabelEdit event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnBeforeLabelEdit(NodeLabelEditEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the afterLabelEdit event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnAfterLabelEdit(NodeLabelEditEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the beforeCheck event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnBeforeCheck(TreeViewCancelEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the afterCheck event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnAfterCheck(TreeViewEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the beforeCollapse event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnBeforeCollapse(TreeViewCancelEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the afterCollapse event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnAfterCollapse(TreeViewEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the beforeExpand event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnBeforeExpand(TreeViewCancelEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the afterExpand event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnAfterExpand(TreeViewEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the itemDrag event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public final void removeOnItemDrag(ItemDragEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the beforeSelect event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnBeforeSelect(TreeViewCancelEventHandler value) {}

    /**
     * Removes the delegate that is assigned to the afterSelect event. 
     * If there are duplicate entries, all are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnAfterSelect(TreeViewEventHandler value) {}

    /**
     * Resets the indentation to the system default. 
     */
    public void resetIndent() {}

    /**
     * Sets the background color for this control. 
     * 
     * @param value A <a HREF="wfc.ui.Color.html">Color</a> object that represents the 
     * background color for this control. Specifying <b>null</b> for this parameter sets the
     * control's background color to its parent's background color.
     */
    public void setBackColor(Color value) {}

    /**
     * Sets a value indicating the kind of border the tree view control has. 
     * @param value Sets Borderstyle to one of the following:
     *     NONE
     *     SUNKEN3D
     */
    public void setBorderStyle(int value) {}

    /**
     * Sets the current foreground color for this control, which is the color the control uses
     * to draw its text.
     * 
     * @param value A <a HREF="wfc.ui.Color.html">Color</a> object that represents the color used 
     * to draw text in this control. 
     */
    public void setForeColor(Color value) {}

    /**
     * Sets the index of the image that appears next to the node that is currently selected in
     * the tree view control. 
     */
    public void setSelectedImageIndex(int value) {}

    /**
     * Sets a boolean value indicating whether the selected node in the tree view
     * control remains highlighted when the control loses the focus.  The HideSelection
     * property determines if the selected item will display as selected
     * when the tree view loses focus.
     */
    public void setHideSelection(boolean value) {}

    /**
     * Sets the index of the image that appears by default next to nodes in the tree view
     * control. 
     */
    public void setImageIndex(int value) {}

    /**
     * Sets the image list control associated with the tree view control. 
     */
    public void setImageList(ImageList value) {}

    /**
     * Sets the distance, in pixels, that nodes are indented relative to their parent nodes. 
     */
    public void setIndent(int value) {}

    /**
     * Replaces the node at the specified position in the tree view control.  Any existing
     * node at the given location is lost.
     */
    public void setNode(int index, TreeNode node) {}

    /**
     * Adds a set of root nodes to the tree view control.  Any existing
     * nodes are lost.
     */
    public void setNodes(TreeNode[] nodes) {}

    /**
     * Sets the delimiter character used in the path returned by the TreeNode.getFullPath method. getFullPath() function.
     */
    public void setPathSeparator(String value) {}

    /**
     * Sets a boolean value indicating whether a plus (+) or minus (-) button, which
     * allows the user to expand or collapse a node by clicking, appears next to tree nodes that
     * have children.  The ShowPlusMinus
     * property determines if the "plus/minus" expand button is shown next
     * to tree nodes that have children.
     */
    public void setShowPlusMinus(boolean value) {}

    /**
     * Sets a boolean value indicating whether a check box appears next to each node in
     * the tree view control.  The CheckBoxes
     * property determines if check boxes are shown next to node in the
     * tree view.
     */
    public void setCheckBoxes(boolean value) {}

    /**
     * Sets a boolean value indicating whether a line connects each child node to its
     * parent node in the tree view control.  The ShowLines property
     * determines if lines are drawn between nodes in the tree view.
     */
    public void setShowLines(boolean value) {}

    /**
     * Sets a boolean value indicating whether a line is drawn to connect all the root
     * nodes of the tree view control.  The ShowRootLines
     * property determines if lines are draw between nodes at the root of
     * the tree view.
     */
    public void setShowRootLines(boolean value) {}

    /**
     * Sets a boolean value indicating whether the nodes in the tree view control are
     * sorted alphabetically.  The Sorted property determines
     * if nodes in the tree view are sorted.
     */
    public void setSorted(boolean value) {}

    /**
     * Sets a boolean value indicating whether the user can edit the labels of tree
     * view nodes.  The LabelEdit property 
     * determines if the label text of nodes in the tree view is editable.
     */
    public void setLabelEdit(boolean value) {}

    /**
     * Sets a boolean value indicating whether a scroll bar is added to the tree view
     * control when there is not enough room to display all the tree view nodes in the control's
     * client area. 
     */
    public void setScrollable(boolean value) {}

    /**
     * Selects the specified node in the tree view control. 
     */
    public void setSelectedNode(TreeNode value) {}

    /**
     * Sets a boolean value indicating whether nodes in the tree view control are
     * highlighted as the mouse pointer passes over them.  The HotTracking
     * property determines if nodes are highlighted as the mousepointer
     * passes over them.
     */
    public void setHotTracking(boolean value) {}

    /**
     * Retrieves a boolean value indicating whether the value of the indent property has been explicitly set and should therefore be
     * persisted. ..
     *
     * @return whether the indentation should be persisted.
     */
    public boolean shouldPersistIndent() {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    private int tvnExpanding(NMTREEVIEW nmtv) {}

    private void tvnExpanded(NMTREEVIEW nmtv) {}

    private int tvnSelecting(NMTREEVIEW nmtv) {}

    private void tvnSelected(NMTREEVIEW nmtv) {}

    private int tvnBeginLabelEdit(NMTVDISPINFO nmtvdi) {}

    private int tvnEndLabelEdit(NMTVDISPINFO nmtvdi) {}

    private void wmMouseDown(Message m, int button, int clicks) {}

    private void wmNotify(Message m) {}

    /**
     * @internalonly
     */
    protected void wndProc(Message m) {}


    /**
     * Encapsulates a Windows tree view control. 
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo backColor =
            new PropertyInfo(Control.ClassInfo.backColor, DefaultValueAttribute.COLOR_WINDOW);

        public static final PropertyInfo borderStyle = 
            new PropertyInfo(TreeView.class, 
                         "borderStyle",
                         com.ms.wfc.ui.BorderStyle.class,
                         CategoryAttribute.Appearance,
                         new DefaultValueAttribute(new Integer(com.ms.wfc.ui.BorderStyle.FIXED_3D)),
                         new DescriptionAttribute(Sys.getString("borderStyleDescr")));

        public static final PropertyInfo checkBoxes = 
            new PropertyInfo(TreeView.class, "checkBoxes", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.FALSE,
                             new DescriptionAttribute(Sys.getString("TreeViewCheckBoxesDescr")));

        public static final PropertyInfo hideSelection = 
            new PropertyInfo(TreeView.class, "hideSelection", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.TRUE,
                             new DescriptionAttribute(Sys.getString("TreeViewHideSelectionDescr")));

        public static final PropertyInfo hotTracking = 
            new PropertyInfo(TreeView.class, "hotTracking", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.FALSE,
                             new DescriptionAttribute(Sys.getString("TreeViewHotTrackingDescr")));

        public static final PropertyInfo imageIndex = 
            new PropertyInfo(TreeView.class, "imageIndex", Integer.TYPE,
                             CategoryAttribute.Behavior,
                             new ValueEditorAttribute(ImageIndexEditor.class),
                             DefaultValueAttribute.ZERO,
                             new DescriptionAttribute(Sys.getString("TreeViewImageIndexDescr")));

        public static final PropertyInfo imageList = 
            new PropertyInfo(TreeView.class, "imageList", com.ms.wfc.ui.ImageList.class,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.NULL,
                             new DescriptionAttribute(Sys.getString("TreeViewImageListDescr")));

        public static final PropertyInfo indent = 
            new PropertyInfo(TreeView.class, "indent", Integer.TYPE,
                             CategoryAttribute.Behavior,
                             new DescriptionAttribute(Sys.getString("TreeViewIndentDescr")));

        public static final PropertyInfo nodes = 
            new PropertyInfo(TreeView.class, "nodes", com.ms.wfc.ui.TreeNode[].class,
                             new MemberAttribute[] {
                                 CategoryAttribute.Behavior,
                                 DefaultValueAttribute.EMPTY_ARRAY,
                                 LocalizableAttribute.YES,
                                 new DescriptionAttribute(Sys.getString("TreeViewNodesDescr")),
                                 new ValueEditorAttribute(TreeNodesEditor.class)
                             });

        public static final PropertyInfo pathSeparator = 
            new PropertyInfo(TreeView.class, "pathSeparator", String.class,
                             CategoryAttribute.Behavior,
                             new DefaultValueAttribute(backSlash),
                             new DescriptionAttribute(Sys.getString("TreeViewPathSeparatorDescr")));

        public static final PropertyInfo selectedImageIndex = 
            new PropertyInfo(TreeView.class, "selectedImageIndex", Integer.TYPE,
                             CategoryAttribute.Behavior,
                             new ValueEditorAttribute(ImageIndexEditor.class),
                             DefaultValueAttribute.ZERO,
                             new DescriptionAttribute(Sys.getString("TreeViewSelectedImageIndexDescr")));

        public static final PropertyInfo showPlusMinus = 
            new PropertyInfo(TreeView.class, "showPlusMinus", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.TRUE,
                             new DescriptionAttribute(Sys.getString("TreeViewShowPlusMinusDescr")));

        public static final PropertyInfo showLines = 
            new PropertyInfo(TreeView.class, "showLines", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.TRUE,
                             new DescriptionAttribute(Sys.getString("TreeViewShowLinesDescr")));

        public static final PropertyInfo showRootLines = 
            new PropertyInfo(TreeView.class, "showRootLines", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.TRUE,
                             new DescriptionAttribute(Sys.getString("TreeViewShowRootLinesDescr")));

        public static final PropertyInfo sorted = 
            new PropertyInfo(TreeView.class, "sorted", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.FALSE,
                             new DescriptionAttribute(Sys.getString("TreeViewSortedDescr")));

        public static final PropertyInfo labelEdit = 
            new PropertyInfo(TreeView.class, "labelEdit", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.FALSE,
                             new DescriptionAttribute(Sys.getString("TreeViewLabelEditDescr")));

        public static final PropertyInfo scrollable = 
            new PropertyInfo(TreeView.class, "scrollable", Boolean.TYPE,
                             CategoryAttribute.Behavior,
                             DefaultValueAttribute.TRUE,
                             new DescriptionAttribute(Sys.getString("TreeViewScrollableDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, BrowsableAttribute.NO);

        public static final EventInfo afterCheck = 
            new EventInfo(TreeView.class, "afterCheck", TreeViewEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewAfterCheckDescr")));

        public static final EventInfo afterCollapse = 
            new EventInfo(TreeView.class, "afterCollapse", TreeViewEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewAfterCollapseDescr")));

        public static final EventInfo afterExpand = 
            new EventInfo(TreeView.class, "afterExpand", TreeViewEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewAfterExpandDescr")));

        public static final EventInfo afterLabelEdit = 
            new EventInfo(TreeView.class, "afterLabelEdit", NodeLabelEditEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewAfterEditDescr")));

        public static final EventInfo afterSelect = 
            new EventInfo(TreeView.class, "afterSelect", TreeViewEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewAfterSelectDescr")));

        public static final EventInfo beforeCheck = 
            new EventInfo(TreeView.class, "beforeCheck", TreeViewCancelEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewBeforeCheckDescr")));

        public static final EventInfo beforeCollapse = 
            new EventInfo(TreeView.class, "beforeCollapse", TreeViewCancelEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewBeforeCollapseDescr")));

        public static final EventInfo beforeExpand = 
            new EventInfo(TreeView.class, "beforeExpand", TreeViewCancelEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewBeforeExpandDescr")));

        public static final EventInfo beforeLabelEdit = 
            new EventInfo(TreeView.class, "beforeLabelEdit", NodeLabelEditEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewBeforeEditDescr")));

        public static final EventInfo beforeSelect = 
            new EventInfo(TreeView.class, "beforeSelect", TreeViewCancelEventHandler.class,
                          CategoryAttribute.Behavior,
                          new DescriptionAttribute(Sys.getString("TreeViewBeforeSelectDescr")));

        public static final EventInfo itemDrag = 
            new EventInfo(TreeView.class, 
                         "itemDrag", 
                         ItemDragEventHandler.class,
                         CategoryAttribute.Action,
                         new DescriptionAttribute(Sys.getString("ListViewItemDragDescr")));

        public String getDefaultEventName() {}

        public void getEvents(IEvents events) {}

        public void getProperties(IProperties props) {}

        public ICustomizer getCustomizer(Object component) {}
    }


    /**
     * Encapsulates a Windows tree view control. 
     * @security(checkClassLinking=on)
     */
    public static class Customizer extends com.ms.wfc.core.Customizer {
        private TreeView treeview = null;
        private TV_HITTESTINFO tvhit = new TV_HITTESTINFO();

        public Customizer(TreeView treeview) {}

        public boolean getHitTest(Point point) {}
    }
}