//STRIPPEDSOURCE//


package com.ms.wfc.ui;

import com.ms.wfc.app.*;
import com.ms.wfc.core.*;
import com.ms.wfc.util.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.Delegate;

/**  
 * This control is an encapsulation of the Windows up-down control.
 * An up-down control is a pair of arrow buttons that the user can click to increment or 
 * decrement a value, such as a scroll position or a number displayed in a companion 
 * control. An up-down control is most often used with a companion control, which is 
 * called a buddy window.  
 *
 * @security(checkClassLinking=on)
 */
public class UpDown extends Control {
    private static final int        DEFAULT_VALUE = 0;
    private static final int        DEFAULT_MIN = 0;
    private static final int        DEFAULT_MAX = 100;
    private static final int        DEFAULT_NUM_ACCELERATORS = 3;
    private static final int        SIZEOF_UDACCEL = 8;
    private static final int        DEFAULT_HEIGHT = 21;
    private static final int        DEFAULT_ALIGNMENT = UpDownAlignment.RIGHT;
    private static final int        DEFAULT_RADIX = Radix.DECIMAL;
    private static final boolean    DEFAULT_INTERCEPT_ARROW_KEYS    = false;
    private static final boolean    DEFAULT_AUTO_BUDDY              = false;
    private static final boolean    DEFAULT_HORIZONTAL_ARROWS       = false;
    private static final boolean    DEFAULT_NO_THOUSANDS_SEPARATOR  = false;
    private static final boolean    DEFAULT_MODIFY_BUDDY            = true;
    private static final boolean    DEFAULT_WRAP                    = false;
    private static final int        UD_MINVAL                       = -32768;
    private static final int        UD_MAXVAL                       =  32767;

    
    private int     alignment = DEFAULT_ALIGNMENT;
    private boolean interceptArrowKeys = DEFAULT_INTERCEPT_ARROW_KEYS;
    private boolean autoBuddy = DEFAULT_AUTO_BUDDY;
    private boolean horizontalArrows = DEFAULT_HORIZONTAL_ARROWS;
    private boolean noThousandsSeparator = DEFAULT_NO_THOUSANDS_SEPARATOR;
    private boolean modifyBuddy = DEFAULT_MODIFY_BUDDY;
    private boolean wrap = DEFAULT_WRAP;

    private static final Object EVENT_VALUECHANGED = new Object();

    private KeyEventHandler onInterceptKeyDown = new KeyEventHandler(this.interceptKeys);

    
    
    private Control             buddy = null;    
    private int                 minimum = DEFAULT_MIN;
    private int                 maximum = DEFAULT_MAX;
    
    private int                 realMin = DEFAULT_MIN;
    private int                 realMax = DEFAULT_MAX;
    private int                 base = DEFAULT_RADIX;
    private UpDownAcceleration  acceleration[] = new UpDownAcceleration[DEFAULT_NUM_ACCELERATORS];
    private int                 value = 0;
    private boolean             up = true; 
    private boolean             internalSetMode = false; 
    
    
    private Point oldSize = new Point(SystemInformation.getVertScrollBarWidth(), DEFAULT_HEIGHT);
    private Point oldLocation = new Point(130,120);    

    
    private UpDownChangedEventHandler  onUpDownChanged;
    
    
    private boolean autoSize = true;

    
    private Rectangle saveSize = new Rectangle(130, 120,
        SystemInformation.getVertScrollBarWidth(),
        DEFAULT_HEIGHT);
    
    /**
     * Creates a new UpDown object.  Styles are the default for a
     * regular updown control.
     */
    public UpDown() {}
    
    /**
     * Adds an event handler for the "upDownChanged" event notification.  
     * This event is fired by the operating system to the parent window of the 
     * updown control when the value of the control is about to change.  
     * This happens when the user requests a change in the value by pressing 
     * the control's up or down arrow.  The upDownChanged notification is sent before 
     * the control's value is changed, thus allowing the user examine, allow, 
     * modify, or disallow the change. 
     * Duplicates adds are not filtered out.
     * 
     * @param value New Event Handler to install for this event.
     */ 
    public void addOnUpDownChanged(UpDownChangedEventHandler value) {}

    /**
     * Adds an event handler for the "valueChanged" event notification. This
     * event is called whenever the scrollbar's current position changes,
     * whether it be because of mouse, keyboard, or programmatic input.
     *
     * @param value New Event Handler to install for this event.
     */
    public void addOnValueChanged(EventHandler eh) {}

    
    
    private void alignToBuddy() {}

    
    private void checkRange(int min, int max) {}
    
    /** 
     * Decrements up-down's value by the default acceleration (specified in the first element returned
     * by getAcceleration)
     *
     * @see #getAcceleration
     */
    public void decrement() {}    
    
    /**
     * Retrieves acceleration information for an up-down control.      
     *
     * @return an array containing the acceleration information
     *
     * @see #setAccel
     * @see com.ms.wfc.ui.UpDownAcceleration
     */ 
    public UpDownAcceleration[] getAcceleration() {}

    private Rectangle getAlignedBounds() {}        
    
    /**
     * Indicates whether this control automatically selects the 
     * previous window in the Z order as the buddy window.
     *
     * @return <b>true</b> if enabled; otherwise, returns <b>false</b>
     *
     * @see #setAutoBuddy
     */
    public boolean getAutoBuddy() {}

    /**
     * Indicates whether or not the UpDown control will try and maintain
     * it's own size based on buddy control size, or whether it will just
     * honour any size.
     *
     * @return boolean  true if the control will resize itself based on
     *                  image height [default], false if it will just
     *                  honour whatever size windows tells it to.
     */
    public final boolean getAutoSize() {}

    
    private Object getBuddyProperty() {}
    
    /**     
     * Indicates the radix value.  The radix value determines whether the buddy window 
     * displays numbers in decimal or hexadecimal digits.  Hexadecimal numbers are 
     * always unsigned, and decimal numbers are signed. 
     *
     * @return a value from com.ms.wfc.ui.Radix
     *
     * @see #setRadix
     * @see com.ms.wfc.ui.Radix
     */
    public int getRadix() {}
    
    /**
     * Retrieves the current buddy control.
     *
     * @return current buddy control
     * 
     * @see #setBuddyControl
     */
    public Control getBuddyControl() {}
    
    /**
     * This is called when creating a window.  Inheriting classes can ovveride
     * this to add extra functionality, but should not forget to first call
     * super.getCreateParams() to make sure the control continues to work
     * correctly.
     *
     * @return   a com.ms.wfc.ui.CreateParams object with the information for creating
     *                       this control.
     *
     * @see com.ms.wfc.ui.CreateParams
     */
    protected CreateParams getCreateParams() {}

    /**
     * Indicates how the up-down control is positioned relative to the buddy 
     * control     
     * 0 - position set manually by the programmer
     * 1 - aligned to the right of the control
     * 2 - aligned to the left of the control
     *
     * @return a value from com.ms.wfc.ui.UpDownAlignment enumeration
     *
     * @see #setAlignment
     * @see com.ms.wfc.ui.UpDownAlignment
     */    
    public int getAlignment() {}
    
    /**
     * Indicates whether the up-down control's arrows point to the left and right 
     * instead of up and down
     *
     * @return <b>true</b> if arrows point left and right; otherwise returns <b>false</b>
     *
     * @see #setHorizontal
     */
    public boolean getHorizontal() {}    
    
    /**
     * Indicates if the up-down control will intercept arrow keys from the control,
     * causing the up-down's value to increment or decrement.
     *
     * @return <b>true</b> if enabled; otherwise returns <b>false</b>
     * 
     * @see #setInterceptArrowKeys
     */
    public boolean getInterceptArrowKeys() {}

    /**
     * Retrieves the upper limit of the up-down control's range. 
     * The default value is 100.
     *
     * @return current upper limit.
     *
     * @see #setMaximum
     */
    public int getMaximum() {}
    
    /**
     * Retrieves the lower limit of the up-down control's range. 
     * The default value is 0.
     *
     * @return current lower limit.
     *
     * @see #setMinimum
     */
    public int getMinimum() {}    
    
    /**
     * Indicates if the up-down control will modify the value of the buddy window 
     * when the value changes.  The text consists of the value formatted as 
     * a decimal or hexadecimal string
     *
     * @return <b>true</b> if enabled; otherwise returns <b>false</b>
     *
     * @see #setModifyBuddy
     */
    public boolean getModifyBuddy() {}    

    /**
     * Indicates whether a thousands separator is inserted between
     * every three decimal digits.
     *
     * @return <b>true</b> if enabled; otherwise returns <b>false</b>
     *
     * @see #setThousandsSeparator
     */
    public boolean getThousandsSeparator() {}
    
    /**
     * Retrieves the current value of the up-down control.       
     *
     * @return the current value for this control
     *
     * @see #setValue     
     */
    public int getValue() {}
    
    
    /**
     * Indicates whether the control will cause the value to "wrap" 
     * if it is incremented or decremented beyond the ending or beginning 
     * of the range.
     *       
     * @return <b>true</b> if enabled; otherwise returns <b>false</b>
     */
    public boolean getWrap() {}    
    
    
    private final static Integer hexToInteger(String s) {}

    /** 
     * Increments up-down's value by the by the default acceleration (specified in the first element returned
     * by getAcceleration)
     *
     * @see #getUpDownAcceleration
     */
    public void increment() {}
    
    private void onBuddyReposition(Object sender, Event e) {}

    /**
     * Overrides Control.onCreateHandle()
     * @internalonly
     */ 
    protected void onCreateHandle(Event e) {}
    
    /**
     * Fires the event indicating that the value of the up-down control is 
     * about to change, due to the user pressing on the control's up or down arrow.
     * 
     * @param event Event data
     *     
     * @see #addOnUpDownChanged
     * @see #removeOnUpDownChanged
     * @see com.ms.wfc.ui.UpDownChangedEvent
     * @see com.ms.wfc.core.Event
     */
    protected void onUpDownChanged(UpDownChangedEvent event) {}
    
    /**
     * Actually fires the "valueChanged" event.  
     * @hidden
     * @internalonly
     */
    protected void onValueChanged(Event e) {}

    /**
     * Removes the given handler for the "upDownChanged" event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.    
     */
    public void removeOnUpDownChanged(UpDownChangedEventHandler value) {}    

    /**
     * Removes the given handler for the "valueChanged" event.
     * If there are duplicate entries, ALL are removed.
     *
     * @param value Event handler to be removed.
     */
    public void removeOnValueChanged(EventHandler eh) {}

    /**
     * Sets the acceleration characteristics for an up-down control.
     * <i>value</i> must not be null, and each element of the array must 
     * not be null.  Each element in the UpDownAcceleration array should be 
     * sorted in ascending order based on the <b>seconds</b> member of 
     * com.ms.wfc.ui.UpDownAcceleration class.
     *
     * @param value     The new acceleration information that the up-down   
     *                  control will take.
     *
     * @see #getAccel
     * @see com.ms.wfc.ui.UpDownAcceleration
     *
     * @exception WFCInvalidArgumentException   Thrown if <i>value</i> is invalid.
     * @exception WFCSystemException            Thrown if an error occurs in setting the 
     *                                          new acceleration information.
     */    
    public void setAcceleration(UpDownAcceleration[] value) {}

    /**
     * Sets how the up-down control aligns itself with the buddy control.       
     *
     * @param value a value from com.ms.wfc.ui.UpDownAlignment
     *
     * @see #getAlignment 
     * @see com.ms.wfc.ui.UpDownAlignment
     * @exception WFCInvalidArgumentException   Thrown if <i>value</i> is invalid.
     */    
    public void setAlignment(int value) {}

    
    private Control selectAutoBuddy() {}

    /**
     * Indicates whether this control automatically selects the 
     * previous window in the Z order as the buddy control.
     * Even if this control already has a buddy, setting the 
     * autoBuddy property will select the previous window in the
     * Z order as the buddy.
     *
     * @param value <b>true</b> if the control will automatically select
     *              a buddy control; otherwise, <b>false</b>
     *
     * @see #setAutoBuddy
     */
    public void setAutoBuddy(boolean value) {}

    /**
     * Controls whether or not the UpDwon control will try and maintain
     * it's own size based on buddy control size, or whether it will just
     * honour any size.
     *
     * @param value  true if the control will resize itself based on
     *               image height [default], false if it will just
     *               honour whatever size windows tells it to.
     */
    public final void setAutoSize(boolean value) {}

    /**
     * Overrides Control.setBoundsCore to enforce fixed default width.     
     *
     * @param x new left of the control.
     * @param y new right of the control.
     * @param width new width of the control.
     * @param height new height of the control.
     * @internalonly
     */
    protected void setBoundsCore(int x, int y, int width, int height) {}
    
    
    private void setBuddy(Control control) {}
    
    /**
     * Sets the buddy window for an up-down control.
     * An up-down control and its buddy window must have the same parent window. 
     *
     * @param control   The new buddy component, which must inherit from Control
     */
    public void setBuddyControl(Control control) {}    

    
    private void setBuddyProperty() {}

    /**
     * Sets the up-down control's arrows to point left and right, or up and down
     *
     * @param horz If this is <b>true</b>, then the arrows will point left and right; 
     *             if it is <b>false</b> it will point up and down.
     *
     * @see #getHorizontal
     */    
    public void setHorizontal(boolean horz) {}

    /**
     * Controls whether the up-down control will intercept arrow keys from 
     * the control, causing the up-down's value to increment or decrement.
     *
     * @return If <b>true</b>, then the keys will be intercepted by the control     
     * 
     * @see #setInterceptArrowKeys
     */    
    public void setInterceptArrowKeys(boolean value) {}

    
    private void interceptKeys(Object source, KeyEvent e) {}

    private void onSettingChange(Object sender, Event event) {}        
    
    /** 
     * Sets the upper limit of the up-down control's range.
     * 
     * @param value The new upper limit of the up-down control's range. 
     *
     * @see #getMaximum
     */ 
    public void setMaximum(int value) {}
    
    /** 
     * Sets the lower limit of the up-down control's range. 
     * 
     * @param value The new lower limit of the up-down control's range. 
     *
     * @see #getMinimum
     */ 
    public void setMinimum(int value) {}    
    
    /**
     * Indicates if the up-down control should modify the value in the buddy when 
     * the value changes.
     *
     * @param value If <b>true</b>, then the control will modify the buddy when
     *              its value changes.
     */
    public void setModifyBuddy(boolean value) {}
    
    /**
     * Sets the radix base for the up-down control.  The base value determines whether 
     * the buddy window displays numbers in decimal or hexadecimal digits.  Hexadecimal 
     * numbers are always unsigned, and decimal numbers are signed. 
     *
     * @param value A value from com.ms.wfc.ui.Radix
     *
     * @see #setRadix
     * @exception WFCInvalidArgumentException   Thrown if <i>value</i> is invalid.
     */
    public void setRadix(int value) {}

    /**
     * Indicates whether a thousands separator is inserted between
     * every three decimal digits
     *
     * @param value If <b>true</b>, then a thousands separator will be inserted
     *
     * @see #getThousandsSeparator
     */
    public void setThousandsSeparator(boolean value) {}
    
    /**
     * Sets the current value for the up-down control.  
     * <i>value</i> must be in the range specified by the upper and lower limits 
     * for the control
     *
     * @param value The new value for this control.
     *
     * @see #getValue
     */    
    public void setValue(int value) {}
    
    /**
     * Controls whether the control will "wrap" the value if it is 
     * incremented or decremented beyond the ending or beginning of the range.
     *
     * @param <b>true</b> if enabled; otherwise returns <b>false</b>
     * 
     * @see #getWrap
     */
    public void setWrap(boolean value) {}

    /**
     * Retrieves <b>true</b> if the buddy control should be persisted in code gen.
     * 
     * @return <b>true</b> if the buddy control should be persisted.
     */
    public boolean shouldPersistBuddyControl() {}    

    
    private void updateOrientation() {}

    
    private void updateRange() {}
    
    
    private void processBuddyValue(int realMin, int realMax) {}

    /**
     * Returns a string representation for this control.
     *
     * @return String
     * @internalonly
     */
    public String toString() {}

    
    private void wrapLogic(int realMin, int realMax, int delta) {}
    
    
    private void wmUpDownChanged(Message m) {}
    
    
    private void wmReflectCommand(Message m) {}     

    /**
     * Overrided wndProc
     * 
     * @internalonly 
     */    
    protected void wndProc(Message m) {}


    /**
     * @security(checkClassLinking=on)
     */
    public static class ClassInfo extends Control.ClassInfo {
        public static final PropertyInfo backColor = new PropertyInfo(
            Control.ClassInfo.backColor, BrowsableAttribute.NO, PersistableAttribute.NO);

        public static final PropertyInfo foreColor = new PropertyInfo(
            Control.ClassInfo.foreColor, BrowsableAttribute.NO, PersistableAttribute.NO);

        public static final PropertyInfo autoBuddy = new PropertyInfo(
            UpDown.class, "autoBuddy", Boolean.TYPE, 
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            PersistableAttribute.YES,
            new DescriptionAttribute(Sys.getString("UpDownAutoBuddyDescr")));

        public static final PropertyInfo acceleration = new PropertyInfo(
            UpDown.class, "acceleration", UpDownAcceleration[].class,
            CategoryAttribute.Behavior,            
            BrowsableAttribute.NO,
            PersistableAttribute.NO,
            new DescriptionAttribute(Sys.getString("UpDownAccelerationDescr")));

        public static final PropertyInfo autoSize = new PropertyInfo(
            UpDown.class, "autoSize", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("UpDownAutoSizeDescr")));

        public static final PropertyInfo buddyControl = new PropertyInfo(
            UpDown.class, "buddyControl", Control.class,
            new ValueEditorAttribute(SameParentReferenceEditor.class),            
            DefaultValueAttribute.NULL,
            CategoryAttribute.Behavior,
            new DescriptionAttribute(Sys.getString("UpDownBuddyControlDescr")));        

        public static final PropertyInfo horizontal = new PropertyInfo(
            UpDown.class, "horizontal", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("UpDownHorizontalDescr")));

        public static final PropertyInfo interceptArrowKeys = new PropertyInfo(
            UpDown.class, "interceptArrowKeys", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("UpDownInterceptArrowKeysDescr")));

        public static final PropertyInfo maximum = new PropertyInfo(
            UpDown.class, "maximum", Integer.TYPE,
            new DefaultValueAttribute(new Integer(DEFAULT_MAX)),            
            CategoryAttribute.Behavior,            
            new DescriptionAttribute(Sys.getString("UpDownMaximumDescr")));
        
        public static final PropertyInfo minimum = new PropertyInfo(
            UpDown.class, "minimum", Integer.TYPE,
            new DefaultValueAttribute(new Integer(DEFAULT_MIN)),            
            CategoryAttribute.Behavior,            
            new DescriptionAttribute(Sys.getString("UpDownMinimumDescr")));

        public static final PropertyInfo modifyBuddy = new PropertyInfo(
            UpDown.class, "modifyBuddy", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("UpDownModifyBuddyDescr")));        

        public static final PropertyInfo alignment = new PropertyInfo(
            UpDown.class, "alignment", UpDownAlignment.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(DEFAULT_ALIGNMENT)),
            new DescriptionAttribute(Sys.getString("UpDownAlignmentDescr")));

        public static final PropertyInfo radix = new PropertyInfo(
            UpDown.class, "radix", Radix.class,
            CategoryAttribute.Behavior,
            new DefaultValueAttribute(new Integer(DEFAULT_RADIX)),
            new DescriptionAttribute(Sys.getString("UpDownRadixDescr")));

        public static final PropertyInfo text = new PropertyInfo(
            Control.ClassInfo.text, 
            com.ms.wfc.core.BrowsableAttribute.NO,
            com.ms.wfc.core.PersistableAttribute.NO);

        public static final PropertyInfo thousandsSeparator = new PropertyInfo(
            UpDown.class, "thousandsSeparator", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.TRUE,
            new DescriptionAttribute(Sys.getString("UpDownThousandsSeparatorDescr")));

        public static final PropertyInfo value = new PropertyInfo(
            UpDown.class, "value", Integer.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.ZERO,
            BindableAttribute.YES,
            new DescriptionAttribute(Sys.getString("UpDownValueDescr")));
        
        public static final PropertyInfo wrap = new PropertyInfo(
            UpDown.class, "wrap", Boolean.TYPE,
            CategoryAttribute.Behavior,
            DefaultValueAttribute.FALSE,
            new DescriptionAttribute(Sys.getString("UpDownWrapDescr")));

        
        public static final EventInfo click = new EventInfo(
            Control.ClassInfo.click, BrowsableAttribute.NO);

        public static final EventInfo doubleClick = new EventInfo(
            Control.ClassInfo.doubleClick, BrowsableAttribute.NO);

        public static final EventInfo upDownChanged =
                                                     new EventInfo(UpDown.class,
            "upDownChanged",
            UpDownChangedEventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("UpDownUpDownChangedDescr")));

        public static final EventInfo valueChanged = new EventInfo(
            UpDown.class, "valueChanged", EventHandler.class,
            CategoryAttribute.Action,
            new DescriptionAttribute(Sys.getString("valueChangedEventDescr")));        

        public String getDefaultEventName() {}

        public String getDefaultPropertyName() {}

        public void getProperties(IProperties props) {}
        
        public void getEvents(IEvents ievents) {}
    }
}