//STRIPPEDSOURCE//

package com.ms.wfc.util;

import com.ms.wfc.core.*;
import java.lang.reflect.*;

/**
 * Implements a hash table data structure, which stores key-value pairs. This stores object values index by the
 * hashcode of object keys. Lookup based on key values is extremely fast, but
 * there is the added overhead of maintaining a complete hashtable. For a 
 * lightweight dynamic array implementation, see com.ms.wfc.util.List.
 *
 * @security(checkClassLinking=on)
 */
public class HashTable implements Cloneable {

    
    protected static final int[] sizes = { 17, 71, 283, 1151, 4621, 18493, 73973 };

    
    protected int[] buckets;
    protected int free;

    
    protected int[] links;        
    protected int[] hashValues;
    protected Object[] keys;
    protected Object[] values;

    protected int iMax;           
    protected int iLim;           
    protected int itemCount;      
    protected float maxAverageDepth;

    /**
     * Creates a new HashTable. This will have a minimum bucket size of 17 and a 
     * maximum average depth of 2.
     */
    public HashTable() {}

    /**
     * Creates a new HashTable. This will have a minimum bucket size equal to
     * <i>minBuckets</i> and a maximum average depth of 2.
     * 
     * @param minBuckets the minimum number of buckets in the hash table.
     */
    public HashTable(int minBuckets) {}

    /**
     * Creates a new HashTable. This will have a minimum bucket size equal to
     * <i>minBuckets</i> and a maximum average depth of <i>maxAverageDepth</i>
     * 
     * @param minBuckets the minimum number of buckets in the hash table.
     * @param maxAverageDepth the maximum average depth in all buckets before
     *        more buckets will be added.
     */
    public HashTable(int minBuckets, float maxAverageDepth) {}

    /**
     * Adds a slot for the specified key-value combination with the
     * specified hash.
     * 
     * @param hash Hash code to create the slot for.
     * @param key Key to store
     * @param value Value to store
     * 
     * @internalonly
     */
    protected int addSlot(int hash, Object key, Object value) {}

    /**
     * Creates an identical copy of this HashTable object.
     * 
     * @return a clone of this HashTable.
     */
    public Object clone() {}

    /**
     * Computes a combined hash code based on two or more hash codes.
     * 
     * @param h1 Hash code
     * @param h2 Hash code
     * 
     * @return combined hash code
     */
    public static int combine(int h1, int h2) {}

    /**
     * Computes a combined hash code based on two or more hash codes.
     * 
     * @param h1 Hash code
     * @param h2 Hash code
     * @param h3 Hash code
     * 
     * @return combined hash code
     */
    public static int combine(int h1, int h2, int h3) {}

    /**
     * Computes a combined hash code based on two or more hash codes.
     * 
     * @param h1 Hash code
     * @param h2 Hash code
     * @param h3 Hash code
     * @param h4 Hash code
     * 
     * @return combined hash code
     */
    public static int combine(int h1, int h2, int h3, int h4) {}

    /**
     * Computes a combined hash code based on two or more hash codes.
     * 
     * @param h1 Hash code
     * @param h2 Hash code
     * @param h3 Hash code
     * @param h4 Hash code
     * @param h5 Hash code
     * 
     * @return combined hash code
     */
    public static int combine(int h1, int h2, int h3, int h4, int h5) {}

    /**
     * Computes what the bucket count should be, assuming the minimum
     * of <i>min</i>
     * 
     * @param min Minimum number of buckets.
     * 
     * @internalonly 
     */
    protected int computeBucketCount(int min) {}

    /**
     * Determines whether a key is present in the current list of keys, using a hash code for
     * lookup.
     * This uses a hash code lookup.
     * 
     * @param key Key to search for
     * 
     * @return <b>true</b> if the key is found; otherwise <b>false</b>.
     */
    public boolean containsKey(Object key) {}

    /**
     * Determines whether the value is present in the current list of values.  
     * This must scan each element in the hash table and perform a comparison
     * to find the item.
     * 
     * @param value Value to search for
     * 
     * @return <b>true</b> if the key is found; otherwise <b>false</b>.
     */
    public boolean containsValue(Object value) {}

    /**
     * Determines the index for the specified key, using the given
     * hash code.
     * 
     * @param hash Hash code to use in the search
     * @param key Key to search for
     * 
     * @return index of the specified key, or -1 if it isn't present.
     * 
     * @internalonly 
     */
    protected int findItem(int hash, Object key) {}

    /**
     * Retrieves the key associated with the specified item.  This must scan 
     * each element in the hash table and perform a comparison to find the 
     * item. 
     * 
     * @param value Value to search for.
     * 
     * @return the key associated with the value.
     */
    public Object getKey(Object value) {}

    /**
     * Retrieves an enumerator for the list of keys.
     * 
     * @return IEnumerator object.
     */
    public IEnumerator getKeyEnumerator() {}

    /**
     * Retrieves the complete list of keys stored in the hash table. This list is not sorted. This
     * list will not be sorted.
     * 
     * @return Object array of keys.
     */
    public Object[] getKeys() {}

    /**
     * Retrieves the complete list of keys stored in the hash table. This list is not sorted. This
     * list will not be sorted. The resulting list will be an array of the
     * type specified.
     * 
     * @param cls Class to create an array of.
     * 
     * @return <i>cls</i> array of keys.
     */
    public Object[] getKeys(Class cls) {}

    /**
     * Retrieves the complete list of keys stored in the hash table. This list is not sorted. The list
     * will be populated into <i>val</i>. If <i>val</i> isn't large enough, an
     * WFCInvalidArgumentException will be thrown.
     * 
     * @param val Object array to populate with the keys.
     * 
     * @return <i>val</i>
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> isn't large enough to 
     *         hold the list of keys.
     */
    public Object[] getKeys(Object[] val) {}

    /**
     * Retrieves the complete list of keys stored in the hash table. This list is not sorted. The list
     * will be populated into <i>val</i> starting at <i>offset</i>.
     * 
     * @param val Object array to populate with the keys.
     * @param offset index into <i>val</i> to start inserting keys into.
     * 
     * @return <i>val</i>
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> isn't large enough to 
     *         hold the list of keys.
     */
    public Object[] getKeys(Object[] val, int offset) {}

    /**
     * Retrieves the complete list of keys stored in the hash table. The list
     * will be populated into <i>val</i> starting at <i>offset</i>. No argument
     * validation occurs.
     * 
     * @param val Object array to populate with the keys.
     * @param offset index into <i>val</i> to start inserting keys into.
     * 
     * @return <i>val</i>
     * 
     * @internalonly 
     */
    protected final Object[] getKeysCore(Object[] val, int offset) {}

    /**
     * Retrieves the current number of items stored.
     * 
     * @return number of items in the hash table.
     */
    public int getSize() {}

    /**
     * Retrieves the object stored with the specified key.
     * 
     * @param key Key to search for
     * 
     * @return Object stored with <i>key</i>, or <b>null</b> if the key wasn't
     *         found.
     */
    public Object getValue(Object key) {}

    /**
     * Retrieves an enumerator for the list of values.
     * 
     * @return IEnumerator object.
     */
    public IEnumerator getValueEnumerator() {}

    /**
     * Retrieves the complete list of values stored in the hash table. This list is not
     * sorted. This
     * list will not be sorted.
     * 
     * @return Object array of values.
     */
    public Object[] getValues() {}

    /**
     * Retrieves the complete list of values stored in the hash table. This list is not
     * sorted. This
     * list will not be sorted. The resulting list will be an array of the
     * type specified.
     * 
     * @param cls Class to create an array of.
     * 
     * @return <i>cls</i> array of values.
     */
    public Object[] getValues(Class cls) {}

    /**
     * Retrieves the complete list of values stored in the hash table. This list is not
     * sorted. The list
     * will be populated into <i>val</i>. If <i>val</i> isn't large enough, an
     * WFCInvalidArgumentException will be thrown.
     * 
     * @param val Object array to populate with the values.
     * 
     * @return <i>val</i>
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> isn't large enough to 
     *         hold the list of values.
     */
    public Object[] getValues(Object[] val) {}

    /**
     * Retrieves the complete list of values stored in the hash table. This list is not
     * sorted. The list
     * will be populated into <i>val</i> starting at <i>offset</i>.
     * 
     * @param val Object array to populate with the keys.
     * @param offset index into <i>val</i> to start inserting keys into.
     * 
     * @return <i>val</i>
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> isn't large enough to 
     *         hold the list of keys.
     */
    public Object[] getValues(Object[] val, int offset) {}

    /**
     * Retrieves the complete list of values stored in the hash table. The list
     * will be populated into <i>val</i> starting at <i>offset</i>. No argument
     * validation occurs.
     * 
     * @param val Object array to populate with the values.
     * @param offset index into <i>val</i> to start inserting values into.
     * 
     * @return <i>val</i>
     * 
     * @internalonly 
     */
    protected final Object[] getValuesCore(Object[] val, int offset) {}

    /**
     * Increases the number of buckets in the hash table. This uses the
     * <i>computeBucketCount</i> function to determine what the next
     * larger size of buckets needs to be.
     * 
     * @internalonly 
     */
    protected void growHashTable() {}

    /**
     * Retrieves the hash code for the specified object. 
     * 
     * @param obj Object to compute the hash code for.
     * 
     * @return <i>obj</i>'s hash code, or 0 if <i>obj</i> is <b>null</b>.
     */
    public static int hashCode(Object obj) {}

    /**
     * Determines whether the hash table contains any items.
     * @param boolean value indicating if there are currently any items stored
     *        in the hash table.
     */
    public boolean getEmpty() {}

    /**
     * Rehashes the entire hash table, placing all items in the correct place.
     */
    public void rehash() {}

    /**
     * Removes all items from the hash table.
     */
    public void removeAllValues() {}

    /**
     * Removes the value associated with the specified key.
     * 
     * @param key Key of the value to remove
     * 
     * @return The value that was removed, or <b>null</b> if the
     *         key wasn't found.
     */
    public Object removeValue(Object  key) {}

    /**
     * Removes a slot from the hash table.
     * 
     * NOTE: This should only be called immediately after a call to
     * findItem, which moves the slot to the top of the hash bucket.
     * 
     * @param hash hash code to remove
     * @param i index of the item to remove
     * 
     * @internalonly 
     */
    protected void removeSlot(int hash, int i) {}

    /**
     * Stores a value in the hash table.
     * 
     * @param key Key to store the value under.
     * @param value Value to store.
     * 
     * @return the value that was stored.
     */
    public Object setValue(Object key, Object value) {}

    /**
     * Creates a meaningful string representation of the contents of the hash table.
     * 
     * @return string representation of the hash table.
     */
    public String toString() {}

    /**
     * Implements a hash table data structure, which stores key-value pairs.
     * 
     * @internalonly
     *
     * @security(checkClassLinking=on)
     */
    protected class HashTableEnumerator implements IEnumerator {
        protected int iCur;
        protected boolean doKeys;

        /**
         * Creates a new HashTableEnumerator.
         * 
         * @param init Initial index to start enumerating
         * @param doKeys If set to <b>true</b> then this will enumerate
         *        over the keys in the hashtable, otherwise it will enumerate
         *        through the values in the hashtable.
         */
        public HashTableEnumerator(int init, boolean doKeys) {}

        /**
         * Creates an identical copy of this HashTable object.
         * @internalonly 
         */
        public Object clone() {}

        /**
         * @internalonly 
         */
        public boolean hasMoreItems() {}

        /**
         * @internalonly 
         */
        public Object nextItem() {}

        /**
         * @internalonly 
         */
        public void reset() {}
    }
}