//STRIPPEDSOURCE//

package com.ms.wfc.util;

import com.ms.wfc.core.*;
import java.lang.reflect.*;

/**
 * Provides a lightweight, dynamically sizing array.  This provides a lightweight dynamically sizing 
 * array. The only extra overhead, above the array items, is 12 bytes that are
 * used to store the increment, capacity, and version of the list. For a key-value
 * store see com.ms.wfc.util.HashTable.
 *
 * @security(checkClassLinking=on)
 */
public class List implements Cloneable {
    protected int capInc;
    protected int itemCount;
    protected Object items[];
    protected int version; 

    /**
     * Creates a new List. The list will have an initial size of 10 items,
     * and will have a capacity increment of 0. When a list is created with 
     * a 0 capacity increment, the list will double in size whenever the 
     * capacity is exceeded.
     */
    public List() {}

    /**
     * Creates a new List. The list will have an initial size of <i>capInit</I>
     * items,and will have a capacity increment of 0. When a list is created 
     * with a 0 capacity increment, the list will double in size whenever the 
     * capacity is exceeded.
     * 
     * @param capInit Initial capacity for the list.
     */
    public List(int capInit) {}

    /**
     * Creates a new List. The list will have an initial size of <i>capInit</I>
     * items,and will have a capacity increment of 0. When a list is created 
     * with a <i>capInc</I> capacity increment, the list will double in size 
     * whenever the capacity is exceeded.
     * 
     * @param capInit Initial capacity for the list.
     * @param capInc Amount to grow the capacity by when the current capacity 
     *        is exceeded.
     */
    public List(int capInit, int  capInc) {}

    /**
     * Creates a new List. The list will have an initial size of equal to <i>items</i> 
     * (and will contain a copy of <i>items</i>), and will have a capacity 
     * increment of 0. When a list is created with a 0 capacity increment, the list 
     * will double in size whenever the capacity is exceeded.
     * 
     * @param items Array of items to initially populate the list with.
     */
    public List(Object[] items) {}

    /**
     * Creates a new List. The list will have an initial size of equal to <i>items</i> 
     * (and will contain a copy of <i>items</i>), and will have a capacity 
     * increment of <i>capInc</i>. When a list is created with a 0 capacity increment, 
     * the list will double in size whenever the capacity is exceeded.
     * 
     * @param items Array of items to initially populate the list with.
     * @param capInc Amount to grow the capacity by when the current capacity 
     *        is exceeded.
     */
    public List(Object[] items, int capInc) {}

    /**
     * Adds an item to the list. If the capacity of the list is exceeded, it will
     * automatically grow.
     * 
     * @param item Item to add to the list.
     */
    public void addItem(Object item) {}

    /**
     * Adds all items to the list.  If the capacity of the 
     * list is exceeded, it will automatically grow.
     * 
     * @param items Array of items to add to the list.
     */
    public void addItems(Object[] items) {}

    /**
     * Adds all items to the list.  If the capacity of the list is exceeded,
     * it will automatically grow.
     * 
     * @param items Array of items to add to the list.
     * @param src Index in <i>items</i> to start adding items from.
     * @param count Number of items to add.
     */
    public void addItems(Object[] items, int src, int count) {}

    /**
     * Adds all items to the list.  If the capacity of the 
     * list is exceeded, it will automatically grow.
     * 
     * @param list List of items to add to the list.
     */
    public void addItems(List list) {}

    /**
     * Adds all items to the list.  If the capacity of the list is exceeded,
     * it will automatically grow.
     * 
     * @param list List of items to add to the list.
     * @param src Index in <i>items</i> to start adding items from.
     * @param count Number of items to add.
     */
    public void addItems(List list, int iSrc, int count) {}

    /**
     * Worker function that items from an array into this list.
     * 
     * @internalonly 
     */
    protected final void addItemsFromArray(Object[] itemsT, int iSrc, int count) {}

    /**
     * Creates an identical copy of this list. 
     * 
     * @return clone of this list.
     */
    public Object clone() {}

    /**
     * Creates an identical copy of this list. 
     * @internalonly 
     */
    protected void clone(List src) {}

    /**
     * Determines whether the specified item is contained in the list.
     * 
     * @param item Item to search for.
     * 
     * @return <b>true</b> if <i>item</i> is in the list; otherwise <b>false</b>.
     */
    public boolean containsItem(Object item) {}

    /**
     * Removes an item from the beginning of the list. This removes the item stored at the 0
     * index. This will remove the item stored
     * at the 0 index.
     * 
     * @return the item that was removed.
     * 
     * @throws EmptyQueueException if there are no items in the list.
     */
    public Object dequeueItem() {}

    /**
     * Removes an item from the beginning of the list. This removes the item stored at the 0
     * index.  This will remove the item stored
     * at the 0 index. 
     * 
     * @return the item that was removed, or <b>null</b> if there are no items 
     * in the list.
     */
    public Object dequeueItemOrNull() {}

    /**
     * Adds an item to the end of the list.  This will add an item at the 
     * itemCount + 1 index.
     * 
     * @param item Item to add to the list.
     */
    public void enqueueItem(Object item) {}

    /**
     * Ensures the minimum capacity of the list.  If the 
     * list is not large enough, the capacity will be increased by the
     * capacity increment. If the capacity increment is 0, the size of the
     * list will be doubled.
     * 
     * @param min Minimum capacity to ensure the last has.
     */
    public final void ensureCapacity(int min) {}

    /**
     * Tests for equality between this list and the object. 
     * 
     * @param obj Object to compare
     * 
     * @return <b>true</b> if the objects are equal.
     */
    public boolean equals(Object obj) {}

    /**
     * Searches the list for the specified item. 
     * 
     * @param item Item to search for.
     * 
     * @return index of <i>item</i> or -1 if it wasn't found.
     */
    public int findIndex(Object item) {}

    /**
     * Searches the list for the specified item. 
     * 
     * @param item Item to search for.
     * @param minIndex index to start searching at.
     * 
     * @return index of <i>item</i> or -1 if it wasn't found.
     */
    public int findIndex(Object item, int minIndex) {}

    /**
     * Searches for an item starting from the end of the list. 
     * 
     * @param item Item to search for.
     * 
     * @return index of <i>item</i> or -1 if it wasn't found.
     */
    public int findLastIndex(Object item) {}

    /**
     * Searches for an item starting from the end of the list. 
     * 
     * @param item Item to search for.
     * @param maxIndex index to start searching at.
     * 
     * @return index of <i>item</i> or -1 if it wasn't found.
     */
    public int findLastIndex(Object item, int maxIndex) {}

    /**
     * Retrieves the current capacity of the list. This doesn't reflect the number of items.  This doesn't
     * reflect the number of items.
     * 
     * @return the capacity of the list.
     * 
     * @see #getSize
     */
    public int getCapacity() {}

    /**
     * Retrieves an array containing all the items in the list. 
     * 
     * @return Object array contained all the items in the list.
     */
    public Object[] getAllItems() {}

    /**
     * Retrieves an array containing all the items in the list.  The resulting
     * array will be of type <i>cls</i>
     * 
     * @param cls Class to make the array.
     * 
     * @return <i>cls</i> array contained all the items in the list.
     */
    public Object[] getAllItems(Class cls) {}

    /**
     * Retrieves an array containing all the items in the list.  If <i>val</i>
     * is too small a WFCInvalidArgumentException will be thrown.
     * 
     * @param val Array to populate.
     * @return <i>val</i>.
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> is too small to hold 
     *         the contents of the list.
     */
    public Object[] getAllItems(Object[] val) {}

    /**
     * Retrieves an array containing all the items in the list.  If <i>val</i>
     * is too small a WFCInvalidArgumentException will be thrown.
     * 
     * @param val Array to populate.
     * @param offset Offset in <i>val</i> at which to start inserting items.
     * 
     * @return <i>val</i>.
     * 
     * @throws WFCInvalidArgumentException if <i>val</i> is too small to hold 
     *         the contents of the list.
     */
    public Object[] getAllItems(Object[] val, int offset) {}

    /**
     * Retrieves the item stored at the index location. 
     * 
     * @param index Index to retrieve the item for.
     * 
     * @return item stored at <i>index</i>
     */
    public Object getItem(int index) {}

    /**
     * Retrieves an enumerator for all the items in the list.
     * 
     * @return enumerator for the items in the list.
     */
    public IEnumerator getItemEnumerator() {}

    /**
     * Retrieves an array containing the items in the list starting at the specified index for
     * a designated number of items.
     * 
     * @param src Index to start retrieving items from
     * @param count Number of items to retrieve
     * 
     * @return Object array contained all the items requested.
     */
    public Object[] getItems(int src, int count) {}

    /**
     * Retrieves an array containing the items in the list starting at the specified index for
     * a designated number of items. The resulting array will be of
     * type <i>cls</i>.
     * 
     * @param src Index to start retrieving items from
     * @param count Number of items to retrieve
     * @param cls Class to make the array.
     * 
     * @return Object array contained all the items requested.
     */
    public Object[] getItems(int iSrc, int count, Class cls) {}

    /**
     * Retrieves an array containing the items in the list starting at the specified index for
     * a designated number of items.
     * 
     * @param src Index to start retrieving items from
     * @param count Number of items to retrieve
     * @param val Array to populate
     * 
     * @return <i>val</i>
     */
    public Object[] getItems(int src, int count, Object[] val) {}

    /**
     * Retrieves an array containing the items in the list starting at the specified index for
     * a designated number of items.
     * 
     * @param src Index to start retrieving items from
     * @param count Number of items to retrieve
     * @param val Array to populate
     * @param dst Index in <i>val</i> to start inserting items
     * 
     * @return <i>val</i>
     */
    public Object[] getItems(int src, int count, Object[] val, int dst) {}

    /**
     * Retrieves the current number of items stored in the list.
     * 
     * @return number of items in the list.
     */
    public int getSize() {}

    /**
     * Retrieves the current version of the list.  The version is incremented
     * when any change is made to the list.
     * 
     * @return version of the list.
     */
    public int getVersion() {}

    /**
     * Inserts the item at the specified position.   Any items that were stored
     * at <i>index</i> of farther back in the list will be moved back.
     * 
     * @param index Index to insert the item at.
     * @param item Item to insert.
     */
    public void insertItem(int index, Object item) {}

    /**
     * Inserts items starting at the specified position.  Any items that were
     * stored at <i>dst</i> or farther back in the list will be moved back.
     * 
     * @param dst Index to start inserting items at.
     * @param items Object array of items to insert into the list.
     */
    public void insertItems(int dst, Object[] items) {}

    /**
     * Inserts items starting at the specified position.  These items will be inserted into the list starting at the 
     * position <i>dst</i>. Any items that were stored at <i>dst</i> or
     * farther back in the list will be moved back.
     * 
     * @param dst Index to start inserting items at.
     * @param items Object array of items to insert into the list.
     * @param src Index in <i>items</i> to start inserting from.
     * @param count Number of items to insert.
     */
    public void insertItems(int dst, Object[] items, int src, int count) {}

    /**
     * Inserts items starting at the specified position.  Any items that were
     * stored at <i>dst</i> or farther back in the list will be moved back.
     * 
     * @param dst Index to start inserting items at.
     * @param list List of items to insert into the list.
     */
    public void insertItems(int dst, List list) {}

    /**
     * Inserts items starting at the specified position.  These items will be inserted into the list starting at the 
     * position <i>dst</i>. Any items that were stored at <i>dst</i> or
     * farther back in the list will be moved back.
     * 
     * @param dst Index to start inserting items at.
     * @param list List of items to insert into the list.
     * @param src Index in <i>items</i> to start inserting from.
     * @param count Number of items to insert.
     */
    public void insertItems(int dst, List list, int src, int count) {}
    
    /**
     * Worker function to insert arrays of items into the list.
     * 
     * @internalonly
     */
    protected final void insertItemsFromArray(int iDst, Object[] itemsT, int iSrc, int count) {}

    /**
     * Determines whether the list currently contains no items. 
     * 
     * @return <b>true</b> if the list is currently empty.
     */
    public boolean getEmpty() {}

    /**
     * Moves the item from the source index to the destination index. 
     * 
     * @param src Index of the item to move
     * @param dst Destination index of the item.
     */
    public void moveItem(int src, int dst) {}

    /**
     * Moves items starting from the source index to the destination index.
     * 
     * @param src Index of the first item to move
     * @param dst Destination index of the first item.
     * @param count Number of items to move
     */
    public void moveItems(int src, int dst, int count) {}

    /**
     * Retrieves the next item in the queue without removing it from the queue. This retrieves
     * the item at the beginning of the list.  This will retrieve the item in the front (index==0) of the
     * list.
     * 
     * @return next item in the queue.
     */
    public Object peekQueue() {}

    /**
     * Retrieves the topmost item in the stack without removing it. This retrieves the item at
     * the end of the list. This
     * will retrieve the item in the back (index==itemCount-1) of the list.
     * 
     * @return next item in the stack.
     */
    public Object peekStack() {}

    /**
     * Retrieves and removes the topmost item in the stack.  This will retrieve and remove
     * the item in the back (index == itemCount-1) of the list.
     * 
     * @return next item in the stack.
     * 
     * @throws EmptyStackException if there are no items in the stack
     */
    public Object popItem() {}

    /**
     * Retrieves and removes the topmost item in the stack.  This will retrieve and remove
     * the item in the back (index == itemCount-1) of the list.
     * 
     * @return next item in the stack, or null if there are no items in
     *         the stack.
     */
    public Object popItemOrNull() {}

    /**
     * Inserts an item into the stack.  This will insert an item at the
     * back (index == itemCount) of the list.
     * 
     * @param item Item to push onto the stack.
     */
    public void pushItem(Object item) {}

    /**
     * Removes all items from the list.
     */
    public void removeAllItems() {}

    /**
     * Removes the specified item from the list.
     * 
     * @param item Item to remove.
     * 
     * @return <b>true</b> if the item was remove, <b>false</b> if the item 
     *         was not found.
     */
    public boolean removeItem(Object item) {}

    /**
     * Removes the specified item from the list. All items after <i>index</i> are
     * shifted forward.
     * 
     * @param index Index to remove.
     * 
     * @return removed item.
     */
    public Object removeItem(int index) {}

    /**
     * Removes a number of items starting at the specified index.  
     * All items after <i>index</i> are shifted forward.
     * 
     * @param index Index to remove.
     * @param count Number of items to remove
     */
    public void removeItems(int index, int count) {}

    /**
     * Reverses all items in the list.
     */
    public void reverseItems() {}

    /**
     * Reverses all items in the list.
     * 
     * @param index Index to start reversing
     * @param count Number of items to reverse
     */
    public void reverseItems(int index, int count) {}

    /**
     * Work proc for reversing items
     * 
     * @internalonly 
     */
    protected final void reverseItemsCore(int iMin, int iLim) {}

    /**
     * Sets all the items in the list given an array of items.  The size of the
     * list will be modified to match the length of the array.
     * 
     * @param items Object array to set the list to.
     */
    public void setAllItems(Object[] items) {}

    /**
     * Sets an item in the list to be the specified item. 
     * 
     * @param index Index to set
     * @param item Item to store at <i>index</i>
     */
    public void setItem(int index, Object item) {}

    /**
     * Sets a number of items starting at the specified index.
     * 
     * @param dst Index to start setting at.
     * @param items Object array to set list item values to.
     */
    public void setItems(int dst, Object[] items) {}

    /**
     * Sets a number of items starting at the specified index. The items will be retrieved from
     * <i>items</i> starting at <i>src</i> for <i>count</i> items.
     * 
     * @param dst Index to start setting at.
     * @param items Object array to set list item values to.
     * @param src Index in <i>items</i> to start copying from.
     * @param count number of items to set.
     */
    public void setItems(int dst, Object[] items, int src, int count) {}

    /**
     * Sets a number of items starting at the specified index.
     * 
     * @param dst Index to start setting at.
     * @param list List to set list item values to.
     */
    public void setItems(int dst, List list) {}

    /**
     * Sets a number of items starting at the specified index. The items will be retrieved from
     * <i>list</i> starting at <i>src</i> for <i>count</i> items.
     * 
     * @param dst Index to start setting at.
     * @param list List to set list item values to.
     * @param src Index in <i>items</i> to start copying from.
     * @param count number of items to set.
     */
    public void setItems(int dst, List list, int src, int count) {}

    /**
     * Sets the number of items contained in the list.   If the new size is larger
     * that the old size the new items will be populated with nulls. If the new
     * size is smaller than the old size, items will be removed.
     * 
     * @param size new number of items it the list.
     */
    public void setSize(int size) {}

    /**
     * Sorts the entire list using the specified comparer.
     * 
     * @param comp IComparer to use to compare items.
     */
    public void sort(IComparer comp) {}

    /**
     * Sorts the entire list using the specified comparer.
     * 
     * @param comp IComparer to use to compare items.
     * @param index Index to start sorting at.
     * @param count Number of items to sort.
     */
    public void sort(IComparer comp, int index, int count) {}

    /**
     * Creates a string representation of this list.
     * 
     * @return string representation of this list.
     */
    public String toString() {}

    /**
     * Removes excess space from the list, ensuring that the capacity of the list is equal to
     * the number of items.
     */
    public void trimToSize() {}

    /**
     * Provides a lightweight, dynamically sizing array. 
     * 
     * @internalonly 
     *
     * @security(checkClassLinking=on)
     */
    protected class ListEnumerator implements IEnumerator {
        protected int iCur;

        /**
         * Creates a new ListEnumerator.
         * 
         * @param init Index to start enumerating from.
         */
        public ListEnumerator(int init) {}

        /**
         * Creates an identical copy of this list. 
         * @internalonly
         */
        public Object clone() {}

        /**
         * @internalonly
         */
        public boolean hasMoreItems() {}

        /**
         * @internalonly
         */
        public Object nextItem() {}

        /**
         * @internalonly
         */
        public void reset() {}
    }
}