//STRIPPEDSOURCE//
package com.ms.wfc.util;

import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.win32.*;
import com.ms.dll.*;
import com.ms.lang.*;

/**
 * Provides methods to perform a locale-based comparison of strings and the sorting of  arrays. 
 *
 * @security(checkClassLinking=on)
 */
public final class StringSorter
{
    /**
     * Specifies that case is ignored when comparing or sorting two strings. When this flag is specified in
     * calls to compare() and sort(), two strings are considered equal if they
     * differ only in casing.
     */
    public static final int IGNORECASE = 0x00000001;

    /**
     * Specifies that Hiragana and Katakana characters are not differentiated. When this
     * flag is specified in calls to compare() and sort(), corresponding
     * Hiragana and Katakana characters compare as equal.
     */
    public static final int IGNOREKANATYPE = 0x00010000;

    /**
     * Specifies that nonspacing characters (such as accents, diacritics, and vowel marks) are
     * ignored when comparing or sorting two strings. When 
     * this flag is specified in calls to compare() and sort(), strings compare
     * as equal if they differ only in how characters are accented.
     */
    public static final int IGNORENONSPACE = 0x00000002;

    /**
     * Specifies that symbols are ignored when comparing or sorting two strings. When this flag is specified in calls to compare() and
     * sort(), strings compare as equal if they differ only in what symbol
     * characters they contain.
     */
    public static final int IGNORESYMBOLS = 0x00000004;

    /**
     * Specifies that character widths are ignored when comparing or sorting two strings. When this flag is specified in calls to
     * compare() and sort(), string comparisons do not differentiate between a
     * single-byte character and the same character as a double-byte character.
     */
    public static final int IGNOREWIDTH = 0x00020000;

    /**
     * Specifies that punctuation and symbols are treated the same when comparing or sorting
     * strings. Typically, strings are compared
     * using what is called a "word sort" technique. In a word sort, all
     * punctuation marks and other nonalphanumeric characters, except for the
     * hyphen and the apostrophe, come before any alphanumeric character. The
     * hyphen and the apostrophe are treated differently than the other
     * nonalphanumeric symbols, in order to ensure that words such as "coop"
     * and "co-op" stay together within a sorted list. If the STRINGSORT flag
     * is specified, strings are compared using what is called a "string sort"
     * technique. In a string sort, the hyphen and apostrophe are treated just
     * like any other nonalphanumeric symbols: they come before the
     * alphanumeric symbols. 
     */
    public static final int STRINGSORT = 0x00001000;

    /**
     * Specifies that two strings are sorted in descending order. When this flag is specified in a call to sort(), the
     * strings are sorted in descending order. This flag should not be used in
     * calls to compare().
     */
    public static final int DESCENDING = 0x80000000;

    private static final int COMPARE_OPTIONS = IGNORECASE | IGNOREKANATYPE |
        IGNORENONSPACE | IGNORESYMBOLS | IGNOREWIDTH | STRINGSORT;

    private String[] keys;
    private Object[] items;
    private int lcid;
    private int options;
    private boolean descending;

    
    private StringSorter(Locale locale, String[] keys, Object[] items, int options) {}

	
	static int arrayLength(Object[] array) {}
	
    /**
     * Compares two strings. 
     *
     * @param s1 The first string.
     * @param s2 The second string.
     * @result -1 if s1 < s2, 0 if s1 == s2, 1 if s1 > s2.
     * @see #compare(Locale, String, String, options)
     */
    public static int compare(String s1, String s2) {}

    /**
     * Compares two strings. 
     *
     * @param s1 The first string.
     * @param s2 The second string.
     * @param options String comparison flags.
     * @result -1 if s1 < s2, 0 if s1 == s2, 1 if s1 > s2.
     * @see #compare(Locale, String, String, options)
     */
    public static int compare(String s1, String s2, int options) {}

    /**
     * Compares two strings.  If the two strings are of different lengths, they are compared up
     * to the length of the shortest one. If they are equal to that point, then
     * the return value will indicate that the longer string is greater. Notice
     * that if the return value is 0, the two strings are "equal" in the
     * collation sense, though not necessarily identical.<p>
     *
     * A <code>null</code> string always sorts before a non-null string. Two
     * <code>null</code> strings are considered equal.<p>
     *
     * The <code>options</code> parameter is a combination of zero or more of
     * the following flags: <code>IGNORECASE</code>, <code>IGNOREKANATYPE</code>,
     * <code>IGNORENONSPACE</code>, <code>IGNORESYMBOLS</code>,
     * <code>IGNOREWIDTH</code>, and <code>STRINGSORT</code>.
     *
     * @param locale The locale to use for comparing the strings.
     * @param s1 The first string.
     * @param s2 The second string.
     * @param options String comparison flags.
     * @result -1 if s1 < s2, 0 if s1 == s2, 1 if s1 > s2.
     * @see #IGNORECASE
     * @see #IGNOREKANATYPE
     * @see #IGNORENONSPACE
     * @see #IGNORESYMBOLS
     * @see #IGNOREWIDTH
     * @see #STRINGSORT
     */
    public static int compare(Locale locale, String s1, String s2, int options) {}

    
    private static int compare(int lcid, String s1, String s2, int options) {}

    
    private int compareKeys(String s1, String s2) {}

    
    private void quickSort(int left, int right) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array, the
     * <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the default locale.
     *
     * @param items The object array to sort.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Object[] items) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array,
     * the <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the default locale.
     *
     * @param items The object array to sort.
     * @param index The starting index in the array.
     * @param count The number of elements to sort.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Object[] items, int index, int count) {}

    /**
     * Sorts the elements in an object array.  The arrays are sorted using the default locale.
     *
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(String[] keys, Object[] items) {}

    /**
     * Sorts the elements in an object array.  The arrays are sorted using the
     * default locale.
     *
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @param index The starting index in the arrays.
     * @param count The number of elements to sort.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(String[] keys, Object[] items, int index, int count) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array, the
     * <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the default locale and the given sorting
     * options.
     *
     * @param items The object array to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Object[] items, int options) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array,
     * the <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the default locale and the given sorting
     * options.
     *
     * @param items The object array to sort.
     * @param index The starting index in the array.
     * @param count The number of elements to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Object[] items, int index, int count, int options) {}

    /**
     * Sorts the elements in an object array.  The arrays are sorted using the default locale and the
     * given sorting options.
     *
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(String[] keys, Object[] items, int options) {}

    /**
     * Sorts the elements in an object array.  The arrays are sorted using the
     * default locale and the given sorting options.
     *
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @param index The starting index in the arrays.
     * @param count The number of elements to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(String[] keys, Object[] items, int index, int count, int options) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array, the
     * <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the given locale and the given sorting
     * options.
     *
     * @param locale The locale to use when comparing strings. <code>null</code>
     * indicates the current locale.
     * @param items The object array to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Locale locale, Object[] items, int options) {}

    /**
     * Sorts the elements in an object array.  If the <code>items</code> parameter is not a string array,
     * the <code>toString</code> method of each of the elements is called to
     * produce the string representation. The objects are then sorted by their
     * string representations using the given locale and the given sorting
     * options.
     *
     * @param locale The locale to use when comparing strings. <code>null</code>
     * indicates the current locale.
     * @param items The object array to sort.
     * @param index The starting index in the array.
     * @param count The number of elements to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Locale locale, Object[] items, int index, int count, int options) {}

    /**
     * Sorts the elements in an object array.  The arrays are sorted using the given locale and the
     * given sorting options.
     *
     * @param locale The locale to use when comparing strings. <code>null</code>
     * indicates the current locale.
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @param options Sorting options.
     * @see #sort(Locale, String[], Object[], int, int, int)
     */
    public static void sort(Locale locale, String[] keys, Object[] items, int options) {}

    /**
     * Sorts the elements in an object array.  Elements in the <code>keys</code>
     * array specify the sort keys for corresponding elements in the
     * <code>items</code> array. The range of elements given by the
     * <code>index</code> and <code>count</code> parameters is sorted in both
     * arrays according to the given locale and sorting options.<p>
     *
     * If the <code>keys</code> parameter is <code>null</code>, the sort keys
     * are instead computed by calling the <code>toString</code> method of each
     * element in the <code>items</code> array.<p>
     *
     * <code>null</code> keys always sort before a non-null keys.<p>
     *
     * The <code>options</code> parameter is a combination of zero or more of
     * the following flags: <code>IGNORECASE</code>, <code>IGNOREKANATYPE</code>,
     * <code>IGNORENONSPACE</code>, <code>IGNORESYMBOLS</code>,
     * <code>IGNOREWIDTH</code>, <code>STRINGSORT</code>, and
     * <code>DESCENDING</code>.
     *
     * @param locale The locale to use when comparing strings. <code>null</code>
     * indicates the current locale.
     * @param keys The keys to sort by. If <code>null</code>, the sort key for
     * an item is produced by calling the <code>toString</code> method.
     * @param items The object array to sort.
     * @param index The starting index in the arrays.
     * @param count The number of elements to sort.
     * @param options Sorting options.
     * @see #IGNORECASE
     * @see #IGNOREKANATYPE
     * @see #IGNORENONSPACE
     * @see #IGNORESYMBOLS
     * @see #IGNOREWIDTH
     * @see #STRINGSORT
     * @see #DESCENDING
     */
    public static void sort(Locale locale, String[] keys, Object[] items, int index, int count, int options) {}
}