//STRIPPEDSOURCE//
package com.ms.wfc.util;

import com.ms.wfc.app.*;
import com.ms.wfc.win32.*;
import com.ms.com.*;
import com.ms.dll.*;
import com.ms.wfc.core.*;

/**
 * Provides methods for data type conversions, string formatting, and string parsing. 
 *
 * The data type conversion methods provided by the class support conversions
 * between primitive types (such as <i>int</i>, <i>double</i>, and
 * <i>boolean</i>), primitive wrapper objects (such as <i>Integer</i>,
 * <i>Double</i>, and <i>Boolean</i>), and variants (objects of type
 * <i>com.ms.com.Variant</i>). The conversion methods fall into four
 * categories, each of which are described below.
 *
 * public xxxx toXxxx(Object value);
 *
 *   Converts an object to a primitive type value. The argument can be a primitive
 *   wrapper object, a string, or a variant, and the result is the value of the
 *   argument converted to a primitive type.
 *
 * public Object toObject(xxxx value);
 *
 *   Converts a primitive type value or a variant value to a primitive wrapper
 *   object. If the argument is a primitive type value, the result is a primitive
 *   wrapper object of the corresponding type. If the argument is a variant, the
 *   result is a primitive wrapper object that corresponds to the dynamic type of
 *   the variant.
 *
 * public String toString(xxxx value);
 *
 *   Converts a primitive type value or an object to a string. If the argument is
 *   a primitive type value, the result is the string representation of the
 *   value. If the argument is an object, the result is the string produced by
 *   calling the object's <i>toString</i> method.
 *
 * public Variant toVariant(xxxx value);
 *
 *   Converts a primitive type value, a primitive wrapper object, or a string to
 *   a variant.
 *
 *   Variant type code        Java class
 *   ------------------------------------------
 *   VariantEmpty (0)         null
 *   VariantNull (1)          null
 *   VariantShort (2)         java.lang.Short
 *   VariantInt (3)           java.lang.Integer
 *   VariantFloat (4)         java.lang.Float
 *   VariantDouble (5)        java.lang.Double
 *   VariantCurrency (6)      java.lang.Double
 *   VariantDate (7)          com.ms.wfc.app.Time
 *   VariantString (8)        java.lang.String
 *   VariantDispatch (9)      java.lang.Object
 *   VariantError (10)        java.lang.Integer
 *   VariantBoolean (11)      java.lang.Boolean
 *   VariantUnknown (13)      java.lang.Object
 *   VariantDecimal (14)      java.lang.Double
 *   VariantSignedChar (16)   java.lang.Byte
 *   VariantByte (17)         java.lang.Byte
 *
 *   Java class               Variant type code
 *   --------------------------------------------
 *   java.lang.Object         VariantDispatch (9)
 *   java.lang.Boolean        VariantBoolean (11)
 *   java.lang.Character      VariantShort (2)
 *   java.lang.Byte           VariantByte (17)
 *   java.lang.Short          VariantShort (2)
 *   java.lang.Integer        VariantInt (3)
 *   java.lang.Long           VariantDouble (5)
 *   java.lang.Float          VariantFloat (4)
 *   java.lang.Double         VariantDouble (5)
 *   java.lang.String         VariantString (8)
 *   com.ms.wfc.app.Time             VariantDate (7)
 *
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public class Value
{
    /**
     * Assigns a value to a variant.  If <i>value</i> is a Variant, that
     * Variant is copied into <i>v</i>. If <i>value</i> is a primitive wrapper
     * object, a <i>String</i>, or a <i>Time</i>, the appropriate type code
     * and value is stored in the variant. If <i>value</i> an object of any
     * other type, a <i>Variant.VariantDispatch</i> value is stored in the
     * variant. If <i>value</i> is null, the type code of the variant is set to
     * <i>Variant.VariantNull</i>.<p>
     *
     * It is generally recommended that Variant objects be treated as immutable
     * entities. In other words, once a Variant object is created, changing the
     * value stored in the Variant is not recommended. Thus, use of the
     * <i>assignVariant</i> method should be avoided whenever possible, and
     * the <i>toVariant</i> method should be used instead.
     *
     * @param v The Variant to assign to.
     * @param value The value to assign to the Variant.
     */
    public static void assignVariant(Variant v, Object value) {}

    
    private static String bstrToString(int bstr) {}

    /**
     * Formats a value using a format string.
     *
     * @param value The value to format.
     * @param format User defined format string or name of a predefined format.
     * @return String containing the formatted value.
     * @see #format(Object, String)
     */
    public static String format(double value, String format) {}

    /**
     * Formats a value using a format string.
     *
     * @param value The value to format.
     * @param format User defined format string or name of a predefined format.
     * @return String containing the formatted value.
     * @see #format(Object, String)
     */
    public static String format(int value, String format) {}

    /**
     * Formats a value using a format string. The <i>value</i> parameter must
     * be a primitive wrapper object, a string, a Time object, a variant, or
     * the value null. The <i>format</i> parameter must contain a user defined
     * format string or the name of a predefined format.
     *
     * @param value The value to format.
     * @param format User defined format string or name of a predefined format.
     * @return String containing the formatted value.
     */
    public static String format(Object value, String format) {}

    /**
     * Formats a numeric value using currency formatting. The resulting string
     * is formatted according to the currency format settings of the current
     * locale.
     *
     * @param value The value to format.
     * @return String containing the formatted value.
     * @see #formatCurrency(double, int)
     * @see #formatCurrency(double, int, int)
     * @see #formatNumber
     */
    public static String formatCurrency(double value) {}

    /**
     * Formats a numeric value using currency formatting. The resulting string
     * is formatted according to the currency format settings of the current
     * locale using the specified number of decimal places.
     *
     * @param value The value to format.
     * @param decimalPlaces Number of decimal places in the resulting string,
     * or -1 for the default number of decimal places.
     * @return String containing the formatted value.
     * @see #formatCurrency(double)
     * @see #formatCurrency(double, int, int)
     * @see #formatNumber
     */
    public static String formatCurrency(double value, int decimalPlaces) {}

    /**
     * Formats a numeric value using currency formatting. The resulting string
     * is formatted according to the currency format settings of the current
     * locale using the specified number of decimal places and the specified
     * formatting options. The formatting options allow you to selectively
     * enable or disable the leading digit on values less than 1, parentheses
     * around negative numbers, and the use of thousand separators.
     *
     * @param value The value to format.
     * @param decimalPlaces Number of decimal places in the resulting string,
     * or -1 for the default number of decimal places.
     * @param options A combination of zero or more flags from the NumberFormat
     * enumeration.
     * @return String containing the formatted value.
     * @see com.ms.wfc.util.NumberFormat
     * @see #formatCurrency(double)
     * @see #formatCurrency(double, int)
     * @see #formatNumber
     */
    public static String formatCurrency(double value, int decimalPlaces, int options) {}

    /**
     * Formats a numeric value using number formatting. The resulting string
     * is formatted according to the number format settings of the current
     * locale.
     *
     * @param value The value to format.
     * @return String containing the formatted value.
     * @see #formatNumber(double, int)
     * @see #formatNumber(double, int, int)
     * @see #formatCurrency
     */
    public static String formatNumber(double value) {}

    /**
     * Formats a numeric value using number formatting. The resulting string
     * is formatted according to the number format settings of the current
     * locale using the specified number of decimal places.
     *
     * @param value The value to format.
     * @param decimalPlaces Number of decimal places in the resulting string,
     * or -1 for the default number of decimal places.
     * @return String containing the formatted value.
     * @see #formatNumber(double)
     * @see #formatNumber(double, int, int)
     * @see #formatCurrency
     */
    public static String formatNumber(double value, int decimalPlaces) {}

    /**
     * Formats a numeric value using number formatting. The resulting string
     * is formatted according to the number format settings of the current
     * locale using the specified number of decimal places and the specified
     * formatting options. The formatting options allow you to selectively
     * enable or disable the leading digit on values less than 1, parentheses
     * around negative numbers, and the use of thousand separators.
     *
     * @param value The value to format.
     * @param decimalPlaces Number of decimal places in the resulting string,
     * or -1 for the default number of decimal places.
     * @param options A combination of zero or more flags from the NumberFormat
     * enumeration.
     * @return String containing the formatted value.
     * @see com.ms.wfc.util.NumberFormat
     * @see #formatNumber(double)
     * @see #formatNumber(double, int)
     * @see #formatCurrency
     */
    public static String formatNumber(double value, int decimalPlaces, int options) {}

    /**
     * Determines whether a specified value is null. The returned value is true if the
     * argument is null or if the argument is a variant with a dynamic type of
     * Variant.VariantEmpty or Variant.VariantNull.
     *
     * @param value The value to check.
     * @return True if the value is null or an empty or null variant, false
     * otherwise.
     */
    public static boolean isNull(Object value) {}

    /**
     * Converts a string to a number. This method accepts strings that were
     * formatted using the <i>formatCurrency</i> and <i>formatNumber</i>
     * methods. In other words, strings may contain thousand separators,
     * currency symbols, or enclosing parentheses. Leading and trailing blanks
     * are allowed and ignored.
     *
     * @param value String containing a numeric value.
     * @return The converted number.
     * @exception NumberFormatException if the string cannot be interpreted
     * as a number.
     * @see #formatCurrency
     * @see #formatNumber
     */
    public static double parseNumber(String value) {}

    /**
     * Converts an object to a boolean
     * value.  The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>false.</td></tr>
     *   <tr><td>Boolean</td><td>The boolean value stored in the object.
     *     Produced by calling <i>Boolean.booleanValue</i>.</td></tr>
     *   <tr><td>String</td><td>true if string equals "true" (case insensitive),
     *     false otherwise.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to boolean.
     *     Produced by calling <i>Variant.toBoolean</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The boolean value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(boolean)
     * @see java.lang.Boolean#booleanValue
     * @see com.ms.com.Variant#toBoolean
     */
    public static boolean toBoolean(Object value) {}

    /**
     * Converts an object to a byte
     * value. The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The low-order byte of the character stored
     *     in the object. Produced by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The byte value of the object. Produced by
     *     calling <i>Number.byteValue</i>.</td></tr>
     *   <tr><td>String</td><td>The result of converting the numeric string to
     *     a byte value. Produced by calling <i>Byte.parseByte</i>.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to a byte
     *     value. Produced by calling <i>Variant.toByte</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The byte value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(byte)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#byteValue
     * @see java.lang.Byte#parseByte
     * @see com.ms.com.Variant#toByte
     */
    public static byte toByte(Object value) {}

    /**
     * Converts an object to a character. The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The character stored in the object. Produced
     *     by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The character value of the object. Produced by
     *     calling <i>Number.shortValue</i> and coercing the result to char.</td></tr>
     *   <tr><td>String</td><td>The first character of the string, or zero if
     *     the length of the string is zero.</td></tr>
     *   <tr><td>Variant</td><td>The character value of the variant. Produced by
     *     calling <i>Variant.toShort</i> and coercing the result to char.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The char value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(char)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#shortValue
     * @see com.ms.com.Variant#toShort
     */
    public static char toChar(Object value) {}

    /**
     * Converts an object to a double value.  The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The character stored in the object. Produced
     *     by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The double value of the object. Produced by
     *     calling <i>Number.doubleValue</i>.</td></tr>
     *   <tr><td>String</td><td>The result of converting the numeric string to
     *     a double value. Produced by calling <i>Double.valueOf(String)</i>.</td></tr>
     *   <tr><td>Time</td><td>The double value of the object. Produced by
     *     calling <i>Time.toDouble</i>.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to a double
     *     value. Produced by calling <i>Variant.toDouble</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The double value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(double)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#doubleValue
     * @see java.lang.Double#valueOf(String)
     * @see com.ms.wfc.app.Time#toDouble
     * @see com.ms.com.Variant#toDouble
     */
    public static double toDouble(Object value) {}

    /**
     * Converts an object to a float value.  The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The character stored in the object. Produced
     *     by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The float value of the object. Produced by
     *     calling <i>Number.floatValue</i>.</td></tr>
     *   <tr><td>String</td><td>The result of converting the numeric string to
     *     a float value. Produced by calling <i>Float.valueOf(String)</i>.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to a float
     *     value. Produced by calling <i>Variant.toFloat</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The float value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(float)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#floatValue
     * @see java.lang.Float#valueOf(String)
     * @see com.ms.com.Variant#toFloat
     */
    public static float toFloat(Object value) {}

    /**
     * Converts an object to an integer value.  The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The character stored in the object. Produced
     *     by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The integer value of the object. Produced by
     *     calling <i>Number.intValue</i>.</td></tr>
     *   <tr><td>String</td><td>The result of converting the numeric string to
     *     an integer value. Produced by calling <i>Integer.parseInt</i>.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to an integer
     *     value. Produced by calling <i>Variant.toInt</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The integer value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(int)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#intValue
     * @see java.lang.Integer#parseInt
     * @see com.ms.com.Variant#toInt
     */
    public static int toInt(Object value) {}

    /**
     * Converts an object to a long value.  The table below lists the supported
     * argument types and the resulting conversion. If the argument is not of a
     * supported type and value, a <i>ClassCastException</i> occurs.<br>
     * <table>
     *   <tr><td>null</td><td>0.</td></tr>
     *   <tr><td>Character</td><td>The character stored in the object. Produced
     *     by calling <i>Character.charValue</i>.</td></tr>
     *   <tr><td>Number</td><td>The long value of the object. Produced by
     *     calling <i>Number.longValue</i>.</td></tr>
     *   <tr><td>String</td><td>The result of converting the numeric string to
     *     a long value. Produced by calling <i>Long.parseLong</i>.</td></tr>
     *   <tr><td>Time</td><td>The long value of the object. Produced by
     *     calling <i>Time.toLong</i>.</td></tr>
     *   <tr><td>Variant</td><td>The result of coercing the variant to a double
     *     value and then casting the result to long. Produced by calling
     *     <i>Variant.toDouble</i>.</td></tr>
     * </table>
     *
     * @param value The value to convert.
     * @result The long value of the argument.
     * @exception ClassCastException if the argument cannot be converted.
     * @see #toObject(long)
     * @see java.lang.Character#charValue
     * @see java.lang.Number#longValue
     * @see java.lang.Long#parseLong
     * @see com.ms.wfc.app.Time#toLong
     * @see com.ms.com.Variant#toDouble
     */
    public static long toLong(Object value) {}

    /**
     * Converts a boolean value to an object.  This method returns <i>Boolean.TRUE</i>
     * or <i>Boolean.FALSE</i> depending on the argument.
     *
     * @param value The value to convert.
     * @return A <i>Boolean</i> object containing the given value.
     * @see #toBoolean
     */
    public static Object toObject(boolean value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Byte</i> object
     * containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Byte</i> object containing the given value.
     * @see #toByte
     */
    public static Object toObject(byte value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Character</i>
     * object containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Character</i> object containing the given value.
     * @see #toChar
     */
    public static Object toObject(char value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Double</i>
     * object containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Double</i> object containing the given value.
     * @see #toDouble
     */
    public static Object toObject(double value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Float</i>
     * object containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Float</i> object containing the given value.
     * @see #toFloat
     */
    public static Object toObject(float value) {}

    /**
     * Converts a boolean value to an object.  This method returns an <i>Integer</i>
     * object containing the given value.
     *
     * @param value The value to convert.
     * @return An <i>Integer</i> object containing the given value.
     * @see #toInt
     */
    public static Object toObject(int value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Long</i> object
     * containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Long</i> object containing the given value.
     * @see #toLong
     */
    public static Object toObject(long value) {}

    /**
     * Converts a boolean value to an object.  This method returns a <i>Short</i> object
     * containing the given value.
     *
     * @param value The value to convert.
     * @return A <i>Short</i> object containing the given value.
     * @see #toShort
     */
    public static Object toObject(short value) {}

    /**
     * Converts a boolean value to an object.  If the <i>value</i>
     * argument is a variant, the returned value is a primitive wrapper object
     * of the corresponding type and with the corresponding value. The
     * following table lists the supported variant type codes and the
     * corresponding primitive wrapper object types.<br>
     * <table>
     *   <tr><td>VariantEmpty (0)</td><td>null</td></tr>
     *   <tr><td>VariantNull (1)</td><td>null</td></tr>
     *   <tr><td>VariantShort (2)</td><td>java.lang.Short</td></tr>
     *   <tr><td>VariantInt (3)</td><td>java.lang.Integer</td></tr>
     *   <tr><td>VariantFloat (4)</td><td>java.lang.Float</td></tr>
     *   <tr><td>VariantDouble (5)</td><td>java.lang.Double</td></tr>
     *   <tr><td>VariantCurrency (6)</td><td>java.lang.Double</td></tr>
     *   <tr><td>VariantDate (7)</td><td>com.ms.wfc.app.Time</td></tr>
     *   <tr><td>VariantString (8)</td><td>java.lang.String</td></tr>
     *   <tr><td>VariantDispatch (9)</td><td>java.lang.Object</td></tr>
     *   <tr><td>VariantError (10)</td><td>java.lang.Integer</td></tr>
     *   <tr><td>VariantBoolean (11)</td><td>java.lang.Boolean</td></tr>
     *   <tr><td>VariantUnknown (13)</td><td>java.lang.Object</td></tr>
     *   <tr><td>VariantDecimal (14)</td><td>java.lang.Double</td></tr>
     *   <tr><td>VariantSignedChar (16)</td><td>java.lang.Byte</td></tr>
     *   <tr><td>VariantByte (17)</td><td>java.lang.Byte</td></tr>
     * </table>
     * If the <i>value</i> parameter passed to this method is not a variant,
     * or if the variant type code is not one of the values listed above, the
     * method simply returns <i>value</i>. In other words, any argument that
     * isn't a variant of one of the above type codes is simply returned
     * unchanged.
     *
     * @param value The value to convert.
     * @return A <i>Short</i> object containing the given value.
     * @see #toShort
     */
    public static Object toObject(Object value) {}

    public static short toShort(Object value) {}

    public static String toString(boolean value) {}

    public static String toString(byte value) {}

    public static String toString(char value) {}

    public static String toString(double value) {}

    public static String toString(float value) {}

    public static String toString(int value) {}

    public static String toString(long value) {}

    public static String toString(short value) {}

    public static String toString(Object value) {}

    public static Variant toVariant(boolean value) {}

    public static Variant toVariant(byte value) {}

    public static Variant toVariant(char value) {}

    public static Variant toVariant(double value) {}

    public static Variant toVariant(float value) {}

    public static Variant toVariant(int value) {}

    public static Variant toVariant(long value) {}

    public static Variant toVariant(short value) {}

    public static Variant toVariant(Object value) {}

    

    private static final int VT_EMPTY = 0;
    private static final int VT_NULL = 1;
    private static final int VT_I2 = 2;
    private static final int VT_I4 = 3;
    private static final int VT_R4 = 4;
    private static final int VT_R8 = 5;
    private static final int VT_CY = 6;
    private static final int VT_DATE = 7;
    private static final int VT_BSTR = 8;
    private static final int VT_DISPATCH = 9;
    private static final int VT_ERROR = 10;
    private static final int VT_BOOL = 11;
    private static final int VT_VARIANT = 12;
    private static final int VT_UNKNOWN = 13;
    private static final int VT_DECIMAL = 14;
    private static final int VT_I1 = 16;
    private static final int VT_UI1 = 17;

    

    private static final int VT_TYPEMASK = 0x0FFF;
    private static final int VT_VECTOR = 0x1000;
    private static final int VT_ARRAY = 0x2000;
    private static final int VT_BYREF = 0x4000;
    private static final int VT_RESERVED = 0x8000;

    /** @dll.import("oleaut32", unicode) */
    public static final native int SysFreeString(int bstr);
    
    private static final native void VarFormat(Variant pvarIn, String pstrFormat, int iFirstDay, int iFirstWeek, int dwFlags, int[] pbstrOut);
    
    private static final native void VarFormatNumber(Variant pvarIn, int iNumDig, int iIncLead, int iUseParens, int iGroup, int dwFlags, int[] pbstrOut);
    
    private static final native void VarFormatCurrency(Variant pvarIn, int iNumDig, int iIncLead, int iUseParens, int iGroup, int dwFlags, int[] pbstrOut);
    
    private static final native int VarR8FromStr(String strIn, int lcid, int dwFlags, double[] pdblOut);
}