//STRIPPEDSOURCE//

package com.ms.wfc.win32;

import com.ms.win32.*;
import com.ms.dll.DllLib;
import com.ms.dll.Callback;
import com.ms.dll.ArrayWithOffset;
import com.ms.com.IUnknown;
import com.ms.wfc.ole32.*;
import com.ms.wfc.util.*;

/** 
 * Contains the WFC implementation for most Win32 function calls.  Most
 * Win32 constants are defined in com.ms.win32 package in the win class.
 * 
 * @hidden
 * @security(checkDllCalls=off)
 * @security(checkClassLinking=on)
 */
public class Windows {
    /**
     * These are WFC specific messages that we add for our convenience.
     */
    public static final int WM_REFLECT          = win.WM_USER + 0x1C00;
    public static final int WM_CTLCOLOR         = 0x0019;

    
    

    
    public static final int FF_MODERN           =(3<<4);  

    
    public static final int WAIT_OBJECT_0    = 0x00000000;
    public static final int WAIT_FAILED      = 0xFFFFFFFF;
    public static final int WAIT_TIMEOUT     = 0x00000102;
    public static final int WAIT_ABANDONED   = 0x00000080;
    public static final int WAIT_ABANDONED_0 = WAIT_ABANDONED;

    public static final String MSH_MOUSEWHEEL   = "MSWHEEL_ROLLMSG";
    public static final String MSH_SCROLL_LINES = "MSH_SCROLL_LINES_MSG";
    public static final String MSH_WHEELSUPPORT = "MSH_WHEELSUPPORT_MSG";
    public static final String MOUSEZ_CLASSNAME = "MouseZ";
    public static final String MOUSEZ_TITLE     = "Magellan MSWHEEL";

    public static final int HWND_TOP = 0;
    public static final int HWND_BOTTOM = 1;
    public static final int HWND_TOPMOST = -1;
    public static final int HWND_NOTOPMOST = -2;

    
    
    public static final int SRCCOPY             = 0x00CC0020;
    public static final int SRCPAINT            = 0x00EE0086;
    public static final int SRCAND              = 0x008800C6;
    public static final int SRCINVERT           = 0x00660046;
    public static final int SRCERASE            = 0x00440328;
    public static final int NOTSRCCOPY          = 0x00330008;
    public static final int NOTSRCERASE         = 0x001100A6;
    public static final int MERGECOPY           = 0x00C000CA;
    public static final int MERGEPAINT          = 0x00BB0226;
    public static final int PATCOPY             = 0x00F00021;
    public static final int PATPAINT            = 0x00FB0A09;
    public static final int PATINVERT           = 0x005A0049;
    public static final int DSTINVERT           = 0x00550009;
    public static final int BLACKNESS           = 0x00000042;
    public static final int WHITENESS           = 0x00FF0062;


    public static final int SM_XVIRTUALSCREEN     =  76; 
    public static final int SM_YVIRTUALSCREEN     =  77; 
    public static final int SM_CXVIRTUALSCREEN    =  78; 
    public static final int SM_CYVIRTUALSCREEN    =  79; 
    public static final int SM_CMONITORS          =  80; 
    public static final int SM_SAMEDISPLAYFORMAT  =  81; 

    public static final int SM_CMETRICS           =  83;

    
    public static final int STD_INPUT_HANDLE  = -10;
    public static final int STD_OUTPUT_HANDLE = -11;
    public static final int STD_ERROR_HANDLE  = -12;

    /**
     * Handle type for accelerator tables.
     * @hidden
     */
    public static final int ACCELERATORHANDLE  = HandleCollector.registerType("Accelerator", 80);

    /**
     * handle type for cursors.
     * @hidden
     */
    public static final int CURSORHANDLE       = HandleCollector.registerType("Cursor", 20);

    /**
     * Handle type for enhanced metafiles.
     * @hidden
     */
    public static final int EMFHANDLE          = HandleCollector.registerType("EnhancedMetaFile", 20);

    /**
     * Handle type for file find handles.
     * @hidden
     */
    public static final int FINDHANDLE         = HandleCollector.registerType("Find", 0);

    /**
     * Handle type for GDI objects.
     * @hidden
     */
    public static final int GDIHANDLE          = HandleCollector.registerType("GDI", 90);

    /**
     * Handle type for HDC's.
     * @hidden
     */
    public static final int HDCHANDLE          = HandleCollector.registerType("HDC", 100);

    /**
     * Handle type for icons.
     * @hidden
     */
    public static final int ICONHANDLE         = HandleCollector.registerType("Icon", 20);

    /**
     * Handle type for kernel objects.
     * @hidden
     */
    public static final int KERNELHANDLE       = HandleCollector.registerType("Kernel", 0);

    /**
     * Handle type for files.
     * @hidden
     */
    public static final int MENUHANDLE         = HandleCollector.registerType("Menu", 30);

    /**
     * Handle type for windows.
     * @hidden
     */
    public static final int WINDOWHANDLE       = HandleCollector.registerType("Window", 5);
    
    
    

    #if DEBUG
    #endif 

    
    private static native boolean intCloseHandle(int handle);
    public static boolean CloseHandle(int handle) {}
    
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean CopyFile(String src, String dst, boolean failIfExists);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory", unicode) */
    public static native void CopyMemoryW(int pdst, String psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory", unicode) */
    public static native void CopyMemoryW(int pdst, char[] psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory") */
    public static native void CopyMemory(int pdst, byte[] psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory", unicode) */
    public static native void CopyMemoryW(StringBuffer pdst, int psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory", unicode) */
    public static native void CopyMemoryW(char[] pdst, int psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory") */
    public static native void CopyMemory(byte[] pdst, int psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory") */
    public static native void CopyMemory(int pdst, int psrc, int cb);
    /** @dll.import("KERNEL32", entrypoint="RtlMoveMemory") */
    public static native void CopyMemory(int pdst, String psrc, int cb);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean CreateDirectory(String src, SECURITY_ATTRIBUTES sa);

    
    private static native int intCreateFile(String lpFileName,int dwDesiredAccess,int dwShareMode,
        int lpSecurityAttributes, int dwCreationDisposition,int dwFlagsAndAttributes,int hTemplateFile);
    public static int CreateFile(String lpFileName,int dwDesiredAccess,int dwShareMode,
        int lpSecurityAttributes, int dwCreationDisposition,int dwFlagsAndAttributes,int hTemplateFile) {}
    
    
    private native static boolean intCreateProcess(String lpApplicationName, String lpCommandLine, SECURITY_ATTRIBUTES lpProcessAttributes, SECURITY_ATTRIBUTES lpThreadAttributes, boolean bInheritHandles, int dwCreationFlags, int lpEnvironment, String lpCurrentDirectory, STARTUPINFO lpStartupInfo, PROCESS_INFORMATION lpProcessInformation);
    public static boolean CreateProcess(String lpApplicationName, String lpCommandLine, SECURITY_ATTRIBUTES lpProcessAttributes, SECURITY_ATTRIBUTES lpThreadAttributes, boolean bInheritHandles, int dwCreationFlags, int lpEnvironment, String lpCurrentDirectory, STARTUPINFO lpStartupInfo, PROCESS_INFORMATION lpProcessInformation) {}

    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean DeleteFile(String name);

    
    private static native int intDuplicateHandle(int processSource, int handleSource, int processTarget, int [] handleTarget, int desiredAccess, boolean inheritHandle, int options);
    public static int DuplicateHandle(int processSource, int handleSource, int processTarget, int [] handleTarget, int desiredAccess, boolean inheritHandle, int options) {}

    
    private static native boolean intFindClose(int handle);
    public static boolean FindClose(int handle) {}

    
    private static native int intFindFirstFile(String path, WIN32_FIND_DATA data);
    public static int FindFirstFile(String path, WIN32_FIND_DATA data) {}
    
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean FindNextFile(int handle, WIN32_FIND_DATA data);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int FlushFileBuffers(int hFile);
    /** @dll.import("kernel32", auto) */
    public static native int FormatMessage(int dwFlags, int lpSource, int dwMessageId,
        int dwLanguageId, StringBuffer lpBuffer, int nSize, int arguments);
    /** @dll.import("kernel32", auto) */
    public static native int GetACP();
    /** @dll.import("kernel32", auto) */
    public static native boolean GetCPInfo(int codePage, CPINFO cpInfo);
    /** @dll.import("kernel32", auto, setLastError) */
    public static native int GetCurrentDirectory(int nBufferLength, StringBuffer lpBuffer);
    /** @dll.import("kernel32", auto) */
    public static native int GetCurrentProcess();
    /** @dll.import("kernel32", auto) */
    public static native int GetCurrentProcessId();
    /** @dll.import("kernel32", auto) */
    public static native int GetCurrentThread();
    /** @dll.import("kernel32", auto) */
    public static native int GetCurrentThreadId();
    /** @dll.import("kernel32", auto) */
    public static native int GetEnvironmentVariable(String lpName, StringBuffer lpBuffer, int nSize);
    /** @dll.import("KERNEL32", auto) */
    public native static boolean GetExitCodeProcess(int hProcess, int[] lpExitCode);
    /** @dll.import("kernel32", auto) */
    public static native int GetDateFormat(int Locale, int dwFlags, SYSTEMTIME lpDate, String lpFormat, StringBuffer lpDateStr, int cchDate);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean GetFileInformationByHandle(int hFile, BY_HANDLE_FILE_INFORMATION bhfi);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int GetFileAttributes(String name);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int GetFileSize(int hFile, int[] high);
    /** @dll.import("kernel32", auto) */
    public static native boolean GetFileTime(int hFile, long[] creationTime, long[] lastAccessTime, long[] lastWriteTime);
    /** @dll.import("kernel32", auto) */
    public static native int GetFileType(int hFile);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int GetFullPathName(String path, int cb, int buffer, int[] filePart);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int GetFullPathName(String path, int cb, StringBuffer buffer, int[] filePart);
    /** @dll.import("KERNEL32", auto) */
    public native static int GetLastError();
    /** @dll.import("kernel32", auto) */
    public static native int GetLogicalDrives();
    /** @dll.import("kernel32", auto) */
    public static native int GetModuleFileName(int hModule, StringBuffer buffer, int length);
    /** @dll.import("kernel32", auto) */
    public static native int GetModuleHandle(String modName);
    /** @dll.import("kernel32", auto) */
    public static native int GetOEMCP();
    /** @dll.import("kernel32", auto) */
    public static native int GetStartupInfo(STARTUPINFO startupinfo);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int GetStdHandle(int type);
    /** @dll.import("kernel32", ansi) */
    public static native int GetProcAddress(int hModule, String lpProcName);
    /** @dll.import("KERNEL32", auto) */
    public native static boolean GetStringTypeEx(int Locale, int dwInfoType, String lpSrcStr, int cchSrc, short[] lpCharType);
    /** @dll.import("kernel32", auto) */
    public static native int GetTempFileName(String lpPathName, String lpPrefixString, int uUnique, StringBuffer lpTempFileName);
    /** @dll.import("kernel32", auto) */
    public static native int GetTempPath(int nBufferLength, StringBuffer lpBuffer);
    /** @dll.import("kernel32", auto) */
    public static native int GetThreadLocale();
    /** @dll.import("kernel32", auto) */
    public static native int GetTickCount();
    /** @dll.import("kernel32", auto) */
    public static native int GetTimeFormat(int Locale, int dwFlags, SYSTEMTIME lpTime, String lpFormat, StringBuffer lpTimeStr, int cchTime);
    /** @dll.import("kernel32", auto, setLastError) */
    public static native short GlobalAddAtom(String atomName);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalAlloc(int uFlags, int dwBytes);
    /** @dll.import("kernel32", auto) */
    public static native short GlobalDeleteAtom(short atom);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalLock(int handle);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalFlags(int handle);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalReAlloc(int handle, int bytes, int flags);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalSize(int handle);
    /** @dll.import("kernel32", auto) */
    public static native int GlobalFree(int handle);
    /** @dll.import("kernel32", auto) */
    public static native boolean GlobalUnlock(int handle);
    /** @dll.import("kernel32", auto, setLastError) */
    public static native boolean LockFile(int handle, long offset, long count);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean MoveFile(String src, String dst);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int MulDiv(int nNumber, int nNumerator, int nDenominator);
    /** @dll.import("kernel32", unicode) */
    public static native int MultiByteToWideChar(int CodePage, int dwFlags,
        byte[] lpMultiByteStr, int cchMultiByte, char[] lpWideCharStr, int cchWideChar);
    /** @dll.import("kernel32", auto) */
    public static native void OutputDebugString(String message);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean ReadFile(int hFile, byte[] buffer,
        int numBytes, int[] numBytesRead, int lpOverlapped);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean ReadFile(int hFile, int lpBuffer,
        int numBytes, int[] numBytesRead, int lpOverlapped);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean ReadFile(int hFile, ArrayWithOffset lpBuffer,
        int numBytes, int[] numBytesRead, int lpOverlapped);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean RemoveDirectory(String name);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean SetEndOfFile(int hFile);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean SetFileAttributes(String name, int attributes);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native int SetFilePointer(int hFile, int low, int[] high, int from);
    /** @dll.import("kernel32", auto) */
    public static native boolean SetFileTime(int hFile, long[] creationTime, long[] lastAccessTime, long[] lastWriteTime);
    /** @dll.import("KERNEL32", auto, setLastError) */
    public native static boolean SetLocaleInfo(int Locale, int LCType, String lpLCData);
    /** @dll.import("KERNEL32", auto) */
    public native static boolean SetThreadLocale(int Locale);
    /** @dll.import("kernel32") */
    public static native void Sleep(int ms);
    /** @dll.import("kernel32", setLastError) */
    public static native int TlsAlloc();
    /** @dll.import("kernel32", setLastError) */
    public static native void TlsFree(int slot);
    /** @dll.import("kernel32", setLastError) */
    public static native int TlsGetValue(int slot);
    /** @dll.import("kernel32", setLastError) */
    public static native boolean TlsSetValue(int slot, int value);
    /** @dll.import("kernel32", auto, setLastError) */
    public static native boolean UnlockFile(int handle, long offset, long count);
    /** @dll.import("kernel32", setLastError) */
    public static native int WaitForSingleObject(int handle, int timeout);
    /** @dll.import("kernel32", unicode) */
    public static native int WideCharToMultiByte(int CodePage, int dwFlags,
        char[] lpWideCharStr, int cchWideChar, byte[] lpMultiByteStr, int cchMultiByte,
        int lpDefaultChar, int lpUsedDefaultChar);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean WriteFile(int hFile, byte[] buffer,
        int numBytes, int[] numBytesWritten, int lpOverlapped);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean WriteFile(int hFile, int lpBuffer,
        int numBytes, int[] numBytesWritten, int lpOverlapped);
    /** @dll.import("kernel32", auto,setLastError) */
    public static native boolean WriteFile(int hFile, ArrayWithOffset lpBuffer,
        int numBytes, int[] numBytesWritten, int lpOverlapped);

    public static void OleInitialize() {}
    
    private static native int InternalOleInitialize(int val);
    /** @dll.import("ole32", auto) */
    public static native int OleUninitialize();
    /** @dll.import("ole32", auto) */
    public static native int RegisterDragDrop(int hwnd, IOleDropTarget target);
    /** @dll.import("ole32", auto) */
    public static native int RevokeDragDrop(int hwnd);
    /** @dll.import("ole32", auto) */
    public static native int DoDragDrop(IOleDataObject dataObject, IOleDropSource dropSource, int allowedEffects, int[] finalEffect);
    /** @dll.import("ole32", ole) */
    public static native ILockBytes CreateILockBytesOnHGlobal(int hGlobal, boolean fDeleteOnRelease);
    /** @dll.import("ole32", ole) */
    public static native int GetHGlobalFromILockBytes(ILockBytes pLkbyt);
    /** @dll.import("ole32", ole) */
    public static native IStorage StgCreateDocfileOnILockBytes(ILockBytes iLockBytes, int grfMode, int reserved);
    /** @dll.import("ole32", ole) */
    public static native IStorage StgOpenStorageOnILockBytes(ILockBytes iLockBytes, IStorage pStgPriority, int grfMode, int sndExcluded, int reserved);
    /** @dll.import("ole32", auto) */
    public static native boolean IsAccelerator(int hAccel, int cAccelEntries, MSG lpMsg, short[] lpwCmd);

    /** @dll.import("shell32", auto) */
    public static native int Shell_NotifyIcon(int message, NOTIFYICONDATA pnid);

    /** @dll.import("user32", auto) */
    public static native int AdjustWindowRectEx(RECT lpRect, int dwStyle, boolean bMenu, int dwExStyle);
    /** @dll.import("user32", auto) */
    public static native int BeginDeferWindowPos(int nNumWindows);

    
    private static native int intBeginPaint(int hWnd, PAINTSTRUCT lpPaint);
    public static int BeginPaint(int hWnd, PAINTSTRUCT lpPaint) {}
    
    /** @dll.import("user32", auto) */
    public static native int CallNextHookEx(int hhook, int code, int wparam, int lparam);
    /** @dll.import("user32", auto) */
    public static native int CallWindowProc(int wndProc, int hWnd, int msg,
        int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public static native int ChildWindowFromPoint(int hwndParent, int x, int y);
    /** @dll.import("user32", auto) */
    public static native int ChildWindowFromPointEx(int hwndParent, int x, int y, int uFlags);
    /** @dll.import("user32", auto) */
    public static native boolean ClipCursor(RECT rcClip);
    /** @dll.import("user32", auto) */
    public static native boolean CloseClipboard();

    
    private static native int intCopyImage(int hImage, int uType, int cxDesired, int cyDesired, int fuFlags);
    public static int CopyImage(int hImage, int uType, int cxDesired, int cyDesired, int fuFlags) {}

    
    private static native int intCreateAcceleratorTable( short [] entries, int cCount);
    public static int CreateAcceleratorTable( short [] entries, int cCount) {}

    
    private static native int intCreateMenu();
    public static int CreateMenu() {}

    
    private static native int intCreatePopupMenu();
    public static int CreatePopupMenu() {}

    
    private static native int intCreateWindowEx(int  dwExStyle, String lpszClassName,
        String lpszWindowName, int style, int x, int y, int width, int height,
        int hWndParent, int hMenu, int hInst, int pvParam);
    public static int CreateWindowEx(int  dwExStyle, String lpszClassName,
        String lpszWindowName, int style, int x, int y, int width, int height,
        int hWndParent, int hMenu, int hInst, int pvParam) {}
    
    /** @dll.import("user32", auto) */
    public static native int CountClipboardFormats();
    /** @dll.import("user32", auto) */
    public static native int DeferWindowPos(int hWinPosInfo, int hWnd, int hWndInsertAfter,
        int x, int y, int cx, int cy, int flags);
    /** @dll.import("user32", auto) */
    public static native int DefFrameProc(int hWnd, int hWndClient, int msg, int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public static native int DefMDIChildProc(int hWnd, int msg, int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public static native int DefWindowProc(int hWnd, int msg, int wParam, int lParam);

    
    private static native boolean intDestroyAcceleratorTable(int hAccel);
    public static boolean DestroyAcceleratorTable(int hAccel) {}

    
    private static native boolean intDestroyCursor(int hCurs);
    public static boolean DestroyCursor(int hCurs) {}

    
    private static native boolean intDestroyIcon(int hIcon);
    public static boolean DestroyIcon(int hIcon) {}

    
    private static native boolean intDestroyMenu(int hMenu);
    public static boolean DestroyMenu(int hMenu) {}

    
    private static native boolean intDestroyWindow(int hWnd);
    public static boolean DestroyWindow(int hWnd) {}
    
    /** @dll.import("user32", auto) */
    public static native int DispatchMessage(MSG msg);
    /** @dll.import("user32", auto) */
    public static native boolean DrawEdge(int hDC, RECT rect, int edge, int flags);
    /** @dll.import("user32", auto) */
    public static native boolean DrawFocusRect(int hDC, RECT rect);
    /** @dll.import("user32", auto) */
    public static native boolean DrawFrameControl(int hDC, RECT rect, int type, int state);
    /** @dll.import("user32", auto) */
    public static native boolean DrawIcon(int hDC, int x, int y, int hIcon);
    /** @dll.import("user32", auto) */
    public static native boolean DrawIconEx(int hDC, int x, int y, int hIcon, int width, int height, int iStepIfAniCursor, int hBrushFlickerFree, int diFlags);
    /** @dll.import("user32", auto) */
    public static native boolean DrawMenuBar(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean EmptyClipboard();
    /** @dll.import("user32", auto) */
    public static native boolean EnableWindow(int hWnd, boolean enable);
    /** @dll.import("user32", auto) */
    public static native boolean EndDeferWindowPos(int hWinPosInfo);

    
    private static native boolean intEndPaint(int hWnd, PAINTSTRUCT lpPaint);
    public static boolean EndPaint(int hWnd, PAINTSTRUCT lpPaint) {}
    
    /** @dll.import("user32", auto) */
    public static native int EnumClipboardFormats(int format);
    /** @dll.import("user32", auto) */
    public native static boolean EnumThreadWindows(int dwThreadId, com.ms.dll.Callback lpfn, int lParam);
    /** @dll.import("user32", auto) */
    public static native int FillRect(int hDC, RECT rect, int hBrush);
    /** @dll.import("user32", auto) */
    public static native int FindWindow(String className, String windowName);
    /** @dll.import("user32", auto) */
    public static native int FrameRect(int hDC, RECT rect, int hBrush);
    /** @dll.import("user32", auto) */
    public static native int GetActiveWindow();
    /** @dll.import("user32", auto) */
    public static native short GetAsyncKeyState(int vkey);
    /** @dll.import("user32", auto) */
    public static native int  GetCapture();
    /** @dll.import("user32", auto) */
    public static native boolean GetClassInfo(int hInst, String lpszClass, WNDCLASS wc);
    /** @dll.import("user32", auto) */
    public static native boolean GetClassInfo(int hInst, String lpszClass, int h);
    /** @dll.import("user32", auto) */
    public static native boolean GetClientRect(int hWnd, RECT rect);
    /** @dll.import("user32", auto, setLastError) */
    public static native int  GetClipboardData(int format);
    /** @dll.import("user32", auto) */
    public static native int GetClipboardFormatName(int format, StringBuffer lpString, int cchMax);
    /** @dll.import("user32", auto) */
    public static native int GetClipboardOwner();
    /** @dll.import("user32", auto) */
    public static native int GetClipboardViewer();
    /** @dll.import("user32", auto) */
    public native static boolean GetClipCursor(RECT lpRect);
    /** @dll.import("user32", auto) */
    public static native boolean GetCursorPos(POINT pt);

    
    private static native int intGetDC(int hWnd);
    public static int GetDC(int hWnd) {}

    
    private static native int intGetDCEx(int hWnd, int hrgnClip, int flags);
    public static int GetDCEx(int hWnd, int hrgnClip, int flags) {}
    
    /** @dll.import("user32", auto) */
    public static native int GetDlgItem(int hWnd, int nIDDlgItem);
    /** @dll.import("user32", auto) */
    public static native int GetDlgItemInt(int hWnd, int nIDDlgItem, boolean[] err, boolean signed);
    /** @dll.import("user32", auto) */
    public static native int GetDesktopWindow();
    /** @dll.import("user32", auto) */
    public static native int GetFocus();
    /** @dll.import("user32", auto) */
    public static native int GetForegroundWindow();
    /** @dll.import("user32", auto) */
    public static native boolean GetIconInfo(int hIcon, ICONINFO info);
    /** @dll.import("user32", auto) */
    public static native int GetKeyboardState(byte [] keystate);
    /** @dll.import("user32", auto) */
    public static native int GetKeyNameText(int lParam, StringBuffer lpString, int nSize);
    /** @dll.import("user32", auto) */
    public static native short GetKeyState(int keyCode);
    /** @dll.import("user32", auto) */
    public static native int GetMenuItemCount(int hMenu);
    /** @dll.import("user32", auto) */
    public static native int GetMenuItemID(int hMenu, int nPos);
    /** @dll.import("user32", auto) */
    public static native boolean GetMenuItemInfo(int hMenu, int uItem, boolean fByPosition, MENUITEMINFO_T lpmii);
    /** @dll.import("user32", auto) */
    public static native boolean GetMessage(MSG msg, int hWnd, int uMsgFilterMin, int uMsgFilterMax);
    /** @dll.import("user32", auto) */
    public static native int GetMessagePos();
    /** @dll.import("user32", auto) */
    public static native int GetOpenClipboardWindow();
    /** @dll.import("user32", auto) */
    public static native int GetParent(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int GetPriorityClipboardFormat(int [] rgPriorityList, int cEntries);
    /** @dll.import("user32", auto) */
    public static native int GetProp(int hWnd, int atom);
    /** @dll.import("user32", auto) */
    public static native int GetProp(int hWnd, String name);
    /** @dll.import("user32", auto) */
    public static native boolean GetScrollInfo(int hWnd, int fnBar, SCROLLINFO si);
    /** @dll.import("user32", auto) */
    public static native int GetSubMenu(int hwnd, int index);
    /** @dll.import("user32", auto) */
    public static native int GetSysColor(int nIndex);
    /** @dll.import("user32", auto) */
    public static native int GetSysColorBrush(int nIndex);
    /** 
     * The constants for this method can be found in the com.ms.win32.win class.
     * @dll.import("user32", auto) 
     */
    public static native int GetSystemMetrics(int nIndex);
    /** @dll.import("user32", auto) */
    public static native int GetSystemMenu(int hWnd, boolean bRevert);
    /** @dll.import("user32", auto) */
    public static native boolean GetUpdateRect(int hwnd, RECT rc, boolean fErase);
    /** @dll.import("user32", auto) */
    public static native boolean GetUpdateRgn(int hwnd, int hrgn, boolean fErase);
    /** @dll.import("user32", auto) */
    public static native int GetWindow(int hWnd, int uCmd);
    /** @dll.import("user32", auto) */
    public static native int GetWindowContextHelpId(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int GetMenuContextHelpId(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int GetWindowLong(int hWnd, int nIndex);
    /** @dll.import("user32", auto) */
    public static native int GetWindowThreadProcessId(int hWnd, int[] lpdwProcessId);
    /** @dll.import("user32", auto) */
    public static native boolean GetWindowRect(int hWnd, RECT rect);
    /** @dll.import("user32", auto) */
    public static native int GetWindowText(int hWnd, StringBuffer lpString, int nMaxCount);
    /** @dll.import("user32", auto) */
    public static native int GetWindowTextLength(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int GetWindowPlacement(int hWnd, WINDOWPLACEMENT placement);
    /** @dll.import("user32", auto) */
    public static native int DrawText(int hDC, String lpszString, int nCount, RECT lpRect, int nFormat);
    
    /** @dll.import("user32", auto) */
    public static native int EnableMenuItem(int hMenu, int UIDEnabledItem, int uEnable);
    /** @dll.import("user32", auto) */
    public static native boolean IntersectRect(RECT rectDest, RECT rectSource1, RECT rectSource2);

    #if DEBUG
    
    private static native boolean intInvalidateRect(int hWnd, RECT rect, boolean erase);
    public static boolean InvalidateRect(int hWnd, RECT rect, boolean erase) {}
    #else
    /** @dll.import("user32", auto) */
    public static native boolean InvalidateRect(int hWnd, RECT rect, boolean erase);
    #endif 
    /** @dll.import("user32", auto) */
    public static native boolean InvalidateRgn(int hWnd, int hrgn, boolean erase);
    /** @dll.import("user32", auto) */
    public native static boolean InsertMenuItem(int hMenu, int uItem, boolean fByPosition, MENUITEMINFO_T lpmii);
    /** @dll.import("user32", auto) */
    public native static boolean IsChild(int parent, int child);
    /** @dll.import("user32", auto) */
    public static native boolean IsClipboardFormatAvailable(int format);
    /** @dll.import("user32", auto) */
    public static native boolean IsDialogMessage(int hDlg, MSG msg);
    /** @dll.import("user32", auto) */
    public static native boolean IsIconic(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean IsWindow(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean IsWindowEnabled(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean IsWindowVisible(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean IsZoomed(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int  LoadBitmap(int hInstance, String lpBitmapName);
    /** @dll.import("user32", auto) */
    public static native int  LoadBitmap(int hInstance, int lpBitmapName);
    /** @dll.import("user32", auto) */
    public static native void keybd_event(byte vk, byte scan, int flags, int extrainfo);
    /** @dll.import("user32", auto) */
    public static native boolean KillTimer(int hwnd, int idEvent);
    /** @dll.import("user32", auto) */
    public static native int LoadCursor(int hInst, int iconId);
    /** @dll.import("user32", auto) */
    public static native int LoadCursorFromFile(String filename);
    /** @dll.import("user32", auto) */
    public static native int LoadIcon(int hInst, int iconId);
    /** @dll.import("user32", auto) */
    public static native int LoadImage(int hinst, String name, int type, int cx, int cy, int fload);
    /** @dll.import("user32", auto) */
    public static native int MapVirtualKey(int uCode, int uMapType);
    /** @dll.import("user32", auto) */
    public static native int MapWindowPoints(int hWndFrom, int hWndTo, RECT rect, int cPoints);
    /** @dll.import("user32", auto) */
    public static native int MapWindowPoints(int hWndFrom, int hWndTo, POINT pt, int cPoints);
    /** @dll.import("user32", auto) */
    public static native boolean MessageBeep(int type);
    /** @dll.import("user32", auto) */
    public static native int MessageBox(int hWnd, String text, String caption, int type);
    /** @dll.import("user32", auto) */
    public static native boolean OpenClipboard(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean PeekMessage(MSG msg, int hwnd, int msgMin, int msgMax, int remove);
    /** @dll.import("user32", auto) */
    public static native int PostMessage(int hwnd, int msg, int wparam, int lparam);
    /** @dll.import("user32", auto) */
    public static native void PostQuitMessage(int nExitCode);
    /** @dll.import("user32", auto) */
    public static native void PostThreadMessage(int id, int msg, int wparam, int lparam);

    
    private native static boolean PtInRect_I (RECT lprc, int pt_x, int pt_y);
    public static boolean PtInRect (RECT lprc, POINT pt) {}

    /** @dll.import("user32", auto) */
    public static native boolean RedrawWindow(int hwnd, RECT rcUpdate, int hrgnUpdate, int flags);
    /** @dll.import("user32", auto) */
    public static native boolean ReleaseCapture();
    /** @dll.import("user32", auto, setLastError) */
    public static native int RegisterClass(WNDCLASS wc);
    /** @dll.import("user32", auto) */
    public static native int RegisterClipboardFormat(String format);
    /** @dll.import("user32", auto) */
    public static native int RegisterWindowMessage(String msg);

    
    private static native int intReleaseDC(int hWnd, int hDC);
    public static int ReleaseDC(int hWnd, int hDC) {}
    
    /** @dll.import("user32", auto) */
    public static native boolean RemoveMenu(int hMenu, int uPosition,     int uFlags);
    /** @dll.import("user32", auto) */
    public static native int RemoveProp(int hWnd, int atom);
    /** @dll.import("user32", auto) */
    public static native int RemoveProp(int hWnd, String propName);
    /** @dll.import("user32", auto) */
    public static native int ScreenToClient( int hWnd, POINT pt );
    /** @dll.import("user32", auto) */
    public static native boolean ScrollDC(int hDC, int dx, int dy, RECT lpRectScroll,
        RECT lpRectClip, int hRgn, RECT lpRectUpdate);
    /** @dll.import("user32", auto) */
    public static native boolean ScrollWindow(int hWnd, int nXAmount, int nYAmount, RECT rectScrollRegion, RECT rectClip);
    /** @dll.import("user32", auto) */
    public static native boolean ScrollWindowEx(int hWnd, int nXAmount, int nYAmount, RECT rectScrollRegion, RECT rectClip, int hrgnUpdate, RECT prcUpdate, int flags);
    /** @dll.import("user32", auto) */
    public native static int SendDlgItemMessage(int hDlg, int nIDDlgItem, int Msg, int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public static native int SendMessage(int hWnd, int msg, int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public native static int SendMessage (int hWnd, int Msg, int wParam, Object lParam);
    /** @dll.import("user32", auto) */
    public native static int SendMessage (int hWnd, int Msg, Object wParam, Object lParam);
    /** @dll.import("user32", unicode, entrypoint="SendMessageW") */
    public static native int SendMessageW(int hWnd, int msg, int wParam, int lParam);
    /** @dll.import("user32", ansi, entrypoint="SendMessageA") */
    public static native int SendMessageA(int hWnd, int msg, int wParam, int lParam);
    /** @dll.import("user32", auto) */
    public static native int SendMessageTimeout(int hWnd, int msg, int wParam, int lParam, int flags, int timeout, int[]pdwResult);
    /** @dll.import("user32", auto) */
    public static native int SetActiveWindow(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int SetCapture(int hwnd);
    /** @dll.import("user32", auto, setLastError) */
    public static native int  SetClipboardData(int format, int hMem);
    /** @dll.import("user32", auto) */
    public static native int SetClipboardViewer(int hwndNewViewer);
    /** @dll.import("user32", auto) */
    public static native int SetCursor(int hcursor);
    /** @dll.import("user32", auto) */
    public static native boolean SetCursorPos(int x, int y);
    /** @dll.import("user32", auto) */
    public static native int SetFocus(int hWnd);
    /** @dll.import("user32", auto) */
    public static native boolean SetForegroundWindow(int hWnd);
    /** @dll.import("user32", auto) */
    public static native int SetKeyboardState(byte [] keystate);
    /** @dll.import("user32", auto) */
    public native static boolean SetMenu(int hWnd, int hMenu);
    /** @dll.import("user32", auto) */
    public native static boolean SetMenuDefaultItem(int hMenu, int uItem, boolean fByPosition);
    /** @dll.import("user32", auto) */
    public native static boolean SetMenuItemInfo(int hMenu, int uItem, boolean fByPosition, MENUITEMINFO_T lpmii);
    /** @dll.import("user32", auto) */
    public static native int SetParent(int hWnd, int hWndParent);
    /** @dll.import("user32", auto) */
    public static native boolean SetProp(int hWnd, int atom, int data);
    /** @dll.import("user32", auto) */
    public static native boolean SetProp(int hWnd, String propName, int data);
    /** @dll.import("user32", auto) */
    public static native int SetScrollInfo(int hWnd, int fnBar, SCROLLINFO si, boolean redraw);
    /** @dll.import("user32", auto) */
    public static native int SetTimer(int hWnd, int nIDEvent, int uElapse, int lpTimerFunc);
    /** @dll.import("user32", auto) */
    public static native int SetWindowContextHelpId(int hWnd, int dwContextHelpId);
    /** @dll.import("user32", auto) */
    public static native int SetMenuContextHelpId(int hWnd, int dwContextHelpId);
    /** @dll.import("user32", auto) */
    public static native int SetWindowLong(int hWnd, int nIndex, int dwNewLong);
    /** @dll.import("user32", auto) */
    public static native boolean SetWindowPos(int hWnd, int hWndInsertAfter,
        int x, int y, int cx, int cy, int flags);

    
    private static native int intSetWindowRgn(int hwnd, int hrgn, boolean fRedraw);
    public static int SetWindowRgn(int hwnd, int hrgn, boolean fRedraw) {}
    
    /** @dll.import("user32", auto) */
    public static native int SetWindowsHookEx(int hookid, int pfnhook, int hinst, int threadid);
    /** @dll.import("user32", auto) */
    public static native boolean SetWindowText(int hWnd, String text);
    /** @dll.import("user32", auto) */
    public static native int SetWindowPlacement(int hWnd, WINDOWPLACEMENT placement);
    /** @dll.import("user32", auto) */
    public native static int ShowCursor(boolean bShow);
    /** @dll.import("user32", auto) */
    public native static boolean ShowScrollBar(int handle, int wBar, boolean bShow);
    /** @dll.import("user32", auto) */
    public static native boolean ShowWindow(int hWnd, int nCmdShow);
    /** @dll.import("user32", auto) */
    public static native boolean SystemParametersInfo(int nAction, int nParam, RECT rc, int nUpdate);
    /** @dll.import("user32", auto) */
    public static native boolean SystemParametersInfo(int nAction, int nParam, boolean [] flag, boolean nUpdate);
    public static boolean TrackMouseEvent(TRACKMOUSEEVENT tme) {}
    /** @dll.import("user32", auto) */
    public static native int TrackPopupMenuEx(int hmenu, int fuFlags, int x, int y, int hwnd, TPMPARAMS tpm);
    /** @dll.import("user32", auto) */
    public static native boolean TranslateAccelerator(int hwnd, int haccel, MSG msg);
    /** @dll.import("user32", auto) */
    public static native boolean TranslateMDISysAccel(int hWndClient, MSG msg);
    /** @dll.import("user32", auto) */
    public static native boolean TranslateMessage(MSG msg);
    /** @dll.import("user32", auto) */
    public static native int UnhookWindowsHookEx(int hhook);
    /** @dll.import("user32", auto, setLastError) */
    public static native boolean UnregisterClass(String className, int hInstance);
    /** @dll.import("user32", auto) */
    public static native boolean UpdateWindow(int hWnd);
    /** @dll.import("user32", auto) */
    public static native short VkKeyScan(char key);
    /** @dll.import("user32", auto) */
    public static native boolean ValidateRect(int hwnd, RECT rect);
    /** @dll.import("user32", auto) */
    public static native boolean ValidateRgn(int hwnd, int hrgn);
    /** @dll.import("user32", auto) */
    public static native int WindowFromPoint(int x, int y);
    /** @dll.import("gdi32", auto)  */
    public static native boolean AnimatePalette(int hpal, int iStartIndex, int cEntries, int ppe);
    /** @dll.import("gdi32", auto)  */
    public static native boolean AnimatePalette(int hpal, int iStartIndex, int cEntries, PALETTEENTRY ppe);

    
    private static native boolean intDeleteObject(int hObject);
    public static boolean DeleteObject(int hObject) {}
    
    /** @dll.import("gdi32", auto) */
    public static native int GetObjectType(int hObject);
    /** @dll.import("gdi32", auto) */
    public static native int GetStockObject(int nIndex);
    /** @dll.import("gdi32", auto) */
    public static native boolean UnrealizeObject(int hObject);
    
    
    private static native int intCreatePen(int nStyle, int nWidth, int crColor);
    public static int CreatePen(int nStyle, int nWidth, int crColor) {}
    
    
    private static native int intCreatePenIndirect(LOGPEN lp);
    public static int CreatePenIndirect(LOGPEN lp) {}

    
    private static native int intCreateSolidBrush(int crColor);
    public static int CreateSolidBrush(int crColor) {}
    
    
    private static native int intCreateHatchBrush(int nIndex, int crColor);
    public static int CreateHatchBrush(int nIndex, int crColor) {}

    
    private static native int intCreateBrushIndirect(LOGBRUSH lb);
    public static int CreateBrushIndirect(LOGBRUSH lb) {}
    
    
    private static native int intCreateFont(int nHeight, int nWidth,
        int nEscapement, int nOrientation, int fnWeight, int fdwItalic,
        int fdwUnderline, int fdwStrikeOut, int fdwCharSet,
        int fdwOutputPrecision, int fdwClipPrecision, int fdwQuality,
        int fdwPitchAndFamily, String lpszFace);
    public static int CreateFont(int nHeight, int nWidth,
        int nEscapement, int nOrientation, int fnWeight, int fdwItalic,
        int fdwUnderline, int fdwStrikeOut, int fdwCharSet,
        int fdwOutputPrecision, int fdwClipPrecision, int fdwQuality,
        int fdwPitchAndFamily, String lpszFace) {}

    
    private static native int intCreateFontIndirect(LOGFONT lf);
    public static int CreateFontIndirect(LOGFONT lf) {}

    
    private static native int intCreateDC(String lpszDriverName, String lpszDeviceName, String lpszOutput, DEVMODE lpInitData);
    public static int CreateDC(String lpszDriverName, String lpszDeviceName, String lpszOutput, DEVMODE lpInitData) {}

    
    private static native int intCreateIC(String lpszDriverName, String lpszDeviceName, String lpszOutput, DEVMODE lpInitData);
    public static int CreateIC(String lpszDriverName, String lpszDeviceName, String lpszOutput, DEVMODE lpInitData) {}

    
    private static native int intCreateCompatibleDC(int hDC);
    public static int CreateCompatibleDC(int hDC) {}
    
    /** @dll.import("user32", auto) */
    public static native int ExcludeUpdateRgn(int hDC, int hWnd);
    /** @dll.import("gdi32", auto) */
    public static native int GetDeviceCaps(int hDC, int nIndex);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetBrushOrgEx(int hDC, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetBrushOrgEx(int hDC, int x, int y, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native int GetNearestColor(int hDC, int crColor); 
    /** @dll.import("gdi32", auto) */
    public static native int RealizePalette(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean UpdateColors(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetBkColor(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetBkMode(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetPolyFillMode(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetROP2(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetStretchBltMode(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetTextColor(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetMapMode(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetMetaFileBitsEx(int hmf, int size, int pvData);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetViewportOrgEx(int hDC, POINT pt);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetViewportExtEx(int hDC, SIZE s);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetWindowOrgEx(int hDC, POINT pt);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetWindowExtEx(int hDC, SIZE s);

    
    private static native int intCreateRectRgn(int x1, int y1, int x2, int y2);
    public static int CreateRectRgn(int x1, int y1, int x2, int y2) {}
    
    
    private static native int intCreateRectRgnIndirect(RECT rc);
    public static int CreateRectRgnIndirect(RECT rc) {}

    
    private static native int intCreateEllipticRgn(int x1, int y1, int x2, int y2);
    public static int CreateEllipticRgn(int x1, int y1, int x2, int y2) {}

    
    private static native int intCreateEllipticRgnIndirect(RECT rc);
    public static int CreateEllipticRgnIndirect(RECT rc) {}

    
    private static native int intCreateRoundRectRgn(int x1, int y1, int x2, int y2, int x3, int y3);
    public static int CreateRoundRectRgn(int x1, int y1, int x2, int y2, int x3, int y3) {}
    
    
    private static native int intCreatePolygonRgn(int points, int count, int mode);
    public static int CreatePolygonRgn(int points, int count, int mode) {}

    
    private static native int intCreatePolyPolygonRgn(int points, int lpPolyCounts[], int count, int mode);
    public static int CreatePolyPolygonRgn(int points, int lpPolyCounts[], int count, int mode) {}

    
    private static native int intPathToRegion(int hDC);
    public static int PathToRegion(int hDC) {}
    
    /** @dll.import("gdi32", auto) */
    public static native boolean SetRectRgn(int hRgn, int x1, int y1, int x2, int y2);
    /** @dll.import("gdi32", auto) */
    public static native int CombineRgn(int hRgn, int hRgn1, int hRgn2, int nCombineMode);
    /** @dll.import("gdi32", auto) */
    public static native int OffsetRgn(int m_hObject, int x, int y);
    /** @dll.import("gdi32", auto) */
    public static native boolean RectInRegion(int hRgn, RECT lpRect);
    /** @dll.import("gdi32", auto) */
    public static native int GetRgnBox(int hRgn, RECT lpRect);
    /** @dll.import("gdi32", auto) */
    public static native boolean PtInRegion(int hRgn, int x, int y);
    /** @dll.import("gdi32", auto) */
    public static native boolean EqualRgn(int hRgn1, int hRgn2);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetViewportExtEx(int hDC, int x, int y, SIZE size);
    /** @dll.import("user32", auto) */
    public static native boolean DrawState(int hDC, int hBrush, int lpOutputFunc, int lData, int wData, int x, int y, int cx, int cy, int uFlags);
    /** @dll.import("user32", auto) */
    public static native boolean DrawState(int hDC, int hBrush, Callback pProc, int lData, int wData, int x, int y, int cx, int cy, int uFlags);
    /** @dll.import("user32", auto) */
    public static native boolean DrawState(int hDC, int hBrush, int lpOutputFunc, String lData, int wData, int x, int y, int cx, int cy, int uFlags);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetCharABCWidths(int hDC, int nFirstChar, int nLastChar, ABC lpabc);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetCharABCWidthsFloat(int hDC, int nFirstChar, int nLastChar, ABCFLOAT lpabc);
    /** @dll.import("gdi32", auto) */
    public static native boolean RoundRect(int hDC, int x1, int y1, int x2, int y2, int x3, int y3);
    /** @dll.import("gdi32", auto) */
    public static native int GetClipBox(int hDC, RECT lpRect);
    /** @dll.import("gdi32", auto) */
    public static native int ExcludeClipRect(int hDC, int x1, int y1, int x2, int y2);
    /** @dll.import("gdi32", auto) */
    public static native boolean RectVisible(int hDC, RECT lpRect);
    /** @dll.import("gdi32", auto) */
    public static native boolean FloodFill(int hDC, int x, int y, int crColor);
    /** @dll.import("gdi32", auto) */
    public static native int SetTextAlign(int hDC, int nFlags);
    /** @dll.import("gdi32", auto) */
    public static native boolean TextOut(int hDC, int x, int y, String lpszString, int nCount);

    
    private static native boolean intDeleteDC(int hDC);
    public static boolean DeleteDC(int hDC) {}
    
    /** @dll.import("gdi32", auto) */
    public static native boolean AngleArc(int hDC, int x, int y, int nRadius, float fStartAngle, float fSweepAngle);
    /** @dll.import("gdi32", auto) */
    public static native boolean AbortPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean BeginPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean CloseFigure(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean EndPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean FillPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean FlattenPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean SelectClipPath(int hDC, int nMode);
    /** @dll.import("gdi32", auto) */
    public static native int GetClipRgn(int hDC, int hRgn);
    /** @dll.import("gdi32", auto) */
    public static native int SelectClipRgn(int hDC, int hRgn);
    /** @dll.import("gdi32", auto) */
    public static native boolean ScaleViewportExtEx(int hDC, int xNum, int xDenom, int yNum, int yDenom, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native boolean FrameRgn(int hDC, int hRgn, int hBrush, int nWidth, int nHeight);
    /** @dll.import("gdi32", auto) */
    public static native boolean PaintRgn(int hDC, int hRgn);
    /** @dll.import("gdi32", auto) */
    public static native boolean OffsetWindowOrgEx(int hDC, int nWidth, int nHeight, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetWindowExtEx(int hDC, int x, int y, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native int OffsetClipRgn(int hDC, int x, int y);
    /** @dll.import("gdi32", auto) */
    public static native int SetBoundsRect(int hDC, RECT lpRectBounds, int flags);
    /** @dll.import("gdi32", auto) */
    public static native int IntersectClipRect(int hDC, int x1, int y1, int x2, int y2);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetColorAdjustment(int hDC, COLORADJUSTMENT lpColorAdjust);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetCurrentPositionEx(int hDC, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native int GetRegionData(int hRgn, int size, byte[] data);
    /** @dll.import("gdi32") */
    public static native boolean LPtoDP(int hDC, POINT lpPoint, int nCount);
    /** @dll.import("gdi32") */
    public static native boolean LPtoDP(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean LPtoDP(int hDC, SIZE lpSize, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean LPtoDP(int hDC, RECT lpRect, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean DPtoLP(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean DPtoLP(int hDC, POINT lpPoint, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean DPtoLP(int hDC, SIZE lpSize, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean DPtoLP(int hDC, RECT lpRect, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native int SelectObject(int hDC, int hObject);
    /** @dll.import("user32", auto) */
    public static native boolean GrayString(int hDC, int hBrush, int lpOutputFunc,
        String lpData, int nCount, int X, int Y, int nWidth, int nHeight);
    /** @dll.import("gdi32", auto) */
    public static native boolean Pie(int hDC, int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4);
    /** @dll.import("gdi32", auto) */
    public static native int StartDoc(int hDC, DOCINFO lpDocInfo);
    /** @dll.import("gdi32", auto) */
    public static native int StartPage(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int EndPage(int hDC);
    
    /** @dll.import("gdi32", auto) */
    public static native int AbortDoc(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int EndDoc(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int GetCurrentObject(int hDC, int nObjectType);
    /** @dll.import("gdi32", auto) */
    public static native int GetDIBColorTable(int hdc, int uStartIndex, int cEntries, int  pEntries);
    /** @dll.import("gdi32", auto) */
    public static native int SetBkColor(int hDC, int clr);
    /** @dll.import("gdi32", auto) */
    public static native boolean ExtTextOut(int hDC, int x, int y, int nOptions, RECT lpRect, String s, int nStrLength, int lpDx[]);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetTextExtentPoint(int hDC, String lpszString, int nCount, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native int SetMapMode(int hDC, int nMapMode);
    /** @dll.import("gdi32", auto) */
    public static native boolean ArcTo(int hDC, int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4);
    /** @dll.import("gdi32", auto) */
    public static native boolean MoveToEx(int hDC, int x, int y, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native int GetPixel(int hDC, int x, int y);
    /** @dll.import("gdi32", auto) */
    public static native boolean Chord(int m_hDC, int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4);
    /** @dll.import("gdi32", auto) */
    public static native boolean FillRgn(int hDC, int hRgn, int hBrush);
    /** @dll.import("gdi32", auto) */
    public static native boolean StrokeAndFillPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean StrokePath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean WidenPath(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean Rectangle(int hDC, int left, int top, int right, int bottom);
    /** @dll.import("gdi32", auto) */
    public static native int SaveDC(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetViewportOrgEx(int hDC, int x, int y, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetMiterLimit(int hDC, float fMiterLimit[]);
    /** @dll.import("gdi32", auto) */
    public static native int  ResetDC(int hDC, DEVMODE lpDevMode);
    /** @dll.import("gdi32", auto) */
    public static native int  SetMapperFlags(int hDC, int dwFlag);
    /** @dll.import("gdi32", auto) */
    public static native boolean PatBlt(int hDC, int x, int y, int nWidth, int nHeight, int dwRop);
    /** @dll.import("gdi32", auto) */
    public static native boolean Ellipse(int hDC, int x1, int y1, int x2, int y2);
    /** @dll.import("gdi32", auto) */
    public static native int SetArcDirection(int hDC, int nArcDirection);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetPixelV(int m_hDC, int x, int y, int crColor);
    /** @dll.import("gdi32", auto) */
    public static native int GetTextCharacterExtra(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int  SetTextColor(int hDC, int crColor);
    /** @dll.import("gdi32", auto) */
    public static native int SetBkMode(int hDC, int nBkMode);
    /** @dll.import("gdi32", auto) */
    public static native int SetDIBColorTable(int hdc, int uStartIndex, int cEntries, int  pEntries);
    /** @dll.import("gdi32", auto) */
    public static native int SetStretchBltMode(int hDC, int nStretchMode);
    
    /** @dll.import("gdi32", auto) */
    public static native boolean Arc(int hDC, int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4);
    /** @dll.import("gdi32", auto) */
    public static native boolean LineTo(int hDC, int x, int y);
    /** @dll.import("gdi32", auto) */
    public static native boolean PlayEnhMetaFile(int hDC, int hEnhMF, RECT lpBounds);
    
    
    private static native int  intCloseEnhMetaFile(int hdc);
    public static int  CloseEnhMetaFile(int hdc) {}

    
    private static native int  intCopyEnhMetaFile(int hemfSrc, String strFile);
    public static int  CopyEnhMetaFile(int hemfSrc, String strFile) {}

    
    private static native int  intCreateEnhMetaFile(int hdcRef, String strFilename, RECT lpRect, String lpDescription);
    public static int  CreateEnhMetaFile(int hdcRef, String strFilename, RECT lpRect, String lpDescription) {}

    
    private static native boolean intDeleteEnhMetaFile(int hEMF);
    public static boolean DeleteEnhMetaFile(int hEMF) {}

    
    private static native int   intGetEnhMetaFile(String strMetafile);
    public static int   GetEnhMetaFile(String strMetafile) {}
    
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFileBits(int hEMF, int cbBuffer, byte buffer[]);
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFileDescription(int hEMF, int cchBuffer, StringBuffer lpszDescription);
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFileHeader(int hEMF, int cbBuffer, ENHMETAHEADER lpemh);
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFilePaletteEntries(int hEMF, int cEntries, int  lppe);
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFilePaletteEntries(int hEMF, int cEntries, PALETTEENTRY lppe);
    /** @dll.import("gdi32", auto) */
    public static native int GetEnhMetaFilePixelFormat(int hEMF, int cbBuffer, PIXELFORMATDESCRIPTOR ppfd);
    /** @dll.import("gdi32", auto) */
    public static native int GetWinMetaFileBits(int hemf, int cbBuffer, byte lpbBuffer[], int fnMapMode, int hdcRef);
    
    
    private static native int   intSetEnhMetaFileBits(int cbBuffer, byte lpData[]);
    public static int   SetEnhMetaFileBits(int cbBuffer, byte lpData[]) {}
    
    
    private static native int   intSetWinMetaFileBits(int cbBuffer, byte lpData[], int hdcref, METAFILEPICT lpmfp);
    public static int   SetWinMetaFileBits(int cbBuffer, byte lpData[], int hdcref, METAFILEPICT lpmfp) {}
    
    
    private static native int   intSetEnhMetaFileBits(int cbBuffer, int lpData);
    public static int   SetEnhMetaFileBits(int cbBuffer, int lpData) {}
    
    
    private static native int   intSetWinMetaFileBits(int cbBuffer, int lpData, int hdcref, METAFILEPICT lpmfp);
    public static int   SetWinMetaFileBits(int cbBuffer, int lpData, int hdcref, METAFILEPICT lpmfp) {}
    
    
    private static native int   intSetMetaFileBitsEx(int cbBuffer, int lpData);
    public static int   SetMetaFileBitsEx(int cbBuffer, int lpData) {}
    
    /** @dll.import("gdi32", auto) */
    public static native boolean OffsetViewportOrgEx(int hDC, int nWidth, int nHeight, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetWindowOrgEx(int hDC, int x, int y, POINT point);
    /** @dll.import("gdi32", auto) */
    public static native int EnumFontFamiliesEx(int hdc, LOGFONT lf, int lpEnumFontFamExProc,
        int lParam, int dwFlags);
    /** @dll.import("gdi32", auto) */
    public static native int ExtSelectClipRgn(int hDC, int hRgn, int nMode);
    /** @dll.import("gdi32", auto) */
    public static native boolean StretchBlt(int hDC, int x, int y, int nWidth, int nHeight,
        int hSrcDC, int xSrc, int ySrc, int nSrcWidth, int nSrcHeight, int dwRop);
    /** @dll.import("gdi32", auto) */
    public static native boolean ScaleWindowExtEx(int hDC, int xNum, int xDenom, int yNum, int yDenom, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native boolean ExtFloodFill(int hDC, int x, int y, int crColor, int nFillType);
    /** @dll.import("gdi32", auto) */
    public static native int GetArcDirection(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean PtVisible(int hDC, int x, int y);
    /** @dll.import("user32", auto) */
    public static native boolean InvertRect(int hDC, RECT lpRect);
    /** @dll.import("gdi32", auto) */
    public static native int GetBoundsRect(int hDC, RECT lpRectBounds, int flags);
    /** @dll.import("gdi32", auto) */
    public static native int GetTextAlign(int hDC);
    /** @dll.import("gdi32", auto) */
    public static native int  SetPixel(int hDC, int x, int y, int crColor);
    /** @dll.import("gdi32", auto) */
    public static native boolean InvertRgn(int hDC, int hRgn);
    /** @dll.import("gdi32", auto) */
    public static native boolean RestoreDC(int hDC, int nSavedDC);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetAspectRatioFilterEx(int hDC, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetMiterLimit(int hDC, float fMiterLimit, float pOld[]);
    /** @dll.import("gdi32", auto) */
    public static native boolean BitBlt(int hDC, int x, int y, int nWidth, int nHeight,
        int hSrcDC, int xSrc, int ySrc, int dwRop);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetTextJustification(int hDC, int nBreakExtra, int nBreakCount);
    /** @dll.import("gdi32", auto) */
    public static native int SetTextCharacterExtra(int hDC, int nCharExtra);
    /** @dll.import("gdi32", auto) */
    public static native int SetPolyFillMode(int hDC, int nPolyFillMode);
    /** @dll.import("gdi32", auto) */
    public static native int GetTextFace(int hDC, int nCount, StringBuffer lpszFacename);
    /** @dll.import("gdi32", auto) */
    public static native int SetROP2(int hDC, int nDrawMode);
    /** @dll.import("gdi32", auto) */
    public static native int  GetKerningPairs(int hDC, int nPairs, int lpkrnpair);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetCharWidth32(int hDC, int nFirstChar, int nLastChar, int lpBuffer[]);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetCharWidthFloat(int hDC, int nFirstChar, int nLastChar, float lpBuffer[]);
    /** @dll.import("gdi32", auto) */
    public static native int GetPath(int hDC, int lpPoints, byte lpTypes[], int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean Polygon(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean Polyline(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolylineTo(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolyPolyline(int hDC, int lpPoints, int PolyPoints[], int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolyPolygon(int hDC, int lpPoints, int PolyPoints[], int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolyBezier(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolyBezierTo(int hDC, int lpPoints, int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean PolyDraw(int hDC, int lpPoints, byte lpbytes[], int nCount);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetColorAdjustment(int hDC, COLORADJUSTMENT lpca);

    
    private static native int  intCreateBitmap(int nWidth, int nHeight, int nPlanes, int nBitsPerPixel, int lpvBits[]);
    public static int  CreateBitmap(int nWidth, int nHeight, int nPlanes, int nBitsPerPixel, int lpvBits[]) {}
    
    
    private static native int  intCreateBitmap(int nWidth, int nHeight, int nPlanes, int nBitsPerPixel, short lpvBits[]);
    public static int  CreateBitmap(int nWidth, int nHeight, int nPlanes, int nBitsPerPixel, short lpvBits[]) {}

    
    private static native int  intCreatePatternBrush(int hbmp);
    public static int  CreatePatternBrush(int hbmp) {}
    
    /** @dll.import("user32", auto) */
    public static native int TabbedTextOut(int hDC, int x, int y, String str,
        int nStrLength, int nTabPositions, int lpnTabStopPositions[], int nTabOrigin);
    /** @dll.import("user32", auto) */
    public static native int GetTabbedTextExtent(int hDC, String str, int nCount, int nTabPosition, int lpnTabStopPositions[]);
    /** @dll.import("gdi32", auto) */
    public static native int GetGlyphOutline(int hDC, int uChar, int uFormat, GLYPHMETRICS lpgm, int cbBuffer, byte lpvBuffer[], MAT2 mat);
    /** @dll.import("gdi32", auto) */
    public static native int GetFontData(int hDC, int dwTable, int dwOffset, byte lpvBuffer[], int cbData);
    /** @dll.import("gdi32", auto) */
    public static native boolean GdiComment(int hDC, int cbSize, byte lpData[]);
    /** @dll.import("gdi32", auto) */
    public static native boolean PlgBlt(int hDC, int lpPoint, int hDCSrc, int nXSrc, int nYSrc, int nWidth,
        int nHeight, int hbmMask, int xMask, int yMask);
    /** @dll.import("gdi32", auto) */
    public static native boolean MaskBlt(int hdcDest, int nXDest, int nYDest, int nWidth, int nHeight, int hdcSrc,
        int nXSrc, int nYSrc, int hbmMask, int xMask, int yMask, int dwRop);
    /** @dll.import("gdi32", auto) */
    public static native int SelectPalette(int hdc, int hpal, boolean bForceBackground);
    /** @dll.import("gdi32", auto) */
    public static native int EnumObjects(int hdc, int nObjectType, Callback lpfn, int lParam);
    /** @dll.import("gdi32", auto) */
    public static native int GetBitmapBits(int hbmp, int cbBuffer, byte lpvBits[]);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetBitmapDimensionEx(int hBitmap, SIZE lpDimension);

    
    private static native int  intCreateCompatibleBitmap(int hdc, int nWidth, int nHeight);
    public static int  CreateCompatibleBitmap(int hdc, int nWidth, int nHeight) {}
    
    
    private static native int intCreateDIBitmap(int hDC, BITMAPINFOHEADER bmih, int fdwInit,
        byte[] bits, BITMAPINFO bmi, int fuUsage);
    public static int CreateDIBitmap(int hDC, BITMAPINFOHEADER bmih, int fdwInit,
        byte[] bits, BITMAPINFO bmi, int fuUsage) {}

    
    private static native int intCreateDIBitmap(int hDC, BITMAPINFOHEADER bmih, int fdwInit,
        byte[] bits, BITMAPINFO256 bmi, int fuUsage);
    public static int CreateDIBitmap(int hDC, BITMAPINFOHEADER bmih, int fdwInit,
        byte[] bits, BITMAPINFO256 bmi, int fuUsage) {}
    
    
    private static native int intCreateDIBitmap(int hDC, int pbmih, int fdwInit,
        int pbits, int pbmi, int fuUsage);
    public static int CreateDIBitmap(int hDC, int pbmih, int fdwInit,
        int pbits, int pbmi, int fuUsage) {}
    
    /** @dll.import("gdi32", auto,setLastError) */
    public static native int GetDIBits(int hDC, int hBitmap, int uStartScan, int cScanLines,
        byte[] bits, BITMAPINFO bi, int uUsage);
    /** @dll.import("gdi32", auto,setLastError) */
    public static native int GetDIBits(int hDC, int hBitmap, int uStartScan, int cScanLines,
        byte[] bits, BITMAPINFO256 bi, int uUsage);
    /** @dll.import("gdi32", auto,setLastError) */
    public static native int GetDIBits(int hDC, int hBitmap, int uStartScan, int cScanLines,
        int pbits, int pbmi, int uUsage);
    /** @dll.import("gdi32", auto) */
    public static native int SetBitmapBits(int hbmp, int nBytes, byte lpBits[]);
    /** @dll.import("gdi32", auto) */
    public static native int GetTextExtentPoint32(int hDC, String str, int len, SIZE size);
    /** @dll.import("gdi32", auto) */
    public static native boolean GetTextMetrics(int hDC, TEXTMETRIC tm);
    /** @dll.import("gdi32", auto) */
    public static native boolean SetBitmapDimensionEx(int hBitmap, int nWidth, int nHeight, SIZE lpSize);
    
    
    private static native int  intCreateMappedBitmap(int hInstance, int idBitmap, int wFlags, int lpColorMap, int iNumMaps);
    public static int  CreateMappedBitmap(int hInstance, int idBitmap, int wFlags, int lpColorMap, int iNumMaps) {}

    
    private static native int  intCreateMappedBitmap(int hInstance, int idBitmap, int wFlags, COLORMAP lpColorMap, int iNumMaps);
    public static int  CreateMappedBitmap(int hInstance, int idBitmap, int wFlags, COLORMAP lpColorMap, int iNumMaps) {}
    
    /** @dll.import("gdi32", auto) */
    public static native int SetPaletteEntries(int hpal, int iStart, int cEntries, int lppe);
    /** @dll.import("gdi32", auto) */
    public static native boolean TranslateCharsetInfo(int lpSrc[], CHARSETINFO lpCs, int dwFlags);

    
    private static native int  intCreateHalftonePalette(int hdc);
    public static int  CreateHalftonePalette(int hdc) {}
    
    /** @dll.import("gdi32", auto) */
    public static native boolean ResizePalette(int hpal, int nEntries);
    /** @dll.import("gdi32", auto) */
    public static native int GetPaletteEntries(int hpal, int iStartIndex, int nEntries, int lppe[]);
    /** @dll.import("gdi32", auto) */
    public static native int GetPaletteEntries(int hpal, int iStartIndex, int nEntries, int lppe);

    
    private static native int  intCreatePalette(LOGPALETTE lplgpl);
    public static int  CreatePalette(LOGPALETTE lplgpl) {}

    
    private static native int  intCreatePalette(int ptrlgpl);
    public static int  CreatePalette(int ptrlgpl) {}
    
    /** @dll.import("gdi32", auto) */
    public static native int GetNearestPaletteIndex(int hpal, int crColor);

    /** @dll.import("kernel32", auto) */
    public static native boolean GetVersionEx(OSVERSIONINFO ver);

    /** @dll.import("kernel32", auto) */
    public static native int LoadLibrary(String libname);
    /** @dll.import("kernel32", auto) */
    public static native int LoadLibraryEx(String libname,int hfile, int flags);
    /** @dll.import("kernel32", auto) */
    public static native int  LoadResource(int hModule, int hResInfo);
    /** @dll.import("kernel32", auto) */
    public static native int  FindResource(int hModule, int lpName, int lpType);
    /** @dll.import("kernel32", auto) */
    public static native int  SizeofResource(int hModule, int hResInfo);
    /** @dll.import("kernel32", auto) */
    public static native boolean SetCurrentDirectory(String directory);


    
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, BITMAP bm);
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, DIBSECTION ds);
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, LOGPEN lp);
    public static int GetObject(int hObject, LOGPEN lp) {}
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, LOGBRUSH lb);
    public static int GetObject(int hObject, LOGBRUSH lb) {}
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, LOGFONT lf);
    public static int GetObject(int hObject, LOGFONT lp) {}
    public static int RGB(int r, int g, int b) {}
    
    /** @dll.import("gdi32", auto) */
    public static native int GetObject(int hObject, int nSize, int nEntries[]);

    /** @dll.import("comdlg32.dll", auto) */
    public static native boolean GetOpenFileName(OPENFILENAME_I ofn);
    /** @dll.import("comdlg32.dll", auto) */
    public static native boolean GetSaveFileName(OPENFILENAME_I ofn);
    /** @dll.import("comdlg32.dll", auto) */
    public static native boolean ChooseFont(CHOOSEFONT cf);
    /** @dll.import("comdlg32.dll", auto) */
    public static native boolean ChooseColor(CHOOSECOLOR cc);

    /** @dll.import("oleaut32.dll", ole) */
    public static native com.ms.com.IUnknown OleLoadPicture(com.ms.com.IStream pStream, int lSize, boolean fRunmode, com.ms.com._Guid refiid);
    /** @dll.import("oleaut32.dll", ole) */
    public static native com.ms.com.IUnknown OleLoadPictureEx(com.ms.com.IStream pStream, int lSize, boolean fRunmode, com.ms.com._Guid refiid, int width, int height, int dwFlags);
    /** @dll.import("oleaut32.dll", ole) */
    public static native com.ms.com.IUnknown OleCreatePictureIndirect(PICTDESC pictdesc, com.ms.com._Guid refiid, boolean fOwn);
}